(***********************************************************************



                    Mathematica-Compatible Notebook



This notebook can be used on any computer system with Mathematica 3.0,

MathReader 3.0, or any compatible application. The data for the notebook 

starts with the line of stars above.



To get the notebook into a Mathematica-compatible application, do one of 

the following:



* Save the data starting with the line of stars above into a file

  with a name ending in .nb, then open the file inside the application;



* Copy the data starting with the line of stars above to the

  clipboard, then use the Paste menu command inside the application.



Data for notebooks contains only printable 7-bit ASCII and can be

sent directly in email or through ftp in text mode.  Newlines can be

CR, LF or CRLF (Unix, Macintosh or MS-DOS style).



NOTE: If you modify the data for this notebook not in a Mathematica-

compatible application, you must delete the line below containing the 

word CacheID, otherwise Mathematica-compatible applications may try to 

use invalid cache data.



For more information on notebooks and Mathematica-compatible 

applications, contact Wolfram Research:

  web: http://www.wolfram.com

  email: info@wolfram.com

  phone: +1-217-398-0700 (U.S.)



Notebook reader applications are available free of charge from 

Wolfram Research.

***********************************************************************)



(*CacheID: 232*)





(*NotebookFileLineBreakTest

NotebookFileLineBreakTest*)

(*NotebookOptionsPosition[    440908,      15677]*)

(*NotebookOutlinePosition[    442509,      15727]*)

(*  CellTagsIndexPosition[    442465,      15723]*)

(*WindowFrame->Normal*)







Notebook[{

Cell[TextData[{

  " ",

  StyleBox["Example # 3 : Generic Hybrid Undulator",

    FontSize->24]

}], "Title",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell["Version 0.5", "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[CellGroupData[{



Cell["Introduction", "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[{

  StyleBox[

  "This example creates and solves a simple U46 Hybrid Undulator made with  \

rectangular blocks. It is important to execute each section in the order of  \

presentation. If not, errors may be reported. Any section can be edited and  \

executed several times. To see the change in the peak field induced by the  \

variation of the magnet size, edit the corresponding parameter in the section \

 entitled \"Create the Geometry\", execute this section and re-execute the  \

section \"Solve\". The section \"Optimizing Parameters\" provides an example  \

of manual optimization of the pole dimensions.",

    Evaluatable->False,

    AspectRatioFixed->True],

  "\n",

  StyleBox[

  "To obtain acceptable precision on the magnetic field, it is essential to  \

increase the segmentation. This is done at the expense of memory and CPU  \

time. The segmentation in this example has been set to",

    Evaluatable->False,

    AspectRatioFixed->True],

  " np={2,2,5} for the pole and nm={1,3,1} for the magnet. ",

  StyleBox[

  "This corresponds to an absolute error in the peak field of the undulator  \

of the order of 1%. The user himself should experience consequences of  \

increasing np and nm and see how CPU time and memory increase, and how the  \

value of the peak field approaches a limit which is the value looked for. To  \

do so, edit the nm or np values in the \"Create the Geometry\" section, and  \

re-execute both the \"Create the Geometry\" and \"Solve\" sections. Using  \

segmentation which is too large segmentation may result in a memory  \

allocation failure. To recover from such situation, the section \"Load and  \

Initialize Radia\" should be re-executed. Memory allocation failure can be  \

avoided (to some extent) by giving more memory to the Radia.exe process  \

(Macintosh). \nIt is a fact that iron pieces need much more segmentation than \

 the magnets since the magnetization there is very sensitive to the external  \

field.",

    Evaluatable->False,

    AspectRatioFixed->True],

  "\n",

  StyleBox[

  "One can also compute the field Integral produced by such an undulator,  \

forces on the magnets and poles, etc. One can build a wedge pole undulator by \

 using polyhedrons or extruded polygons instead of rectangular blocks... To  \

learn more, read the Radia documentation, make tests and develop experience.",

    

    Evaluatable->False,

    AspectRatioFixed->True]

}], "Text",

  Evaluatable->False,

  AspectRatioFixed->True]

}, Open  ]],



Cell[CellGroupData[{



Cell["Load and Initialize Radia", "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell["\<\

The following instruction loads the Radia package and returns the Radia \

version number.\

\>", "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell["<<Radia`;", "Input",

  AspectRatioFixed->True]

}, Open  ]],



Cell[CellGroupData[{



Cell[TextData["Functions"], "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[StyleBox[

"The following function builds an array of rectangular permanent magnets with \

their mirror symmetric counterparts, distributes the colors, magnetic \

materials and sets the segmentation. The function is very generic and can be \

used to build almost any hybrid undulator (without optimizing the design of \

terminations).",

  Evaluatable->False,

  AspectRatioFixed->True]], "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[{

  "und[]:=Module[{},\nzer={0,0,0};\nGrp=",

  StyleBox["radObjCnt",

    FontColor->RGBColor[1, 0, 0]],

  "[{}];\n\n(* Principal Poles and Magnets *)\ny=lp[[2]]/4;\nPole=",

  StyleBox["RadObjFullMag",

    FontColor->RGBColor[1, 0, 0]],

  "[{lp[[1]]/4,y,-lp[[3]]/2-gap/2},{lp[[1]]/2,lp[[2]]/2,lp[[3]]},zer,np,Grp,  \

mp,cp];\ny+=lp[[2]]/4;\n\nFor[i=1, i<=Nper,i++,(\n\

initm={0,Mod[i+1,2]-Mod[i,2],0};\ny+=lm[[2]]/2;\nMagnet=",

  StyleBox["RadObjFullMag",

    FontColor->RGBColor[1, 0, 0]],

  "[{lm[[1]]/4,y,-lm[[3]]/2-gap/2-gapoffset},{lm[[1]]/2,lm[[2]],lm[[3]]},\

initm,nm,Grp,mm,cm];\ny+=(lm[[2]]+lp[[2]])/2;\nPole=",

  StyleBox["RadObjFullMag",

    FontColor->RGBColor[1, 0, 0]],

  "[{lp[[1]]/4,y,-lp[[3]]/2-gap/2},{lp[[1]]/2,lp[[2]],lp[[3]]},zer,np,Grp,mp,\

cp];\ny+=lp[[2]]/2;\n)];\n\ninitm={0,Mod[Nper,2]-Mod[Nper+1,2],0};\n\

y+=lm[[2]]/4;\nMagnet=",

  StyleBox["RadObjFullMag",

    FontColor->RGBColor[1, 0, 0]],

  "[{lm[[1]]/4,y,-lm[[3]]/2-gap/2-gapoffset},{lm[[1]]/2,lm[[2]]/2,lm[[3]]},\

initm,nm,Grp,mm,cm];\n\n(* Mirrors *)\n",

  StyleBox["RadTrfZerPerp",

    FontColor->RGBColor[1, 0, 0]],

  "[Grp,{0,0,0},{1,0,0}];\n",

  StyleBox["RadTrfZerPara",

    FontColor->RGBColor[1, 0, 0]],

  "[Grp,zer,{0,0,1}];\n",

  StyleBox["RadTrfZerPerp",

    FontColor->RGBColor[1, 0, 0]],

  "[Grp,zer,{0,1,0}];\nGrp\n]"

}], "Input",

  AspectRatioFixed->True]

}, Open  ]],



Cell[CellGroupData[{



Cell[TextData["Create the Geometry"], "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[StyleBox[

"The following instructions build an undulator with NdFeB magnets and poles \

made of Vanadium Permendur.",

  Evaluatable->False,

  AspectRatioFixed->True]], "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[{

  StyleBox["radUtiDelAll",

    FontColor->RGBColor[1, 0, 0]],

  "[];\n\n(* General Parameters *)\ngap=20;Nper=2;per=46;gapoffset=1;\n\n(* \

Pole Parameters *)\nlp={45,5,25};np={2,2,5};cp={1,0,1};\nll=per/2-lp[[2]];\n\

mp=",

  StyleBox["RadMatXc06",

    FontColor->RGBColor[1, 0, 0]],

  "[];\n\n(* Magnet Parameters *)\nlm={65,ll,45};nm={1,3,1};cm={0,1,1};\nmm=",

  

  StyleBox["RadMatNdFeB",

    FontColor->RGBColor[1, 0, 0]],

  "[];\n\n(* Build the Structure *)\nGrp=und[];"

}], "Input",

  AspectRatioFixed->True]

}, Open  ]],



Cell[CellGroupData[{



Cell["Display the Geometry with QuickDraw 3D", "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[{

  StyleBox[

  "If you have QuickDraw 3D installed on your platform (freely available for  \

PC and Macs from  Apple at \"",

    Evaluatable->False,

    AspectRatioFixed->True],

  StyleBox["http://www.apple.com/quicktime/qd3d/\" ",

    FontFamily->"Monaco",

    FontSize->9],

  StyleBox[

  ") , execute the following line to display the geometry in a dedicated  \

window where you will be able to zoom, rotate etc... When you have finished, \

Quit from the Menu File of Radia.exe (for Macs) or Exit from the Menu File of \

the Viewer window (for PC) to release the  memory required by QuickDraw3D and \

continue working in ",

    Evaluatable->False,

    AspectRatioFixed->True],

  StyleBox["Mathematica",

    Evaluatable->False,

    AspectRatioFixed->True,

    FontSlant->"Italic"],

  StyleBox[". ",

    Evaluatable->False,

    AspectRatioFixed->True]

}], "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell["radObjDrwQD3D[Grp];", "Input",

  AspectRatioFixed->True]

}, Open  ]],



Cell[CellGroupData[{



Cell["Plot the Geometry", "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell["\<\

The following instructions create a set of 3D graphical primitives \

representing the structure in space, and plot it.\

\>", "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[{

  "draw=",

  StyleBox["radObjDrw",

    FontColor->RGBColor[1, 0, 0]],

  "[Grp];"

}], "Input",

  AspectRatioFixed->True],



Cell[CellGroupData[{



Cell[TextData[{

  StyleBox["RadPlot3DOptions",

    FontColor->RGBColor[1, 0, 0]],

  "[];\nShow[Graphics3D[draw]\n,ViewPoint->{5,-1.5,2}\n,PlotRange->All\n\

,AmbientLight->GrayLevel[0.1]];"

}], "Input",

  AspectRatioFixed->True],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: 1 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics3D

/Times findfont 12  scalefont  setfont

% Scaling calculations

0 1 0 1 [

[.15246 .2124 -25 -8.44428 ]

[.15246 .2124 0 6.55572 ]

[.17474 .16775 -10 -8.47073 ]

[.17474 .16775 0 6.52927 ]

[.19822 .12069 -16 -8.4987 ]

[.19822 .12069 0 6.5013 ]

[.11275 .15973 -16 -8.47073 ]

[.11275 .15973 0 6.52927 ]

[.28548 .08285 -12.208 -15 ]

[.28548 .08285 12.792 0 ]

[.42116 .10132 -12.3929 -15 ]

[.42116 .10132 12.6071 0 ]

[.55412 .11941 -5.02935 -15 ]

[.55412 .11941 4.97065 0 ]

[.68442 .13715 -8.15972 -15 ]

[.68442 .13715 7.84028 0 ]

[.81215 .15454 -8.26983 -15 ]

[.81215 .15454 7.73017 0 ]

[.55375 .05691 -8.04696 -15 ]

[.55375 .05691 7.95304 0 ]

[.879 .21882 0 -6.5057 ]

[.879 .21882 25 8.4943 ]

[.88391 .34315 0 -6.57848 ]

[.88391 .34315 25 8.42152 ]

[.88895 .47085 0 -6.65328 ]

[.88895 .47085 10 8.34672 ]

[.89413 .60206 0 -6.73021 ]

[.89413 .60206 16 8.26979 ]

[.89946 .73691 0 -6.80933 ]

[.89946 .73691 16 8.19067 ]

[.95106 .47787 0 -6.65328 ]

[.95106 .47787 15 8.34672 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.003 w

.1498 .24411 m

.22797 .08757 L

s

.25 Mabswid

.16486 .21396 m

.17106 .21474 L

s

gsave

.15246 .2124 -86 -12.4443 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(20) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.18713 .16935 m

.19333 .17016 L

s

gsave

.17474 .16775 -71 -12.4707 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.21061 .12234 m

.21681 .12316 L

s

gsave

.19822 .12069 -77 -12.4987 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(20) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

.17032 .20302 m

.17404 .2035 L

s

.17585 .19195 m

.17957 .19242 L

s

.18145 .18072 m

.18517 .1812 L

s

.19289 .15783 m

.1966 .15832 L

s

.19871 .14616 m

.20243 .14665 L

s

.20462 .13433 m

.20834 .13482 L

s

.15947 .22476 m

.16319 .22522 L

s

.15414 .23542 m

.15787 .23588 L

s

.21668 .11018 m

.2204 .11068 L

s

.22283 .09786 m

.22655 .09836 L

s

gsave

.11275 .15973 -77 -12.4707 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

74.625000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.003 w

.22797 .08757 m

.86491 .17415 L

s

.25 Mabswid

.28518 .09535 m

.28504 .1016 L

s

gsave

.28548 .08285 -73.208 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(50) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.42106 .11382 m

.421 .12007 L

s

gsave

.42116 .10132 -73.3929 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(25) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.55419 .13191 m

.55423 .13816 L

s

gsave

.55412 .11941 -66.0293 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.68467 .14965 m

.6848 .1559 L

s

gsave

.68442 .13715 -69.1597 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(25) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.81257 .16703 m

.81278 .17328 L

s

gsave

.81215 .15454 -69.2698 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(50) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

.31258 .09907 m

.3125 .10282 L

s

.33987 .10278 m

.3398 .10653 L

s

.36704 .10647 m

.36699 .11022 L

s

.3941 .11015 m

.39406 .1139 L

s

.4479 .11746 m

.44788 .12121 L

s

.47464 .1211 m

.47463 .12485 L

s

.50126 .12472 m

.50126 .12847 L

s

.52778 .12832 m

.52779 .13207 L

s

.5805 .13549 m

.58053 .13924 L

s

.6067 .13905 m

.60674 .1428 L

s

.63279 .1426 m

.63285 .14635 L

s

.65878 .14613 m

.65885 .14988 L

s

.71046 .15315 m

.71054 .1569 L

s

.73614 .15664 m

.73623 .16039 L

s

.76172 .16012 m

.76182 .16387 L

s

.78719 .16358 m

.78731 .16733 L

s

.25767 .09161 m

.25757 .09536 L

s

.23005 .08785 m

.22994 .0916 L

s

.83785 .17047 m

.83799 .17422 L

s

.86303 .17389 m

.86317 .17764 L

s

gsave

.55375 .05691 -69.047 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(Y) show

74.625000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.003 w

.86491 .17415 m

.88891 .78418 L

s

.25 Mabswid

.8666 .21718 m

.86041 .21636 L

s

gsave

.879 .21882 -61 -10.5057 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(50) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.8715 .34163 m

.8653 .34087 L

s

gsave

.88391 .34315 -61 -10.5785 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(25) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.87653 .46945 m

.87032 .46875 L

s

gsave

.88895 .47085 -61 -10.6533 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.8817 .60078 m

.87548 .60014 L

s

gsave

.89413 .60206 -61 -10.7302 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(25) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.88701 .73577 m

.88078 .73519 L

s

gsave

.89946 .73691 -61 -10.8093 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(50) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

.86757 .24181 m

.86385 .24132 L

s

.86855 .26656 m

.86483 .26608 L

s

.86953 .29145 m

.86581 .29098 L

s

.87051 .31647 m

.86679 .31601 L

s

.8725 .36692 m

.86877 .36647 L

s

.8735 .39235 m

.86977 .3919 L

s

.8745 .41791 m

.87078 .41747 L

s

.87551 .44361 m

.87179 .44318 L

s

.87755 .49543 m

.87383 .49502 L

s

.87858 .52156 m

.87485 .52115 L

s

.87961 .54782 m

.87588 .54742 L

s

.88065 .57423 m

.87692 .57384 L

s

.88275 .62748 m

.87902 .62711 L

s

.8838 .65433 m

.88007 .65396 L

s

.88487 .68133 m

.88113 .68097 L

s

.88593 .70847 m

.8822 .70812 L

s

.86564 .19268 m

.86192 .19218 L

s

.88809 .76322 m

.88435 .76288 L

s

gsave

.95106 .47787 -61 -10.6533 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(Z) show

73.187500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.001 w

[ .01 .01 ] 0 setdash

.1498 .24411 m

.12776 .8324 L

s

.12776 .8324 m

.75209 .88219 L

s

.75209 .88219 m

.73781 .31674 L

s

.73781 .31674 m

.1498 .24411 L

s

.22797 .08757 m

.86491 .17415 L

s

.86491 .17415 m

.88891 .78418 L

s

.88891 .78418 m

.20912 .72415 L

s

.20912 .72415 m

.22797 .08757 L

s

.1498 .24411 m

.12776 .8324 L

s

.12776 .8324 m

.20912 .72415 L

s

.20912 .72415 m

.22797 .08757 L

s

.22797 .08757 m

.1498 .24411 L

s

.73781 .31674 m

.86491 .17415 L

s

.86491 .17415 m

.88891 .78418 L

s

.88891 .78418 m

.75209 .88219 L

s

.75209 .88219 m

.73781 .31674 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

[ ] 0 setdash

.73253 .53445 m .72747 .32471 L .6852 .31952 L p 0 .669 .759 r

F P

0 g

s

.78512 .25988 m .72747 .32471 L .73253 .53445 L p 0 .34 .703 r

F P

0 g

s

.72747 .32471 m .78512 .25988 L .74132 .25425 L p 0 .844 1 r

F P

0 g

s

.74132 .25425 m .6852 .31952 L .72747 .32471 L p 0 .844 1 r

F P

0 g

s

.6852 .31952 m .68934 .52985 L .73253 .53445 L p 0 .669 .759 r

F P

0 g

s

.7439 .35458 m .7041 .39799 L .70656 .51252 L p .413 0 .697 r

F P

0 g

s

.73253 .53445 m .68934 .52985 L p .70656 .51252 L 0 .863 1 r

F P

0 g

s

.73253 .53445 m .79174 .4769 L .78512 .25988 L p 0 .34 .703 r

F P

0 g

s

.74693 .4719 m .7439 .35458 L p .70813 .51094 L .413 0 .697 r

F P

0 g

s

.7439 .35458 m .70656 .51252 L .70813 .51094 L .413 0 .697 r

F

.70656 .51252 m .7041 .39799 L .7041 .39799 L p .844 0 .758 r

F P

0 g

s

.70199 .29999 m .74132 .25425 L p .71682 .38411 L 0 .328 .697 r

F P

0 g

s

.71682 .38411 m .70513 .44611 L .7041 .39799 L 0 .328 .697 r

F

.71682 .38411 m .7041 .39799 L .70199 .29999 L F

.68934 .52985 m .6852 .31952 L .70199 .29999 L p F P

0 g

s

.70513 .44611 m .68934 .52985 L .69612 .40669 L 0 .328 .697 r

F

.7041 .39799 m .69612 .40669 L .70199 .29999 L F

.70513 .44611 m .69612 .40669 L .7041 .39799 L F

.71685 .25111 m .6616 .31662 L .66327 .41377 L p 0 .32 .693 r

F P

0 g

s

.67999 .39517 m .7041 .39799 L p .71918 .3516 L .755 0 1 r

F P

0 g

s

.68934 .52985 m .70656 .51252 L p .70656 .51252 L 0 .863 1 r

F P

0 g

s

.68934 .52985 m .68934 .52985 L p .70656 .51252 L 0 .863 1 r

F P

0 g

s

.7041 .39799 m .7439 .35458 L .7439 .35458 L p .755 0 1 r

F P

0 g

s

.7041 .39799 m .7041 .39799 L .7439 .35458 L .755 0 1 r

F

.74132 .25425 m .74693 .4719 L .74693 .4719 L p 0 .328 .697 r

F P

0 g

s

.70656 .51252 m .70656 .51252 L .7041 .39799 L .844 0 .758 r

F

.74693 .4719 m .70656 .51252 L p .71682 .38411 L 0 .328 .697 r

F P

0 g

s

.70656 .51252 m .68934 .52985 L p .70513 .44611 L 0 .328 .697 r

F P

0 g

s

.71682 .38411 m .70656 .51252 L .70513 .44611 L 0 .328 .697 r

F

.66521 .52728 m .68216 .50989 L p .6809 .44337 L 0 .32 .693 r

F P

0 g

s

.67999 .39517 m .68216 .50989 L p .68216 .50989 L .844 0 .758 r

F P

0 g

s

.67999 .39517 m .68216 .50989 L .70558 .51242 L .844 0 .758 r

F

.67999 .39517 m .68216 .50989 L .67999 .39517 L F

.74132 .25425 m .7439 .35458 L .71682 .38411 L 0 .328 .697 r

F

.7439 .35458 m .74693 .4719 L .71682 .38411 L F

.7041 .39799 m .67999 .39517 L p .70666 .51736 L .844 0 .758 r

F P

0 g

s

.7439 .35458 m .71918 .3516 L p .7041 .39799 L .755 0 1 r

F P

0 g

s

.7219 .46911 m .71918 .3516 L p .6809 .44337 L 0 .32 .693 r

F P

0 g

s

.71918 .3516 m .71685 .25111 L p .69252 .38124 L 0 .32 .693 r

F P

0 g

s

.69252 .38124 m .6809 .44337 L .71918 .3516 L 0 .32 .693 r

F

.68216 .50989 m .7219 .46911 L p .6809 .44337 L F P

0 g

s

.66327 .41377 m .66521 .52728 L p .6809 .44337 L 0 .32 .693 r

F P

0 g

s

.66521 .52728 m .6616 .31662 L .57591 .3061 L p 0 .669 .759 r

F P

0 g

s

.57591 .3061 m .57762 .51794 L .66521 .52728 L p 0 .669 .759 r

F P

0 g

s

.69252 .38124 m .67999 .39517 L .6809 .44337 L 0 .32 .693 r

F

.71918 .3516 m .67999 .39517 L .71918 .3516 L .755 0 1 r

F

.67999 .39517 m .71918 .3516 L p .68371 .5083 L .405 0 .693 r

F P

0 g

s

.71685 .25111 m .66327 .41377 L .69252 .38124 L 0 .32 .693 r

F

.71918 .3516 m .67999 .39517 L .67999 .39517 L p .755 0 1 r

F P

0 g

s

.6616 .31662 m .71685 .25111 L .62799 .2397 L p 0 .844 1 r

F P

0 g

s

.62799 .2397 m .57591 .3061 L .6616 .31662 L p 0 .844 1 r

F P

0 g

s

.7219 .46911 m .68216 .50989 L p .68216 .50989 L 0 .863 1 r

F P

0 g

s

.7219 .46911 m .7219 .46911 L p .68216 .50989 L 0 .863 1 r

F P

0 g

s

.68216 .50989 m .68225 .51473 L p .70558 .51242 L .844 0 .758 r

F P

0 g

s

.71918 .3516 m .72202 .47407 L .72202 .47407 L p .405 0 .693 r

F P

0 g

s

.74132 .25425 m .74693 .4719 L .74132 .25425 L 0 .328 .697 r

F

.74132 .25425 m .78512 .25988 L .79174 .4769 L p 0 .669 .756 r

F P

0 g

s

.79174 .4769 m .78512 .25988 L .74132 .25425 L p 0 .669 .756 r

F P

0 g

s

.7439 .35458 m .74693 .4719 L p .74693 .4719 L .845 0 .756 r

F P

0 g

s

.7439 .35458 m .7439 .35458 L p .74693 .4719 L .845 0 .756 r

F P

0 g

s

.79174 .4769 m .74693 .4719 L .74132 .25425 L p 0 .669 .756 r

F P

0 g

s

.74132 .25425 m .74693 .4719 L .79174 .4769 L p 0 .669 .756 r

F P

0 g

s

.78512 .25988 m .79174 .4769 L .85611 .41432 L p 0 .34 .703 r

F P

0 g

s

.78607 .3086 m .7439 .35458 L p .78796 .43062 L .413 0 .697 r

F P

0 g

s

.80958 .40887 m .85611 .41432 L p .8216 .43252 L 0 .863 1 r

F P

0 g

s

.74693 .4719 m .78972 .42885 L .8216 .43252 L 0 .863 1 r

F

.78972 .42885 m .80958 .40887 L .8216 .43252 L F

.78972 .42885 m .78607 .3086 L p .78796 .43062 L .413 0 .697 r

F P

0 g

s

.74693 .4719 m .78936 .47664 L .73253 .53445 L p 0 .863 1 r

F P

0 g

s

.70656 .51252 m .74693 .4719 L p .74693 .4719 L 0 .863 1 r

F P

0 g

s

.74693 .4719 m .73683 .51579 L .70656 .51252 L 0 .863 1 r

F

.74693 .4719 m .70656 .51252 L .70656 .51252 L F

.73683 .51579 m .73253 .53445 L .70656 .51252 L F

.70666 .51736 m .74706 .47685 L .74693 .4719 L p .413 0 .697 r

F P

0 g

s

.70813 .51094 m .70666 .51736 L .74693 .4719 L .413 0 .697 r

F

.74706 .47685 m .72202 .47407 L .7219 .46911 L p .845 0 .756 r

F P

0 g

s

.71918 .3516 m .7219 .46911 L p .7219 .46911 L 0 .669 .756 r

F P

0 g

s

.7219 .46911 m .71918 .3516 L p .74593 .47179 L .845 0 .756 r

F P

0 g

s

.74593 .47179 m .74706 .47685 L .7219 .46911 L .845 0 .756 r

F

.85611 .41432 m .79174 .4769 L .74693 .4719 L p 0 .863 1 r

F P

0 g

s

.74706 .47685 m .78988 .43393 L p .78796 .43062 L .413 0 .697 r

F P

0 g

s

.7439 .35458 m .74693 .4719 L p .78796 .43062 L .413 0 .697 r

F P

0 g

s

.74693 .4719 m .74706 .47685 L p .78796 .43062 L .413 0 .697 r

F P

0 g

s

.74693 .4719 m .7439 .35458 L p .78859 .39152 L 0 .328 .697 r

F P

0 g

s

.80958 .40887 m .78972 .42885 L p .78859 .39152 L 0 .328 .697 r

F P

0 g

s

.78972 .42885 m .74693 .4719 L p .78859 .39152 L 0 .328 .697 r

F P

0 g

s

.78607 .3086 m .78972 .42885 L p .78972 .42885 L .846 0 .754 r

F P

0 g

s

.7439 .35458 m .74132 .25425 L p .77205 .32388 L 0 .328 .697 r

F P

0 g

s

.78607 .3086 m .78607 .3086 L p .78972 .42885 L .846 0 .754 r

F P

0 g

s

.77205 .32388 m .7876 .3591 L .7439 .35458 L 0 .328 .697 r

F

.7876 .3591 m .80958 .40887 L .78859 .39152 L F

.7876 .3591 m .78859 .39152 L .7439 .35458 L F

.85611 .41432 m .8477 .18952 L .78512 .25988 L p 0 .34 .703 r

F P

0 g

s

.74132 .25425 m .78512 .25988 L .8477 .18952 L p 0 .844 1 r

F P

0 g

s

.8477 .18952 m .80224 .1834 L .74132 .25425 L p 0 .844 1 r

F P

0 g

s

.74132 .25425 m .80224 .1834 L .80562 .28728 L p 0 .328 .697 r

F P

0 g

s

.80562 .28728 m .80958 .40887 L p .77205 .32388 L 0 .328 .697 r

F P

0 g

s

.74132 .25425 m .80562 .28728 L .77205 .32388 L 0 .328 .697 r

F

.74401 .35446 m .74401 .35446 L .78607 .3086 L .755 0 1 r

F

.78607 .3086 m .74402 .35445 L .78607 .3086 L F

.71918 .3516 m .74401 .35446 L .78607 .3086 L F

.77684 .17999 m .71685 .25111 L p .7469 .32078 L 0 .32 .693 r

F P

0 g

s

.71685 .25111 m .71918 .3516 L p .7469 .32078 L 0 .32 .693 r

F P

0 g

s

.76069 .30544 m .71918 .3516 L p .71918 .3516 L .755 0 1 r

F P

0 g

s

.78607 .3086 m .76069 .30544 L p .71918 .3516 L .755 0 1 r

F P

0 g

s

.76069 .30544 m .76069 .30544 L p .71918 .3516 L .755 0 1 r

F P

0 g

s

.74401 .35446 m .78607 .3086 L p .78607 .3086 L .755 0 1 r

F P

0 g

s

.76069 .30544 m .78972 .42885 L .7887 .42873 L .846 0 .754 r

F

.71918 .3516 m .7439 .35458 L .74401 .35446 L p .755 0 1 r

F P

0 g

s

.71918 .3516 m .7439 .35458 L p .74693 .4719 L .845 0 .756 r

F P

0 g

s

.71918 .3516 m .74693 .4719 L .74593 .47179 L .845 0 .756 r

F

.74693 .4719 m .74706 .47685 L p .74593 .47179 L F P

0 g

s

.74706 .47685 m .7439 .35458 L .71918 .3516 L p .845 0 .756 r

F P

0 g

s

.71918 .3516 m .72202 .47407 L .74706 .47685 L p .845 0 .756 r

F P

0 g

s

.7469 .32078 m .7621 .35602 L .76069 .30544 L 0 .32 .693 r

F

.7219 .46911 m .76403 .42589 L p .7469 .32078 L F P

0 g

s

.76403 .42589 m .7219 .46911 L .7219 .46911 L p 0 .863 1 r

F P

0 g

s

.76403 .42589 m .76069 .30544 L p .76069 .30544 L .846 0 .754 r

F P

0 g

s

.78988 .43393 m .78972 .42885 L p .78796 .43062 L .413 0 .697 r

F P

0 g

s

.80958 .40887 m .80958 .40887 L p .78972 .42885 L 0 .863 1 r

F P

0 g

s

.74693 .4719 m .78972 .42885 L p .78972 .42885 L 0 .863 1 r

F P

0 g

s

.78972 .42885 m .80958 .40887 L p .78972 .42885 L 0 .863 1 r

F P

0 g

s

.74693 .4719 m .78972 .42885 L .74693 .4719 L 0 .863 1 r

F

.78988 .43393 m .76417 .43097 L p .76403 .42589 L .846 0 .754 r

F P

0 g

s

.76069 .30544 m .7887 .42873 L .76403 .42589 L .846 0 .754 r

F

.71918 .3516 m .7219 .46911 L p .7469 .32078 L 0 .32 .693 r

F P

0 g

s

.71918 .3516 m .7219 .46911 L .68371 .5083 L .405 0 .693 r

F

.71918 .3516 m .72202 .47407 L .71918 .3516 L F

.67144 .34584 m .71918 .3516 L .7219 .46911 L 0 .669 .756 r

F

.71918 .3516 m .71918 .3516 L .7219 .46911 L F

.68216 .50989 m .67999 .39517 L p .68371 .5083 L .405 0 .693 r

F P

0 g

s

.67999 .39517 m .66327 .41377 L .6809 .44337 L 0 .32 .693 r

F

.62799 .2397 m .71918 .3516 L .67144 .34584 L 0 .669 .756 r

F

.62799 .2397 m .71685 .25111 L .71918 .3516 L p F P

0 g

s

.71685 .25111 m .62799 .2397 L p .67144 .34584 L 0 .669 .756 r

F P

0 g

s

.57762 .51794 m .57591 .3061 L .59149 .28624 L p 0 .291 .679 r

F P

0 g

s

.62938 .34076 m .59245 .38494 L .59358 .50031 L p .371 0 .679 r

F P

0 g

s

.66521 .52728 m .57762 .51794 L .59358 .50031 L p 0 .863 1 r

F P

0 g

s

.59358 .50031 m .631 .45897 L p .65503 .50695 L 0 .863 1 r

F P

0 g

s

.65503 .50695 m .66521 .52728 L .59358 .50031 L 0 .863 1 r

F

.59292 .43341 m .57762 .51794 L .58505 .39379 L 0 .291 .679 r

F

.59245 .38494 m .58505 .39379 L .59149 .28624 L F

.59292 .43341 m .58505 .39379 L .59245 .38494 L F

.59149 .28624 m .62799 .2397 L p .60426 .37082 L F P

0 g

s

.60426 .37082 m .59292 .43341 L .59245 .38494 L 0 .291 .679 r

F

.60426 .37082 m .59245 .38494 L .59149 .28624 L F

.62938 .34076 m .59358 .50031 L .59503 .4987 L .371 0 .679 r

F

.59358 .50031 m .57762 .51794 L p .59292 .43341 L 0 .291 .679 r

F P

0 g

s

.56793 .38207 m .56875 .49763 L p .59258 .50021 L .844 0 .758 r

F P

0 g

s

.59362 .50518 m .63107 .46396 L .62938 .34076 L p .371 0 .679 r

F P

0 g

s

.631 .45897 m .59358 .50031 L p .60426 .37082 L 0 .291 .679 r

F P

0 g

s

.60426 .37082 m .59358 .50031 L .59292 .43341 L 0 .291 .679 r

F

.59245 .38494 m .56793 .38207 L p .59258 .50021 L .844 0 .758 r

F P

0 g

s

.59358 .50031 m .59245 .38494 L p .59258 .50021 L .844 0 .758 r

F P

0 g

s

.55308 .51532 m .55191 .30315 L .46476 .29245 L p 0 .669 .759 r

F P

0 g

s

.60421 .33772 m .56793 .38207 L .59245 .38494 L p .755 0 1 r

F P

0 g

s

.56875 .49763 m .56879 .50251 L p .59258 .50021 L .844 0 .758 r

F P

0 g

s

.62799 .2397 m .62938 .34076 L p .60426 .37082 L 0 .291 .679 r

F P

0 g

s

.59245 .38494 m .62938 .34076 L .60421 .33772 L p .755 0 1 r

F P

0 g

s

.56879 .50251 m .56793 .38207 L .60421 .33772 L p .361 0 .675 r

F P

0 g

s

.60309 .23651 m .55191 .30315 L .55308 .51532 L p 0 .282 .675 r

F P

0 g

s

.55191 .30315 m .60309 .23651 L .51266 .22489 L p 0 .844 1 r

F P

0 g

s

.51266 .22489 m .46476 .29245 L .55191 .30315 L p 0 .844 1 r

F P

0 g

s

.60309 .23651 m .51266 .22489 L p .55562 .33186 L 0 .669 .756 r

F P

0 g

s

.62938 .34076 m .631 .45897 L p .60426 .37082 L 0 .291 .679 r

F P

0 g

s

.60421 .33772 m .60557 .46112 L .56879 .50251 L p .361 0 .675 r

F P

0 g

s

.55308 .51532 m .60552 .45613 L .60309 .23651 L p 0 .282 .675 r

F P

0 g

s

.60552 .45613 m .60421 .33772 L p .55562 .33186 L 0 .669 .756 r

F P

0 g

s

.60421 .33772 m .60309 .23651 L p .55562 .33186 L 0 .669 .756 r

F P

0 g

s

.46476 .29245 m .46396 .50582 L .55308 .51532 L p 0 .669 .759 r

F P

0 g

s

.51296 .4458 m .60552 .45613 L .56875 .49763 L p 0 .863 1 r

F P

0 g

s

.51296 .4458 m .56875 .49763 L .54115 .49465 L 0 .863 1 r

F

.5128 .3267 m .47886 .37166 L .4786 .48789 L p .321 0 .657 r

F P

0 g

s

.55308 .51532 m .46396 .50582 L .4786 .48789 L p 0 .863 1 r

F P

0 g

s

.51296 .4458 m .5128 .3267 L p .47994 .48625 L .321 0 .657 r

F P

0 g

s

.5128 .3267 m .4786 .48789 L .47994 .48625 L .321 0 .657 r

F

.51266 .22489 m .51296 .4458 L .60552 .45613 L p 0 .669 .756 r

F P

0 g

s

.51297 .45083 m .5128 .3267 L .5128 .3267 L p .845 0 .756 r

F P

0 g

s

.60552 .45613 m .51296 .4458 L p .5128 .3267 L 0 .669 .756 r

F P

0 g

s

.51266 .22489 m .55562 .33186 L .5128 .3267 L 0 .669 .756 r

F

.51266 .22489 m .60309 .23651 L .60421 .33772 L p F P

0 g

s

.60421 .33772 m .60552 .45613 L p .55562 .33186 L 0 .669 .756 r

F P

0 g

s

.51266 .22489 m .60421 .33772 L .55562 .33186 L 0 .669 .756 r

F

.51296 .4458 m .51266 .22489 L p .51266 .22489 L F P

0 g

s

.51296 .4458 m .51296 .4458 L p .51266 .22489 L 0 .669 .756 r

F P

0 g

s

.51266 .22489 m .53682 .29488 L .5128 .3267 L 0 .248 .657 r

F

.51266 .22489 m .51266 .22489 L .5128 .3267 L F

.5128 .3267 m .51266 .22489 L p .5128 .3267 L F P

0 g

s

.51296 .4458 m .51296 .4458 L p .5128 .3267 L 0 .248 .657 r

F P

0 g

s

.51266 .22489 m .5128 .3267 L .5128 .3267 L 0 .248 .657 r

F

.5128 .3267 m .51296 .4458 L .5128 .3267 L F

.51266 .22489 m .51296 .4458 L .51296 .4458 L p F P

0 g

s

.51296 .4458 m .51296 .4458 L p .51274 .28229 L 0 .248 .657 r

F P

0 g

s

.51266 .22489 m .51296 .4458 L .51274 .28229 L 0 .248 .657 r

F

.47886 .37166 m .5128 .3267 L .5128 .3267 L p .755 0 1 r

F P

0 g

s

.51266 .22489 m .5128 .3267 L .49672 .348 L 0 .248 .657 r

F

.47886 .37166 m .47886 .37166 L .5128 .3267 L .755 0 1 r

F

.48971 .35729 m .4786 .48789 L .47875 .42049 L 0 .248 .657 r

F

.51266 .22489 m .49672 .348 L .48971 .35729 L F

.49672 .348 m .4786 .48789 L .48971 .35729 L F

.46396 .50582 m .46476 .29245 L .47908 .27224 L p F P

0 g

s

.4786 .48789 m .47886 .37166 L p .47886 .37166 L .844 0 .758 r

F P

0 g

s

.47908 .27224 m .51266 .22489 L p .47875 .42049 L 0 .248 .657 r

F P

0 g

s

.47875 .42049 m .46396 .50582 L .47908 .27224 L 0 .248 .657 r

F

.4786 .48789 m .46396 .50582 L p .47875 .42049 L F P

0 g

s

.4781 .48783 m .4786 .48789 L .47886 .37166 L .844 0 .758 r

F

.4786 .48789 m .4786 .48789 L .47886 .37166 L F

.5 .32515 m .4664 .3702 L .47886 .37166 L p .755 0 1 r

F P

0 g

s

.5128 .3267 m .5 .32515 L p .47886 .37166 L .755 0 1 r

F P

0 g

s

.51296 .4458 m .4786 .48789 L p .49672 .348 L 0 .248 .657 r

F P

0 g

s

.47886 .37166 m .4664 .3702 L p .4781 .48783 L .844 0 .758 r

F P

0 g

s

.3483 .4935 m .43899 .50316 L .44035 .28945 L p 0 .669 .759 r

F P

0 g

s

.44035 .28945 m .43899 .50316 L p .45367 .41765 L 0 .237 .651 r

F P

0 g

s

.4664 .3702 m .45391 .36874 L p .45334 .48516 L .844 0 .758 r

F P

0 g

s

.45385 .48521 m .45334 .48516 L .45332 .49007 L .844 0 .758 r

F

.4664 .3702 m .45334 .48516 L .45385 .48521 L F

.43899 .50316 m .3483 .4935 L p .38995 .47831 L 0 .863 1 r

F P

0 g

s

.45332 .49007 m .46597 .49143 L .46598 .48652 L p .844 0 .758 r

F P

0 g

s

.46598 .48652 m .4664 .3702 L p .45385 .48521 L .844 0 .758 r

F P

0 g

s

.45385 .48521 m .45332 .49007 L .46598 .48652 L .844 0 .758 r

F

.43899 .50316 m .45334 .48516 L p .45367 .41765 L 0 .237 .651 r

F P

0 g

s

.4664 .3702 m .46597 .49143 L .47859 .49279 L p .844 0 .758 r

F P

0 g

s

.5 .32515 m .4664 .3702 L .46597 .49143 L p .315 0 .654 r

F P

0 g

s

.46597 .49143 m .4664 .3702 L .5 .32515 L p .315 0 .654 r

F P

0 g

s

.5128 .3267 m .51296 .4458 L .49672 .348 L 0 .248 .657 r

F

.46597 .49143 m .5 .44938 L .5 .32515 L p .315 0 .654 r

F P

0 g

s

.5 .32515 m .5 .44938 L .46597 .49143 L p .315 0 .654 r

F P

0 g

s

.45334 .48516 m .48701 .4429 L p .45367 .41765 L 0 .237 .651 r

F P

0 g

s

.45391 .36874 m .45334 .48516 L p .45334 .48516 L .844 0 .758 r

F P

0 g

s

.45439 .26917 m .44035 .28945 L p .45367 .41765 L 0 .237 .651 r

F P

0 g

s

.45391 .36874 m .45391 .36874 L p .45332 .49007 L .844 0 .758 r

F P

0 g

s

.45391 .36874 m .4664 .3702 L .5 .32515 L p .755 0 1 r

F P

0 g

s

.48718 .3236 m .45391 .36874 L p .45391 .36874 L .755 0 1 r

F P

0 g

s

.5 .32515 m .48718 .3236 L p .45391 .36874 L .755 0 1 r

F P

0 g

s

.48718 .3236 m .48718 .3236 L p .45391 .36874 L .755 0 1 r

F P

0 g

s

.48732 .22164 m .45439 .26917 L p .45391 .36874 L 0 .237 .651 r

F P

0 g

s

.46454 .35431 m .45391 .36874 L .45367 .41765 L 0 .237 .651 r

F

.48732 .22164 m .45391 .36874 L .46454 .35431 L F

.48701 .4429 m .48718 .3236 L p .45367 .41765 L F P

0 g

s

.48718 .3236 m .48732 .22164 L p .46454 .35431 L 0 .237 .651 r

F P

0 g

s

.46454 .35431 m .45367 .41765 L .48718 .3236 L 0 .237 .651 r

F

.45391 .36874 m .48718 .3236 L p .45465 .48351 L .309 0 .651 r

F P

0 g

s

.48701 .4429 m .48718 .3236 L p .48718 .3236 L 0 .669 .756 r

F P

0 g

s

.45334 .48516 m .45391 .36874 L p .45465 .48351 L .309 0 .651 r

F P

0 g

s

.48701 .44794 m .45332 .49007 L p .45465 .48351 L .309 0 .651 r

F P

0 g

s

.48718 .3236 m .48701 .4429 L p .45465 .48351 L .309 0 .651 r

F P

0 g

s

.48701 .4429 m .48701 .44794 L p .45465 .48351 L .309 0 .651 r

F P

0 g

s

.48701 .4429 m .45334 .48516 L p .45334 .48516 L 0 .863 1 r

F P

0 g

s

.48701 .4429 m .45334 .48516 L .38995 .47831 L 0 .863 1 r

F

.48701 .4429 m .45334 .48516 L .48701 .4429 L F

.39276 .43239 m .48701 .4429 L p .48718 .3236 L 0 .669 .756 r

F P

0 g

s

.48701 .4429 m .48701 .4429 L p .48718 .3236 L 0 .669 .756 r

F P

0 g

s

.45332 .49007 m .45334 .48516 L p .45465 .48351 L .309 0 .651 r

F P

0 g

s

.48701 .4429 m .38995 .47831 L .39276 .43239 L 0 .863 1 r

F

.36158 .47524 m .39276 .43239 L p .38995 .47831 L F P

0 g

s

.44035 .28945 m .3517 .27856 L .3483 .4935 L p 0 .669 .759 r

F P

0 g

s

.3517 .27856 m .44035 .28945 L .48732 .22164 L p 0 .844 1 r

F P

0 g

s

.48732 .22164 m .39526 .20982 L .3517 .27856 L p 0 .844 1 r

F P

0 g

s

.39526 .20982 m .39276 .43239 L .3483 .4935 L p 0 .195 .628 r

F P

0 g

s

.3483 .4935 m .36158 .47524 L p .38995 .47831 L 0 .863 1 r

F P

0 g

s

.3483 .4935 m .3517 .27856 L .39526 .20982 L p 0 .195 .628 r

F P

0 g

s

.39411 .31238 m .36328 .35814 L .36151 .48018 L p .26 0 .628 r

F P

0 g

s

.36151 .48018 m .3927 .43745 L .39411 .31238 L p .26 0 .628 r

F P

0 g

s

.36626 .43452 m .3927 .43745 L .39276 .43239 L p .845 0 .756 r

F P

0 g

s

.36739 .42956 m .36626 .43452 L .39276 .43239 L .845 0 .756 r

F

.3927 .43745 m .36626 .43452 L p .36739 .42956 L F P

0 g

s

.39276 .43239 m .39411 .31238 L p .36739 .42956 L .845 0 .756 r

F P

0 g

s

.39411 .31238 m .39276 .43239 L p .36739 .42956 L .845 0 .756 r

F P

0 g

s

.39276 .43239 m .3927 .43745 L p .36739 .42956 L .845 0 .756 r

F P

0 g

s

.39276 .43239 m .48701 .4429 L p .48701 .4429 L 0 .863 1 r

F P

0 g

s

.48701 .4429 m .39276 .43239 L .39276 .43239 L 0 .863 1 r

F

.38995 .47831 m .45334 .48516 L .38995 .47831 L F

.45334 .48516 m .43899 .50316 L p .38995 .47831 L F P

0 g

s

.48718 .3236 m .48732 .22164 L p .44391 .31838 L 0 .669 .756 r

F P

0 g

s

.44391 .31838 m .39276 .43239 L .48718 .3236 L 0 .669 .756 r

F

.51266 .22489 m .5128 .3267 L .51266 .22489 L 0 .248 .657 r

F

.5128 .3267 m .51296 .4458 L .5128 .3267 L F

.5128 .3267 m .5128 .3267 L .51266 .22489 L F

.5 .32515 m .5128 .3267 L p .5128 .32669 L .755 0 1 r

F P

0 g

s

.51283 .32665 m .5128 .3267 L .54878 .27903 L .755 0 1 r

F

.55562 .33186 m .55562 .33186 L .5128 .3267 L 0 .669 .756 r

F

.55562 .33186 m .60552 .45613 L .5128 .3267 L F

.5128 .3267 m .54878 .27903 L p .54878 .27903 L .755 0 1 r

F P

0 g

s

.51266 .22489 m .60309 .23651 L .65871 .16409 L p 0 .844 1 r

F P

0 g

s

.65871 .16409 m .56474 .15145 L .51266 .22489 L p 0 .844 1 r

F P

0 g

s

.51266 .22489 m .56474 .15145 L .56548 .2569 L p 0 .248 .657 r

F P

0 g

s

.54878 .27903 m .5128 .3267 L p .54791 .40298 L .321 0 .657 r

F P

0 g

s

.7219 .46911 m .631 .45897 L .62799 .2397 L p 0 .669 .756 r

F P

0 g

s

.62799 .2397 m .62938 .34076 L p .67144 .34584 L 0 .669 .756 r

F P

0 g

s

.631 .45897 m .7219 .46911 L p .67144 .34584 L 0 .669 .756 r

F P

0 g

s

.62938 .34076 m .631 .45897 L p .67144 .34584 L 0 .669 .756 r

F P

0 g

s

.7219 .46911 m .71918 .3516 L p .67144 .34584 L 0 .669 .756 r

F P

0 g

s

.7887 .42873 m .7887 .42873 L .76403 .42589 L .846 0 .754 r

F

.7887 .42873 m .76403 .42589 L .76403 .42589 L F

.78358 .40583 m .78358 .40583 L .76403 .42589 L 0 .863 1 r

F

.76403 .42589 m .76403 .42589 L .7219 .46911 L F

.7469 .32078 m .76403 .42589 L .7621 .35602 L 0 .32 .693 r

F

.76403 .42589 m .76403 .42589 L p .76069 .30544 L .846 0 .754 r

F P

0 g

s

.76417 .43097 m .72202 .47407 L .7219 .46911 L p .405 0 .693 r

F P

0 g

s

.7219 .46911 m .71918 .3516 L p .7623 .42767 L .405 0 .693 r

F P

0 g

s

.7623 .42767 m .76417 .43097 L .7219 .46911 L .405 0 .693 r

F

.66851 .29395 m .62938 .34076 L p .66905 .41693 L .371 0 .679 r

F P

0 g

s

.76403 .42589 m .78358 .40583 L p .7621 .35602 L 0 .32 .693 r

F P

0 g

s

.71918 .3516 m .76069 .30544 L .76417 .43097 L p .405 0 .693 r

F P

0 g

s

.6891 .39478 m .78358 .40583 L p .73545 .42259 L 0 .863 1 r

F P

0 g

s

.631 .45897 m .67068 .41512 L p .73545 .42259 L 0 .863 1 r

F P

0 g

s

.67068 .41512 m .6891 .39478 L p .73545 .42259 L 0 .863 1 r

F P

0 g

s

.67068 .41512 m .66851 .29395 L p .66905 .41693 L .371 0 .679 r

F P

0 g

s

.62938 .34076 m .631 .45897 L .66905 .41693 L .371 0 .679 r

F

.631 .45897 m .62938 .34076 L p .67001 .37751 L 0 .291 .679 r

F P

0 g

s

.6891 .39478 m .67068 .41512 L p .67001 .37751 L 0 .291 .679 r

F P

0 g

s

.67068 .41512 m .631 .45897 L p .67001 .37751 L 0 .291 .679 r

F P

0 g

s

.62938 .34076 m .62799 .2397 L p .6555 .30951 L 0 .291 .679 r

F P

0 g

s

.6555 .30951 m .66942 .34484 L .62938 .34076 L 0 .291 .679 r

F

.66942 .34484 m .6891 .39478 L .67001 .37751 L F

.66942 .34484 m .67001 .37751 L .62938 .34076 L F

.71918 .3516 m .71685 .25111 L p .67144 .34584 L 0 .669 .756 r

F P

0 g

s

.62799 .2397 m .71685 .25111 L .77684 .17999 L p 0 .844 1 r

F P

0 g

s

.77684 .17999 m .68458 .16757 L .62799 .2397 L p 0 .844 1 r

F P

0 g

s

.62799 .2397 m .68458 .16757 L .6891 .39478 L p 0 .291 .679 r

F P

0 g

s

.66851 .29395 m .64267 .29073 L .60421 .33772 L p .755 0 1 r

F P

0 g

s

.60421 .33772 m .62938 .34076 L .66851 .29395 L p .755 0 1 r

F P

0 g

s

.64267 .29073 m .67068 .41512 L .66964 .415 L .846 0 .754 r

F

.64267 .29073 m .66851 .29395 L .67068 .41512 L p F P

0 g

s

.67077 .42024 m .67068 .41512 L p .66905 .41693 L .371 0 .679 r

F P

0 g

s

.67068 .41512 m .67077 .42024 L p .66964 .415 L .846 0 .754 r

F P

0 g

s

.7219 .46911 m .631 .45897 L p .73545 .42259 L 0 .863 1 r

F P

0 g

s

.631 .45897 m .7219 .46911 L p .68216 .50989 L 0 .863 1 r

F P

0 g

s

.631 .45897 m .68216 .50989 L .65503 .50695 L 0 .863 1 r

F

.63107 .46396 m .67077 .42024 L p .66905 .41693 L .371 0 .679 r

F P

0 g

s

.631 .45897 m .63107 .46396 L .66905 .41693 L .371 0 .679 r

F

.62938 .34076 m .63107 .46396 L .63107 .46396 L p F P

0 g

s

.62938 .34076 m .63107 .46396 L .62938 .34076 L .371 0 .679 r

F

.63107 .46396 m .62938 .34076 L .60421 .33772 L p .845 0 .756 r

F P

0 g

s

.60421 .33772 m .62938 .34076 L .63107 .46396 L p .845 0 .756 r

F P

0 g

s

.60557 .46112 m .63107 .46396 L p .62998 .45885 L .845 0 .756 r

F P

0 g

s

.60421 .33772 m .60552 .45613 L p .62998 .45885 L .845 0 .756 r

F P

0 g

s

.60552 .45613 m .60557 .46112 L p .62998 .45885 L .845 0 .756 r

F P

0 g

s

.60552 .45613 m .51296 .4458 L p .51296 .4458 L 0 .863 1 r

F P

0 g

s

.63107 .46396 m .60557 .46112 L .60552 .45613 L p .845 0 .756 r

F P

0 g

s

.60552 .45613 m .60421 .33772 L p .62998 .45885 L .845 0 .756 r

F P

0 g

s

.62998 .45885 m .63107 .46396 L .60552 .45613 L .845 0 .756 r

F

.64459 .41723 m .60557 .46112 L .60552 .45613 L p .361 0 .675 r

F P

0 g

s

.60552 .45613 m .60421 .33772 L p .64291 .41392 L .361 0 .675 r

F P

0 g

s

.64291 .41392 m .64459 .41723 L .60552 .45613 L .361 0 .675 r

F

.60421 .33772 m .64267 .29073 L .64459 .41723 L p F P

0 g

s

.67077 .42024 m .64459 .41723 L .64451 .41211 L p .846 0 .754 r

F P

0 g

s

.64451 .41211 m .64267 .29073 L p .66964 .415 L .846 0 .754 r

F P

0 g

s

.66964 .415 m .67077 .42024 L .64451 .41211 L .846 0 .754 r

F

.51296 .4458 m .6154 .40875 L .60552 .45613 L 0 .863 1 r

F

.66261 .39167 m .64451 .41211 L p .6154 .40875 L F P

0 g

s

.64451 .41211 m .60552 .45613 L p .6154 .40875 L 0 .863 1 r

F P

0 g

s

.60504 .4125 m .66261 .39167 L p .60309 .23651 L 0 .282 .675 r

F P

0 g

s

.60552 .45613 m .60552 .45613 L p .51296 .4458 L 0 .863 1 r

F P

0 g

s

.56634 .38041 m .66261 .39167 L p .6154 .40875 L 0 .863 1 r

F P

0 g

s

.51296 .4458 m .54941 .40114 L .6154 .40875 L 0 .863 1 r

F

.54941 .40114 m .56634 .38041 L .6154 .40875 L F

.54941 .40114 m .54878 .27903 L p .54791 .40298 L .321 0 .657 r

F P

0 g

s

.56548 .2569 m .56634 .38041 L p .54905 .33031 L 0 .248 .657 r

F P

0 g

s

.53682 .29488 m .54878 .27903 L .54905 .33031 L 0 .248 .657 r

F

.54878 .27903 m .56548 .2569 L .54905 .33031 L F

.54878 .27903 m .54941 .40114 L p .54941 .40114 L .846 0 .754 r

F P

0 g

s

.51266 .22489 m .54861 .24668 L .53682 .29488 L 0 .248 .657 r

F

.54861 .24668 m .56548 .2569 L .54878 .27903 L F

.54861 .24668 m .54878 .27903 L .53682 .29488 L F

.5128 .3267 m .51283 .32665 L p .54878 .27903 L .755 0 1 r

F P

0 g

s

.54878 .27903 m .53563 .27739 L .5 .32515 L p .755 0 1 r

F P

0 g

s

.54878 .27903 m .51354 .32572 L .54878 .27903 L .755 0 1 r

F

.5 .32515 m .51354 .32572 L .54878 .27903 L F

.51354 .32572 m .51354 .32572 L .54878 .27903 L F

.54878 .27903 m .51354 .32572 L .54878 .27903 L F

.54878 .27903 m .54878 .27903 L p .54941 .40114 L .846 0 .754 r

F P

0 g

s

.5128 .3267 m .51296 .4458 L p .54791 .40298 L .321 0 .657 r

F P

0 g

s

.5128 .3267 m .54922 .36323 L .51296 .4458 L 0 .248 .657 r

F

.56634 .38041 m .54941 .40114 L p .54922 .36323 L F P

0 g

s

.54941 .40114 m .51296 .4458 L p .54922 .36323 L 0 .248 .657 r

F P

0 g

s

.54944 .4063 m .54941 .40114 L p .54791 .40298 L .321 0 .657 r

F P

0 g

s

.51296 .4458 m .56634 .38041 L .56634 .38041 L p 0 .863 1 r

F P

0 g

s

.51296 .4458 m .54941 .40114 L .51296 .4458 L 0 .863 1 r

F

.51296 .4458 m .54115 .49465 L .4786 .48789 L F

.4786 .48789 m .51296 .4458 L p .51296 .4458 L F P

0 g

s

.51296 .4458 m .4786 .48789 L .4786 .48789 L 0 .863 1 r

F

.54115 .49465 m .55308 .51532 L .4786 .48789 L F

.47859 .49279 m .51297 .45083 L .51296 .4458 L p .321 0 .657 r

F P

0 g

s

.47994 .48625 m .47859 .49279 L .51296 .4458 L .321 0 .657 r

F

.51296 .4458 m .51297 .45083 L p .51244 .44574 L .845 0 .756 r

F P

0 g

s

.51297 .45083 m .54944 .4063 L p .54791 .40298 L .321 0 .657 r

F P

0 g

s

.51296 .4458 m .51297 .45083 L p .54791 .40298 L .321 0 .657 r

F P

0 g

s

.54944 .4063 m .53611 .40477 L .5361 .39961 L p .846 0 .754 r

F P

0 g

s

.53682 .29488 m .56634 .38041 L .5128 .3267 L 0 .248 .657 r

F

.54878 .27903 m .51283 .32665 L .54878 .27903 L .755 0 1 r

F

.5361 .39961 m .53563 .27739 L p .54888 .40108 L .846 0 .754 r

F P

0 g

s

.54888 .40108 m .54944 .4063 L .5361 .39961 L .846 0 .754 r

F

.54941 .40114 m .54944 .4063 L p .54888 .40108 L F P

0 g

s

.53563 .27739 m .54941 .40114 L .54888 .40108 L .846 0 .754 r

F

.53563 .27739 m .54878 .27903 L p .54941 .40114 L F P

0 g

s

.51354 .32572 m .5128 .32669 L .51354 .32572 L .755 0 1 r

F

.5 .32515 m .5128 .32669 L .51354 .32572 L F

.51296 .4458 m .5128 .3267 L p .5128 .3267 L 0 .248 .657 r

F P

0 g

s

.5 .32515 m .5128 .3267 L p .51296 .4458 L .845 0 .756 r

F P

0 g

s

.5 .32515 m .51296 .4458 L .51244 .44574 L .845 0 .756 r

F

.5128 .3267 m .5 .32515 L p .51297 .45083 L F P

0 g

s

.51297 .45083 m .51297 .45083 L .5128 .3267 L .845 0 .756 r

F

.5128 .3267 m .51296 .4458 L p .51296 .4458 L F P

0 g

s

.5128 .3267 m .5128 .3267 L p .51296 .4458 L .845 0 .756 r

F P

0 g

s

.4786 .48789 m .47859 .49279 L p .47994 .48625 L .321 0 .657 r

F P

0 g

s

.47859 .49279 m .4786 .48789 L p .4781 .48783 L .844 0 .758 r

F P

0 g

s

.56875 .49763 m .55308 .51532 L p .54115 .49465 L 0 .863 1 r

F P

0 g

s

.56879 .50251 m .59362 .50518 L p .59258 .50021 L .844 0 .758 r

F P

0 g

s

.59362 .50518 m .59358 .50031 L p .59258 .50021 L .844 0 .758 r

F P

0 g

s

.59358 .50031 m .59362 .50518 L p .59503 .4987 L .371 0 .679 r

F P

0 g

s

.73545 .42259 m .78358 .40583 L .76403 .42589 L 0 .863 1 r

F

.73545 .42259 m .76403 .42589 L .7219 .46911 L F

.7887 .42873 m .78988 .43393 L .76403 .42589 L .846 0 .754 r

F

.76069 .30544 m .78607 .3086 L p .78972 .42885 L F P

0 g

s

.78358 .40583 m .77994 .28403 L p .76069 .30544 L 0 .32 .693 r

F P

0 g

s

.7621 .35602 m .78358 .40583 L .76069 .30544 L 0 .32 .693 r

F

.77994 .28403 m .77684 .17999 L p .7469 .32078 L F P

0 g

s

.78972 .42885 m .78988 .43393 L p .7887 .42873 L .846 0 .754 r

F P

0 g

s

.72202 .47407 m .68225 .51473 L p .68371 .5083 L .405 0 .693 r

F P

0 g

s

.7219 .46911 m .72202 .47407 L .68371 .5083 L .405 0 .693 r

F

.68225 .51473 m .68216 .50989 L p .68371 .5083 L F P

0 g

s

.68225 .51473 m .70666 .51736 L p .70558 .51242 L .844 0 .758 r

F P

0 g

s

.68216 .50989 m .66521 .52728 L p .65503 .50695 L 0 .863 1 r

F P

0 g

s

.70656 .51252 m .70666 .51736 L p .70813 .51094 L .413 0 .697 r

F P

0 g

s

0 0 0 r

.63615 .52418 m

.63615 .52418 L

s

.63615 .52418 m

.63615 .52418 L

s

.60695 .52107 m

.60695 .52107 L

s

.60695 .52107 m

.60695 .52107 L

s

.52351 .51217 m

.52351 .51217 L

s

.52351 .51217 m

.52351 .51217 L

s

.4938 .50901 m

.4938 .50901 L

s

.4938 .50901 m

.4938 .50901 L

s

.71817 .53292 m

.71817 .53292 L

s

.71817 .53292 m

.71817 .53292 L

s

.70377 .53139 m

.70377 .53139 L

s

.70377 .53139 m

.70377 .53139 L

s

.77684 .47524 m

.77684 .47524 L

s

.77684 .47524 m

.77684 .47524 L

s

.77684 .47524 m

.77684 .47524 L

s

.71817 .53292 m

.71817 .53292 L

s

.4089 .49996 m

.4089 .49996 L

s

.4089 .49996 m

.4089 .49996 L

s

.7619 .47357 m

.7619 .47357 L

s

.7619 .47357 m

.7619 .47357 L

s

.7619 .47357 m

.7619 .47357 L

s

.72115 .5141 m

.72115 .5141 L

s

.70377 .53139 m

.72115 .5141 L

s

.70377 .53139 m

.70377 .53139 L

s

.37867 .49673 m

.37867 .49673 L

s

.37867 .49673 m

.37867 .49673 L

s

.69174 .46575 m

.69174 .46575 L

s

.69174 .46575 m

.69174 .46575 L

s

.63615 .52418 m

.65277 .50671 L

s

.63615 .52418 m

.63615 .52418 L

s

.71974 .37584 m

.71974 .37584 L

s

.23059 .48095 m .32289 .49079 L .32686 .27551 L p 0 .669 .759 r

F P

0 g

s

.32686 .27551 m .23668 .26443 L .23059 .48095 L p 0 .669 .759 r

F P

0 g

s

.32289 .49079 m .23059 .48095 L p .27134 .46549 L 0 .863 1 r

F P

0 g

s

.36328 .35814 m .33788 .35517 L .33587 .47246 L p .844 0 .758 r

F P

0 g

s

.36328 .35814 m .33587 .47246 L .3369 .47257 L .844 0 .758 r

F

.32686 .27551 m .32289 .49079 L p .33703 .40444 L 0 .182 .621 r

F P

0 g

s

.36158 .47524 m .36328 .35814 L p .3369 .47257 L .844 0 .758 r

F P

0 g

s

.32289 .49079 m .33587 .47246 L p .33703 .40444 L 0 .182 .621 r

F P

0 g

s

.33587 .47246 m .36633 .42944 L p .33703 .40444 L 0 .182 .621 r

F P

0 g

s

.33788 .35517 m .36328 .35814 L .39411 .31238 L p .755 0 1 r

F P

0 g

s

.39411 .31238 m .36802 .30923 L .33788 .35517 L p .755 0 1 r

F P

0 g

s

.36946 .2065 m .3396 .25488 L p .33788 .35517 L 0 .182 .621 r

F P

0 g

s

.34751 .34049 m .33788 .35517 L .33703 .40444 L 0 .182 .621 r

F

.36946 .2065 m .33788 .35517 L .34751 .34049 L F

.36633 .42944 m .36802 .30923 L p .33703 .40444 L F P

0 g

s

.34751 .34049 m .33703 .40444 L .36802 .30923 L 0 .182 .621 r

F

.33788 .35517 m .36802 .30923 L p .33705 .47079 L .245 0 .621 r

F P

0 g

s

.36802 .30923 m .36946 .2065 L p .34751 .34049 L 0 .182 .621 r

F P

0 g

s

.3396 .25488 m .32686 .27551 L p .33703 .40444 L 0 .182 .621 r

F P

0 g

s

.36802 .30923 m .36626 .43452 L .36626 .43452 L p .245 0 .621 r

F P

0 g

s

.3369 .47257 m .33578 .47741 L .36158 .47524 L .844 0 .758 r

F

.36802 .30923 m .36633 .42944 L .33705 .47079 L .245 0 .621 r

F

.33587 .47246 m .33788 .35517 L p .33705 .47079 L F P

0 g

s

.36633 .42944 m .33587 .47246 L p .27134 .46549 L 0 .863 1 r

F P

0 g

s

.33587 .47246 m .33578 .47741 L p .3369 .47257 L .844 0 .758 r

F P

0 g

s

.36626 .43452 m .33578 .47741 L p .33705 .47079 L .245 0 .621 r

F P

0 g

s

.36633 .42944 m .36626 .43452 L .33705 .47079 L .245 0 .621 r

F

.36802 .30923 m .36633 .42944 L .36802 .30923 L F

.36633 .42944 m .27033 .41873 L p .32396 .30391 L 0 .669 .756 r

F P

0 g

s

.36802 .30923 m .36633 .42944 L p .32396 .30391 L 0 .669 .756 r

F P

0 g

s

.48732 .22164 m .39526 .20982 L .39276 .43239 L p 0 .669 .756 r

F P

0 g

s

.39526 .20982 m .48732 .22164 L p .44391 .31838 L 0 .669 .756 r

F P

0 g

s

.39276 .43239 m .39411 .31238 L p .44391 .31838 L 0 .669 .756 r

F P

0 g

s

.39411 .31238 m .39526 .20982 L p .44391 .31838 L 0 .669 .756 r

F P

0 g

s

.48732 .22164 m .48701 .4429 L .39276 .43239 L p 0 .669 .756 r

F P

0 g

s

.44123 .36577 m .39276 .43239 L .39526 .20982 L p 0 .195 .628 r

F P

0 g

s

.44266 .13502 m .39526 .20982 L .48732 .22164 L p 0 .844 1 r

F P

0 g

s

.39526 .20982 m .44266 .13502 L .44123 .36577 L p 0 .195 .628 r

F P

0 g

s

.41582 .13141 m .36946 .2065 L p .38937 .27669 L 0 .182 .621 r

F P

0 g

s

.4 .26048 m .36802 .30923 L .39411 .31238 L p .755 0 1 r

F P

0 g

s

.48701 .4429 m .39276 .43239 L .42585 .3869 L p 0 .863 1 r

F P

0 g

s

.42585 .3869 m .44123 .36577 L p .45582 .39035 L 0 .863 1 r

F P

0 g

s

.48701 .4429 m .42585 .3869 L .45582 .39035 L 0 .863 1 r

F

.39411 .31238 m .3927 .43745 L .42581 .39209 L p .26 0 .628 r

F P

0 g

s

.42581 .39209 m .39863 .38897 L p .39977 .38389 L .846 0 .754 r

F P

0 g

s

.40801 .34733 m .42682 .26383 L .39411 .31238 L p .26 0 .628 r

F P

0 g

s

.42585 .3869 m .42364 .38664 L p .42581 .39209 L .26 0 .628 r

F P

0 g

s

.42682 .26383 m .42585 .3869 L p .39977 .38389 L .846 0 .754 r

F P

0 g

s

.42585 .3869 m .42581 .39209 L p .39977 .38389 L .846 0 .754 r

F P

0 g

s

.39411 .31238 m .42682 .26383 L .4 .26048 L p .755 0 1 r

F P

0 g

s

.39411 .31238 m .36802 .30923 L .36626 .43452 L p .845 0 .756 r

F P

0 g

s

.36626 .43452 m .36802 .30923 L .39411 .31238 L p .845 0 .756 r

F P

0 g

s

.4 .26048 m .42682 .26383 L p .39977 .38389 L .846 0 .754 r

F P

0 g

s

.39868 .38376 m .4 .26048 L p .39977 .38389 L .846 0 .754 r

F P

0 g

s

.36633 .42944 m .39868 .38376 L p .38937 .27669 L 0 .182 .621 r

F P

0 g

s

.39868 .38376 m .41371 .36255 L p .39945 .31225 L 0 .182 .621 r

F P

0 g

s

.38937 .27669 m .39868 .38376 L .39945 .31225 L 0 .182 .621 r

F

.36802 .30923 m .36633 .42944 L p .38937 .27669 L F P

0 g

s

.36946 .2065 m .36802 .30923 L p .32396 .30391 L 0 .669 .756 r

F P

0 g

s

.27033 .41873 m .36633 .42944 L .36946 .2065 L p 0 .669 .756 r

F P

0 g

s

.23668 .26443 m .32686 .27551 L .36946 .2065 L p 0 .844 1 r

F P

0 g

s

.36946 .2065 m .27574 .19447 L .23668 .26443 L p 0 .844 1 r

F P

0 g

s

.27033 .41873 m .27574 .19447 L .36946 .2065 L p 0 .669 .756 r

F P

0 g

s

.23059 .48095 m .24246 .46236 L p .24246 .46236 L 0 .863 1 r

F P

0 g

s

.27134 .46549 m .23059 .48095 L .24246 .46236 L 0 .863 1 r

F

.23059 .48095 m .23059 .48095 L .24246 .46236 L F

.27325 .29779 m .24564 .34439 L .24246 .46236 L p .186 0 .591 r

F P

0 g

s

.27134 .46549 m .24246 .46236 L .27033 .41873 L 0 .863 1 r

F

.24233 .46734 m .27021 .42384 L .27033 .41873 L p .186 0 .591 r

F P

0 g

s

.27033 .41873 m .27325 .29779 L p .24354 .46067 L .186 0 .591 r

F P

0 g

s

.24354 .46067 m .24233 .46734 L .27033 .41873 L .186 0 .591 r

F

.24246 .46236 m .27033 .41873 L p .27033 .41873 L 0 .863 1 r

F P

0 g

s

.24246 .46236 m .24246 .46236 L .27033 .41873 L 0 .863 1 r

F

.24246 .46236 m .24233 .46734 L p .24354 .46067 L .186 0 .591 r

F P

0 g

s

.27325 .29779 m .24246 .46236 L .24354 .46067 L .186 0 .591 r

F

.24564 .34439 m .27325 .29779 L p .27325 .29779 L .755 0 1 r

F P

0 g

s

.27574 .19447 m .27325 .29779 L p .26016 .31988 L 0 .131 .591 r

F P

0 g

s

.24564 .34439 m .24564 .34439 L p .27325 .29779 L .755 0 1 r

F P

0 g

s

.24233 .46734 m .24233 .46734 L p .24564 .34439 L .844 0 .758 r

F P

0 g

s

.25446 .3295 m .24246 .46236 L .2443 .39394 L 0 .131 .591 r

F

.27574 .19447 m .26016 .31988 L .25446 .3295 L F

.26016 .31988 m .24246 .46236 L .25446 .3295 L F

.24233 .46734 m .24564 .34439 L p .24564 .34439 L .844 0 .758 r

F P

0 g

s

.23059 .48095 m .23668 .26443 L .24836 .24352 L p 0 .131 .591 r

F P

0 g

s

.24836 .24352 m .27574 .19447 L p .2443 .39394 L 0 .131 .591 r

F P

0 g

s

.2443 .39394 m .23059 .48095 L .24836 .24352 L 0 .131 .591 r

F

.21141 .26133 m .20473 .47819 L p .21832 .391 L 0 .115 .582 r

F P

0 g

s

.24564 .34439 m .21979 .34137 L p .21628 .45954 L .844 0 .758 r

F P

0 g

s

.21733 .45965 m .21628 .45954 L .21613 .46452 L .844 0 .758 r

F

.24564 .34439 m .21628 .45954 L .21733 .45965 L F

.15792 .4732 m .20473 .47819 L .21141 .26133 L p 0 .669 .759 r

F P

0 g

s

.20473 .47819 m .15792 .4732 L p .18351 .45599 L 0 .863 1 r

F P

0 g

s

.27325 .29779 m .24668 .29459 L p .21979 .34137 L .755 0 1 r

F P

0 g

s

.21979 .34137 m .24564 .34439 L p .27325 .29779 L .755 0 1 r

F P

0 g

s

.24947 .1911 m .22279 .24034 L p .21979 .34137 L 0 .115 .582 r

F P

0 g

s

.22838 .32642 m .21979 .34137 L .21832 .391 L 0 .115 .582 r

F

.24947 .1911 m .21979 .34137 L .22838 .32642 L F

.24246 .46236 m .23059 .48095 L p .2443 .39394 L 0 .131 .591 r

F P

0 g

s

.24564 .34439 m .21733 .45965 L .24246 .46236 L .844 0 .758 r

F

.24342 .41573 m .24668 .29459 L p .21737 .42286 L 0 .115 .582 r

F P

0 g

s

.20473 .47819 m .21628 .45954 L p .21737 .42286 L 0 .115 .582 r

F P

0 g

s

.21628 .45954 m .24342 .41573 L p .21737 .42286 L 0 .115 .582 r

F P

0 g

s

.22838 .32642 m .20473 .47819 L .24668 .29459 L 0 .115 .582 r

F

.21979 .34137 m .21628 .45954 L p .21628 .45954 L .844 0 .758 r

F P

0 g

s

.22279 .24034 m .21141 .26133 L p .21832 .391 L 0 .115 .582 r

F P

0 g

s

.21979 .34137 m .21979 .34137 L p .21613 .46452 L .844 0 .758 r

F P

0 g

s

.24668 .29459 m .24947 .1911 L p .22838 .32642 L 0 .115 .582 r

F P

0 g

s

.24668 .29459 m .21979 .34137 L p .21979 .34137 L .755 0 1 r

F P

0 g

s

.24668 .29459 m .24668 .29459 L p .21979 .34137 L .755 0 1 r

F P

0 g

s

.21979 .34137 m .24668 .29459 L p .21734 .45783 L .168 0 .582 r

F P

0 g

s

.21613 .46452 m .21628 .45954 L p .21734 .45783 L .168 0 .582 r

F P

0 g

s

.21628 .45954 m .21979 .34137 L p .21734 .45783 L .168 0 .582 r

F P

0 g

s

.21733 .45965 m .21613 .46452 L .24246 .46236 L .844 0 .758 r

F

.24328 .42084 m .21613 .46452 L p .21734 .45783 L .168 0 .582 r

F P

0 g

s

.24668 .29459 m .24342 .41573 L p .21734 .45783 L .168 0 .582 r

F P

0 g

s

.24342 .41573 m .21628 .45954 L p .21628 .45954 L 0 .863 1 r

F P

0 g

s

.24342 .41573 m .21628 .45954 L .24342 .41573 L 0 .863 1 r

F

.24342 .41573 m .24328 .42084 L p .21734 .45783 L .168 0 .582 r

F P

0 g

s

.24342 .41573 m .21628 .45954 L .18351 .45599 L 0 .863 1 r

F

.1947 .41029 m .24342 .41573 L p .18351 .45599 L F P

0 g

s

.15792 .4732 m .1689 .45441 L p .18351 .45599 L 0 .863 1 r

F P

0 g

s

.1689 .45441 m .1947 .41029 L p .18351 .45599 L 0 .863 1 r

F P

0 g

s

.21613 .46452 m .24233 .46734 L p .24246 .46236 L .844 0 .758 r

F P

0 g

s

.18351 .45599 m .21628 .45954 L .18351 .45599 L 0 .863 1 r

F

.21628 .45954 m .20473 .47819 L p .18351 .45599 L F P

0 g

s

.27033 .41873 m .24246 .46236 L p .26016 .31988 L 0 .131 .591 r

F P

0 g

s

.27325 .29779 m .27033 .41873 L p .26016 .31988 L 0 .131 .591 r

F P

0 g

s

.27325 .29779 m .27021 .42384 L .24328 .42084 L p .845 0 .756 r

F P

0 g

s

.27033 .41873 m .27325 .29779 L p .2445 .41585 L .845 0 .756 r

F P

0 g

s

.24328 .42084 m .24668 .29459 L .27325 .29779 L p .845 0 .756 r

F P

0 g

s

.24947 .1911 m .24342 .41573 L .24342 .41573 L p 0 .115 .582 r

F P

0 g

s

.27033 .41873 m .27325 .29779 L .27033 .41873 L 0 .669 .756 r

F

.27574 .19447 m .27325 .29779 L p .27325 .29779 L F P

0 g

s

.27325 .29779 m .27033 .41873 L p .27325 .29779 L 0 .669 .756 r

F P

0 g

s

.36946 .2065 m .27574 .19447 L p .27325 .29779 L 0 .669 .756 r

F P

0 g

s

.32396 .30391 m .27325 .29779 L .27033 .41873 L 0 .669 .756 r

F

.36946 .2065 m .27325 .29779 L .32396 .30391 L F

.27325 .29779 m .27021 .42384 L .27021 .42384 L p .186 0 .591 r

F P

0 g

s

.27033 .41873 m .36633 .42944 L p .27134 .46549 L 0 .863 1 r

F P

0 g

s

.27325 .29779 m .27033 .41873 L .29872 .37429 L .186 0 .591 r

F

.27033 .41873 m .29994 .37238 L p .29994 .37238 L 0 .863 1 r

F P

0 g

s

.36633 .42944 m .27033 .41873 L p .29994 .37238 L 0 .863 1 r

F P

0 g

s

.33048 .3759 m .29994 .37238 L .31369 .35084 L 0 .863 1 r

F

.36633 .42944 m .29994 .37238 L .33048 .3759 L F

.27033 .41873 m .27033 .41873 L p .29994 .37238 L F P

0 g

s

.27021 .42384 m .29983 .37762 L p .29872 .37429 L .186 0 .591 r

F P

0 g

s

.27033 .41873 m .27021 .42384 L .29872 .37429 L .186 0 .591 r

F

.30256 .24834 m .27325 .29779 L p .29872 .37429 L F P

0 g

s

.29994 .37238 m .30256 .24834 L p .29872 .37429 L .186 0 .591 r

F P

0 g

s

.27325 .29779 m .27021 .42384 L .27325 .29779 L .186 0 .591 r

F

.27033 .41873 m .27325 .29779 L p .30075 .33386 L 0 .131 .591 r

F P

0 g

s

.31369 .35084 m .29994 .37238 L p .30075 .33386 L 0 .131 .591 r

F P

0 g

s

.29994 .37238 m .27033 .41873 L p .30075 .33386 L 0 .131 .591 r

F P

0 g

s

.29983 .37762 m .27212 .37444 L p .27335 .36931 L .846 0 .754 r

F P

0 g

s

.27325 .29779 m .30256 .24834 L .30256 .24834 L p .755 0 1 r

F P

0 g

s

.29281 .26479 m .30146 .30042 L .27325 .29779 L 0 .131 .591 r

F

.30256 .24834 m .29994 .37238 L p .29994 .37238 L .846 0 .754 r

F P

0 g

s

.30146 .30042 m .31369 .35084 L .30075 .33386 L 0 .131 .591 r

F

.30146 .30042 m .30075 .33386 L .27325 .29779 L F

.30256 .24834 m .29994 .37238 L .30256 .24834 L .846 0 .754 r

F

.27325 .29779 m .30256 .24834 L .27325 .29779 L .755 0 1 r

F

.31828 .11829 m .27574 .19447 L .36946 .2065 L p 0 .844 1 r

F P

0 g

s

.31828 .11829 m .31369 .35084 L p .30146 .30042 L 0 .131 .591 r

F P

0 g

s

.27574 .19447 m .30479 .14244 L p .30146 .30042 L 0 .131 .591 r

F P

0 g

s

.30479 .14244 m .31828 .11829 L p .30146 .30042 L 0 .131 .591 r

F P

0 g

s

.27574 .19447 m .27574 .19447 L p .27033 .41873 L 0 .669 .756 r

F P

0 g

s

.27325 .29779 m .27574 .19447 L p .29281 .26479 L 0 .131 .591 r

F P

0 g

s

.30256 .24834 m .27523 .24494 L p .27325 .29779 L .755 0 1 r

F P

0 g

s

.29093 .11461 m .24947 .1911 L p .26574 .26145 L 0 .115 .582 r

F P

0 g

s

.27325 .29779 m .27523 .24494 L .24668 .29459 L .755 0 1 r

F

.26574 .26145 m .27398 .2971 L .27523 .24494 L 0 .115 .582 r

F

.27523 .24494 m .30256 .24834 L p .27212 .37444 L .846 0 .754 r

F P

0 g

s

.30256 .24834 m .29994 .37238 L .27335 .36931 L .846 0 .754 r

F

.24668 .29459 m .24668 .29459 L .27325 .29779 L p .755 0 1 r

F P

0 g

s

.27325 .29779 m .24668 .29459 L .24328 .42084 L p .845 0 .756 r

F P

0 g

s

.24342 .41573 m .27224 .36919 L p .26574 .26145 L 0 .115 .582 r

F P

0 g

s

.27224 .36919 m .28564 .34756 L p .27398 .2971 L 0 .115 .582 r

F P

0 g

s

.26574 .26145 m .27224 .36919 L .27398 .2971 L 0 .115 .582 r

F

.27212 .37444 m .27523 .24494 L .27523 .24494 L p .846 0 .754 r

F P

0 g

s

.27212 .37444 m .27212 .37444 L .27523 .24494 L .846 0 .754 r

F

.28564 .34756 m .28849 .22187 L p .27523 .24494 L 0 .115 .582 r

F P

0 g

s

.27398 .2971 m .28564 .34756 L .27523 .24494 L 0 .115 .582 r

F

.28849 .22187 m .29093 .11461 L p .26574 .26145 L F P

0 g

s

.24668 .29459 m .24342 .41573 L .26574 .26145 L 0 .115 .582 r

F

.24947 .1911 m .24342 .41573 L .1947 .41029 L p 0 .669 .756 r

F P

0 g

s

.1947 .41029 m .24342 .41573 L .24947 .1911 L p 0 .669 .756 r

F P

0 g

s

.2445 .41585 m .24328 .42084 L .27033 .41873 L .845 0 .756 r

F

.27212 .37444 m .24328 .42084 L .24342 .41573 L p .168 0 .582 r

F P

0 g

s

.24342 .41573 m .24668 .29459 L p .27106 .3711 L .168 0 .582 r

F P

0 g

s

.27106 .3711 m .27212 .37444 L .24342 .41573 L .168 0 .582 r

F

.28564 .34756 m .27224 .36919 L p .27224 .36919 L 0 .863 1 r

F P

0 g

s

.24947 .1911 m .24668 .29459 L .26574 .26145 L 0 .115 .582 r

F

.27523 .24494 m .24668 .29459 L p .24668 .29459 L .755 0 1 r

F P

0 g

s

.27523 .24494 m .27523 .24494 L .24668 .29459 L .755 0 1 r

F

.24668 .29459 m .27523 .24494 L .27224 .36919 L p .168 0 .582 r

F P

0 g

s

.27224 .36919 m .27212 .37444 L p .27106 .3711 L .168 0 .582 r

F P

0 g

s

.24668 .29459 m .27224 .36919 L .27106 .3711 L .168 0 .582 r

F

.27224 .36919 m .24342 .41573 L p .24342 .41573 L 0 .863 1 r

F P

0 g

s

.24342 .41573 m .23758 .36519 L .27224 .36919 L 0 .863 1 r

F

.24342 .41573 m .27224 .36919 L .27224 .36919 L F

.23485 .34161 m .28564 .34756 L p .27224 .36919 L F P

0 g

s

.28564 .34756 m .28564 .34756 L p .27224 .36919 L 0 .863 1 r

F P

0 g

s

.23758 .36519 m .23485 .34161 L .27224 .36919 L 0 .863 1 r

F

.29983 .37762 m .29994 .37238 L p .29872 .37429 L .186 0 .591 r

F P

0 g

s

.29994 .37238 m .29983 .37762 L p .27335 .36931 L .846 0 .754 r

F P

0 g

s

.31369 .35084 m .29994 .37238 L .31369 .35084 L 0 .863 1 r

F

.29994 .37238 m .31369 .35084 L p .29994 .37238 L F P

0 g

s

.24328 .42084 m .27021 .42384 L .27033 .41873 L p .845 0 .756 r

F P

0 g

s

.39863 .38897 m .36626 .43452 L .36633 .42944 L p .245 0 .621 r

F P

0 g

s

.36633 .42944 m .36802 .30923 L p .39735 .38564 L .245 0 .621 r

F P

0 g

s

.39735 .38564 m .39863 .38897 L .36633 .42944 L .245 0 .621 r

F

.41371 .36255 m .41485 .23785 L p .38937 .27669 L 0 .182 .621 r

F P

0 g

s

.36802 .30923 m .4 .26048 L .39868 .38376 L p .245 0 .621 r

F P

0 g

s

.39868 .38376 m .39863 .38897 L p .39735 .38564 L .245 0 .621 r

F P

0 g

s

.36802 .30923 m .39868 .38376 L .39735 .38564 L .245 0 .621 r

F

.39868 .38376 m .36634 .42943 L p .33048 .3759 L 0 .863 1 r

F P

0 g

s

.31369 .35084 m .41371 .36255 L .39868 .38376 L p 0 .863 1 r

F P

0 g

s

.33048 .3759 m .31369 .35084 L .39868 .38376 L 0 .863 1 r

F

.39863 .38897 m .39868 .38376 L p .39977 .38389 L .846 0 .754 r

F P

0 g

s

.36946 .2065 m .36802 .30923 L p .38937 .27669 L 0 .182 .621 r

F P

0 g

s

.41485 .23785 m .41582 .13141 L p .38937 .27669 L 0 .182 .621 r

F P

0 g

s

.33578 .47741 m .33587 .47246 L p .33705 .47079 L .245 0 .621 r

F P

0 g

s

.33578 .47741 m .36151 .48018 L .36158 .47524 L p .844 0 .758 r

F P

0 g

s

.33587 .47246 m .32289 .49079 L p .27134 .46549 L 0 .863 1 r

F P

0 g

s

0 0 0 r

.66144 .46236 m

.66144 .46236 L

s

.66144 .46236 m

.66144 .46236 L

s

.60695 .52107 m

.60695 .52107 L

s

.29226 .48752 m

.29226 .48752 L

s

.29226 .48752 m

.29226 .48752 L

s

.73509 .64043 m .69143 .63613 L .69585 .86101 L p 0 .669 .759 r

F P

0 g

s

.69585 .86101 m .7405 .86463 L .73509 .64043 L p 0 .669 .759 r

F P

0 g

s

.73509 .64043 m .7405 .86463 L .80217 .81934 L p 0 .34 .703 r

F P

0 g

s

.80217 .81934 m .79508 .58671 L .73509 .64043 L p 0 .34 .703 r

F P

0 g

s

.74964 .57698 m .70876 .61503 L p .71046 .61849 L .413 0 .697 r

F P

0 g

s

.73509 .64043 m .79508 .58671 L .74977 .58204 L p 0 .872 1 r

F P

0 g

s

.69143 .63613 m .73509 .64043 L p .73947 .62302 L 0 .872 1 r

F P

0 g

s

.74977 .58204 m .70887 .61996 L .73947 .62302 L 0 .872 1 r

F

.70887 .61996 m .69143 .63613 L p .73947 .62302 L F P

0 g

s

.71144 .73995 m .75295 .70511 L p .71046 .61849 L .413 0 .697 r

F P

0 g

s

.70876 .61503 m .70887 .61996 L p .71046 .61849 L .413 0 .697 r

F P

0 g

s

.70887 .61996 m .71144 .73995 L p .71046 .61849 L .413 0 .697 r

F P

0 g

s

.74977 .58204 m .74964 .57698 L p .71046 .61849 L .413 0 .697 r

F P

0 g

s

.70876 .61503 m .74964 .57698 L .72435 .57436 L p .736 0 1 r

F P

0 g

s

.72435 .57436 m .74964 .57698 L p .74876 .58193 L .845 0 .756 r

F P

0 g

s

.74977 .58204 m .70887 .61996 L p .70887 .61996 L 0 .872 1 r

F P

0 g

s

.74977 .58204 m .70887 .61996 L .74977 .58204 L 0 .872 1 r

F

.75295 .70511 m .7488 .58294 L p .71046 .61849 L .413 0 .697 r

F P

0 g

s

.79508 .58671 m .80217 .81934 L .75579 .8154 L p 0 .669 .756 r

F P

0 g

s

.74977 .58204 m .75295 .70511 L p .75295 .70511 L .845 0 .756 r

F P

0 g

s

.74977 .58204 m .74977 .58204 L .75295 .70511 L .845 0 .756 r

F

.75579 .8154 m .74977 .58204 L .79508 .58671 L p 0 .669 .756 r

F P

0 g

s

.79508 .58671 m .74977 .58204 L .75579 .8154 L p 0 .669 .756 r

F P

0 g

s

.75579 .8154 m .80217 .81934 L .79508 .58671 L p 0 .669 .756 r

F P

0 g

s

.74977 .58204 m .79508 .58671 L .83968 .54677 L p 0 .872 1 r

F P

0 g

s

.83968 .54677 m .86037 .52823 L p .8254 .54525 L 0 .872 1 r

F P

0 g

s

.74977 .58204 m .83968 .54677 L .8254 .54525 L 0 .872 1 r

F

.79137 .54347 m .793 .53662 L .74977 .58204 L .413 0 .697 r

F

.793 .53662 m .74964 .57698 L .74977 .58204 L p F P

0 g

s

.79316 .54181 m .793 .53662 L p .79137 .54347 L .413 0 .697 r

F P

0 g

s

.72435 .57436 m .74964 .57698 L .793 .53662 L p .736 0 1 r

F P

0 g

s

.793 .53662 m .76702 .53384 L .72435 .57436 L p .736 0 1 r

F P

0 g

s

.86037 .52823 m .8133 .52314 L p .79316 .54181 L 0 .872 1 r

F P

0 g

s

.74977 .58204 m .8254 .54525 L .79316 .54181 L 0 .872 1 r

F

.8254 .54525 m .86037 .52823 L .79316 .54181 L F

.72446 .57943 m .72435 .57436 L p .74876 .58193 L .845 0 .756 r

F P

0 g

s

.72435 .57436 m .68411 .61256 L .70876 .61503 L p .736 0 1 r

F P

0 g

s

.68411 .61256 m .72435 .57436 L .72446 .57943 L p .405 0 .693 r

F P

0 g

s

.7247 .72882 m .71035 .68882 L .75295 .70511 L 0 .328 .697 r

F

.71144 .73995 m .70876 .61503 L p .70876 .61503 L .844 0 .758 r

F P

0 g

s

.69143 .63613 m .70887 .61996 L p .71035 .68882 L 0 .328 .697 r

F P

0 g

s

.71144 .73995 m .71144 .73995 L p .70876 .61503 L .844 0 .758 r

F P

0 g

s

.75579 .8154 m .69585 .86101 L .69376 .75479 L p 0 .328 .697 r

F P

0 g

s

.69376 .75479 m .69143 .63613 L p .7247 .72882 L 0 .328 .697 r

F P

0 g

s

.75579 .8154 m .69376 .75479 L .7247 .72882 L 0 .328 .697 r

F

.66704 .63373 m .67091 .85899 L .68852 .84531 L p 0 .32 .693 r

F P

0 g

s

.68648 .73769 m .69613 .73856 L p .68913 .72308 L .844 0 .758 r

F P

0 g

s

.69613 .73856 m .71144 .73995 L p .68913 .72308 L .844 0 .758 r

F P

0 g

s

.68913 .72308 m .71144 .73995 L .70876 .61503 L .844 0 .758 r

F

.71144 .73995 m .68648 .73769 L p .72732 .70271 L .721 0 1 r

F P

0 g

s

.75295 .70511 m .71144 .73995 L p .71144 .73995 L .721 0 1 r

F P

0 g

s

.70887 .61996 m .74977 .58204 L p .71035 .68882 L 0 .328 .697 r

F P

0 g

s

.67263 .52375 m .63245 .56485 L .63252 .56996 L p .371 0 .679 r

F P

0 g

s

.72446 .57943 m .63252 .56996 L p .65677 .61477 L 0 .872 1 r

F P

0 g

s

.66704 .63373 m .6842 .6175 L p .65677 .61477 L 0 .872 1 r

F P

0 g

s

.70876 .61503 m .68411 .61256 L .6842 .6175 L p .844 0 .758 r

F P

0 g

s

.68577 .61602 m .68411 .61256 L .72446 .57943 L .405 0 .693 r

F

.6842 .6175 m .72446 .57943 L p .72446 .57943 L 0 .872 1 r

F P

0 g

s

.6842 .6175 m .68411 .61256 L p .68577 .61602 L .405 0 .693 r

F P

0 g

s

.65677 .61477 m .6842 .6175 L .72446 .57943 L 0 .872 1 r

F

.6842 .6175 m .6842 .6175 L .72446 .57943 L F

.6842 .6175 m .68648 .73769 L p .70788 .61987 L .844 0 .758 r

F P

0 g

s

.70788 .61987 m .70876 .61503 L .6842 .6175 L .844 0 .758 r

F

.72446 .57943 m .6842 .6175 L p .69953 .72651 L 0 .32 .693 r

F P

0 g

s

.69953 .72651 m .6842 .6175 L .68551 .68648 L 0 .32 .693 r

F

.75295 .70511 m .71035 .68882 L .74977 .58204 L 0 .328 .697 r

F

.72732 .70271 m .72446 .57943 L p .69953 .72651 L 0 .32 .693 r

F P

0 g

s

.69953 .72651 m .68551 .68648 L .68648 .73769 L 0 .32 .693 r

F

.72446 .57943 m .72732 .70271 L p .72732 .70271 L 0 .669 .756 r

F P

0 g

s

.72732 .70271 m .68648 .73769 L .6842 .6175 L p .405 0 .693 r

F P

0 g

s

.72732 .70271 m .6842 .6175 L .68577 .61602 L .405 0 .693 r

F

.6842 .6175 m .66704 .63373 L p .68551 .68648 L 0 .32 .693 r

F P

0 g

s

.68551 .68648 m .66704 .63373 L .68852 .84531 L 0 .32 .693 r

F

.72446 .57943 m .72732 .70271 L p .72732 .70271 L .405 0 .693 r

F P

0 g

s

.72732 .70271 m .68577 .61602 L .72446 .57943 L .405 0 .693 r

F

.72732 .70271 m .72446 .57943 L .72446 .57943 L F

.67783 .69809 m .72446 .57943 L .72732 .70271 L 0 .669 .756 r

F

.72446 .57943 m .72446 .57943 L .72732 .70271 L F

.66704 .63373 m .57848 .62502 L .58031 .85165 L p 0 .669 .759 r

F P

0 g

s

.58031 .85165 m .67091 .85899 L .66704 .63373 L p 0 .669 .759 r

F P

0 g

s

.57848 .62502 m .66704 .63373 L p .65677 .61477 L 0 .872 1 r

F P

0 g

s

.63252 .56996 m .59463 .60857 L p .65677 .61477 L 0 .872 1 r

F P

0 g

s

.59463 .60857 m .57848 .62502 L p .65677 .61477 L 0 .872 1 r

F P

0 g

s

.63245 .56485 m .59458 .60359 L p .5961 .60706 L .371 0 .679 r

F P

0 g

s

.63422 .69401 m .63252 .56996 L p .5961 .60706 L .371 0 .679 r

F P

0 g

s

.63252 .56996 m .63245 .56485 L p .5961 .60706 L .371 0 .679 r

F P

0 g

s

.59581 .72948 m .63422 .69401 L p .5961 .60706 L .371 0 .679 r

F P

0 g

s

.59458 .60359 m .59463 .60857 L p .5961 .60706 L .371 0 .679 r

F P

0 g

s

.59463 .60857 m .59581 .72948 L p .5961 .60706 L .371 0 .679 r

F P

0 g

s

.59458 .60359 m .56949 .60108 L .56953 .60606 L p .844 0 .758 r

F P

0 g

s

.60808 .71815 m .59531 .67796 L .63422 .69401 L 0 .291 .679 r

F

.57848 .62502 m .59463 .60857 L p .59531 .67796 L F P

0 g

s

.63574 .8052 m .58031 .85165 L .57945 .74459 L p 0 .291 .679 r

F P

0 g

s

.57945 .74459 m .57848 .62502 L p .60808 .71815 L 0 .291 .679 r

F P

0 g

s

.63574 .8052 m .57945 .74459 L .60808 .71815 L 0 .291 .679 r

F

.60812 .69157 m .63422 .69401 L .59581 .72948 L p .721 0 1 r

F P

0 g

s

.57507 .7276 m .59581 .72948 L .59557 .70525 L p .844 0 .758 r

F P

0 g

s

.59557 .70525 m .59458 .60359 L p .57507 .7276 L .844 0 .758 r

F P

0 g

s

.5704 .72718 m .57507 .7276 L p .59458 .60359 L .844 0 .758 r

F P

0 g

s

.59581 .72948 m .5704 .72718 L .60812 .69157 L p .721 0 1 r

F P

0 g

s

.63422 .69401 m .63574 .8052 L p .60808 .71815 L 0 .291 .679 r

F P

0 g

s

.4627 .84212 m .55492 .84959 L .55367 .62258 L p 0 .669 .759 r

F P

0 g

s

.56953 .60606 m .5704 .72718 L p .59363 .60847 L .844 0 .758 r

F P

0 g

s

.63252 .56996 m .63422 .69401 L p .59531 .67796 L 0 .291 .679 r

F P

0 g

s

.59463 .60857 m .63252 .56996 L p .59531 .67796 L 0 .291 .679 r

F P

0 g

s

.59363 .60847 m .59458 .60359 L .56953 .60606 L .844 0 .758 r

F

.60812 .69157 m .5704 .72718 L .56949 .60108 L p .361 0 .675 r

F P

0 g

s

.55367 .62258 m .55492 .84959 L .60935 .80295 L p 0 .282 .675 r

F P

0 g

s

.59458 .60359 m .63245 .56485 L .60669 .56219 L p .736 0 1 r

F P

0 g

s

.60669 .56219 m .56949 .60108 L .59458 .60359 L p .736 0 1 r

F P

0 g

s

.56949 .60108 m .60669 .56219 L .60812 .69157 L p .361 0 .675 r

F P

0 g

s

.60935 .80295 m .60675 .5673 L .55367 .62258 L p 0 .282 .675 r

F P

0 g

s

.51343 .7948 m .60935 .80295 L .60812 .69157 L p 0 .669 .756 r

F P

0 g

s

.60812 .69157 m .60675 .5673 L p .55771 .68685 L 0 .669 .756 r

F P

0 g

s

.51343 .7948 m .60812 .69157 L .55771 .68685 L 0 .669 .756 r

F

.63574 .8052 m .63252 .56996 L .72446 .57943 L p F P

0 g

s

.72732 .70271 m .72446 .57943 L p .74876 .58193 L .845 0 .756 r

F P

0 g

s

.74964 .57698 m .72435 .57436 L .72732 .70271 L p .845 0 .756 r

F P

0 g

s

.72446 .57943 m .76717 .53904 L p .76717 .53904 L 0 .872 1 r

F P

0 g

s

.72446 .57943 m .72446 .57943 L p .76717 .53904 L 0 .872 1 r

F P

0 g

s

.72435 .57436 m .76702 .53384 L p .76541 .5407 L .405 0 .693 r

F P

0 g

s

.74977 .58204 m .75036 .60473 L p .75734 .57502 L .413 0 .697 r

F P

0 g

s

.75036 .60473 m .75295 .70511 L p .75734 .57502 L .413 0 .697 r

F P

0 g

s

.75295 .70511 m .79137 .54347 L .75734 .57502 L .413 0 .697 r

F

.72732 .70271 m .75295 .70511 L p .71144 .73995 L .721 0 1 r

F P

0 g

s

.75295 .70511 m .75295 .70511 L p .71144 .73995 L .721 0 1 r

F P

0 g

s

.75579 .8154 m .7247 .72882 L .75295 .70511 L 0 .328 .697 r

F

.75579 .8154 m .75579 .8154 L .75018 .59796 L F

.75295 .70511 m .797 .66814 L .79316 .54181 L p .413 0 .697 r

F P

0 g

s

.75295 .70511 m .79316 .54181 L .79137 .54347 L .413 0 .697 r

F

.74977 .58204 m .74977 .58204 L p .75579 .8154 L 0 .328 .697 r

F P

0 g

s

.74876 .58193 m .74977 .58204 L .75295 .70511 L .845 0 .756 r

F

.75295 .70511 m .72732 .70271 L p .74876 .58193 L F P

0 g

s

.74964 .57698 m .74977 .58204 L p .74876 .58193 L .845 0 .756 r

F P

0 g

s

.72732 .70271 m .75295 .70511 L .74964 .57698 L p .845 0 .756 r

F P

0 g

s

.79316 .54181 m .74977 .58204 L p .74977 .58204 L 0 .872 1 r

F P

0 g

s

.8133 .52314 m .8133 .52314 L p .74977 .58204 L 0 .872 1 r

F P

0 g

s

.797 .66814 m .75295 .70511 L .75295 .70511 L p .721 0 1 r

F P

0 g

s

.74977 .58204 m .79316 .54181 L p .77317 .68813 L 0 .328 .697 r

F P

0 g

s

.75295 .70511 m .74977 .58204 L p .77317 .68813 L 0 .328 .697 r

F P

0 g

s

.797 .66814 m .797 .66814 L .75295 .70511 L .721 0 1 r

F

.75579 .8154 m .79316 .54181 L .79536 .61429 L 0 .328 .697 r

F

.86037 .52823 m .79508 .58671 L .80217 .81934 L p 0 .34 .703 r

F P

0 g

s

.80217 .81934 m .86942 .76994 L .86037 .52823 L p 0 .34 .703 r

F P

0 g

s

.8133 .52314 m .82119 .76563 L .80044 .78142 L p 0 .328 .697 r

F P

0 g

s

.80044 .78142 m .75579 .8154 L p .79536 .61429 L 0 .328 .697 r

F P

0 g

s

.79316 .54181 m .797 .66814 L p .797 .66814 L .846 0 .754 r

F P

0 g

s

.79536 .61429 m .8133 .52314 L .80044 .78142 L 0 .328 .697 r

F

.79212 .5417 m .79316 .54181 L .797 .66814 L .846 0 .754 r

F

.79316 .54181 m .79316 .54181 L .797 .66814 L F

.797 .66814 m .797 .66814 L .75295 .70511 L .721 0 1 r

F

.75579 .8154 m .75295 .70511 L p .77317 .68813 L 0 .328 .697 r

F P

0 g

s

.79316 .54181 m .8133 .52314 L p .79536 .61429 L 0 .328 .697 r

F P

0 g

s

.797 .66814 m .77068 .66559 L p .79212 .5417 L .846 0 .754 r

F P

0 g

s

.75305 .70503 m .72732 .70271 L p .797 .66814 L .721 0 1 r

F P

0 g

s

.77068 .66559 m .797 .66814 L p .75719 .68789 L .721 0 1 r

F P

0 g

s

.79212 .5417 m .76717 .53904 L .79212 .5417 L .846 0 .754 r

F

.77068 .66559 m .76717 .53904 L p .79212 .5417 L F P

0 g

s

.76717 .53904 m .76717 .53904 L p .79212 .5417 L .846 0 .754 r

F P

0 g

s

.76702 .53384 m .793 .53662 L p .79212 .5417 L .846 0 .754 r

F P

0 g

s

.76717 .53904 m .76702 .53384 L p .79212 .5417 L .846 0 .754 r

F P

0 g

s

.76918 .61165 m .77718 .66002 L .78699 .52029 L 0 .32 .693 r

F

.79424 .76322 m .79081 .64835 L p .77718 .66002 L F P

0 g

s

.79081 .64835 m .78699 .52029 L p .77718 .66002 L 0 .32 .693 r

F P

0 g

s

.75626 .67794 m .76918 .61165 L .72732 .70271 L 0 .32 .693 r

F

.72732 .70271 m .76054 .67427 L p .76054 .67427 L .721 0 1 r

F P

0 g

s

.72732 .70271 m .76054 .67427 L .75719 .68789 L .721 0 1 r

F

.72732 .70271 m .76054 .67427 L .72732 .70271 L F

.72988 .81319 m .77382 .77908 L p .77068 .66559 L 0 .32 .693 r

F P

0 g

s

.75626 .67794 m .77068 .66559 L .76918 .61165 L 0 .32 .693 r

F

.76054 .67427 m .77068 .66559 L p .75719 .68789 L .721 0 1 r

F P

0 g

s

.72988 .81319 m .77068 .66559 L .75626 .67794 L 0 .32 .693 r

F

.77382 .77908 m .79424 .76322 L p .76918 .61165 L F P

0 g

s

.72446 .57943 m .72732 .70271 L p .76918 .61165 L 0 .32 .693 r

F P

0 g

s

.72732 .70271 m .72988 .81319 L p .75626 .67794 L 0 .32 .693 r

F P

0 g

s

.76717 .53904 m .72446 .57943 L p .76918 .61165 L 0 .32 .693 r

F P

0 g

s

.72732 .70271 m .72446 .57943 L p .76541 .5407 L .405 0 .693 r

F P

0 g

s

.72446 .57943 m .72435 .57436 L p .76541 .5407 L .405 0 .693 r

F P

0 g

s

.77068 .66559 m .72732 .70271 L p .76541 .5407 L .405 0 .693 r

F P

0 g

s

.76702 .53384 m .76717 .53904 L p .76541 .5407 L .405 0 .693 r

F P

0 g

s

.76717 .53904 m .77068 .66559 L p .76541 .5407 L .405 0 .693 r

F P

0 g

s

.76717 .53904 m .78699 .52029 L p .78699 .52029 L 0 .872 1 r

F P

0 g

s

.73826 .53596 m .76717 .53904 L .78699 .52029 L 0 .872 1 r

F

.76717 .53904 m .76717 .53904 L .78699 .52029 L F

.63252 .56996 m .76717 .53904 L .73826 .53596 L F

.63252 .56996 m .72446 .57943 L p .76717 .53904 L F P

0 g

s

.63252 .56996 m .63574 .8052 L p .63574 .8052 L 0 .669 .756 r

F P

0 g

s

.72446 .57943 m .63252 .56996 L p .63422 .69401 L 0 .669 .756 r

F P

0 g

s

.63574 .8052 m .67783 .69809 L .63422 .69401 L 0 .669 .756 r

F

.67783 .69809 m .72446 .57943 L .63422 .69401 L F

.63252 .56996 m .63252 .56996 L p .63574 .8052 L F P

0 g

s

.70666 .51736 m .68225 .51473 L .72202 .47407 L p .745 0 1 r

F P

0 g

s

.72202 .47407 m .74706 .47685 L .70666 .51736 L p .745 0 1 r

F P

0 g

s

.78699 .52029 m .69139 .50996 L .67273 .52898 L p 0 .872 1 r

F P

0 g

s

.67273 .52898 m .63252 .56996 L p .73826 .53596 L 0 .872 1 r

F P

0 g

s

.73826 .53596 m .78699 .52029 L .67273 .52898 L 0 .872 1 r

F

.63422 .69401 m .67501 .65634 L .67273 .52898 L p .371 0 .679 r

F P

0 g

s

.63422 .69401 m .67273 .52898 L .67107 .53067 L .371 0 .679 r

F

.63252 .56996 m .63422 .69401 L p .67107 .53067 L F P

0 g

s

.63252 .56996 m .67273 .52898 L p .65294 .67672 L 0 .291 .679 r

F P

0 g

s

.63422 .69401 m .63252 .56996 L p .65294 .67672 L 0 .291 .679 r

F P

0 g

s

.66144 .66887 m .67273 .52898 L .67404 .60205 L 0 .291 .679 r

F

.63574 .8052 m .65294 .67672 L .66144 .66887 L F

.65294 .67672 m .67273 .52898 L .66144 .66887 L F

.60812 .69157 m .63422 .69401 L .63245 .56485 L p .845 0 .756 r

F P

0 g

s

.63245 .56485 m .63422 .69401 L .60812 .69157 L p .845 0 .756 r

F P

0 g

s

.68648 .73769 m .72732 .70271 L p .72732 .70271 L .721 0 1 r

F P

0 g

s

.68648 .73769 m .68648 .73769 L p .72732 .70271 L .721 0 1 r

F P

0 g

s

.69953 .72651 m .68648 .73769 L .68852 .84531 L 0 .32 .693 r

F

.68852 .84531 m .72988 .81319 L p .69953 .72651 L F P

0 g

s

.72988 .81319 m .63574 .8052 L p .67783 .69809 L 0 .669 .756 r

F P

0 g

s

.72988 .81319 m .72732 .70271 L p .69953 .72651 L 0 .32 .693 r

F P

0 g

s

.72732 .70271 m .72988 .81319 L p .67783 .69809 L 0 .669 .756 r

F P

0 g

s

.63574 .8052 m .72988 .81319 L .72446 .57943 L p 0 .669 .756 r

F P

0 g

s

.69139 .50996 m .69626 .75448 L .67706 .77057 L p 0 .291 .679 r

F P

0 g

s

.67706 .77057 m .63574 .8052 L p .67404 .60205 L 0 .291 .679 r

F P

0 g

s

.67404 .60205 m .69139 .50996 L .67706 .77057 L 0 .291 .679 r

F

.67273 .52898 m .67263 .52375 L p .67107 .53067 L .371 0 .679 r

F P

0 g

s

.66717 .55281 m .67167 .52887 L .67501 .65634 L .846 0 .754 r

F

.67499 .65636 m .63422 .69401 L .63422 .69401 L p .721 0 1 r

F P

0 g

s

.60812 .69157 m .64818 .65374 L .67501 .65634 L p .721 0 1 r

F P

0 g

s

.63574 .8052 m .63422 .69401 L p .65294 .67672 L 0 .291 .679 r

F P

0 g

s

.67273 .52898 m .69139 .50996 L p .67404 .60205 L 0 .291 .679 r

F P

0 g

s

.67501 .65634 m .64818 .65374 L p .66717 .55281 L .846 0 .754 r

F P

0 g

s

.67263 .52375 m .67273 .52898 L p .67167 .52887 L .846 0 .754 r

F P

0 g

s

.67273 .52898 m .67501 .65634 L p .67167 .52887 L .846 0 .754 r

F P

0 g

s

.67107 .53067 m .67263 .52375 L .63252 .56996 L .371 0 .679 r

F

.78699 .52029 m .76717 .53904 L p .76918 .61165 L 0 .32 .693 r

F P

0 g

s

.793 .53662 m .79316 .54181 L p .79212 .5417 L .846 0 .754 r

F P

0 g

s

0 0 0 r

.2615 .48424 m

.2615 .48424 L

s

.2615 .48424 m

.2615 .48424 L

s

.57481 .4527 m

.57481 .4527 L

s

.57481 .4527 m

.57481 .4527 L

s

.52351 .51217 m

.53884 .4944 L

s

.52351 .51217 m

.52351 .51217 L

s

.65277 .50671 m

.69174 .46575 L

s

.72199 .51326 m

.7619 .47357 L

s

.73656 .51484 m

.77684 .47524 L

s

.21141 .26133 m .16569 .25572 L .15792 .4732 L p 0 .669 .759 r

F P

0 g

s

.16569 .25572 m .21141 .26133 L .24947 .1911 L p 0 .844 1 r

F P

0 g

s

0 0 0 r

.72657 .4974 m

.72657 .4974 L

s

.72657 .4974 m

.72657 .4974 L

s

.18916 .47653 m

.18916 .47653 L

s

.18916 .47653 m

.18916 .47653 L

s

.54396 .44926 m

.54396 .44926 L

s

.54396 .44926 m

.54396 .44926 L

s

.54396 .44926 m

.54396 .44926 L

s

.4938 .50901 m

.50725 .49299 L

s

.4938 .50901 m

.4938 .50901 L

s

.77684 .47524 m

.77684 .47524 L

s

.77684 .47524 m

.77684 .47524 L

s

.77684 .47524 m

.77684 .47524 L

s

.17356 .47487 m

.17356 .47487 L

s

.17356 .47487 m

.17356 .47487 L

s

.70185 .49469 m

.70185 .49469 L

s

.70175 .48979 m

.70185 .49469 L

s

.7619 .47357 m

.7619 .47357 L

s

.7619 .47357 m

.7619 .47357 L

s

.7619 .47357 m

.7619 .47357 L

s

.24947 .1911 m .20193 .18499 L .16569 .25572 L p 0 .844 1 r

F P

0 g

s

.15792 .4732 m .16569 .25572 L .20193 .18499 L p 0 .1 .563 r

F P

0 g

s

0 0 0 r

.4089 .49996 m

.42289 .48187 L

s

.4089 .49996 m

.4089 .49996 L

s

.55367 .62258 m .46355 .61371 L .4627 .84212 L p 0 .669 .759 r

F P

0 g

s

.54998 .51063 m .5131 .55251 L .51311 .55765 L p .321 0 .657 r

F P

0 g

s

.55367 .62258 m .60675 .5673 L .51311 .55765 L p 0 .872 1 r

F P

0 g

s

.46355 .61371 m .55367 .62258 L p .54161 .60328 L 0 .872 1 r

F P

0 g

s

.51311 .55765 m .47836 .59696 L .54161 .60328 L 0 .872 1 r

F

.47836 .59696 m .46355 .61371 L p .54161 .60328 L F P

0 g

s

.5131 .55251 m .47837 .59195 L p .47971 .59544 L .321 0 .657 r

F P

0 g

s

.51328 .6827 m .51311 .55765 L p .47971 .59544 L .321 0 .657 r

F P

0 g

s

.51311 .55765 m .5131 .55251 L p .47971 .59544 L .321 0 .657 r

F P

0 g

s

.47809 .71882 m .51328 .6827 L p .47971 .59544 L .321 0 .657 r

F P

0 g

s

.51311 .55765 m .47836 .59696 L p .47836 .59696 L 0 .872 1 r

F P

0 g

s

.51311 .55765 m .47836 .59696 L .51311 .55765 L 0 .872 1 r

F

.47837 .59195 m .5131 .55251 L .5 .55115 L p .736 0 1 r

F P

0 g

s

.5 .55115 m .5131 .55251 L p .51259 .5576 L .845 0 .756 r

F P

0 g

s

.60675 .5673 m .51311 .55765 L .51343 .7948 L p 0 .669 .756 r

F P

0 g

s

.51311 .55765 m .60675 .5673 L p .55771 .68685 L 0 .669 .756 r

F P

0 g

s

.51328 .6827 m .51311 .55765 L .55771 .68685 L 0 .669 .756 r

F

.60669 .56219 m .63245 .56485 L .67263 .52375 L p .736 0 1 r

F P

0 g

s

.63245 .56485 m .60669 .56219 L .60675 .5673 L p .845 0 .756 r

F P

0 g

s

.60675 .5673 m .60812 .69157 L p .63149 .56985 L .845 0 .756 r

F P

0 g

s

.63149 .56985 m .63245 .56485 L .60675 .5673 L .845 0 .756 r

F

.51311 .55765 m .60675 .5673 L .60675 .5673 L p 0 .872 1 r

F P

0 g

s

.60669 .56219 m .63245 .56485 L p .63149 .56985 L .845 0 .756 r

F P

0 g

s

.60812 .69157 m .60675 .5673 L p .63149 .56985 L .845 0 .756 r

F P

0 g

s

.60675 .5673 m .60669 .56219 L p .63149 .56985 L .845 0 .756 r

F P

0 g

s

.67263 .52375 m .64616 .52092 L .60669 .56219 L p .736 0 1 r

F P

0 g

s

.60812 .69157 m .60669 .56219 L .64616 .52092 L p .361 0 .675 r

F P

0 g

s

.64616 .52092 m .64818 .65374 L .60812 .69157 L p .361 0 .675 r

F P

0 g

s

.64616 .52092 m .67263 .52375 L p .67167 .52887 L .846 0 .754 r

F P

0 g

s

.64818 .65374 m .64624 .52616 L p .67167 .52887 L .846 0 .754 r

F P

0 g

s

.64624 .52616 m .64616 .52092 L p .67167 .52887 L .846 0 .754 r

F P

0 g

s

.60675 .5673 m .64624 .52616 L p .51311 .55765 L 0 .872 1 r

F P

0 g

s

.64624 .52616 m .66459 .50706 L p .61679 .52302 L 0 .872 1 r

F P

0 g

s

.51311 .55765 m .64624 .52616 L .61679 .52302 L 0 .872 1 r

F

.59362 .50518 m .56879 .50251 L .60557 .46112 L p .745 0 1 r

F P

0 g

s

.60557 .46112 m .63107 .46396 L .59362 .50518 L p .745 0 1 r

F P

0 g

s

.66459 .50706 m .56715 .49652 L .55001 .51591 L p 0 .872 1 r

F P

0 g

s

.55001 .51591 m .51311 .55765 L p .61679 .52302 L 0 .872 1 r

F P

0 g

s

.61679 .52302 m .66459 .50706 L .55001 .51591 L 0 .872 1 r

F

.51328 .6827 m .55068 .64431 L .55001 .51591 L p .321 0 .657 r

F P

0 g

s

.55001 .51591 m .54998 .51063 L p .54849 .51763 L .321 0 .657 r

F P

0 g

s

.51328 .6827 m .55001 .51591 L .54849 .51763 L .321 0 .657 r

F

.51328 .6827 m .5131 .55251 L p .5131 .55251 L .845 0 .756 r

F P

0 g

s

.47836 .59696 m .47809 .71882 L p .47971 .59544 L .321 0 .657 r

F P

0 g

s

.48933 .70729 m .4782 .6669 L .51328 .6827 L 0 .248 .657 r

F

.47809 .71882 m .47837 .59195 L p .47837 .59195 L .844 0 .758 r

F P

0 g

s

.46355 .61371 m .47836 .59696 L p .4782 .6669 L 0 .248 .657 r

F P

0 g

s

.47809 .71882 m .47809 .71882 L p .47837 .59195 L .844 0 .758 r

F P

0 g

s

.51343 .7948 m .4627 .84212 L .4631 .7342 L p 0 .248 .657 r

F P

0 g

s

.4631 .7342 m .46355 .61371 L p .48933 .70729 L 0 .248 .657 r

F P

0 g

s

.51343 .7948 m .4631 .7342 L .48933 .70729 L 0 .248 .657 r

F

.47837 .59195 m .46561 .59067 L .4656 .59569 L p .844 0 .758 r

F P

0 g

s

.4656 .59569 m .46516 .71765 L p .47785 .59691 L .844 0 .758 r

F P

0 g

s

.47785 .59691 m .47837 .59195 L .4656 .59569 L .844 0 .758 r

F

.43685 .84002 m .4383 .61123 L .34658 .6022 L p 0 .669 .759 r

F P

0 g

s

.34658 .6022 m .4383 .61123 L .45281 .59441 L p 0 .872 1 r

F P

0 g

s

.46561 .59067 m .45283 .58939 L p .45332 .59447 L .844 0 .758 r

F P

0 g

s

.46516 .71765 m .4656 .59569 L p .45332 .59447 L .844 0 .758 r

F P

0 g

s

.4656 .59569 m .46561 .59067 L p .45332 .59447 L .844 0 .758 r

F P

0 g

s

.5 .68146 m .51328 .6827 L .47809 .71882 L p .721 0 1 r

F P

0 g

s

.46516 .71765 m .47393 .71845 L p .46846 .68632 L .844 0 .758 r

F P

0 g

s

.47393 .71845 m .47809 .71882 L p .46846 .68632 L .844 0 .758 r

F P

0 g

s

.46846 .68632 m .47809 .71882 L .47837 .59195 L .844 0 .758 r

F

.47809 .71882 m .46516 .71765 L .5 .68146 L p .721 0 1 r

F P

0 g

s

.51328 .6827 m .4782 .6669 L .51311 .55765 L 0 .248 .657 r

F

.47836 .59696 m .51311 .55765 L p .4782 .6669 L F P

0 g

s

.47837 .59195 m .47836 .59696 L p .47971 .59544 L .321 0 .657 r

F P

0 g

s

.5 .55115 m .46561 .59067 L .47837 .59195 L p .736 0 1 r

F P

0 g

s

.45283 .58939 m .46561 .59067 L .5 .55115 L p .736 0 1 r

F P

0 g

s

.46561 .59067 m .46516 .71765 L .5 .68146 L p .315 0 .654 r

F P

0 g

s

.5 .68146 m .5 .55115 L .46561 .59067 L p .315 0 .654 r

F P

0 g

s

.46561 .59067 m .5 .55115 L .5 .68146 L p .315 0 .654 r

F P

0 g

s

.5 .68146 m .46516 .71765 L .46561 .59067 L p .315 0 .654 r

F P

0 g

s

.45247 .66446 m .4383 .61123 L .45168 .82584 L 0 .237 .651 r

F

.45283 .58939 m .45221 .71648 L .45221 .71648 L p .844 0 .758 r

F P

0 g

s

.45221 .71648 m .46516 .71765 L p .45283 .58939 L .844 0 .758 r

F P

0 g

s

.45283 .58939 m .45283 .58939 L .45221 .71648 L .844 0 .758 r

F

.4383 .61123 m .43685 .84002 L .45168 .82584 L p 0 .237 .651 r

F P

0 g

s

.5 .68146 m .46516 .71765 L .45221 .71648 L p .721 0 1 r

F P

0 g

s

.45221 .71648 m .48669 .68021 L .5 .68146 L p .721 0 1 r

F P

0 g

s

.5 .55115 m .48687 .5498 L .45283 .58939 L p .736 0 1 r

F P

0 g

s

.48686 .55495 m .45281 .59441 L p .47034 .69741 L 0 .237 .651 r

F P

0 g

s

.48654 .79252 m .48669 .68021 L p .47034 .69741 L 0 .237 .651 r

F P

0 g

s

.48669 .68021 m .48686 .55495 L p .47034 .69741 L 0 .237 .651 r

F P

0 g

s

.45168 .82584 m .48654 .79252 L p .46322 .7049 L 0 .237 .651 r

F P

0 g

s

.46322 .7049 m .45247 .66446 L .45221 .71648 L 0 .237 .651 r

F

.46322 .7049 m .45221 .71648 L .45168 .82584 L F

.34658 .6022 m .34294 .83241 L .43685 .84002 L p 0 .669 .759 r

F P

0 g

s

.48654 .79252 m .45281 .59441 L .45247 .66446 L 0 .237 .651 r

F

.48669 .68021 m .45221 .71648 L .45281 .59441 L p .309 0 .651 r

F P

0 g

s

.45281 .59441 m .45283 .58939 L p .45413 .59288 L .309 0 .651 r

F P

0 g

s

.48669 .68021 m .45281 .59441 L .45413 .59288 L .309 0 .651 r

F

.48669 .68021 m .48686 .55495 L p .48686 .55495 L 0 .669 .756 r

F P

0 g

s

.45281 .59441 m .4383 .61123 L p .45247 .66446 L 0 .237 .651 r

F P

0 g

s

.45281 .59441 m .48686 .55495 L p .48686 .55495 L 0 .872 1 r

F P

0 g

s

.48687 .5498 m .48669 .68021 L p .48669 .68021 L .309 0 .651 r

F P

0 g

s

.48686 .55495 m .45281 .59441 L .45281 .59441 L 0 .872 1 r

F

.45283 .58939 m .48687 .5498 L p .48686 .55495 L .309 0 .651 r

F P

0 g

s

.22751 .59049 m .32088 .59967 L .33398 .58256 L p 0 .872 1 r

F P

0 g

s

.36007 .5801 m .33407 .5775 L p .33502 .58266 L .844 0 .758 r

F P

0 g

s

.35999 .58515 m .34658 .6022 L p .38869 .58802 L 0 .872 1 r

F P

0 g

s

.38869 .58802 m .34658 .6022 L .45281 .59441 L 0 .872 1 r

F

.48686 .55495 m .39149 .54512 L .39149 .54512 L p F P

0 g

s

.39149 .54512 m .35999 .58515 L p .48686 .55495 L 0 .872 1 r

F P

0 g

s

.39155 .53994 m .36482 .53717 L .33407 .5775 L p .736 0 1 r

F P

0 g

s

.39155 .53994 m .36482 .53717 L p .36582 .54247 L .845 0 .756 r

F P

0 g

s

.48686 .55495 m .35999 .58515 L .38869 .58802 L 0 .872 1 r

F

.45413 .59288 m .45283 .58939 L .48686 .55495 L .309 0 .651 r

F

.48686 .55495 m .38869 .58802 L .45281 .59441 L 0 .872 1 r

F

.39007 .67118 m .3888 .78421 L p .44178 .67601 L 0 .669 .756 r

F P

0 g

s

.39149 .54512 m .3888 .78421 L p .3888 .78421 L 0 .195 .628 r

F P

0 g

s

.34658 .6022 m .39149 .54512 L p .3888 .78421 L 0 .195 .628 r

F P

0 g

s

.39149 .54512 m .39007 .67118 L p .44178 .67601 L 0 .669 .756 r

F P

0 g

s

.39149 .54512 m .39149 .54512 L p .3888 .78421 L 0 .195 .628 r

F P

0 g

s

.33407 .5775 m .36007 .5801 L .39155 .53994 L p .736 0 1 r

F P

0 g

s

.39007 .67118 m .39155 .53994 L .36007 .5801 L p .26 0 .628 r

F P

0 g

s

.39007 .67118 m .39149 .54512 L p .36582 .54247 L .845 0 .756 r

F P

0 g

s

.39149 .54512 m .39155 .53994 L p .36582 .54247 L .845 0 .756 r

F P

0 g

s

.3888 .78421 m .34294 .83241 L .34658 .6022 L p 0 .195 .628 r

F P

0 g

s

.35822 .70797 m .35999 .58515 L p .33502 .58266 L .844 0 .758 r

F P

0 g

s

.35999 .58515 m .36007 .5801 L p .33502 .58266 L .844 0 .758 r

F P

0 g

s

.36007 .5801 m .35822 .70797 L .39007 .67118 L p .26 0 .628 r

F P

0 g

s

.33407 .5775 m .33187 .70559 L .35822 .70797 L p .844 0 .758 r

F P

0 g

s

.32088 .59967 m .31662 .83028 L .32998 .81584 L p 0 .182 .621 r

F P

0 g

s

.33277 .65316 m .32088 .59967 L .32998 .81584 L 0 .182 .621 r

F

.39007 .67118 m .35822 .70797 L .33187 .70559 L p .721 0 1 r

F P

0 g

s

.36475 .54236 m .33398 .58256 L p .34823 .68616 L 0 .182 .621 r

F P

0 g

s

.33187 .70559 m .36298 .66865 L .39007 .67118 L p .721 0 1 r

F P

0 g

s

.32998 .81584 m .36139 .78189 L p .3418 .69379 L 0 .182 .621 r

F P

0 g

s

.3418 .69379 m .33187 .70559 L .32998 .81584 L 0 .182 .621 r

F

.31662 .83028 m .32088 .59967 L .22751 .59049 L p 0 .669 .759 r

F P

0 g

s

.22751 .59049 m .22099 .82253 L .31662 .83028 L p 0 .669 .759 r

F P

0 g

s

.36139 .78189 m .26177 .77342 L .26452 .65944 L p 0 .669 .756 r

F P

0 g

s

.33407 .5775 m .36482 .53717 L .36475 .54236 L p .245 0 .621 r

F P

0 g

s

.33518 .581 m .33407 .5775 L .36475 .54236 L .245 0 .621 r

F

.36298 .66865 m .36475 .54236 L p .34823 .68616 L 0 .182 .621 r

F P

0 g

s

.3418 .69379 m .33277 .65316 L .33187 .70559 L 0 .182 .621 r

F

.36139 .78189 m .33398 .58256 L .33277 .65316 L F

.36298 .66864 m .33187 .70559 L .33407 .5775 L p .245 0 .621 r

F P

0 g

s

.36139 .78189 m .36298 .66865 L p .34823 .68616 L 0 .182 .621 r

F P

0 g

s

.36298 .66865 m .36139 .78189 L p .31722 .66437 L 0 .669 .756 r

F P

0 g

s

.33398 .58256 m .36475 .54236 L p .2687 .57604 L 0 .872 1 r

F P

0 g

s

.36475 .54236 m .36298 .66864 L p .33518 .581 L .245 0 .621 r

F P

0 g

s

.33398 .58256 m .32088 .59967 L p .33277 .65316 L 0 .182 .621 r

F P

0 g

s

.2687 .57604 m .22751 .59049 L .33398 .58256 L 0 .872 1 r

F

.36475 .54236 m .26759 .53235 L p .23948 .57313 L F P

0 g

s

.23948 .57313 m .22751 .59049 L p .22751 .59049 L 0 .872 1 r

F P

0 g

s

.2687 .57604 m .23948 .57313 L .22751 .59049 L 0 .872 1 r

F

.23948 .57313 m .23948 .57313 L .22751 .59049 L F

.26772 .52713 m .23962 .56804 L p .24057 .57154 L .186 0 .591 r

F P

0 g

s

.36475 .54236 m .23948 .57313 L .2687 .57604 L 0 .872 1 r

F

.26452 .65944 m .26759 .53235 L p .24057 .57154 L .186 0 .591 r

F P

0 g

s

.26759 .53235 m .26772 .52713 L p .24057 .57154 L .186 0 .591 r

F P

0 g

s

.23614 .69692 m .26452 .65944 L p .24057 .57154 L .186 0 .591 r

F P

0 g

s

.23962 .56804 m .23948 .57313 L p .24057 .57154 L .186 0 .591 r

F P

0 g

s

.23948 .57313 m .23614 .69692 L p .24057 .57154 L .186 0 .591 r

F P

0 g

s

.26759 .53235 m .23948 .57313 L p .23948 .57313 L 0 .872 1 r

F P

0 g

s

.26759 .53235 m .26759 .53235 L p .23948 .57313 L 0 .872 1 r

F P

0 g

s

.23962 .56804 m .21314 .56539 L p .21405 .57059 L .844 0 .758 r

F P

0 g

s

.23614 .69692 m .23948 .57313 L p .23948 .57313 L .844 0 .758 r

F P

0 g

s

.22751 .59049 m .23948 .57313 L p .23757 .64416 L 0 .131 .591 r

F P

0 g

s

.23614 .69692 m .23948 .57313 L .23614 .69692 L .844 0 .758 r

F

.22099 .82253 m .22751 .59049 L p .23757 .64416 L 0 .131 .591 r

F P

0 g

s

.26452 .65944 m .23614 .69692 L .23614 .69692 L p .721 0 1 r

F P

0 g

s

.24521 .68496 m .23614 .69692 L .23757 .64416 L 0 .131 .591 r

F

.23316 .80788 m .22099 .82253 L p .23217 .70217 L F P

0 g

s

.23614 .69692 m .23217 .70217 L .23757 .64416 L 0 .131 .591 r

F

.23316 .80788 m .23217 .70217 L .23614 .69692 L F

.20134 .58791 m .19418 .82035 L .20601 .80564 L p 0 .115 .582 r

F P

0 g

s

.20931 .6945 m .23614 .69692 L p .21405 .57059 L .844 0 .758 r

F P

0 g

s

.21299 .57048 m .20931 .6945 L p .21405 .57059 L .844 0 .758 r

F P

0 g

s

.23614 .69692 m .23948 .57313 L .21405 .57059 L .844 0 .758 r

F

.26452 .65944 m .23614 .69692 L .26452 .65944 L .721 0 1 r

F

.26759 .53235 m .26452 .65944 L p .23757 .64416 L 0 .131 .591 r

F P

0 g

s

.26452 .65944 m .26177 .77342 L p .24521 .68496 L 0 .131 .591 r

F P

0 g

s

.24521 .68496 m .23757 .64416 L .26452 .65944 L 0 .131 .591 r

F

.26452 .65944 m .26759 .53235 L p .31722 .66437 L 0 .669 .756 r

F P

0 g

s

.23948 .57313 m .26759 .53235 L p .23757 .64416 L 0 .131 .591 r

F P

0 g

s

.21314 .56539 m .23962 .56804 L .26772 .52713 L p .736 0 1 r

F P

0 g

s

.26772 .52713 m .24049 .52431 L .21314 .56539 L p .736 0 1 r

F P

0 g

s

.24049 .52431 m .26772 .52713 L .26452 .65944 L p .845 0 .756 r

F P

0 g

s

.26772 .52713 m .24049 .52431 L p .24144 .52966 L .845 0 .756 r

F P

0 g

s

.26452 .65944 m .26759 .53235 L p .24144 .52966 L .845 0 .756 r

F P

0 g

s

.26759 .53235 m .26772 .52713 L p .24144 .52966 L .845 0 .756 r

F P

0 g

s

.27021 .42384 m .24233 .46734 L .21613 .46452 L p .745 0 1 r

F P

0 g

s

.21314 .56539 m .24049 .52431 L .24035 .52954 L p .168 0 .582 r

F P

0 g

s

.23692 .65686 m .26452 .65944 L p .20931 .6945 L .721 0 1 r

F P

0 g

s

.21314 .56539 m .21299 .57048 L p .21405 .57059 L .844 0 .758 r

F P

0 g

s

.23948 .57313 m .23962 .56804 L p .21405 .57059 L .844 0 .758 r

F P

0 g

s

.24035 .52954 m .21299 .57048 L p .22382 .67471 L 0 .115 .582 r

F P

0 g

s

.23614 .69692 m .20931 .6945 L p .26452 .65944 L .721 0 1 r

F P

0 g

s

.21812 .68248 m .21299 .57048 L .21088 .64164 L 0 .115 .582 r

F

.23384 .77105 m .22382 .67471 L .21812 .68248 L F

.22382 .67471 m .21299 .57048 L .21812 .68248 L F

.23384 .77105 m .23692 .65686 L p .22382 .67471 L F P

0 g

s

.23692 .65686 m .24035 .52954 L p .22382 .67471 L 0 .115 .582 r

F P

0 g

s

.24035 .52954 m .23692 .65686 L p .21405 .56889 L .168 0 .582 r

F P

0 g

s

.21405 .56889 m .21314 .56539 L .24035 .52954 L .168 0 .582 r

F

.21299 .57048 m .24035 .52954 L p .24035 .52954 L 0 .872 1 r

F P

0 g

s

.21299 .57048 m .21314 .56539 L p .21405 .56889 L .168 0 .582 r

F P

0 g

s

.24035 .52954 m .17983 .56718 L .21299 .57048 L 0 .872 1 r

F

.24035 .52954 m .21299 .57048 L .21299 .57048 L F

.21812 .68248 m .21088 .64164 L .20931 .6945 L 0 .115 .582 r

F

.23692 .65686 m .20931 .6945 L .21299 .57048 L p .168 0 .582 r

F P

0 g

s

.23692 .65686 m .21299 .57048 L .21405 .56889 L .168 0 .582 r

F

.21405 .56889 m .21405 .56889 L .24035 .52954 L F

.24035 .52954 m .24035 .52954 L p .21405 .56889 L F P

0 g

s

.26956 .48065 m .24049 .52431 L .26772 .52713 L p .736 0 1 r

F P

0 g

s

.26772 .52713 m .29759 .48364 L .26956 .48065 L p .736 0 1 r

F P

0 g

s

.26452 .65944 m .23692 .65686 L .24049 .52431 L p .845 0 .756 r

F P

0 g

s

.20931 .6945 m .23692 .65686 L .23692 .65686 L p .721 0 1 r

F P

0 g

s

.20931 .6945 m .20931 .6945 L .23692 .65686 L .721 0 1 r

F

.15398 .58325 m .20134 .58791 L .21299 .57048 L p 0 .872 1 r

F P

0 g

s

.17983 .56718 m .15398 .58325 L .21299 .57048 L 0 .872 1 r

F

.21299 .57048 m .20134 .58791 L p .21088 .64164 L 0 .115 .582 r

F P

0 g

s

.24035 .52954 m .19103 .52446 L .15398 .58325 L p 0 .872 1 r

F P

0 g

s

.19103 .52446 m .24035 .52954 L .23384 .77105 L p 0 .669 .756 r

F P

0 g

s

.23384 .77105 m .24035 .52954 L .19103 .52446 L p 0 .669 .756 r

F P

0 g

s

.24049 .52431 m .23692 .65686 L .23692 .65686 L p .845 0 .756 r

F P

0 g

s

.23692 .65686 m .26452 .65944 L p .24049 .52431 L .845 0 .756 r

F P

0 g

s

.24049 .52431 m .24049 .52431 L .23692 .65686 L .845 0 .756 r

F

.24035 .52954 m .23384 .77105 L p .23384 .77105 L 0 .115 .582 r

F P

0 g

s

.26759 .53235 m .36475 .54236 L .36298 .66865 L p 0 .669 .756 r

F P

0 g

s

.31722 .66437 m .26759 .53235 L .36298 .66865 L 0 .669 .756 r

F

.29624 .49079 m .29759 .48364 L .26759 .53235 L .186 0 .591 r

F

.26759 .53235 m .36475 .54236 L p .32839 .4923 L 0 .872 1 r

F P

0 g

s

.32839 .4923 m .31137 .46886 L .29747 .48901 L 0 .872 1 r

F

.32839 .4923 m .29747 .48901 L .26759 .53235 L F

.36139 .78189 m .36475 .54236 L .26759 .53235 L p 0 .669 .756 r

F P

0 g

s

.26759 .53235 m .26452 .65944 L p .26452 .65944 L 0 .669 .756 r

F P

0 g

s

.36139 .78189 m .26452 .65944 L .31722 .66437 L 0 .669 .756 r

F

.26177 .77342 m .36139 .78189 L p .31722 .66437 L F P

0 g

s

.31722 .66437 m .26759 .53235 L .26452 .65944 L 0 .669 .756 r

F

.31722 .66437 m .26452 .65944 L .26177 .77342 L F

.26759 .53235 m .26452 .65944 L p .26452 .65944 L .186 0 .591 r

F P

0 g

s

.26759 .53235 m .26759 .53235 L .26177 .77342 L 0 .669 .756 r

F

.26452 .65944 m .29624 .49079 L .26759 .53235 L .186 0 .591 r

F

.26452 .65944 m .26759 .53235 L .26759 .53235 L F

.26177 .77342 m .26177 .77342 L p .26452 .65944 L 0 .669 .756 r

F P

0 g

s

.26452 .65944 m .26177 .77342 L p .26452 .65944 L 0 .669 .756 r

F P

0 g

s

.26452 .65944 m .29472 .61956 L .29759 .48364 L p .186 0 .591 r

F P

0 g

s

.31137 .46886 m .31137 .46886 L .29747 .48901 L 0 .872 1 r

F

.29747 .48901 m .29747 .48901 L .26759 .53235 L F

.26759 .53235 m .29747 .48901 L p .27838 .64114 L 0 .131 .591 r

F P

0 g

s

.26177 .77342 m .26452 .65944 L p .27838 .64114 L 0 .131 .591 r

F P

0 g

s

.26452 .65944 m .26759 .53235 L p .27838 .64114 L 0 .131 .591 r

F P

0 g

s

.29472 .61956 m .26452 .65944 L p .26452 .65944 L .721 0 1 r

F P

0 g

s

.29472 .61956 m .29472 .61956 L p .26452 .65944 L .721 0 1 r

F P

0 g

s

.26177 .77342 m .29747 .48901 L .29589 .5639 L 0 .131 .591 r

F

.31137 .46886 m .30642 .71967 L .29224 .73674 L p F P

0 g

s

.29224 .73674 m .26177 .77342 L p .29589 .5639 L 0 .131 .591 r

F P

0 g

s

.29747 .48901 m .29472 .61956 L p .29472 .61956 L .846 0 .754 r

F P

0 g

s

.29589 .5639 m .31137 .46886 L .29224 .73674 L 0 .131 .591 r

F

.31137 .46886 m .26759 .53235 L .26759 .53235 L p 0 .872 1 r

F P

0 g

s

.29759 .48364 m .26772 .52713 L .26759 .53235 L p .186 0 .591 r

F P

0 g

s

.25651 .63014 m .26763 .56104 L .23692 .65686 L 0 .115 .582 r

F

.29472 .61956 m .26629 .61681 L p .26943 .48602 L .846 0 .754 r

F P

0 g

s

.29472 .61956 m .26943 .48602 L .27056 .48614 L .846 0 .754 r

F

.23692 .65686 m .26848 .52589 L .24035 .52954 L 0 .115 .582 r

F

.26943 .48602 m .26956 .48065 L p .27056 .48614 L .846 0 .754 r

F P

0 g

s

.29472 .61956 m .27056 .48614 L .29747 .48901 L .846 0 .754 r

F

.26956 .48065 m .29759 .48364 L .29747 .48901 L p F P

0 g

s

.26629 .61681 m .29472 .61956 L p .26452 .65944 L .721 0 1 r

F P

0 g

s

.27056 .48614 m .26956 .48065 L .29747 .48901 L .846 0 .754 r

F

.26763 .56104 m .2707 .6108 L .28296 .46578 L 0 .115 .582 r

F

.27726 .71707 m .27996 .59818 L p .2707 .6108 L F P

0 g

s

.27996 .59818 m .28296 .46578 L p .2707 .6108 L 0 .115 .582 r

F P

0 g

s

.26452 .65944 m .24235 .65737 L p .26629 .61681 L .721 0 1 r

F P

0 g

s

.26177 .77342 m .23316 .80788 L p .23614 .69692 L 0 .131 .591 r

F P

0 g

s

.26177 .77342 m .23614 .69692 L .24521 .68496 L 0 .131 .591 r

F

.23384 .77105 m .26347 .73421 L p .26763 .56104 L 0 .115 .582 r

F P

0 g

s

.26347 .73421 m .27726 .71707 L p .26763 .56104 L 0 .115 .582 r

F P

0 g

s

.24035 .52954 m .26943 .48602 L .24035 .52954 L 0 .872 1 r

F

.28296 .46578 m .26943 .48602 L p .26848 .52589 L 0 .115 .582 r

F P

0 g

s

.26943 .48602 m .24035 .52954 L p .26848 .52589 L 0 .115 .582 r

F P

0 g

s

.26763 .56104 m .28296 .46578 L .26848 .52589 L 0 .115 .582 r

F

.26763 .56104 m .26848 .52589 L .23692 .65686 L F

.26629 .61681 m .26943 .48602 L p .26943 .48602 L .846 0 .754 r

F P

0 g

s

.26629 .61681 m .26629 .61681 L p .26943 .48602 L .846 0 .754 r

F P

0 g

s

.29472 .61956 m .29747 .48901 L .29747 .48901 L .846 0 .754 r

F

.29747 .48901 m .31137 .46886 L p .29589 .5639 L 0 .131 .591 r

F P

0 g

s

.23692 .65686 m .26629 .61681 L p .26629 .61681 L .721 0 1 r

F P

0 g

s

.23692 .65686 m .23692 .65686 L p .26629 .61681 L .721 0 1 r

F P

0 g

s

.23384 .77105 m .25651 .63014 L .23692 .65686 L 0 .115 .582 r

F

.24035 .52954 m .24035 .52954 L p .23384 .77105 L F P

0 g

s

.24035 .52954 m .28296 .46578 L .28296 .46578 L p 0 .872 1 r

F P

0 g

s

.23692 .65686 m .24049 .52431 L .26956 .48065 L p .168 0 .582 r

F P

0 g

s

.26956 .48065 m .26629 .61681 L .23692 .65686 L p .168 0 .582 r

F P

0 g

s

.28296 .46578 m .23152 .46022 L p .24035 .52954 L 0 .872 1 r

F P

0 g

s

.20601 .80564 m .23384 .77105 L p .21812 .68248 L 0 .115 .582 r

F P

0 g

s

.21812 .68248 m .20931 .6945 L .20601 .80564 L 0 .115 .582 r

F

.21088 .64164 m .20134 .58791 L .20601 .80564 L F

.48669 .68021 m .45413 .59288 L .48686 .55495 L .309 0 .651 r

F

.48686 .55495 m .4868 .55494 L p .44178 .67601 L 0 .669 .756 r

F P

0 g

s

.4868 .55494 m .39149 .54512 L p .39149 .54512 L 0 .669 .756 r

F P

0 g

s

.44178 .67601 m .4868 .55494 L .39149 .54512 L 0 .669 .756 r

F

.48669 .68021 m .48686 .55495 L .44178 .67601 L F

.48669 .68021 m .48686 .55495 L .48669 .68021 L F

.3888 .78421 m .48654 .79252 L p .44178 .67601 L F P

0 g

s

.48654 .79252 m .48669 .68021 L p .44178 .67601 L 0 .669 .756 r

F P

0 g

s

.51343 .7948 m .48933 .70729 L .51328 .6827 L 0 .248 .657 r

F

.51311 .55765 m .51311 .55765 L .51328 .6827 L .845 0 .756 r

F

.51311 .55765 m .51311 .55765 L p .51343 .7948 L 0 .248 .657 r

F P

0 g

s

.51259 .5576 m .51311 .55765 L .51328 .6827 L .845 0 .756 r

F

.51328 .6827 m .5 .68146 L p .51259 .5576 L F P

0 g

s

.5131 .55251 m .51311 .55765 L p .51259 .5576 L .845 0 .756 r

F P

0 g

s

.5 .68146 m .51328 .6827 L p .5131 .55251 L .845 0 .756 r

F P

0 g

s

.51328 .6827 m .51328 .6827 L p .5131 .55251 L .845 0 .756 r

F P

0 g

s

.51311 .55765 m .51328 .6827 L p .51328 .6827 L 0 .248 .657 r

F P

0 g

s

.51328 .6827 m .51311 .55765 L p .51311 .55765 L 0 .669 .756 r

F P

0 g

s

.51328 .6827 m .51311 .55765 L .51328 .6827 L 0 .669 .756 r

F

.51328 .6827 m .55771 .68685 L .55771 .68685 L F

.51311 .55765 m .51328 .6827 L p .54849 .51763 L .321 0 .657 r

F P

0 g

s

.51343 .7948 m .51328 .6827 L p .55771 .68685 L 0 .669 .756 r

F P

0 g

s

.55068 .64431 m .51328 .6827 L .51328 .6827 L p .721 0 1 r

F P

0 g

s

.55068 .64431 m .55068 .64431 L .51328 .6827 L .721 0 1 r

F

.53824 .65709 m .55001 .51591 L .55039 .58957 L 0 .248 .657 r

F

.51343 .7948 m .53045 .66508 L .53824 .65709 L F

.53045 .66508 m .55001 .51591 L .53824 .65709 L F

.51311 .55765 m .55001 .51591 L p .53045 .66508 L F P

0 g

s

.51311 .55765 m .51328 .6827 L p .51328 .6827 L .845 0 .756 r

F P

0 g

s

.51328 .6827 m .51311 .55765 L p .53045 .66508 L 0 .248 .657 r

F P

0 g

s

.60675 .5673 m .60935 .80295 L .51343 .7948 L p 0 .669 .756 r

F P

0 g

s

.56715 .49652 m .56888 .7431 L .55128 .75952 L p 0 .248 .657 r

F P

0 g

s

.55128 .75952 m .51343 .7948 L p .55039 .58957 L 0 .248 .657 r

F P

0 g

s

.55001 .51591 m .55068 .64431 L p .55068 .64431 L .846 0 .754 r

F P

0 g

s

.55039 .58957 m .56715 .49652 L .55128 .75952 L 0 .248 .657 r

F

.54947 .51585 m .55001 .51591 L .55068 .64431 L .846 0 .754 r

F

.55001 .51591 m .55001 .51591 L .55068 .64431 L F

.5 .68146 m .53702 .64299 L .55068 .64431 L p .721 0 1 r

F P

0 g

s

.55068 .64431 m .55068 .64431 L .51328 .6827 L .721 0 1 r

F

.51343 .7948 m .51328 .6827 L p .53045 .66508 L 0 .248 .657 r

F P

0 g

s

.55001 .51591 m .56715 .49652 L p .55039 .58957 L 0 .248 .657 r

F P

0 g

s

.55068 .64431 m .53702 .64299 L p .54947 .51585 L .846 0 .754 r

F P

0 g

s

.54998 .51063 m .55001 .51591 L p .54947 .51585 L .846 0 .754 r

F P

0 g

s

.51328 .6827 m .5 .68146 L p .55068 .64431 L .721 0 1 r

F P

0 g

s

.51343 .7948 m .51343 .7948 L .51328 .6827 L 0 .248 .657 r

F

.51328 .6827 m .51343 .7948 L p .51328 .6827 L F P

0 g

s

.5 .68146 m .5 .5563 L p .51259 .5576 L .845 0 .756 r

F P

0 g

s

.5 .5563 m .5 .55115 L p .51259 .5576 L .845 0 .756 r

F P

0 g

s

.54849 .51763 m .54998 .51063 L .51311 .55765 L .321 0 .657 r

F

0 0 0 r

.53884 .4944 m

.57481 .4527 L

s

.62403 .50267 m

.66144 .46236 L

s

.69174 .46575 m

.69174 .46575 L

s

.69174 .46575 m

.69174 .46575 L

s

.68938 .348 m

.69032 .39492 L

s

.69078 .41744 m

.69119 .43801 L

s

.68737 .24733 m

.68938 .348 L

s

.61207 .48487 m

.61207 .48487 L

s

.61207 .48487 m

.61207 .48487 L

s

.42433 .43591 m

.42433 .43591 L

s

.42433 .43591 m

.42433 .43591 L

s

.37867 .49673 m

.37867 .49673 L

s

.66144 .46236 m

.66144 .46236 L

s

.66144 .46236 m

.66144 .46236 L

s

.58691 .48211 m

.58691 .48211 L

s

.58687 .47718 m

.58691 .48211 L

s

.70185 .49469 m

.70185 .49469 L

s

.70185 .49469 m

.70185 .49469 L

s

.70185 .49469 m

.72657 .4974 L

s

.72657 .4974 m

.72657 .4974 L

s

.72657 .4974 m

.72657 .4974 L

s

.72493 .59976 m

.72493 .59976 L

s

.66261 .39167 m .65871 .16409 L .60309 .23651 L p 0 .282 .675 r

F P

0 g

s

0 0 0 r

.60448 .36215 m

.60448 .36215 L

s

.72553 .6253 m

.72553 .6253 L

s

.33449 .42589 m

.33449 .42589 L

s

.33449 .42589 m

.33449 .42589 L

s

.2951 .48338 m

.33449 .42589 L

s

.7405 .86463 m .69585 .86101 L .75579 .8154 L p 0 .893 1 r

F P

0 g

s

0 0 0 r

.71077 .86222 m

.71077 .86222 L

s

.71077 .86222 m

.71077 .86222 L

s

.72565 .86343 m

.72565 .86343 L

s

.72565 .86343 m

.72565 .86343 L

s

.75579 .8154 m .80217 .81934 L .7405 .86463 L p 0 .893 1 r

F P

0 g

s

.47859 .49279 m .46597 .49143 L .5 .44938 L p .745 0 1 r

F P

0 g

s

0 0 0 r

.47228 .49211 m

.47228 .49211 L

s

.47228 .49211 m

.47228 .49211 L

s

.5 .44938 m .51297 .45083 L .47859 .49279 L p .745 0 1 r

F P

0 g

s

0 0 0 r

.47228 .49211 m

.47228 .49211 L

s

.36767 .33402 m

.36767 .33402 L

s

.57481 .4527 m

.57481 .4527 L

s

.57481 .4527 m

.57481 .4527 L

s

.57481 .4527 m

.57481 .4527 L

s

.57481 .4527 m

.57481 .4527 L

s

.57388 .33407 m

.57425 .38133 L

s

.57309 .23265 m

.57388 .33407 L

s

.71974 .37584 m

.71974 .37584 L

s

.5 .44938 m .46597 .49143 L .45332 .49007 L p .745 0 1 r

F P

0 g

s

0 0 0 r

.45964 .49075 m

.45964 .49075 L

s

.45964 .49075 m

.45964 .49075 L

s

.72565 .86343 m

.72565 .86343 L

s

.45964 .49075 m

.45964 .49075 L

s

.45332 .49007 m .48701 .44794 L .5 .44938 L p .745 0 1 r

F P

0 g

s

0 0 0 r

.49553 .47212 m

.49553 .47212 L

s

.49553 .47212 m

.49553 .47212 L

s

.30249 .42232 m

.30249 .42232 L

s

.30249 .42232 m

.30249 .42232 L

s

.27433 .46485 m

.30249 .42232 L

s

.72612 .65097 m

.72612 .65097 L

s

.71077 .86222 m

.71077 .86222 L

s

.48273 .47072 m

.48273 .47072 L

s

.48273 .47072 m

.48273 .47072 L

s

.71974 .37584 m

.71974 .37584 L

s

.54396 .44926 m

.54396 .44926 L

s

.54396 .44926 m

.54396 .44926 L

s

.54396 .44926 m

.54396 .44926 L

s

.54396 .44926 m

.54396 .44926 L

s

.46992 .46931 m

.46992 .46931 L

s

.46992 .46931 m

.46993 .46434 L

s

.46993 .46434 m

.46993 .46434 L

s

.72672 .67677 m

.72672 .67677 L

s

.67091 .85899 m .58031 .85165 L .63574 .8052 L p 0 .893 1 r

F P

0 g

s

0 0 0 r

.61065 .85411 m

.61065 .85411 L

s

.61065 .85411 m

.61065 .85411 L

s

.63574 .8052 m .72988 .81319 L .67091 .85899 L p 0 .893 1 r

F P

0 g

s

0 0 0 r

.64085 .85655 m

.64085 .85655 L

s

.64085 .85655 m

.64085 .85655 L

s

.58691 .48211 m

.58691 .48211 L

s

.58691 .48211 m

.58691 .48211 L

s

.58691 .48211 m

.61207 .48487 L

s

.61207 .48487 m

.61207 .48487 L

s

.61207 .48487 m

.61207 .48487 L

s

.33791 .42627 m

.33791 .42627 L

s

.22924 .46594 m

.22924 .46594 L

s

.22924 .46594 m

.22924 .46594 L

s

.53611 .40477 m .53563 .27739 L .5 .32515 L p .315 0 .654 r

F P

0 g

s

.48718 .3236 m .5 .32515 L p .52246 .27575 L .755 0 1 r

F P

0 g

s

.48732 .22164 m .48701 .4429 L .48701 .4429 L p 0 .237 .651 r

F P

0 g

s

.48718 .3236 m .5 .32515 L p .48753 .44296 L .845 0 .756 r

F P

0 g

s

.48753 .44296 m .48701 .44794 L .48701 .4429 L .845 0 .756 r

F

.48753 .44296 m .48701 .4429 L .48718 .3236 L F

.5 .32515 m .5 .44938 L .48701 .44794 L p F P

0 g

s

.51297 .45083 m .5 .44938 L .5 .32515 L p .845 0 .756 r

F P

0 g

s

.48701 .4429 m .48701 .4429 L p .48732 .22164 L 0 .237 .651 r

F P

0 g

s

.48701 .44794 m .5 .44938 L .5 .44435 L p .845 0 .756 r

F P

0 g

s

.5 .44435 m .5 .32515 L p .48753 .44296 L .845 0 .756 r

F P

0 g

s

.48753 .44296 m .48701 .44794 L .5 .44435 L .845 0 .756 r

F

.5 .32515 m .48718 .3236 L .48701 .44794 L p F P

0 g

s

.5 .32515 m .5 .44938 L .51297 .45083 L p .845 0 .756 r

F P

0 g

s

.5 .32515 m .5 .44938 L .53611 .40477 L p .315 0 .654 r

F P

0 g

s

.5 .32515 m .53563 .27739 L .52246 .27575 L p .755 0 1 r

F P

0 g

s

.53611 .40477 m .5 .44938 L .5 .32515 L p .315 0 .654 r

F P

0 g

s

.5 .32515 m .53563 .27739 L .53611 .40477 L p .315 0 .654 r

F P

0 g

s

.52246 .27575 m .53563 .27739 L p .52276 .40323 L .846 0 .754 r

F P

0 g

s

.53563 .27739 m .53611 .40477 L .52276 .40323 L p .846 0 .754 r

F P

0 g

s

.53934 .37725 m .53883 .25353 L p .52246 .27575 L 0 .237 .651 r

F P

0 g

s

.51073 .29166 m .52258 .32711 L .52246 .27575 L 0 .237 .651 r

F

.52258 .32711 m .53934 .37725 L .52246 .27575 L F

.52275 .39807 m .52246 .27575 L .52246 .27575 L p .846 0 .754 r

F P

0 g

s

.52276 .40323 m .52276 .40323 L .52246 .27575 L .846 0 .754 r

F

.48701 .4429 m .52275 .39807 L p .51073 .29166 L 0 .237 .651 r

F P

0 g

s

.52275 .39807 m .53934 .37725 L p .52258 .32711 L 0 .237 .651 r

F P

0 g

s

.51073 .29166 m .52275 .39807 L .52258 .32711 L 0 .237 .651 r

F

.48718 .3236 m .48701 .4429 L .51073 .29166 L F

.48732 .22164 m .48701 .4429 L .48732 .22164 L F

.48732 .22164 m .48701 .4429 L .48732 .22164 L F

.48701 .44794 m .48718 .3236 L .48718 .3236 L p .845 0 .756 r

F P

0 g

s

.48701 .44794 m .48701 .44794 L .48718 .3236 L .845 0 .756 r

F

.52276 .40323 m .48701 .44794 L .48701 .4429 L p .309 0 .651 r

F P

0 g

s

.48701 .4429 m .48718 .3236 L p .52128 .39991 L .309 0 .651 r

F P

0 g

s

.52128 .39991 m .52276 .40323 L .48701 .4429 L .309 0 .651 r

F

.48718 .3236 m .52246 .27575 L .52275 .39807 L p F P

0 g

s

.52275 .39807 m .52276 .40323 L p .52128 .39991 L .309 0 .651 r

F P

0 g

s

.48718 .3236 m .52275 .39807 L .52128 .39991 L .309 0 .651 r

F

.52275 .39807 m .48701 .4429 L p .48701 .4429 L 0 .863 1 r

F P

0 g

s

.48701 .4429 m .45582 .39035 L .52275 .39807 L 0 .863 1 r

F

.48701 .4429 m .52275 .39807 L .52275 .39807 L F

.44123 .36577 m .53934 .37725 L .52275 .39807 L p F P

0 g

s

.45582 .39035 m .44123 .36577 L .52275 .39807 L 0 .863 1 r

F

.48732 .22164 m .48718 .3236 L .51073 .29166 L 0 .237 .651 r

F

.52246 .27575 m .48718 .3236 L .48718 .3236 L p .755 0 1 r

F P

0 g

s

.52246 .27575 m .52246 .27575 L .48718 .3236 L .755 0 1 r

F

.53839 .1479 m .48732 .22164 L p .51073 .29166 L 0 .237 .651 r

F P

0 g

s

.53883 .25353 m .53839 .1479 L p .51073 .29166 L 0 .237 .651 r

F P

0 g

s

0 0 0 r

.48714 .34821 m

.48714 .34821 L

s

.48732 .22164 m .53839 .1479 L .44266 .13502 L p 0 .844 1 r

F P

0 g

s

0 0 0 r

.18916 .47653 m

.18916 .47653 L

s

.64085 .85655 m

.64085 .85655 L

s

.35347 .428 m

.35347 .428 L

s

.82042 .43239 m

.82042 .43239 L

s

.77684 .47524 m

.77684 .47524 L

s

.17356 .47487 m

.17356 .47487 L

s

.74376 .45185 m

.74642 .45215 L

s

.3927 .43745 m .36151 .48018 L .33578 .47741 L p .745 0 1 r

F P

0 g

s

0 0 0 r

.34866 .4788 m

.34866 .4788 L

s

.34866 .4788 m

.34866 .4788 L

s

.45575 .43942 m

.45575 .43942 L

s

.80509 .43062 m

.80509 .43062 L

s

.7619 .47357 m

.7619 .47357 L

s

.45575 .43942 m

.45575 .43942 L

s

.45608 .3675 m

.4563 .31988 L

s

.4563 .31988 m

.45677 .21772 L

s

.60448 .36215 m

.60448 .36215 L

s

.20193 .18499 m .1947 .41029 L .15792 .4732 L p 0 .1 .563 r

F P

0 g

s

0 0 0 r

.18916 .47653 m

.20053 .45783 L

s

.34866 .4788 m

.34866 .4788 L

s

.61065 .85411 m

.61065 .85411 L

s

.75301 .41648 m

.75301 .41648 L

s

.33578 .47741 m .36626 .43452 L .3927 .43745 L p .745 0 1 r

F P

0 g

s

0 0 0 r

.37688 .45913 m

.37688 .45913 L

s

.37688 .45913 m

.37688 .45913 L

s

.37867 .49673 m

.42433 .43591 L

s

.34746 .4366 m

.34746 .4366 L

s

.78988 .43393 m .74706 .47685 L .72202 .47407 L p .745 0 1 r

F P

0 g

s

0 0 0 r

.73421 .4616 m

.73434 .46678 L

s

.73455 .47546 m

.73455 .47546 L

s

.73455 .47546 m

.73455 .47546 L

s

.6996 .51084 m

.73455 .47546 L

s

.73455 .47546 m

.73455 .47546 L

s

.73455 .47546 m

.73455 .47546 L

s

.60448 .36215 m

.60448 .36215 L

s

.42433 .43591 m

.42433 .43591 L

s

.42433 .43591 m

.42433 .43591 L

s

.73455 .47546 m

.73455 .47546 L

s

.3508 .45628 m

.3508 .45628 L

s

.3508 .45628 m

.35088 .45127 L

s

.35113 .43521 m

.35124 .42776 L

s

.73963 .32885 m

.73963 .32885 L

s

.73963 .32885 m

.73963 .32885 L

s

.72202 .47407 m .76417 .43097 L .78988 .43393 L p .745 0 1 r

F P

0 g

s

0 0 0 r

.76815 .45571 m

.76815 .45571 L

s

.76815 .45571 m

.76815 .45571 L

s

.73455 .47546 m

.77704 .43245 L

s

.77704 .43245 m

.77704 .43245 L

s

.77684 .47524 m

.82042 .43239 L

s

.7619 .47357 m

.80509 .43062 L

s

.55492 .84959 m .4627 .84212 L .51343 .7948 L p 0 .893 1 r

F P

0 g

s

0 0 0 r

.49358 .84462 m

.49358 .84462 L

s

.49358 .84462 m

.49358 .84462 L

s

.51343 .7948 m .60935 .80295 L .55492 .84959 L p 0 .893 1 r

F P

0 g

s

0 0 0 r

.52433 .84711 m

.52433 .84711 L

s

.52433 .84711 m

.52433 .84711 L

s

.48273 .47072 m

.48273 .47072 L

s

.48273 .47072 m

.49553 .47212 L

s

.49553 .47212 m

.49553 .47212 L

s

.49553 .47212 m

.49553 .47212 L

s

.74278 .45284 m

.74278 .45284 L

s

.74266 .44782 m

.74278 .45284 L

s

.73963 .32885 m

.74146 .4009 L

s

.73963 .32885 m

.73963 .32885 L

s

.73963 .32885 m

.73963 .32885 L

s

.69174 .46575 m

.69174 .46575 L

s

.46992 .46931 m

.46992 .46931 L

s

.46992 .46931 m

.46992 .46931 L

s

.46992 .46931 m

.48273 .47072 L

s

.48273 .47072 m

.48273 .47072 L

s

.36946 .2065 m .41582 .13141 L .31828 .11829 L p 0 .844 1 r

F P

0 g

s

0 0 0 r

.52433 .84711 m

.52433 .84711 L

s

.54221 .27821 m

.54221 .27821 L

s

.54221 .27821 m

.54221 .27821 L

s

.50648 .44508 m

.50648 .44508 L

s

.50648 .44138 m

.50648 .44508 L

s

.50725 .49299 m

.54396 .44926 L

s

.66144 .46236 m

.66144 .46236 L

s

.62569 .43849 m

.63073 .43906 L

s

.49351 .44363 m

.49351 .44363 L

s

.49351 .44363 m

.49351 .43981 L

s

.19418 .82035 m .20134 .58791 L .15398 .58325 L p 0 .669 .759 r

F P

0 g

s

0 0 0 r

.33449 .42589 m

.33449 .42589 L

s

.33449 .42589 m

.33449 .42589 L

s

.33449 .42589 m

.33449 .42589 L

s

.33523 .383 m

.33523 .383 L

s

.33575 .35342 m

.33658 .30544 L

s

.33658 .30544 m

.33837 .20251 L

s

.22924 .46594 m

.22924 .46594 L

s

.49358 .84462 m

.49358 .84462 L

s

.48714 .34821 m

.48714 .34821 L

s

.48714 .34821 m

.48714 .34821 L

s

.21613 .46452 m .24328 .42084 L .27021 .42384 L p .745 0 1 r

F P

0 g

s

0 0 0 r

.25606 .44591 m

.25606 .44591 L

s

.25606 .44591 m

.25606 .44591 L

s

.22924 .46594 m

.23174 .46198 L

s

.22317 .42934 m

.22317 .42934 L

s

.67077 .42024 m .63107 .46396 L .60557 .46112 L p .745 0 1 r

F P

0 g

s

0 0 0 r

.61814 .44699 m

.61822 .4532 L

s

.61833 .46254 m

.61833 .46254 L

s

.61833 .46254 m

.61833 .46254 L

s

.58597 .49855 m

.61833 .46254 L

s

.61833 .46254 m

.61833 .46254 L

s

.61833 .46254 m

.61833 .46254 L

s

.48714 .34821 m

.48714 .34821 L

s

.48714 .34821 m

.48714 .34821 L

s

.30249 .42232 m

.30249 .42232 L

s

.30249 .42232 m

.30249 .42232 L

s

.30249 .42232 m

.30249 .42232 L

s

.61833 .46254 m

.61833 .46254 L

s

.15398 .58325 m .14565 .81642 L .19418 .82035 L p 0 .669 .759 r

F P

0 g

s

.15398 .58325 m .19103 .52446 L .18325 .76675 L p 0 .1 .563 r

F P

0 g

s

.18325 .76675 m .14565 .81642 L .15398 .58325 L p 0 .1 .563 r

F P

0 g

s

0 0 0 r

.2295 .44301 m

.2295 .44301 L

s

.2295 .44301 m

.22965 .43796 L

s

.23002 .42473 m

.23002 .42473 L

s

.62316 .31457 m

.62316 .31457 L

s

.60557 .46112 m .64459 .41723 L .67077 .42024 L p .745 0 1 r

F P

0 g

s

0 0 0 r

.65062 .44242 m

.65062 .44242 L

s

.65062 .44242 m

.65062 .44243 L

s

.61833 .46254 m

.6577 .41874 L

s

.6577 .41874 m

.6577 .41874 L

s

.66144 .46236 m

.70195 .41873 L

s

.48654 .79252 m .43685 .84002 L .34294 .83241 L p 0 .893 1 r

F P

0 g

s

0 0 0 r

.37439 .83496 m

.37439 .83496 L

s

.37439 .83496 m

.37439 .83496 L

s

.40569 .8375 m

.40569 .8375 L

s

.40569 .8375 m

.40569 .8375 L

s

.3508 .45628 m

.3508 .45628 L

s

.3508 .45628 m

.3508 .45628 L

s

.3508 .45628 m

.37688 .45913 L

s

.37688 .45913 m

.37688 .45913 L

s

.37688 .45913 m

.37688 .45913 L

s

.62479 .43951 m

.62479 .43951 L

s

.62472 .43444 m

.62479 .43951 L

s

.62316 .31457 m

.62411 .38717 L

s

.62316 .31457 m

.62316 .31457 L

s

.57481 .4527 m

.57481 .4527 L

s

.72493 .59976 m

.72493 .59976 L

s

.72493 .59976 m

.72493 .59976 L

s

.1947 .41029 m .20193 .18499 L .24947 .1911 L p 0 .669 .756 r

F P

0 g

s

.24947 .1911 m .20193 .18499 L .1947 .41029 L p 0 .669 .756 r

F P

0 g

s

0 0 0 r

.24601 .31957 m

.24601 .31957 L

s

.24601 .31957 m

.24601 .31957 L

s

.24141 .10795 m .20193 .18499 L .24947 .1911 L p 0 .844 1 r

F P

0 g

s

.24947 .1911 m .29093 .11461 L .24141 .10795 L p 0 .844 1 r

F P

0 g

s

0 0 0 r

.40569 .8375 m

.40569 .8375 L

s

.74278 .45284 m

.74278 .45284 L

s

.74278 .45284 m

.74278 .45284 L

s

.74278 .45284 m

.76815 .45571 L

s

.76815 .45571 m

.76815 .45571 L

s

.76815 .45571 m

.76815 .45571 L

s

.80224 .1834 m .8477 .18952 L .85611 .41432 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.81743 .18545 m

.81743 .18545 L

s

.81743 .18545 m

.81743 .18545 L

s

.83258 .18748 m

.83258 .18748 L

s

.83258 .18748 m

.83258 .18748 L

s

.76775 .55991 m

.76775 .55991 L

s

.72493 .59976 m

.76775 .55991 L

s

.72493 .59976 m

.72493 .59976 L

s

.58127 .40481 m

.58127 .40481 L

s

.54396 .44926 m

.54396 .44926 L

s

.69396 .57629 m

.69644 .69983 L

s

.72553 .6253 m

.72553 .6253 L

s

.72553 .6253 m

.72553 .6253 L

s

.83258 .18748 m

.83258 .18748 L

s

.36767 .33402 m

.36767 .33402 L

s

.37439 .83496 m

.37439 .83496 L

s

.81743 .18545 m

.81743 .18545 L

s

.77704 .43245 m

.77704 .43245 L

s

.77689 .42737 m

.77704 .43245 L

s

.77689 .42737 m

.77689 .42737 L

s

.77648 .41312 m

.77689 .42737 L

s

.23485 .34161 m .1947 .41029 L .20193 .18499 L p 0 .1 .563 r

F P

0 g

s

.20193 .18499 m .24141 .10795 L .23485 .34161 L p 0 .1 .563 r

F P

0 g

s

0 0 0 r

.76847 .58611 m

.76847 .58611 L

s

.72553 .6253 m

.76847 .58611 L

s

.72553 .6253 m

.72553 .6253 L

s

.60834 .71142 m

.61473 .71201 L

s

.54944 .4063 m .51297 .45083 L .5 .44938 L p .745 0 1 r

F P

0 g

s

0 0 0 r

.50649 .45011 m

.50649 .45011 L

s

.47228 .49211 m

.50649 .45011 L

s

.50649 .45011 m

.50649 .45011 L

s

.50649 .45011 m

.50649 .45011 L

s

.50649 .45011 m

.50649 .45011 L

s

.72612 .65097 m

.72612 .65097 L

s

.72612 .65097 m

.72612 .65097 L

s

.85611 .41432 m .80958 .40887 L .80224 .1834 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.81743 .18545 m

.82513 .41069 L

s

.82513 .41069 m

.82513 .41069 L

s

.83258 .18748 m

.84064 .41251 L

s

.84064 .41251 m

.84064 .41251 L

s

.82042 .43239 m

.84064 .41251 L

s

.84064 .41251 m

.84064 .41251 L

s

.80509 .43062 m

.82513 .41069 L

s

.82513 .41069 m

.82513 .41069 L

s

.50649 .45011 m

.50649 .45011 L

s

.7814 .33273 m

.78682 .3334 L

s

.52276 .40323 m .53611 .40477 L .5 .44938 L p .745 0 1 r

F P

0 g

s

.5 .44938 m .48701 .44794 L .52276 .40323 L p .745 0 1 r

F P

0 g

s

0 0 0 r

.49351 .44866 m

.49351 .44866 L

s

.49351 .44866 m

.49351 .44866 L

s

.45964 .49075 m

.49351 .44866 L

s

.49351 .44866 m

.49351 .44866 L

s

.49351 .44866 m

.49351 .44866 L

s

.5 .44938 m .53611 .40477 L .54944 .4063 L p .745 0 1 r

F P

0 g

s

0 0 0 r

.50649 .45011 m

.54278 .40553 L

s

.54278 .40553 m

.54278 .40553 L

s

.54396 .44926 m

.58127 .40481 L

s

.34294 .83241 m .3888 .78421 L .48654 .79252 L p 0 .893 1 r

F P

0 g

s

0 0 0 r

.42289 .48187 m

.45575 .43942 L

s

.45575 .43942 m

.45575 .43942 L

s

.45575 .43942 m

.45575 .43942 L

s

.52944 .404 m

.52944 .404 L

s

.49351 .44866 m

.52944 .404 L

s

.49351 .44866 m

.49351 .44866 L

s

.53093 .4289 m

.53093 .4289 L

s

.53093 .4289 m

.53093 .4289 L

s

.7692 .61246 m

.7692 .61246 L

s

.72612 .65097 m

.7692 .61246 L

s

.72612 .65097 m

.72612 .65097 L

s

.68458 .16757 m .77684 .17999 L .78358 .40583 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.74317 .4011 m

.76277 .38036 L

s

.76277 .38036 m

.76277 .38036 L

s

.76277 .38036 m

.76277 .38036 L

s

.7218 .3986 m

.76207 .35525 L

s

.76207 .35525 m

.76207 .35525 L

s

.76207 .35525 m

.76207 .35525 L

s

.71974 .37584 m

.75506 .3372 L

s

.71548 .17173 m

.71548 .17173 L

s

.71548 .17173 m

.71548 .17173 L

s

.74623 .17587 m

.74623 .17587 L

s

.74623 .17587 m

.74623 .17587 L

s

.51779 .42741 m

.51779 .42741 L

s

.50455 .30003 m

.50455 .30003 L

s

.50455 .30003 m

.50455 .30003 L

s

.51779 .42741 m

.51779 .42741 L

s

.72672 .67677 m

.72672 .67677 L

s

.72672 .67677 m

.72672 .67677 L

s

.36139 .78189 m .31662 .83028 L .22099 .82253 L p 0 .893 1 r

F P

0 g

s

0 0 0 r

.25302 .82512 m

.25302 .82512 L

s

.25302 .82512 m

.25302 .82512 L

s

.28489 .82771 m

.28489 .82771 L

s

.28489 .82771 m

.28489 .82771 L

s

.2295 .44301 m

.2295 .44301 L

s

.2295 .44301 m

.2295 .44301 L

s

.2295 .44301 m

.25606 .44591 L

s

.25606 .44591 m

.25606 .44591 L

s

.25606 .44591 m

.25606 .44591 L

s

.76207 .35525 m

.76207 .35525 L

s

.76207 .35525 m

.76207 .35525 L

s

.78214 .35767 m

.78758 .35833 L

s

.50462 .42592 m

.50462 .42592 L

s

.50461 .42082 m

.50462 .42592 L

s

.50461 .42082 m

.50461 .42082 L

s

.50455 .30003 m

.50459 .37318 L

s

.50455 .30003 m

.50455 .30003 L

s

.23978 .55053 m

.23978 .55053 L

s

.23978 .55053 m

.23978 .55053 L

s

.45575 .43942 m

.49669 .3865 L

s

.45575 .43942 m

.45575 .43942 L

s

.66459 .50706 m .60675 .5673 L .60935 .80295 L p 0 .282 .675 r

F P

0 g

s

0 0 0 r

.60783 .66542 m

.60783 .66542 L

s

.60754 .6394 m

.60754 .6394 L

s

.60726 .61353 m

.60726 .61353 L

s

.60697 .58779 m

.60697 .58779 L

s

.60697 .58779 m

.60697 .58779 L

s

.74623 .17587 m

.74623 .17587 L

s

.76994 .63895 m

.76994 .63895 L

s

.72672 .67677 m

.76994 .63895 L

s

.72672 .67677 m

.72672 .67677 L

s

.28489 .82771 m

.28489 .82771 L

s

.62479 .43951 m

.62479 .43951 L

s

.62479 .43951 m

.65062 .44243 L

s

.65062 .44243 m

.65062 .44243 L

s

.65062 .44243 m

.65062 .44243 L

s

.28891 .24664 m

.28891 .24664 L

s

.28891 .24664 m

.28891 .24664 L

s

.60697 .58779 m

.60697 .58779 L

s

.60697 .58779 m

.60697 .58779 L

s

.45831 .39064 m

.46429 .38267 L

s

.42433 .43591 m

.42433 .43591 L

s

.76277 .38036 m

.76277 .38036 L

s

.76277 .38036 m

.76277 .38036 L

s

.78289 .38275 m

.78834 .3834 L

s

.23907 .5769 m

.23907 .5769 L

s

.23907 .5769 m

.23907 .5769 L

s

.57568 .5641 m

.57666 .68863 L

s

.57568 .5641 m

.57568 .5641 L

s

.38295 .41104 m

.39299 .41217 L

s

.60726 .61353 m

.60726 .61353 L

s

.21085 .64244 m

.21085 .64244 L

s

.21085 .64244 m

.21085 .64244 L

s

.71548 .17173 m

.71548 .17173 L

s

.24601 .31957 m

.24601 .31957 L

s

.25302 .82512 m

.25302 .82512 L

s

.6577 .41874 m

.6577 .41874 L

s

.65761 .41362 m

.6577 .41874 L

s

.65761 .41362 m

.65761 .41362 L

s

.65735 .39762 m

.65761 .41362 L

s

.60726 .61353 m

.60726 .61353 L

s

.60726 .61353 m

.60726 .61353 L

s

.78173 .40773 m

.78911 .40859 L

s

.48666 .70023 m

.49542 .70103 L

s

.23836 .6034 m

.23836 .6034 L

s

.23836 .6034 m

.23836 .6034 L

s

.21085 .64244 m

.21138 .64169 L

s

.21085 .64244 m

.21085 .64244 L

s

.21085 .64244 m

.21085 .64244 L

s

.21085 .64244 m

.21085 .64244 L

s

.39863 .38897 m .42581 .39209 L .3927 .43745 L p .745 0 1 r

F P

0 g

s

0 0 0 r

.42433 .43591 m

.45831 .39064 L

s

.3927 .43745 m .36626 .43452 L .39863 .38897 L p .745 0 1 r

F P

0 g

s

0 0 0 r

.3795 .43599 m

.3795 .43599 L

s

.3795 .43599 m

.3795 .43599 L

s

.3795 .43599 m

.3795 .43599 L

s

.3795 .43599 m

.3795 .43599 L

s

.34866 .4788 m

.3795 .43599 L

s

.74867 .68443 m

.74867 .68443 L

s

.74867 .68443 m

.74867 .68443 L

s

.7455 .55954 m

.74867 .68443 L

s

.60754 .6394 m

.60754 .6394 L

s

.78358 .40583 m .6891 .39478 L .68458 .16757 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.71548 .17173 m

.72075 .39848 L

s

.72075 .39848 m

.72075 .39848 L

s

.74623 .17587 m

.75224 .40216 L

s

.75224 .40216 m

.75224 .40216 L

s

.69174 .46575 m

.75224 .40216 L

s

.75224 .40216 m

.75224 .40216 L

s

.70195 .41873 m

.72075 .39848 L

s

.72075 .39848 m

.72075 .39848 L

s

.21008 .6684 m

.21008 .6684 L

s

.21008 .6684 m

.21008 .6684 L

s

.24601 .31957 m

.24601 .31957 L

s

.24601 .31957 m

.24601 .31957 L

s

.66135 .318 m

.66896 .31894 L

s

.41223 .39053 m

.41223 .39053 L

s

.3795 .43599 m

.41223 .39053 L

s

.3795 .43599 m

.3795 .43599 L

s

.22099 .82253 m .26177 .77342 L .36139 .78189 L p 0 .893 1 r

F P

0 g

s

.5 .55115 m .5131 .55251 L .54998 .51063 L p .736 0 1 r

F P

0 g

s

.5131 .55251 m .5 .55115 L .5 .68146 L p .845 0 .756 r

F P

0 g

s

0 0 0 r

.40901 .41512 m

.40901 .41512 L

s

.40901 .41512 m

.40901 .41512 L

s

.38377 .28522 m

.38377 .28522 L

s

.38377 .28522 m

.38377 .28522 L

s

.60754 .6394 m

.60754 .6394 L

s

.60754 .6394 m

.60754 .6394 L

s

.56474 .15145 m .65871 .16409 L .66261 .39167 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.62566 .38735 m

.64381 .36622 L

s

.64381 .36622 m

.64381 .36622 L

s

.60613 .38507 m

.64242 .34212 L

s

.60448 .36215 m

.63542 .32493 L

s

.59621 .15568 m

.59621 .15568 L

s

.59621 .15568 m

.59621 .15568 L

s

.62754 .1599 m

.62754 .1599 L

s

.62754 .1599 m

.62754 .1599 L

s

.48687 .5498 m .5 .55115 L .5 .5563 L p .845 0 .756 r

F P

0 g

s

.48739 .555 m .48687 .5498 L .5 .5563 L .845 0 .756 r

F

.52301 .50775 m .48687 .5498 L .5 .55115 L p .736 0 1 r

F P

0 g

s

.5 .55115 m .53651 .50919 L .52301 .50775 L p .736 0 1 r

F P

0 g

s

.5 .55115 m .48687 .5498 L p .48739 .555 L .845 0 .756 r

F P

0 g

s

.5 .5563 m .5 .68146 L p .48739 .555 L .845 0 .756 r

F P

0 g

s

.5 .68146 m .5 .5563 L p .48739 .555 L .845 0 .756 r

F P

0 g

s

.5 .5563 m .5 .55115 L p .48739 .555 L .845 0 .756 r

F P

0 g

s

.48669 .68021 m .48687 .5498 L p .48687 .5498 L .845 0 .756 r

F P

0 g

s

.5 .68146 m .48669 .68021 L p .48687 .5498 L .845 0 .756 r

F P

0 g

s

.48669 .68021 m .48669 .68021 L p .48687 .5498 L .845 0 .756 r

F P

0 g

s

.48686 .55495 m .48654 .79252 L p .48654 .79252 L 0 .237 .651 r

F P

0 g

s

.54998 .51063 m .53651 .50919 L .5 .55115 L p .736 0 1 r

F P

0 g

s

.53651 .50919 m .5 .55115 L .5 .68146 L p .315 0 .654 r

F P

0 g

s

.5 .68146 m .5 .55115 L .53651 .50919 L p .315 0 .654 r

F P

0 g

s

.48687 .5498 m .48669 .68021 L .48669 .68021 L p .845 0 .756 r

F P

0 g

s

.48669 .68021 m .5 .68146 L p .48687 .5498 L .845 0 .756 r

F P

0 g

s

.48687 .5498 m .48687 .5498 L .48669 .68021 L .845 0 .756 r

F

.48654 .79252 m .48654 .79252 L .48686 .55495 L 0 .237 .651 r

F

.5 .68146 m .53702 .64299 L .53651 .50919 L p .315 0 .654 r

F P

0 g

s

.53651 .50919 m .53702 .64299 L .5 .68146 L p .315 0 .654 r

F P

0 g

s

.52333 .64167 m .53702 .64299 L .5 .68146 L p .721 0 1 r

F P

0 g

s

.53983 .49356 m .4405 .48282 L p .45528 .50582 L 0 .872 1 r

F P

0 g

s

.48687 .5498 m .52301 .50775 L p .52154 .51476 L .309 0 .651 r

F P

0 g

s

.48669 .68021 m .52312 .55225 L .48686 .55495 L 0 .237 .651 r

F

.52303 .51304 m .48686 .55495 L p .52312 .55225 L F P

0 g

s

.48686 .55495 m .48686 .55495 L p .48654 .79252 L 0 .237 .651 r

F P

0 g

s

.48669 .68021 m .48686 .55495 L p .52154 .51476 L .309 0 .651 r

F P

0 g

s

.48686 .55495 m .48687 .5498 L p .52154 .51476 L .309 0 .651 r

F P

0 g

s

.48686 .55495 m .51394 .52357 L p .45528 .50582 L 0 .872 1 r

F P

0 g

s

.52301 .50775 m .53651 .50919 L .53653 .51447 L p .846 0 .754 r

F P

0 g

s

.52357 .51309 m .52301 .50775 L .53653 .51447 L .846 0 .754 r

F

.53653 .51447 m .53702 .64299 L p .52357 .51309 L F P

0 g

s

.53702 .64299 m .53651 .50919 L .54998 .51063 L p .846 0 .754 r

F P

0 g

s

.51114 .6545 m .5232 .58683 L .48669 .68021 L 0 .237 .651 r

F

.53702 .64299 m .52333 .64167 L p .52301 .50775 L .846 0 .754 r

F P

0 g

s

.5232 .58683 m .53983 .49356 L .52312 .55225 L 0 .237 .651 r

F

.5232 .58683 m .52312 .55225 L .48669 .68021 L F

.48654 .79252 m .54085 .7406 L .54037 .62375 L p F P

0 g

s

.54037 .62375 m .53983 .49356 L p .51114 .6545 L 0 .237 .651 r

F P

0 g

s

.5 .68146 m .48669 .68021 L p .52333 .64167 L .721 0 1 r

F P

0 g

s

.48654 .79252 m .54037 .62375 L .51114 .6545 L 0 .237 .651 r

F

.48669 .68021 m .52333 .64167 L p .52333 .64167 L .721 0 1 r

F P

0 g

s

.48669 .68021 m .48669 .68021 L p .52333 .64167 L .721 0 1 r

F P

0 g

s

.52333 .64167 m .52301 .50775 L p .52301 .50775 L .846 0 .754 r

F P

0 g

s

.52333 .64167 m .52333 .64167 L p .52301 .50775 L .846 0 .754 r

F P

0 g

s

.52333 .64167 m .48669 .68021 L p .52154 .51476 L .309 0 .651 r

F P

0 g

s

.52301 .50775 m .52303 .51304 L p .52154 .51476 L .309 0 .651 r

F P

0 g

s

.52303 .51304 m .52333 .64167 L p .52154 .51476 L .309 0 .651 r

F P

0 g

s

.52303 .51304 m .53983 .49356 L p .45528 .50582 L 0 .872 1 r

F P

0 g

s

.53983 .49356 m .52303 .51304 L p .52312 .55225 L 0 .237 .651 r

F P

0 g

s

.48654 .79252 m .51114 .6545 L .48669 .68021 L 0 .237 .651 r

F

.48686 .55495 m .48686 .55495 L p .48654 .79252 L F P

0 g

s

0 0 0 r

.54325 .50991 m

.54325 .50991 L

s

.54325 .50991 m

.54325 .50991 L

s

.23764 .63006 m

.23764 .63006 L

s

.23764 .63006 m

.23764 .63006 L

s

.21008 .6684 m

.21486 .66175 L

s

.21008 .6684 m

.21008 .6684 L

s

.21008 .6684 m

.21008 .6684 L

s

.21008 .6684 m

.21008 .6684 L

s

.60783 .66542 m

.60783 .66542 L

s

.23384 .77105 m .19418 .82035 L .14565 .81642 L p 0 .893 1 r

F P

0 g

s

0 0 0 r

.17804 .81905 m

.17804 .81905 L

s

.17804 .81905 m

.17804 .81905 L

s

.16187 .81773 m

.16187 .81773 L

s

.16187 .81773 m

.16187 .81773 L

s

.66178 .34314 m

.66941 .34406 L

s

.3822 .41209 m

.3822 .41209 L

s

.3822 .41209 m

.38226 .40695 L

s

.38286 .35894 m

.38377 .28522 L

s

.38377 .28522 m

.38377 .28522 L

s

.33449 .42589 m

.33449 .42589 L

s

.39155 .53994 m .42499 .49727 L .3975 .49433 L p .736 0 1 r

F P

0 g

s

.39149 .54512 m .48686 .55495 L p .45528 .50582 L 0 .872 1 r

F P

0 g

s

.42495 .50259 m .39149 .54512 L p .45528 .50582 L 0 .872 1 r

F P

0 g

s

.39149 .54512 m .48686 .55495 L .48654 .79252 L p 0 .669 .756 r

F P

0 g

s

.4405 .48282 m .42495 .50259 L p .45528 .50582 L 0 .872 1 r

F P

0 g

s

.48654 .79252 m .3888 .78421 L .39007 .67118 L p 0 .669 .756 r

F P

0 g

s

.39007 .67118 m .39149 .54512 L p .44178 .67601 L 0 .669 .756 r

F P

0 g

s

.48654 .79252 m .39007 .67118 L .44178 .67601 L 0 .669 .756 r

F

.39149 .54512 m .4405 .48282 L p .41267 .64508 L 0 .195 .628 r

F P

0 g

s

.3888 .78421 m .39007 .67118 L p .41267 .64508 L 0 .195 .628 r

F P

0 g

s

.39007 .67118 m .39149 .54512 L p .41267 .64508 L 0 .195 .628 r

F P

0 g

s

.42499 .49727 m .39155 .53994 L .39007 .67118 L p .26 0 .628 r

F P

0 g

s

.4405 .48282 m .43896 .7315 L .3888 .78421 L p 0 .195 .628 r

F P

0 g

s

.39007 .67118 m .42394 .63206 L .42499 .49727 L p .26 0 .628 r

F P

0 g

s

.39842 .62959 m .42394 .63206 L p .39007 .67118 L .721 0 1 r

F P

0 g

s

.42394 .63206 m .39007 .67118 L p .39007 .67118 L .721 0 1 r

F P

0 g

s

.41264 .47981 m .31137 .46886 L p .32839 .4923 L 0 .872 1 r

F P

0 g

s

.3975 .49433 m .36482 .53717 L .39155 .53994 L p .736 0 1 r

F P

0 g

s

.36482 .53717 m .39155 .53994 L .39007 .67118 L p .845 0 .756 r

F P

0 g

s

.36482 .53717 m .3975 .49433 L p .3961 .50142 L .245 0 .621 r

F P

0 g

s

.36482 .53717 m .36298 .66864 L .39007 .67118 L p .845 0 .756 r

F P

0 g

s

.39007 .67118 m .36298 .66864 L .36482 .53717 L p .845 0 .756 r

F P

0 g

s

.42394 .63206 m .39606 .62936 L .39744 .49966 L p .846 0 .754 r

F P

0 g

s

.39744 .49966 m .3975 .49433 L p .39855 .49977 L .846 0 .754 r

F P

0 g

s

.42394 .63206 m .39744 .49966 L .39855 .49977 L .846 0 .754 r

F

.39007 .67118 m .36298 .66864 L .39606 .62936 L p .721 0 1 r

F P

0 g

s

.36475 .54236 m .36298 .66864 L p .39665 .57406 L 0 .182 .621 r

F P

0 g

s

.36298 .66864 m .36139 .78189 L p .38505 .64244 L 0 .182 .621 r

F P

0 g

s

.38505 .64244 m .39665 .57406 L .36298 .66864 L 0 .182 .621 r

F

.3975 .49433 m .42499 .49727 L .42495 .50259 L p .846 0 .754 r

F P

0 g

s

.42495 .50259 m .42394 .63206 L p .39855 .49977 L .846 0 .754 r

F P

0 g

s

.39855 .49977 m .3975 .49433 L .42495 .50259 L .846 0 .754 r

F

.41264 .47981 m .39744 .49966 L p .39665 .57406 L 0 .182 .621 r

F P

0 g

s

.39744 .49966 m .36475 .54236 L p .39665 .57406 L 0 .182 .621 r

F P

0 g

s

.36298 .66864 m .36475 .54236 L p .3961 .50142 L .245 0 .621 r

F P

0 g

s

.36475 .54236 m .36482 .53717 L p .3961 .50142 L .245 0 .621 r

F P

0 g

s

.41144 .61109 m .41264 .47981 L p .38505 .64244 L 0 .182 .621 r

F P

0 g

s

.39606 .62936 m .36298 .66864 L p .3961 .50142 L .245 0 .621 r

F P

0 g

s

.3975 .49433 m .39744 .49966 L p .3961 .50142 L .245 0 .621 r

F P

0 g

s

.39744 .49966 m .39606 .62936 L p .3961 .50142 L .245 0 .621 r

F P

0 g

s

.39744 .49966 m .41264 .47981 L p .32839 .4923 L 0 .872 1 r

F P

0 g

s

.36475 .54236 m .39744 .49966 L p .32839 .4923 L 0 .872 1 r

F P

0 g

s

.41037 .72895 m .41144 .61109 L p .39568 .66488 L 0 .182 .621 r

F P

0 g

s

.36139 .78189 m .39482 .74576 L p .39568 .66488 L 0 .182 .621 r

F P

0 g

s

.39482 .74576 m .41037 .72895 L p .39568 .66488 L 0 .182 .621 r

F P

0 g

s

.39606 .62936 m .39842 .62959 L p .39007 .67118 L .721 0 1 r

F P

0 g

s

.36139 .78189 m .41144 .61109 L .38505 .64244 L 0 .182 .621 r

F

0 0 0 r

.48683 .5756 m

.48683 .5756 L

s

.4868 .60154 m

.4868 .60154 L

s

.48676 .62763 m

.48676 .62763 L

s

.48673 .65385 m

.48673 .65385 L

s

.86942 .76994 m .80217 .81934 L .75579 .8154 L p 0 .893 1 r

F P

0 g

s

0 0 0 r

.77094 .80387 m

.77108 .80928 L

s

.77129 .81671 m

.77129 .81671 L

s

.77129 .81671 m

.77129 .81671 L

s

.786 .79241 m

.78632 .80318 L

s

.78675 .81803 m

.78675 .81803 L

s

.78675 .81803 m

.78675 .81803 L

s

.72565 .86343 m

.78675 .81803 L

s

.71077 .86222 m

.77129 .81671 L

s

.77129 .81671 m

.77129 .81671 L

s

.77129 .81671 m

.77129 .81671 L

s

.78675 .81803 m

.78675 .81803 L

s

.78675 .81803 m

.78675 .81803 L

s

.17804 .81905 m

.17804 .81905 L

s

.62754 .1599 m

.62754 .1599 L

s

.60783 .66542 m

.60783 .66542 L

s

.60783 .66542 m

.60783 .66542 L

s

.48683 .5756 m

.48683 .5756 L

s

.48683 .5756 m

.48683 .5756 L

s

.48683 .5756 m

.48683 .5756 L

s

.78675 .81803 m

.78675 .81803 L

s

.16187 .81773 m

.16187 .81773 L

s

.51779 .42741 m

.51779 .42741 L

s

.51779 .42741 m

.53093 .4289 L

s

.53093 .4289 m

.53093 .4289 L

s

.53093 .4289 m

.53093 .4289 L

s

.52308 .53424 m

.52308 .53424 L

s

.48683 .5756 m

.52308 .53424 L

s

.48683 .5756 m

.48683 .5756 L

s

.48683 .5756 m

.48683 .5756 L

s

.48683 .5756 m

.48683 .5756 L

s

.30249 .42232 m

.33302 .37619 L

s

.30249 .42232 m

.30249 .42232 L

s

.64381 .36622 m

.64381 .36622 L

s

.66221 .36841 m

.66986 .36932 L

s

.48588 .51508 m

.4905 .50957 L

s

.77129 .81671 m

.77129 .81671 L

s

.45464 .67722 m

.45522 .55169 L

s

.45522 .55169 m

.45522 .55169 L

s

.25814 .39692 m

.27082 .39836 L

s

.27082 .39836 m

.27082 .39836 L

s

.14565 .81642 m .18325 .76675 L .23384 .77105 L p 0 .893 1 r

F P

0 g

s

0 0 0 r

.50462 .42592 m

.50462 .42592 L

s

.50462 .42592 m

.50462 .42592 L

s

.50462 .42592 m

.51779 .42741 L

s

.51779 .42741 m

.51779 .42741 L

s

.59621 .15568 m

.59621 .15568 L

s

.75579 .8154 m .82119 .76563 L .86942 .76994 L p 0 .893 1 r

F P

0 g

s

0 0 0 r

.4868 .60154 m

.4868 .60154 L

s

.4868 .60154 m

.4868 .60154 L

s

.54278 .40553 m

.54278 .40553 L

s

.54276 .40037 m

.54278 .40553 L

s

.54276 .40037 m

.54276 .40037 L

s

.54221 .27821 m

.54276 .40037 L

s

.54221 .27821 m

.54221 .27821 L

s

.45748 .50648 m

.4578 .50609 L

s

.52314 .56087 m

.52314 .56087 L

s

.4868 .60154 m

.52314 .56087 L

s

.4868 .60154 m

.4868 .60154 L

s

.4868 .60154 m

.4868 .60154 L

s

.4868 .60154 m

.4868 .60154 L

s

.6609 .39361 m

.67032 .39471 L

s

.52944 .404 m

.52944 .404 L

s

.52943 .39884 m

.52944 .404 L

s

.52943 .39884 m

.52943 .39884 L

s

.5294 .38973 m

.52943 .39884 L

s

.27212 .37444 m .29983 .37762 L .27021 .42384 L p .745 0 1 r

F P

0 g

s

.27021 .42384 m .24328 .42084 L .27212 .37444 L p .745 0 1 r

F P

0 g

s

0 0 0 r

.25676 .42234 m

.25676 .42234 L

s

.25676 .42234 m

.25676 .42234 L

s

.25676 .42234 m

.25676 .42234 L

s

.25676 .42234 m

.25676 .42234 L

s

.23277 .46036 m

.25676 .42234 L

s

.66261 .39167 m .56634 .38041 L .56474 .15145 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.59621 .15568 m

.59859 .38418 L

s

.59859 .38418 m

.59859 .38418 L

s

.62754 .1599 m

.63068 .38794 L

s

.63068 .38794 m

.63068 .38794 L

s

.57481 .4527 m

.63068 .38794 L

s

.63068 .38794 m

.63068 .38794 L

s

.58127 .40481 m

.59859 .38418 L

s

.59859 .38418 m

.59859 .38418 L

s

.79424 .76322 m .72988 .81319 L .63574 .8052 L p 0 .893 1 r

F P

0 g

s

0 0 0 r

.66679 .77918 m

.66709 .7969 L

s

.66728 .80788 m

.66728 .80788 L

s

.66728 .80788 m

.66728 .80788 L

s

.69644 .69983 m

.69822 .78865 L

s

.69866 .81054 m

.69866 .81054 L

s

.69866 .81054 m

.69866 .81054 L

s

.61065 .85411 m

.66728 .80788 L

s

.66728 .80788 m

.66728 .80788 L

s

.66728 .80788 m

.66728 .80788 L

s

.64085 .85655 m

.69866 .81054 L

s

.69866 .81054 m

.69866 .81054 L

s

.69866 .81054 m

.69866 .81054 L

s

.53903 .303 m

.54891 .30421 L

s

.28599 .37603 m

.28599 .37603 L

s

.25676 .42234 m

.28599 .37603 L

s

.25676 .42234 m

.25676 .42234 L

s

.48676 .62763 m

.48676 .62763 L

s

.48676 .62763 m

.48676 .62763 L

s

.24342 .41573 m .1947 .41029 L .23485 .34161 L p 0 .863 1 r

F P

0 g

s

0 0 0 r

.21098 .41211 m

.21098 .41211 L

s

.21098 .41211 m

.21098 .41211 L

s

.22722 .41392 m

.22722 .41392 L

s

.22722 .41392 m

.22722 .41392 L

s

.20053 .45783 m

.22722 .41392 L

s

.17356 .47487 m

.21098 .41211 L

s

.21098 .41211 m

.21098 .41211 L

s

.21098 .41211 m

.21098 .41211 L

s

.22722 .41392 m

.22722 .41392 L

s

.22722 .41392 m

.22722 .41392 L

s

.28479 .40108 m

.28479 .40108 L

s

.28479 .40108 m

.28479 .40108 L

s

.26074 .27014 m

.26074 .27014 L

s

.26074 .27014 m

.26074 .27014 L

s

.74867 .68443 m

.74867 .68443 L

s

.74867 .68443 m

.74867 .68443 L

s

.5232 .58766 m

.5232 .58766 L

s

.48676 .62763 m

.5232 .58766 L

s

.48676 .62763 m

.48676 .62763 L

s

.48676 .62763 m

.48676 .62763 L

s

.48676 .62763 m

.48676 .62763 L

s

.44123 .36577 m .44266 .13502 L .53839 .1479 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.47472 .13934 m

.47472 .13934 L

s

.47472 .13934 m

.47472 .13934 L

s

.50664 .14363 m

.50664 .14363 L

s

.50664 .14363 m

.50664 .14363 L

s

.53839 .1479 m .53934 .37725 L .44123 .36577 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.47409 .36961 m

.47409 .36961 L

s

.46429 .38267 m

.47409 .36961 L

s

.5068 .37344 m

.5068 .37344 L

s

.49669 .3865 m

.5068 .37344 L

s

.22722 .41392 m

.22722 .41392 L

s

.69866 .81054 m

.69866 .81054 L

s

.36335 .64206 m

.36335 .64206 L

s

.36372 .61563 m

.36372 .61563 L

s

.36409 .58933 m

.36409 .58933 L

s

.36446 .56318 m

.36446 .56318 L

s

.53914 .32833 m

.54904 .32952 L

s

.25748 .39799 m

.25748 .39799 L

s

.25748 .39799 m

.25761 .39281 L

s

.25885 .34442 m

.26074 .27014 L

s

.26074 .27014 m

.26074 .27014 L

s

.21098 .41211 m

.21098 .41211 L

s

.48673 .65385 m

.48673 .65385 L

s

.48673 .65385 m

.48673 .65385 L

s

.36446 .56318 m

.36446 .56318 L

s

.5068 .37344 m

.5068 .37344 L

s

.50664 .14363 m

.5068 .37344 L

s

.50664 .14363 m

.50664 .14363 L

s

.52327 .61459 m

.52327 .61459 L

s

.48673 .65385 m

.52327 .61459 L

s

.48673 .65385 m

.48673 .65385 L

s

.48673 .65385 m

.48673 .65385 L

s

.48673 .65385 m

.48673 .65385 L

s

.66728 .80788 m

.66728 .80788 L

s

.3822 .41209 m

.3822 .41209 L

s

.3822 .41209 m

.3822 .41209 L

s

.3822 .41209 m

.40901 .41512 L

s

.40901 .41512 m

.40901 .41512 L

s

.40901 .41512 m

.40901 .41512 L

s

.54385 .64365 m

.54385 .64365 L

s

.54046 .64715 m

.54385 .64365 L

s

.39722 .52103 m

.39722 .52103 L

s

.36446 .56318 m

.39722 .52103 L

s

.53925 .3538 m

.54917 .35498 L

s

.33252 .53904 m

.33252 .53904 L

s

.33032 .66559 m

.33252 .53904 L

s

.76775 .55991 m

.76775 .55991 L

s

.76775 .55991 m

.76775 .55991 L

s

.78824 .56206 m

.79379 .56264 L

s

.36409 .58933 m

.36409 .58933 L

s

.47409 .36961 m

.47409 .36961 L

s

.47409 .36961 m

.47472 .13934 L

s

.47472 .13934 m

.47472 .13934 L

s

.63574 .8052 m .69626 .75448 L .79424 .76322 L p 0 .893 1 r

F P

0 g

s

0 0 0 r

.41223 .39053 m

.41223 .39053 L

s

.41223 .39053 m

.41228 .38533 L

s

.41228 .38533 m

.41248 .36429 L

s

.39693 .54789 m

.39693 .54789 L

s

.36409 .58933 m

.39693 .54789 L

s

.53777 .37922 m

.54931 .38057 L

s

.76847 .58611 m

.76847 .58611 L

s

.76847 .58611 m

.76847 .58611 L

s

.78902 .58823 m

.79459 .5888 L

s

.50473 .66124 m

.50473 .66124 L

s

.50467 .53431 m

.50473 .66124 L

s

.36372 .61563 m

.36372 .61563 L

s

.60935 .80295 m .66878 .75202 L .66459 .50706 L p 0 .282 .675 r

F P

0 g

s

0 0 0 r

.6262 .54704 m

.62784 .67295 L

s

.62784 .67295 m

.62784 .67295 L

s

.60783 .66542 m

.64777 .62689 L

s

.64777 .62689 m

.64777 .62689 L

s

.60754 .6394 m

.64737 .60018 L

s

.64737 .60018 m

.64737 .60018 L

s

.60726 .61353 m

.64697 .57361 L

s

.64697 .57361 m

.64697 .57361 L

s

.60697 .58779 m

.64656 .54719 L

s

.64656 .54719 m

.64656 .54719 L

s

.66878 .75202 m .60935 .80295 L .51343 .7948 L p 0 .893 1 r

F P

0 g

s

0 0 0 r

.54541 .76498 m

.54551 .78597 L

s

.54556 .79753 m

.54556 .79753 L

s

.54556 .79753 m

.54556 .79753 L

s

.57666 .68863 m

.57735 .7772 L

s

.57753 .80025 m

.57753 .80025 L

s

.57753 .80025 m

.57753 .80025 L

s

.49358 .84462 m

.54556 .79753 L

s

.54556 .79753 m

.54556 .79753 L

s

.54556 .79753 m

.54556 .79753 L

s

.52433 .84711 m

.57753 .80025 L

s

.57753 .80025 m

.57753 .80025 L

s

.57753 .80025 m

.57753 .80025 L

s

.41439 .2877 m

.42662 .2892 L

s

.62784 .67295 m

.62784 .67295 L

s

.39664 .57489 m

.39664 .57489 L

s

.36372 .61563 m

.39664 .57489 L

s

.31369 .35084 m .31828 .11829 L .41582 .13141 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.35095 .12269 m

.35095 .12269 L

s

.35095 .12269 m

.35095 .12269 L

s

.38346 .12706 m

.38346 .12706 L

s

.38346 .12706 m

.38346 .12706 L

s

.41582 .13141 m .41371 .36255 L .31369 .35084 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.3472 .35476 m

.3472 .35476 L

s

.33302 .37619 m

.3472 .35476 L

s

.38054 .35866 m

.38054 .35866 L

s

.33449 .42589 m

.38054 .35866 L

s

.28359 .48215 m

.28359 .48215 L

s

.28359 .48215 m

.28359 .48215 L

s

.7692 .61246 m

.7692 .61246 L

s

.7692 .61246 m

.7692 .61246 L

s

.7898 .61454 m

.79539 .6151 L

s

.57753 .80025 m

.57753 .80025 L

s

.36335 .64206 m

.36335 .64206 L

s

.41416 .31323 m

.42642 .31472 L

s

.42642 .31472 m

.42642 .31472 L

s

.23152 .46022 m .19103 .52446 L .24035 .52954 L p 0 .872 1 r

F P

0 g

s

0 0 0 r

.23978 .55053 m

.23978 .55053 L

s

.23978 .55053 m

.23978 .55053 L

s

.38054 .35866 m

.38054 .35866 L

s

.38054 .35866 m

.38346 .12706 L

s

.38346 .12706 m

.38346 .12706 L

s

.86037 .52823 m .86942 .76994 L .82119 .76563 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.85338 .76851 m

.85339 .76851 L

s

.78675 .81803 m

.85338 .76851 L

s

.83731 .76707 m

.83731 .76707 L

s

.77129 .81671 m

.83731 .76707 L

s

.82119 .76563 m .8133 .52314 L .86037 .52823 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.82903 .52484 m

.82903 .52484 L

s

.82903 .52484 m

.82903 .52484 L

s

.84472 .52654 m

.84472 .52654 L

s

.84472 .52654 m

.84472 .52654 L

s

.39635 .60205 m

.39635 .60205 L

s

.36335 .64206 m

.39635 .60205 L

s

.54556 .79753 m

.54556 .79753 L

s

.76994 .63895 m

.76994 .63895 L

s

.76994 .63895 m

.76994 .63895 L

s

.79059 .64099 m

.79619 .64155 L

s

.25748 .39799 m

.25748 .39799 L

s

.25748 .39799 m

.25748 .39799 L

s

.25748 .39799 m

.28479 .40108 L

s

.28479 .40108 m

.28479 .40108 L

s

.28479 .40108 m

.28479 .40108 L

s

.26892 .50757 m

.26892 .50757 L

s

.23978 .55053 m

.26892 .50757 L

s

.23978 .55053 m

.23978 .55053 L

s

.85339 .76851 m

.85339 .76851 L

s

.84472 .52654 m

.85339 .76851 L

s

.84472 .52654 m

.84472 .52654 L

s

.41393 .33891 m

.42622 .34037 L

s

.42622 .34037 m

.42622 .34037 L

s

.64656 .54719 m

.64656 .54719 L

s

.66531 .54916 m

.6731 .54998 L

s

.23907 .5769 m

.23907 .5769 L

s

.23907 .5769 m

.23907 .5769 L

s

.3472 .35476 m

.3472 .35476 L

s

.3472 .35476 m

.35095 .12269 L

s

.35095 .12269 m

.35095 .12269 L

s

.83731 .76707 m

.83731 .76707 L

s

.82903 .52484 m

.83731 .76707 L

s

.82903 .52484 m

.82903 .52484 L

s

.51343 .7948 m .56888 .7431 L .66878 .75202 L p 0 .893 1 r

F P

0 g

s

.23384 .77105 m .18325 .76675 L .19103 .52446 L p 0 .669 .756 r

F P

0 g

s

.19103 .52446 m .18325 .76675 L .23384 .77105 L p 0 .669 .756 r

F P

0 g

s

.18325 .76675 m .19103 .52446 L .23152 .46022 L p 0 .1 .563 r

F P

0 g

s

0 0 0 r

.2203 .6553 m

.22395 .52785 L

s

.28599 .37603 m

.28599 .37603 L

s

.28599 .37603 m

.28611 .37078 L

s

.28891 .24664 m

.28891 .24664 L

s

.26827 .53465 m

.26827 .53465 L

s

.23907 .5769 m

.26827 .53465 L

s

.23907 .5769 m

.23907 .5769 L

s

.41229 .36456 m

.42602 .36616 L

s

.42602 .36616 m

.42602 .36616 L

s

.64697 .57361 m

.64697 .57361 L

s

.66576 .57555 m

.67357 .57635 L

s

.37926 .64931 m

.37926 .64931 L

s

.37926 .64931 m

.38085 .52134 L

s

.23836 .6034 m

.23836 .6034 L

s

.23836 .6034 m

.23836 .6034 L

s

.43896 .7315 m .54085 .7406 L .48654 .79252 L p 0 .893 1 r

F P

0 g

s

0 0 0 r

.45438 .73288 m

.45464 .67722 L

s

.48654 .79252 m .3888 .78421 L .43896 .7315 L p 0 .893 1 r

F P

0 g

s

0 0 0 r

.45412 .78976 m

.45412 .78976 L

s

.45412 .78976 m

.45412 .78976 L

s

.40569 .8375 m

.45412 .78976 L

s

.45412 .78976 m

.45412 .78976 L

s

.45412 .78976 m

.45412 .78976 L

s

.42154 .787 m

.42154 .787 L

s

.42154 .787 m

.42154 .787 L

s

.37439 .83496 m

.42154 .787 L

s

.42154 .787 m

.42154 .787 L

s

.42154 .787 m

.42154 .787 L

s

.28735 .27211 m

.30202 .27391 L

s

.78699 .52029 m .79424 .76322 L .69626 .75448 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.72909 .75741 m

.72909 .75741 L

s

.66728 .80788 m

.72909 .75741 L

s

.76175 .76032 m

.76175 .76032 L

s

.69866 .81054 m

.76175 .76032 L

s

.69626 .75448 m .69139 .50996 L .78699 .52029 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.72342 .51342 m

.72342 .51342 L

s

.72342 .51342 m

.72342 .51342 L

s

.75528 .51687 m

.75528 .51687 L

s

.75528 .51687 m

.75528 .51687 L

s

.26761 .56188 m

.26761 .56188 L

s

.23836 .6034 m

.26761 .56188 L

s

.23836 .6034 m

.23836 .6034 L

s

.23485 .34161 m .24141 .10795 L .29093 .11461 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.25796 .11017 m

.25796 .11017 L

s

.25796 .11017 m

.25796 .11017 L

s

.27446 .11239 m

.27446 .11239 L

s

.27446 .11239 m

.27446 .11239 L

s

.29093 .11461 m .28564 .34756 L .23485 .34161 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.28611 .37078 m

.28891 .24664 L

s

.25182 .3436 m

.25182 .3436 L

s

.21098 .41211 m

.25182 .3436 L

s

.26875 .34558 m

.26875 .34558 L

s

.22722 .41392 m

.26875 .34558 L

s

.64737 .60018 m

.64737 .60018 L

s

.66621 .60208 m

.67405 .60287 L

s

.45412 .78976 m

.45412 .78976 L

s

.23764 .63006 m

.23764 .63006 L

s

.23764 .63006 m

.23764 .63006 L

s

.50473 .66124 m

.50473 .66124 L

s

.50473 .66124 m

.50473 .66124 L

s

.26875 .34558 m

.26875 .34558 L

s

.26875 .34558 m

.27446 .11239 L

s

.27446 .11239 m

.27446 .11239 L

s

.28677 .29785 m

.30147 .29963 L

s

.76175 .76032 m

.76175 .76032 L

s

.75528 .51687 m

.76175 .76032 L

s

.75528 .51687 m

.75528 .51687 L

s

.54385 .64365 m

.54385 .64365 L

s

.54327 .51519 m

.54385 .64365 L

s

.54325 .50991 m

.54327 .51519 L

s

.54325 .50991 m

.54325 .50991 L

s

.25182 .3436 m

.25182 .3436 L

s

.25182 .3436 m

.25796 .11017 L

s

.25796 .11017 m

.25796 .11017 L

s

.26695 .58927 m

.26695 .58927 L

s

.23764 .63006 m

.26695 .58927 L

s

.23764 .63006 m

.23764 .63006 L

s

.42154 .787 m

.42154 .787 L

s

.64777 .62689 m

.64777 .62689 L

s

.66667 .62875 m

.67453 .62953 L

s

.72909 .75741 m

.72909 .75741 L

s

.72342 .51342 m

.72909 .75741 L

s

.72342 .51342 m

.72342 .51342 L

s

.28618 .32373 m

.30093 .32548 L

s

.54 .53601 m

.55012 .53707 L

s

.28052 .61819 m

.28052 .61819 L

s

.27947 .61959 m

.28052 .61819 L

s

.52308 .53424 m

.52308 .53424 L

s

.52308 .53424 m

.52308 .53424 L

s

.28437 .34961 m

.30038 .35148 L

s

.54011 .56262 m

.55026 .56366 L

s

.25137 .63715 m

.25137 .63715 L

s

.25137 .63715 m

.25467 .50812 L

s

.25467 .50812 m

.25467 .50812 L

s

.30642 .71967 m .41037 .72895 L .36139 .78189 L p 0 .893 1 r

F P

0 g

s

0 0 0 r

.32935 .72172 m

.33032 .66559 L

s

.36139 .78189 m .26177 .77342 L .30642 .71967 L p 0 .893 1 r

F P

0 g

s

0 0 0 r

.28489 .82771 m

.32835 .77908 L

s

.32835 .77908 m

.32835 .77908 L

s

.32835 .77908 m

.32835 .77908 L

s

.32835 .77908 m

.32835 .77908 L

s

.32835 .77908 m

.32835 .77908 L

s

.29515 .77626 m

.29515 .77626 L

s

.29515 .77626 m

.29515 .77626 L

s

.29515 .77626 m

.29515 .77626 L

s

.29515 .77626 m

.29515 .77626 L

s

.25302 .82512 m

.29515 .77626 L

s

.52314 .56087 m

.52314 .56087 L

s

.52314 .56087 m

.52314 .56087 L

s

.66459 .50706 m .66878 .75202 L .56888 .7431 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.63565 .74907 m

.63565 .74907 L

s

.57753 .80025 m

.63565 .74907 L

s

.60235 .74609 m

.60235 .74609 L

s

.54556 .79753 m

.60235 .74609 L

s

.56888 .7431 m .56715 .49652 L .66459 .50706 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.59979 .50005 m

.59979 .50005 L

s

.59979 .50005 m

.59979 .50005 L

s

.63227 .50356 m

.63227 .50356 L

s

.63227 .50356 m

.63227 .50356 L

s

.37926 .64931 m

.37926 .64931 L

s

.37926 .64931 m

.37926 .64931 L

s

.54022 .58937 m

.5504 .5904 L

s

.32835 .77908 m

.32835 .77908 L

s

.5232 .58766 m

.5232 .58766 L

s

.5232 .58766 m

.5232 .58766 L

s

.63565 .74907 m

.63565 .74907 L

s

.63227 .50356 m

.63565 .74907 L

s

.63227 .50356 m

.63227 .50356 L

s

.29515 .77626 m

.29515 .77626 L

s

.54034 .61627 m

.55054 .61728 L

s

.60235 .74609 m

.60235 .74609 L

s

.59979 .50005 m

.60235 .74609 L

s

.59979 .50005 m

.59979 .50005 L

s

.52327 .61459 m

.52327 .61459 L

s

.52327 .61459 m

.52327 .61459 L

s

.39722 .52103 m

.39722 .52103 L

s

.39722 .52103 m

.39722 .52103 L

s

.41225 .52261 m

.42478 .52393 L

s

.42478 .52393 m

.42478 .52393 L

s

.39693 .54789 m

.39693 .54789 L

s

.39693 .54789 m

.39693 .54789 L

s

.41201 .54944 m

.42457 .55073 L

s

.42457 .55073 m

.42457 .55073 L

s

.22444 .71235 m .27726 .71707 L .23384 .77105 L p 0 .893 1 r

F P

0 g

s

.23384 .77105 m .18325 .76675 L .22444 .71235 L p 0 .893 1 r

F P

0 g

s

0 0 0 r

.20016 .76819 m

.20016 .76819 L

s

.20016 .76819 m

.20016 .76819 L

s

.21702 .76962 m

.21702 .76962 L

s

.21702 .76962 m

.21702 .76962 L

s

.21702 .76962 m

.21702 .76962 L

s

.21702 .76962 m

.21702 .76962 L

s

.17804 .81905 m

.21702 .76962 L

s

.20016 .76819 m

.20016 .76819 L

s

.20016 .76819 m

.20016 .76819 L

s

.16187 .81773 m

.20016 .76819 L

s

.20091 .74343 m

.20425 .63339 L

s

.21843 .72028 m

.2203 .6553 L

s

.4405 .48282 m .53983 .49356 L .54085 .7406 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.47378 .48642 m

.47378 .48642 L

s

.47378 .48642 m

.47378 .48642 L

s

.50688 .49 m

.50688 .49 L

s

.50688 .49 m

.50688 .49 L

s

.21702 .76962 m

.21702 .76962 L

s

.25137 .63715 m

.25137 .63715 L

s

.25137 .63715 m

.25137 .63715 L

s

.27901 .63978 m

.27938 .63981 L

s

.39664 .57489 m

.39664 .57489 L

s

.39664 .57489 m

.39664 .57489 L

s

.41176 .57642 m

.42436 .57769 L

s

.42436 .57769 m

.42436 .57769 L

s

.20016 .76819 m

.20016 .76819 L

s

.50688 .49 m

.50688 .49 L

s

.23152 .46022 m .22444 .71235 L .18325 .76675 L p 0 .1 .563 r

F P

0 g

s

0 0 0 r

.28052 .61819 m

.28052 .61819 L

s

.28052 .61819 m

.28347 .48752 L

s

.28347 .48752 m

.28347 .48752 L

s

.28347 .48752 m

.28347 .48752 L

s

.28347 .48752 m

.28359 .48215 L

s

.28359 .48215 m

.28359 .48215 L

s

.39635 .60205 m

.39635 .60205 L

s

.39635 .60205 m

.39635 .60205 L

s

.41151 .60355 m

.42415 .6048 L

s

.42415 .6048 m

.42415 .6048 L

s

.47378 .48642 m

.47378 .48642 L

s

.26892 .50757 m

.26892 .50757 L

s

.26892 .50757 m

.26892 .50757 L

s

.28198 .50894 m

.29702 .51052 L

s

.54085 .7406 m .43896 .7315 L .4405 .48282 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.4731 .73455 m

.47378 .48642 L

s

.4731 .73455 m

.4731 .73455 L

s

.50688 .49 m

.50706 .73758 L

s

.50706 .73758 m

.50706 .73758 L

s

.45412 .78976 m

.50706 .73758 L

s

.50706 .73758 m

.50706 .73758 L

s

.42154 .787 m

.4731 .73455 L

s

.4731 .73455 m

.4731 .73455 L

s

.26827 .53465 m

.26827 .53465 L

s

.26827 .53465 m

.26827 .53465 L

s

.28137 .536 m

.29645 .53755 L

s

.31137 .46886 m .41264 .47981 L .41037 .72895 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.3453 .47253 m

.3453 .47253 L

s

.3453 .47253 m

.3453 .47253 L

s

.37905 .47618 m

.37905 .47618 L

s

.37905 .47618 m

.37905 .47618 L

s

.26761 .56188 m

.26761 .56188 L

s

.26761 .56188 m

.26761 .56188 L

s

.28075 .56321 m

.29587 .56473 L

s

.37905 .47618 m

.37905 .47618 L

s

.26695 .58927 m

.26695 .58927 L

s

.26695 .58927 m

.26695 .58927 L

s

.28013 .59057 m

.2953 .59207 L

s

.3453 .47253 m

.3453 .47253 L

s

.41037 .72895 m .30642 .71967 L .31137 .46886 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.34125 .72278 m

.3453 .47253 L

s

.34125 .72278 m

.34125 .72278 L

s

.3759 .72587 m

.37905 .47618 L

s

.3759 .72587 m

.3759 .72587 L

s

.32835 .77908 m

.3759 .72587 L

s

.3759 .72587 m

.3759 .72587 L

s

.29515 .77626 m

.34125 .72278 L

s

.34125 .72278 m

.34125 .72278 L

s

.23152 .46022 m .28296 .46578 L .27726 .71707 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.24871 .46208 m

.24871 .46208 L

s

.24871 .46208 m

.24871 .46208 L

s

.26586 .46393 m

.26586 .46393 L

s

.26586 .46393 m

.26586 .46393 L

s

.26586 .46393 m

.26586 .46393 L

s

.24871 .46208 m

.24871 .46208 L

s

.27726 .71707 m .22444 .71235 L .23152 .46022 L p 0 .668 .753 r

F P

0 g

s

0 0 0 r

.24209 .71393 m

.24871 .46208 L

s

.24209 .71393 m

.24209 .71393 L

s

.2597 .7155 m

.26586 .46393 L

s

.2597 .7155 m

.2597 .7155 L

s

.20016 .76819 m

.24209 .71393 L

s

.24209 .71393 m

.24209 .71393 L

s

.21702 .76962 m

.2597 .7155 L

s

.2597 .7155 m

.2597 .7155 L

s

0 g

[ .01 .01 ] 0 setdash

.22797 .08757 m

.86491 .17415 L

s

.86491 .17415 m

.88891 .78418 L

s

.88891 .78418 m

.20912 .72415 L

s

.20912 .72415 m

.22797 .08757 L

s

.1498 .24411 m

.12776 .8324 L

s

.12776 .8324 m

.20912 .72415 L

s

.20912 .72415 m

.22797 .08757 L

s

.22797 .08757 m

.1498 .24411 L

s

.003 w

[ ] 0 setdash

.1498 .24411 m

.22797 .08757 L

s

.25 Mabswid

.16486 .21396 m

.17106 .21474 L

s

gsave

.15246 .2124 -86 -12.4443 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(20) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.18713 .16935 m

.19333 .17016 L

s

gsave

.17474 .16775 -71 -12.4707 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.21061 .12234 m

.21681 .12316 L

s

gsave

.19822 .12069 -77 -12.4987 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(20) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

.17032 .20302 m

.17404 .2035 L

s

.17585 .19195 m

.17957 .19242 L

s

.18145 .18072 m

.18517 .1812 L

s

.19289 .15783 m

.1966 .15832 L

s

.19871 .14616 m

.20243 .14665 L

s

.20462 .13433 m

.20834 .13482 L

s

.15947 .22476 m

.16319 .22522 L

s

.15414 .23542 m

.15787 .23588 L

s

.21668 .11018 m

.2204 .11068 L

s

.22283 .09786 m

.22655 .09836 L

s

gsave

.11275 .15973 -77 -12.4707 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

74.625000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.003 w

.86491 .17415 m

.88891 .78418 L

s

.25 Mabswid

.8666 .21718 m

.86041 .21636 L

s

gsave

.879 .21882 -61 -10.5057 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(50) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.8715 .34163 m

.8653 .34087 L

s

gsave

.88391 .34315 -61 -10.5785 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(25) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.87653 .46945 m

.87032 .46875 L

s

gsave

.88895 .47085 -61 -10.6533 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.8817 .60078 m

.87548 .60014 L

s

gsave

.89413 .60206 -61 -10.7302 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(25) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.88701 .73577 m

.88078 .73519 L

s

gsave

.89946 .73691 -61 -10.8093 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(50) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

.86757 .24181 m

.86385 .24132 L

s

.86855 .26656 m

.86483 .26608 L

s

.86953 .29145 m

.86581 .29098 L

s

.87051 .31647 m

.86679 .31601 L

s

.8725 .36692 m

.86877 .36647 L

s

.8735 .39235 m

.86977 .3919 L

s

.8745 .41791 m

.87078 .41747 L

s

.87551 .44361 m

.87179 .44318 L

s

.87755 .49543 m

.87383 .49502 L

s

.87858 .52156 m

.87485 .52115 L

s

.87961 .54782 m

.87588 .54742 L

s

.88065 .57423 m

.87692 .57384 L

s

.88275 .62748 m

.87902 .62711 L

s

.8838 .65433 m

.88007 .65396 L

s

.88487 .68133 m

.88113 .68097 L

s

.88593 .70847 m

.8822 .70812 L

s

.86564 .19268 m

.86192 .19218 L

s

.88809 .76322 m

.88435 .76288 L

s

gsave

.95106 .47787 -61 -10.6533 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(Z) show

73.187500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  Evaluatable->False,

  AspectRatioFixed->True,

  ImageSize->{318, 318},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004n0001?Q000`40O003h00Oogoo?goo003oOolo

Ool00?moocmoo`00ogoo?goo003oOoloOol00?moocmoo`00ogoo?goo003oOoloOol00?moocmoo`00

Zgoo0`00T7oo002/Ool00`00Oomoo`2?Ool00:aoo`03001oogoo08moo`00[7oo00<007ooOol0Sgoo

002[Ool00`00Ool0002@Ool00:]oo`03001oo`00091oo`00Zgoo00@007ooOol008moo`00ZWoo00<0

07ooOol00Woo00<007ooOol0S7oo001HOol30004Ool30017Ool30002Ool3002=Ool005]oo`04001o

ogoo0003Ool00`00Oomoo`3IOol005aoo`03001oo`0000=oo`03001oogoo0=Uoo`00DGoo1`0017oo

00<007oo00000goo00<007ooOol0fGoo001LOol00`00Ool00003Ool00`00Oomoo`3IOol005]oo`04

001oogoo0003Ool00`00Oomoo`3IOol005Uoo`8000=oo`05001oogooOol0000POol5000017oo0000

0000/Woo001IOol00`00Oomoo`02Ool01@00Oomoogoo00008Goo00@007ooOol000Aoo`03001oogoo

0:moo`00FWoo0`000Woo0`008goo00<007ooOol01Goo00<007ooOol0[Woo001lOol70003Ool00`00

Oomoo`04Ool00`00Oomoo`2^Ool008Moo`03001oogoo00=oo`03001oogoo0:ioo`00B7oo1000>goo

00<007ooOol00Woo00<007ooOol0[goo0017Ool200000goo00000007000dOol00`00Oomoo`02000Q

Ool3002>Ool004Moo`8000Moo`800003Ool0000000H002Qoo`05001oogooOol00002Ool00`00Oomo

o`0OOol01@00Oomoogoo0000SGoo0016Ool00`00Ool00008Ool00`00Oomoo`06Ool8000ROol30004

Ool3000NOol01@00Oomoogoo0000SGoo0016Ool3000AOol00`00Oomoo`04Ool80013Ool01@00Oomo

ogoo0000SGoo0015Ool01000Oomoo`004Goo00<007ooOol01Woo00@007ooOomoo`T003aoo`05001o

ogooOol0002=Ool004Eoo`04001oogoo000ROol01000Oomoogoo2000=Goo00D007ooOomoo`00025o

o`D00004Ool00000001SOol004Aoo`03001oogoo00Eoo`@00003Ool00000025oo`03001oo`0000P0

02eoo`05001oogooOol0000ROol01000Oomoo`0017oo00<007ooOol0H7oo000`Ool50002Ool3000:

Ool20005Ool200030[P8000TOol200000goo00000005000VOol01@00Oomoogoo00008goo00<007oo

Ool01Goo00<007ooOol0Ggoo000aOol01P00Oomoo`00Ool000=oo`03001oogoo00Ioo`03001oogoo

009oo`03001oogoo008000@2^0030002^0:h00<2^0H001moo`03001oogoo00Ioo`P0021oo`<002Eo

o`03001oogoo00Aoo`03001oogoo05moo`00<Woo00D007ooOomoo`0000=oo`03001oogoo00Ioo`03

001oogoo009oo`05001oo`00078000040[P00`000[P2^0030[P00`000[P2^0020[P00`00Oomoo`05

Ool4000MOol00`00Oomoo`05Ool70012Ool00`00Oomoo`03Ool00`00Oomoo`1OOol003=oo`04001o

ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01P00Oomoo`00078000@2^0030002^0:h00<2

^0030002^0:h0082^003001oogoo00Aoo`8000<2^0P001Eoo`03001oogoo00Eoo`03001oogoo00=o

o`P003]oo`03001oogoo009oo`03001oogoo061oo`00=7oo00<007oo00000goo00<007ooOol01Goo

0`000Woo00<007oo00000P1b00<000:h0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h00<007oo

Ool017oo0P002P:h2@0000=oo`00Ool06goo00<007ooOol00Woo2000<goo00<007ooOol00P0087oo

0`0017oo0`00>Goo000dOol00`00Ool00003Ool00`00Oomoo`04Ool00`00Oomoo`05Ool010000780

LP0010:h00<000:h0[P00`:h00<000:h0[P00P:h00<007ooOol00goo00<0002B00002P:h00<000:h

0[P01P:h20007Woo00@007ooOomoo`P002Qoo`05001oogooOol00002Ool00`00Oomoo`0ROol01000

Oomoo`000goo00<007ooOol0=Woo000dOol00`00Ool00003Ool00`00Oomoo`04Ool00`00Oomoo`04

Ool01@000780LP1b000010:h00<000:h0[P00`:h00<000:h0[P00P:h00<007ooOol00goo00<0002B

00002P:h00<000:h0[P01`:h00<000:h0[P010:h10008goo2P008Woo0`0017oo0`008Woo00<007oo

00000goo00<007ooOol0=Woo000`Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00=oo`<000Ao

o`8000<0LP030002^0:h0082^0030002^0:h00<2^0030002^0:h0082^003001oogoo009oo`040000

TP2B000:0[P00`000[P2^0070[P00`000[P2^0070[P00`00Oomoo`06Ool4000OOol00`00Ool00007

0016Ool00`00Ool00003Ool00`00Oomoo`0fOol0035oo`<000=oo`<000Ioo`03001oogoo00Aoo`03

0000LP1b0080LP030002^0:h0082^0030002^0:h00<2^0030002^0:h0082^003001oogoo009oo`04

0000TP2B000:0[P00`000[P2^0070[P00`000[P2^0070[P00`00Oomoo`05Ool200030[P8000GOol0

0`00Oomoo`06Ool8000oOol00`00Ool00003Ool00`00Oomoo`0fOol003moo`03001oogoo00Eoo`03

0000LP1b0080LP030002^0:h0082^0030002^0:h00<2^0030002^0:h0082^005001oogooOol00003

09800`000[P2^0080[P00`000[P2^0070[P00`000[P2^0070[P00`00Oomoo`05Ool200090[P00`00

0[P00006000IOol00`00Oomoo`04Ool8000gOol01000Oomoo`000goo00<007ooOol0=Woo000oOol0

0`00Oomoo`04Ool2000407800`000[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P01@00Oomo

ogoo00000`2B00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h00<007ooOol017oo00<0

003D00002@:h00<000:h0[P01P:h20006Goo00<007ooOol017oo1`00;Woo0P000goo00D007ooOomo

o`0003Qoo`00?Woo0`001Goo00<0001b07800`1b00<000:h0[P00P:h00<000:h0[P00`:h00<000:h

0[P00P:h00@007ooOol000@0TP030002^0:h00P2^0030002^0:h00L2^0030002^0:h00L2^003001o

ogoo00=oo`040000e03D00090[P00`000[P2^0070[P00`000[P2^0040[P4000MOol00`00Oomoo`03

Ool7000WOol00`00Oomoo`02Ool01@00Oomoogoo0000>7oo000EOol30002Ool3000QOol00`00Oomo

o`04Ool00`000780LP0407800`000[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P01000Oomo

o`00102B00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h00<007ooOol00goo00@0003D

0=@000T2^0030002^0:h00L2^0030002^0:h00L2^003001oogoo02=oo`04001oogooOol8000QOol3

0002Ool3000iOol001Ioo`03001oogoo009oo`03001oogoo01moo`03001oogoo00Eoo`030000LP00

00@0LP030002^0:h0082^0030002^0:h00<2^0030002^0:h0082^003001oo`0000D0TP030002^0:h

00P2^0030002^0:h00L2^0030002^0:h00L2^003001oogoo009oo`050000e03D0=@000090[P00`00

0[P2^0070[P00`000[P2^0070[P00`00Oomoo`06Ool40006Ool00`00Oomoo`0IOol00`00Oomoo`08

001JOol001Moo`04001oogoo000ROol00`00Oomoo`04Ool010000780LP00101b00<000:h0[P00P:h

00<000:h0[P00`:h00<000:h0[P00P:h0`001@2B00<000:h0[P020:h00<000:h0[P01`:h00<000:h

0[P01`:h00<007ooOol00Woo00D0003D0=@0e00000T2^0030002^0:h00L2^0030002^0:h00L2^003

001oogoo00Eoo`8000<2^0L001]oo`03001oogoo00Eoo`03001oogoo00L005=oo`0067oo0P005Woo

0`002Goo0`001Goo00@0001b078000@0LP030002^0:h0082^0030002^0:h00<2^0030002^0:h0082

^08000H0TP030002^0:h00P2^0030002^0:h00L2^0030002^0:h00L2^005001oogooOol000040=@0

0`000[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P00`00Oomoo`05Ool200090[P;000QOol0

0`00Ool00007001;Ool001Uoo`03001oogoo01=oo`05001oogooOol00008Ool00`00Oomoo`04Ool0

1@000780LP1b0000101b00<000:h0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h0P001P2B00<0

00:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h00@007ooOol000D0e0030002^0:h00L2^003

0002^0:h00L2^0030002^0:h00L2^003001oogoo00Aoo`030000m@0000T2^0030002^0:h00H2^0L0

02Aoo`T004Aoo`0067oo0P005Goo00D007ooOomoo`0000Moo`03001oogoo00Eoo`050000LP1b0780

000407800`000[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P00`000980TP0509800`000[P2

^0080[P00`000[P2^0070[P00`000[P2^0070[P01000Oomoo`001@3D00<000:h0[P01`:h00<000:h

0[P01`:h00<000:h0[P01`:h00<007ooOol00goo00@0003e0?D000T2^0030002^0:h00H2^0030002

^0:h00@2^0@002Qoo`T003aoo`005goo00@007ooOol001Aoo`05001oogooOol00007Ool30004Ool0

0`000780LP0607800`000[P2^0020[P00`000[P2^0040[P00`000[P2^0020[P00`000980TP050980

0`000[P2^0080[P00`000[P2^0070[P00`000[P2^0070[P00`00Ool000060=@00`000[P2^0070[P0

0`000[P2^0070[P00`000[P2^0070[P00`00Oomoo`02Ool01@000?D0m@3e00002@:h00<000:h0[P0

1P:h00<000:h0[P01`:h00<007ooOol01Woo100077oo00<007ooOol017oo2000=Woo000FOol00`00

Oomoo`02Ool00`00Oomoo`0AOol01@00Oomoogoo00001Woo00<007ooOol01Goo00<0001b07801P1b

00<000:h0[P00P:h00<000:h0[P00`:h00<000:h0[P00`:h00<0002B09801@2B00<000:h0[P020:h

00<000:h0[P01`:h00<000:h0[P01`:h0P001`3D00<000:h0[P01`:h00<000:h0[P01`:h00<000:h

0[P01`:h00<007ooOol00Woo00D0003e0?D0m@0000T2^0030002^0:h00H2^0030002^0:h00L2^003

001oogoo00Eoo`8000<2^0L001eoo`03001oogoo00Aoo`L002moo`005Goo0`000Woo0`004Woo00D0

07ooOomoo`0000Ioo`03001oogoo00Aoo`030000LP1b00<0LP050000LP1b078000040[P00`000[P2

^0030[P00`000[P2^0020[P00`000980TP0609800`000[P2^0080[P00`000[P2^0070[P00`000[P2

^0070[P200070=@00`000[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P01@00Oomoogoo0000

103e00<000:h0[P01`:h00<000:h0[P01P:h00<000:h0[P01`:h00<007ooOol017oo00<0004e0000

20:h00<000:h0000200077oo00<007ooOol00goo1000:goo000_Ool01@00Oomoogoo00001Goo0P00

1Woo00<0001b07800`1b00D0001b0780LP0000@2^0030002^0:h00<2^0030002^0:h0082^0030000

TP2B00H0TP030002^0:h00P2^0030002^0:h00L2^0030002^0:h00L2^0030000e03D00H0e0030002

^0:h00L2^0030002^0:h00L2^0030002^0:h00L2^004001oogoo00050?D00`000[P2^0070[P00`00

0[P2^0060[P00`000[P2^0070[P00`00Oomoo`04Ool00`000CD000080[P00`000[P2^0070[P7000M

Ool3000[Ool002moo`05001oogooOol00005Ool20005Ool00`000780LP0407801@000780LP1b0000

10:h00<000:h0[P00`:h00<000:h0[P00P:h00<0002B09801P2B00<000:h0[P020:h00<000:h0[P0

1`:h00<000:h0[P01`:h00<0003D0=@01P3D00<000:h0[P01`:h00<000:h0[P01`:h00<000:h0[P0

1`:h00<007oo00001P3e00<000:h0[P01`:h00<000:h0[P01P:h00<000:h0[P01`:h00<007ooOol0

0goo00@0004e0CD000P2^0030002^0:h00L2^0030002^0:h00@2^0@001Qoo`04001oogoo000[Ool0

031oo`<000Eoo`03001oogoo00Eoo`030000LP1b00@0LP050000LP1b078000040[P00`000[P2^003

0[P00`000[P2^0020[P00`000980TP0609800`000[P2^0080[P00`000[P2^0070[P00`000[P2^007

0[P00`000=@0e0060=@00`000[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P00`00Ool00006

0?D00`000[P2^0070[P00`000[P2^0060[P00`000[P2^0070[P00`00Oomoo`02Ool01@000CD1=@4e

000020:h00<000:h0[P01`:h00<000:h0[P01`:h00<007ooOol01Goo100000=oo`00Ool03Goo00<0

07ooOol0:Goo000hOol00`00Oomoo`04Ool2000:07800`000[P2^0020[P00`000[P2^0030[P00`00

0[P2^0020[P00`000980TP0609800`000[P2^0080[P00`000[P2^0070[P00`000[P2^0070[P00`00

0=@0e0060=@00`000[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P200070?D00`000[P2^007

0[P00`000[P2^0060[P00`000[P2^0070[P01@00Oomoogoo0000104e00<000:h0[P01P:h00<000:h

0[P01`:h00<000:h0[P01`:h00<007ooOol017oo0P000`:h1`002Goo00<007ooOol0:Goo000gOol2

0006Ool2000:07800`000[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P00`000980TP060980

0`000[P2^0080[P00`000[P2^0070[P00`000[P2^0070[P00`000=@0e0060=@00`000[P2^0070[P0

0`000[P2^0070[P00`000[P2^0070[P00`000?D0m@060?D00`000[P2^0070[P00`000[P2^0060[P0

0`000[P2^0070[P01000Oomoo`001@4e00<000:h0[P01P:h00<000:h0[P01`:h00<000:h0[P01`:h

00<007ooOol00goo00<0005F000010:h00H000:h0[P2^0000[P50003Ool2000[Ool003Moo`03001o

ogoo00Aoo`030000LP0000H0LP050000LP1b078000040[P00`000[P2^0030[P00`000[P2^0020[P0

0`000980TP0609800`000[P2^0080[P00`000[P2^0070[P00`000[P2^0070[P00`000=@0e0060=@0

0`000[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P00`000?D0m@060?D00`000[P2^0070[P0

0`000[P2^0060[P00`000[P2^0070[P00`00Ool000060CD00`000[P2^0060[P00`000[P2^0070[P0

0`000[P2^0070[P00`00Oomoo`02Ool010000EH1EP0010:h00D000:h0[P2^00000@2^003001oogoo

00=oo`03001oogoo02Uoo`00=Woo00<007ooOol01Goo00<0001b00001P1b00D0001b0780LP0000@2

^0030002^0:h00<2^0030002^0:h0082^0030000TP2B00H0TP030002^0:h00P2^0030002^0:h00L2

^0030002^0:h00L2^0030000e03D00H0e0030002^0:h00L2^0030002^0:h00L2^0030002^0:h00L2

^0030000m@3e00H0m@030002^0:h00L2^0030002^0:h00H2^0030002^0:h00L2^003001oo`0000H1

=@030002^0:h00H2^0030002^0:h00L2^0030002^0:h00L2^005001oogooOol000030EH00`000[P2

^0020[P01@000[P2^0:h000010:h00<007ooOol00goo00<007ooOol0:Goo000fOol00`00Oomoo`04

Ool010000780LP001P1b00D0001b0780LP0000@2^0030002^0:h00<2^0030002^0:h0082^0030000

TP2B00H0TP030002^0:h00P2^0030002^0:h00L2^0030002^0:h00L2^0030000e03D00H0e0030002

^0:h00L2^0030002^0:h00L2^0030002^0:h00L2^0030000m@3e00H0m@030002^0:h00L2^0030002

^0:h00H2^0030002^0:h00L2^08000L1=@030002^0:h00H2^0030002^0:h00L2^0030002^0:h00L2

^004001oogoo00040EH00`000[P2^0020[P01@000[P2^0:h000010:h00<007ooOol00goo00<007oo

Ool0:Goo000QOol50002Ool3000:Ool30005Ool010000780LP001P1b00D0001b0780LP0000@2^003

0002^0:h00<2^0030002^0:h0082^0030000TP2B00H0TP030002^0:h00P2^0030002^0:h00L2^003

0002^0:h00L2^0030000e03D00H0e0030002^0:h00L2^0030002^0:h00L2^0030002^0:h00L2^003

0000m@3e00H0m@030002^0:h00L2^0030002^0:h00H2^0030002^0:h00L2^0030001=@4e00H1=@03

0002^0:h00H2^0030002^0:h00L2^0030002^0:h00L2^004001oogoo00040EH00`000[P2^0020[P0

1@000[P2^0:h000010:h00<007ooOol00goo00<007ooOol0:Goo000ROol01P00Oomoo`00Ool000=o

o`03001oogoo00Moo`03001oogoo00Aoo`050000LP1b0780000:07800`000[P2^0020[P00`000[P2

^0030[P00`000[P2^0020[P00`000980TP0609800`000[P2^0080[P00`000[P2^0070[P00`000[P2

^0070[P00`000=@0e0060=@00`000[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P00`000?D0

m@060?D00`000[P2^0070[P00`000[P2^0060[P00`000[P2^0070[P00`000CD1=@060CD00`000[P2

^0060[P00`000[P2^0070[P00`000[P2^0070[P00`00Ool000050EH00`000[P2^0020[P01@000[P2

^0:h000010:h00<007ooOol00goo00<007ooOol0:Goo000SOol01@00Oomoogoo00000goo00<007oo

Ool01Woo00<007ooOol01Goo00D0001b0780LP0000X0LP030002^0:h0082^0030002^0:h00<2^003

0002^0:h0082^0030000TP2B00H0TP030002^0:h00P2^0030002^0:h00L2^0030002^0:h00L2^003

0000e03D00H0e0030002^0:h00L2^0030002^0:h00L2^0030002^0:h00L2^0030000m@3e00H0m@03

0002^0:h00L2^0030002^0:h00H2^0030002^0:h00L2^0030001=@4e00H1=@030002^0:h00H2^003

0002^0:h00L2^0030002^0:h00L2^08000H1EP030002^0:h0082^0050002^0:h0[P000040[P00`00

Oomoo`03Ool00`00Oomoo`0YOol001Yoo`L000=oo`04001oogoo0003Ool00`00Oomoo`06Ool00`00

Oomoo`04Ool00`000780LP0207800`000780LP0407801@000780LP1b000010:h00<000:h0[P00`:h

00<000:h0[P00P:h00<0002B09801P2B00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h

00<0003D0=@01P3D00<000:h0[P01`:h00<000:h0[P01`:h00<000:h0[P01`:h00<0003e0?D01P3e

00<000:h0[P01`:h00<000:h0[P01P:h00<000:h0[P01`:h00<0004e0CD01P4e00<000:h0[P01P:h

00<000:h0[P01`:h00<000:h0[P01`:h00<0005F0EH01@5F00<000:h0[P00P:h00D000:h0[P2^000

00@2^003001oogoo00=oo`03001oogoo02Uoo`009Goo00<007oo00000goo00<007ooOol01Goo00@0

07oo000000Aoo`030000LP1b0080LP030000LP1b00@0LP050000LP1b078000040[P00`000[P2^003

0[P00`000[P2^0020[P00`000980TP0609800`000[P2^0080[P00`000[P2^0070[P00`000[P2^007

0[P00`000=@0e0060=@00`000[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P00`000?D0m@06

0?D00`000[P2^0070[P00`000[P2^0060[P00`000[P2^0070[P00`000CD1=@060CD00`000[P2^006

0[P00`000[P2^0070[P00`000[P2^0070[P00`000EH1EP050EH00`000[P2^0020[P01@000[P2^0:h

000010:h00@007ooOomoo`<000eoo`<000Aoo`<001Aoo`009Goo00<007oo00000goo00<007ooOol0

1Goo00<007ooOol017oo00<0001b07800`1b00<0001b07800`1b00<0001b07800P1b00<000:h0[P0

0P:h00<000:h0[P00`:h00<000:h0[P00P:h00<0002B09801P2B00<000:h0[P020:h00<000:h0[P0

1`:h00<000:h0[P01`:h00<0003D0=@01P3D00<000:h0[P01`:h00<000:h0[P01`:h00<000:h0[P0

1`:h00<0003e0?D01P3e00<000:h0[P01`:h00<000:h0[P01P:h00<000:h0[P01`:h00<0004e0CD0

1P4e00<000:h0[P01P:h00<000:h0[P01`:h00<000:h0[P01`:h00<0005F0EH01@5F00<000:h0[P0

0P:h00D000:h0[P2^00000@2^003001oogoo00=oo`8000moo`04001oogoo0003Ool00`00Oomoo`0A

Ool002Eoo`03001oo`0000=oo`03001oogoo00Aoo`03001oogoo00Eoo`030000LP1b0080LP030000

LP1b00@0LP030000LP1b0080LP030002^0:h0082^0030002^0:h00<2^0030002^0:h0082^0030000

TP2B00H0TP030002^0:h00P2^0030002^0:h00L2^0030002^0:h00L2^0030000e03D00H0e0030002

^0:h00L2^0030002^0:h00L2^0030002^0:h00L2^0030000m@3e00H0m@030002^0:h00L2^0030002

^0:h00H2^0030002^0:h00L2^0030001=@4e00H1=@030002^0:h00H2^0030002^0:h00L2^0030002

^0:h00L2^0030001EP5F00D1EP030002^0:h0082^0050002^0:h0[P000040[P00`00Oomoo`03Ool2

000@Ool00`00Ool00003Ool00`00Oomoo`0AOol0025oo`07001oogooOol007oo00000goo00<007oo

Ool017oo0P001Goo00<0001b07800`1b00<0001b0780101b00<0001b07800P1b00<000:h0[P00P:h

00<000:h0[P00`:h00<000:h0[P00P:h00<0002B09801P2B00<000:h0[P020:h00<000:h0[P01`:h

00<000:h0[P01`:h00<0003D0=@01P3D00<000:h0[P01`:h00<000:h0[P01`:h00<000:h0[P01`:h

00<0003e0?D01P3e00<000:h0[P01`:h00<000:h0[P01P:h00<000:h0[P020:h00<0004e0CD01@4e

00<000:h0[P01P:h00<000:h0[P01`:h00<000:h0[P01`:h00<0005F0EH01@5F00<000:h0[P00P:h

00<000:h0[P00P:h00D000:h0[P2^00000Eoo`8000Eoo`L000Aoo`03001oo`0000=oo`03001oogoo

015oo`008Woo0`000goo0`001Woo00<007ooOol01Goo00<0001b07800`1b00<0001b07802@1b00<0

00:h0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h00<0002B09801P2B00<000:h0[P020:h00<0

00:h0[P01`:h00<000:h0[P01`:h00<0003D0=@01P3D00<000:h0[P01`:h00<000:h0[P01`:h00<0

00:h0[P01`:h00<0003e0?D01P3e00<000:h0[P01`:h00<000:h0[P01P:h00<000:h0[P020:h00<0

004e0CD01@4e00<000:h0[P01P:h00<000:h0[P01`:h00<000:h0[P01`:h00<0005F0EH01@5F00<0

00:h0[P00P:h00<000:h0[P00P:h00<000:h0[P00P:h00<007ooOol00goo00<007ooOol03Woo00<0

07oo00000goo00<007ooOol04Goo000aOol00`00Oomoo`04Ool00`000780LP0407800`000780LP09

07800`000[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P00`000980TP0609800`000[P2^008

0[P00`000[P2^0070[P00`000[P2^0070[P00`000=@0e0060=@00`000[P2^0070[P00`000[P2^007

0[P00`000[P2^0070[P00`000?D0m@060?D00`000[P2^0070[P00`000[P2^0060[P00`000[P2^008

0[P00`000CD1=@050CD00`000[P2^0070[P00`000[P2^0060[P00`000[P2^0070[P00`000EH1EP05

0EH00`000[P2^0020[P00`000[P2^0020[P00`000[P2^0020[P00`00Oomoo`03Ool00`00Oomoo`0=

Ool01000Oomoo`000goo00<007ooOol04Goo000`Ool30005Ool00`000780LP0407800`000780LP04

07800`000780LP0207800`000[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P00`000980TP05

09800`000[P2^0090[P00`000[P2^0070[P00`000[P2^0070[P00`000=@0e0060=@00`000[P2^007

0[P00`000[P2^0070[P00`000[P2^0070[P00`000?D0m@060?D00`000[P2^0070[P00`000[P2^006

0[P00`000[P2^0080[P00`000CD1=@050CD00`000[P2^0070[P00`000[P2^0070[P00`000[P2^006

0[P200060EH00`000[P2^0020[P00`000[P2^0020[P00`000[P2^0020[P00`00Oomoo`02Ool2000=

Ool20003Ool01@00Oomoogoo00004goo000`Ool00`00Oomoo`04Ool00`000780LP0507800`000780

LP0407800`000780LP0207800`000[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P00`000980

TP0509800`000[P2^0080[P00`000[P2^0080[P00`000[P2^0070[P00`000=@0e0060=@00`000[P2

^0070[P00`000[P2^0070[P00`000[P2^0070[P00`000?D0m@060?D00`000[P2^0070[P00`000[P2

^0060[P00`000[P2^0080[P00`000CD1=@050CD00`000[P2^0070[P00`000[P2^0070[P00`000[P2

^0070[P00`000EH1EP040EH00`000[P2^0020[P00`000[P2^0020[P00`000[P2^0020[P00`00Oomo

o`02Ool2000=Ool00`00Oomoo`02Ool01@00Oomoogoo00004goo000_Ool20006Ool00`000780LP05

07800`000780LP0407800`000780LP0207800`000[P2^0020[P00`000[P2^0030[P00`000[P2^002

0[P00`000980TP0509800`000[P2^0080[P00`000[P2^0080[P00`000[P2^0070[P00`000=@0e006

0=@00`000[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P00`000?D0m@060?D00`000[P2^007

0[P00`000[P2^0060[P00`000[P2^0080[P00`000CD1=@050CD00`000[P2^0070[P00`000[P2^007

0[P00`000[P2^0070[P00`000EH1EP050EH01@000[P2^0:h000010:h00<000:h0[P00P:h00@007oo

Oomoo`<000ioo`<0009oo`<001Aoo`00;goo1@000Woo00<0001b07801P1b00<0001b0780101b00<0

001b07800P1b00<000:h0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h00<0002B09801@2B00<0

00:h0[P020:h00<000:h0[P01`:h00<000:h0[P020:h00<0003D0=@01P3D00<000:h0[P01`:h00<0

00:h0[P01`:h00<000:h0[P01`:h00<0003e0[P01P3e00<000:h0[P01`:h00<000:h0[P01P:h00<0

00:h0[P020:h00<0004e0CD01@4e00<000:h0[P01`:h00<000:h0[P01`:h00<000:h0[P01`:h00<0

005F0EH01@5F00<000:h0[P00P:h00D000:h0[P2^00000@2^003001oogoo00=oo`03001oogoo02Qo

o`00;goo00<007ooOol017oo00<0001b07801P1b00<0001b07802@1b00<000:h0[P00P:h00<000:h

0[P00`:h00<000:h0[P00P:h1@000`2B00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P020:h

00<0003D0=@01P3D00<000:h0[P01`:h00<000:h0[P01`:h00<000:h0[P01`:h00@0003e0?D2^0D0

m@030002^0:h00L2^0030002^0:h00H2^0030002^0:h00P2^0030001=@4e00D1=@030002^0:h00L2

^0030002^0:h00L2^0030002^0:h00L2^0030001EP5F00D1EP030002^0:h0082^0050002^0:h0[P0

00040[P00`00Oomoo`03Ool00`00Oomoo`0XOol002moo`03001oogoo00=oo`030000LP1b00L0LP03

0000LP1b00T0LP030002^0:h0082^0030002^0:h00<2^0030002^0:h0082^004001/66`HK1P40980

0`000[P2^0080[P00`000[P2^0070[P00`000[P2^0080[P00`000=@0e0050=@00`000[P2^0080[P0

0`000[P2^0070[P00`000[P2^0070[P00`000?D0m@020?D01@:h0?D0m@3e00002@:h00<000:h0[P0

1P:h00<000:h0[P020:h00<0004e0CD01@4e00<000:h0[P01`:h00<000:h0[P01`:h00<000:h0[P0

1`:h00<0005F0EH01@5F00<000:h0[P00P:h00D000:h0[P2^00000@2^003001oogoo00=oo`03001o

ogoo02Qoo`00;goo00<007ooOol00goo00<0001b07801`1b00<0001b0780101b00<0001b07800P1b

00<000:h0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h00@006`HK1Q/60@0TP030002^0:h00P2

^0030002^0:h00L2^0030002^0:h00P2^0030000e03D00D0e0030002^0:h00P2^0030002^0:h00L2

^0030002^0:h00L2^0030000m@3e00@0m@030[P0m@0000T2^0030002^0:h00H2^0030002^0:h00P2

^0030001=@4e00D1=@030002^0:h00L2^0030002^0:h00L2^0030002^0:h00L2^0030001EP5F00D1

EP030002^0:h0082^0050002^0:h0[P000040[P00`00Oomoo`03Ool00`00Oomoo`0XOol003Aoo`03

0000LP1b00P0LP030000LP1b00@0LP030000LP1b0080LP030002^0:h0082^0030002^0:h00<2^003

0002^0:h0082^004001/66`HK1P409800`000[P2^0080[P00`000[P2^0070[P00`000[P2^0080[P0

0`000=@0e0050=@00`000[P2^0080[P00`000[P2^0070[P00`000[P2^0070[P00`000?D0m@060?D0

0`000[P2^0070[P00`000[P2^0060[P00`000[P2^0080[P00`000CD1=@050CD00`000[P2^0070[P0

0`000[P2^0070[P00`000[P2^0070[P00`000EH1EP050EH00`000[P2^0020[P01@000[P2^0:h0000

10:h00<007ooOol00goo00<007ooOol0:7oo000dOol00`000780LP0807800`000780LP0407800`00

0780LP0207800`000[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P01000K1Q/66`H102B00<0

00:h0[P020:h00<000:h0[P01`:h00<000:h0[P020:h00<0003D0=@01@3D00<000:h0[P020:h00<0

00:h0[P01`:h00<000:h0[P01`:h00<0003e0?D01P3e00<000:h0[P01`:h00<000:h0[P01P:h00<0

00:h0[P020:h00<0004e0CD01@4e00<000:h0[P01`:h00<000:h0[P01`:h00<000:h0[P01`:h00<0

005F0EH01@5F00<000:h0[P00P:h00D000:h0[P2^00000@2^003001oogoo00=oo`03001oogoo02Qo

o`00;goo00<007ooOol00Woo00<0001b0780201b00<0001b0780101b00<0001b07800P1b00<000:h

0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h00@006`HK1Q/60@0TP030002^0:h00P2^0030002

^0:h00L2^0030002^0:h00P2^0D000<0e0030002^0:h00P2^0030002^0:h00L2^0030002^0:h00L2

^0030000m@3e00H0m@030002^0:h00L2^0030002^0:h00H2^0030002^0:h00P2^0030001=@4e00D1

=@030002^0:h00L2^0030002^0:h00L2^0030002^0:h00L2^0030001EP5F00D1EP030002^0:h0082

^0050002^0:h0[P000040[P00`00Oomoo`03Ool00`00Oomoo`0XOol002moo`03001oogoo009oo`03

0000LP1b00P0LP030000LP1b00T0LP030002^0:h0082^0030002^0:h00<2^0030002^0:h0082^004

001/66`HK1P409800`000[P2^0080[P00`000[P2^0070[P00`000[P2^0080[P01@00K1Q/66`H0000

0`3D00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h00<0003e0?D01P3e00<000:h0[P0

1`:h00<000:h0[P01P:h00<000:h0[P020:h00<0004e0CD01@4e00<000:h0[P01`:h00<000:h0[P0

1`:h00<000:h0[P01`:h00<0005F0EH01@5F00<000:h0[P00P:h00D000:h0[P2^00000@2^003001o

ogoo009oo`8002Yoo`00;goo00<007ooOol00Woo00<0001b0780201b00<0001b07802@1b00<000:h

0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h00@006`HK1Q/60@0TP030002^0:h00P2^0030002

^0:h00L2^0030002^0:h00P2^005001/66`HK1P000030=@00`000[P2^0080[P00`000[P2^0070[P0

0`000[P2^0070[P00`000?D0m@060?D00`000[P2^0070[P00`000[P2^0060[P00`000[P2^0080[P0

0`000CD1=@050CD00`000[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P00`000EH1EP050EH0

0`000[P2^0020[P01@000[P2^0:h000010:h00<007ooOol00goo00<007ooOol0:7oo000_Ool00`00

Oomoo`02Ool00`000780LP0807800`000780LP0407800`000780LP0207800`000[P2^0020[P00`00

0[P2^0030[P00`000[P2^0020[P5000309800`000[P2^0080[P00`000[P2^0070[P00`000[P2^008

0[P01@00K1Q/66`H00000`3D00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h00<0003e

0?D01P3e00<000:h0[P01`:h00<000:h0[P01P:h00<000:h0[P020:h00<0004e0CD01@4e00<000:h

0[P01`:h00<000:h0[P01`:h00<000:h0[P01`:h00<0005F0EH01@5F00<000:h0[P00P:h00D000:h

0[P2^00000@2^003001oogoo00=oo`03001oogoo02Qoo`00=7oo00<0001b0780201b00<0001b0780

101b00<0001b07800P1b00<000:h0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h00@006`HK1Q/

60@0TP030002^0:h00P2^0030002^0:h00L2^0030002^0:h00P2^005001/66`HK1P000030=@00`00

0[P2^0080[P00`000[P2^0070[P00`000[P2^0070[P00`000?D000060?D00`000[P2^0070[P00`00

0[P2^0070[P00`000[P2^0070[P00`000CD1=@050CD00`000[P2^0070[P00`000[P2^0070[P00`00

0[P2^0070[P00`000EH1EP050EH00`000[P2^0020[P01@000[P2^0:h000010:h00<007ooOol00goo

00<007ooOol0:7oo000dOol00`000780LP0807800`000780LP0407800`000780LP0207800`000[P2

^0020[P00`000[P2^0030[P00`000[P2^0020[P01000K1Q/66`H102B00<000:h0[P020:h00<000:h

0[P01`:h00<000:h0[P020:h00D006`HK1Q/600000<0e0030002^0:h00P2^0030002^0:h00L2^003

0002^0:h00L2^0D000@0m@030002^0:h00L2^0030002^0:h00L2^0030002^0:h00L2^0030001=@4e

00D1=@030002^0:h00L2^0030002^0:h00L2^0030002^0:h00L2^0030001EP5F00D1EP030002^0:h

0082^0050002^0:h0[P000040[P00`00Oomoo`03Ool00`00Oomoo`0XOol003Aoo`030000LP1b00P0

LP030000LP1b00@0LP030000LP1b0080LP030002^0:h0082^0030002^0:h00<2^0030002^0:h0082

^004001/66`HK1P409800`000[P2^0080[P00`000[P2^0070[P00`000[P2^0080[P01@00K1Q/66`H

00000`3D00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h0P000V`H1@3e00<000:h0[P0

1`:h00<000:h0[P01`:h00<000:h0[P01`:h00<0004e0CD01@4e00<000:h0[P01`:h00<000:h0[P0

1`:h00<000:h0[P01`:h00<0005F0EH01@5F00<000:h0[P00P:h00D000:h0[P2^00000@2^003001o

ogoo00=oo`03001oogoo02Qoo`00;Woo00<007ooOol00goo00<0001b0780201b00<0001b0780101b

00D0001b0780LP0000@2^0030002^0:h00@2^0030002^0:h0082^004001/66`HK1P409800`000[P2

^0080[P00`000[P2^0070[P00`000[P2^0080[P01@00K1Q/66`H00000`3D00<000:h0[P020:h00<0

00:h0[P01`:h00<000:h0[P01`:h0P000V`H1@3e00<000:h0[P01`:h00<000:h0[P01`:h00<000:h

0[P01`:h00<0004e0CD01@4e0P0020:h00<000:h0[P01`:h00<000:h0[P01`:h00<0005F0EH01@5F

00<000:h0[P00P:h00D000:h0[P2^00000@2^003001oogoo00=oo`03001oogoo02Qoo`00;Woo00<0

07ooOol00goo00<0001b0780201b00<0001b0780201b00<000:h0[P00P:h00<000:h0[P00`:h00<0

00:h0[P00`:h00@006`HK1Q/60@0TP030002^0:h00P2^0030002^0:h00L2^0030002^0:h00P2^0D0

00<0e0030002^0:h00P2^0030002^0:h00L2^0030002^0:h00L2^080009/60D0m@030002^0:h00L2

^0030002^0:h00L2^0030002^0:h00L2^0030001=@4e00D1=@8000P2^0030002^0:h00L2^0030002

^0:h00L2^0030001EP5F00D1EP030002^0:h0082^0050002^0:h0[P000040[P00`00Oomoo`03Ool0

0`00Oomoo`0XOol002ioo`03001oogoo00=oo`030000LP1b00P0LP030000LP1b00P0LP030002^0:h

0082^0030002^0:h00<2^0030002^0:h0082^08000=/60@0TP030002^0:h00P2^0030002^0:h00L2

^0030002^0:h00P2^005001/66`HK1P000030=@00`000[P2^0080[P00`000[P2^0070[P00`000[P2

^0070[P20002K1P50?D00`000[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P00`000CD1=@05

0CD200080[P00`000[P2^0070[P00`000[P2^0070[P00`000EH1EP050EH00`000[P2^0020[P01@00

0[P2^0:h000010:h00<007ooOol00Woo0P00:Woo000^Ool00`00Oomoo`03Ool00`000780LP080780

0`000780LP0407801@000780LP1b000010:h00<000:h0[P00`:h00<000:h0[P00P:h0P000f`H102B

00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P020:h00D006`HK1Q/600000<0e0030002^0:h

00P2^0030002^0:h00L2^0030002^0:h00L2^080009/60D0m@030002^0:h00L2^0030002^0:h00L2

^0030002^0:h00L2^0<000D1=@8000P2^0030002^0:h00L2^0030002^0:h00L2^0030001EP5F00D1

EP030002^0:h0082^0050002^0:h0[P000040[P00`00Oomoo`03Ool00`00Oomoo`0XOol003Aoo`03

0000LP1b00L0LP030000LP1b00D0LP050000LP1b078000040[P00`000[P2^0030[P00`000[P2^002

0[P6000309800`000[P2^0080[P00`000[P2^0070[P00`000[P2^0080[P01@00K1Q/66`H00000`3D

00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h0P000V`H1@3e00<000:h0[P01`:h00<0

00:h0[P01`:h00<000:h0[P01`:h00<006`H00001@4e0P0020:h00<000:h0[P01`:h00<000:h0[P0

1`:h00<0005F0EH01@5F00<000:h0[P00P:h00D000:h0[P2^00000@2^003001oogoo00=oo`03001o

ogoo02Qoo`00=7oo00<0001b07801`1b00<0001b07801@1b00D0001b0780LP0000@2^0030002^0:h

00<2^0030002^0:h0082^08000=/60@0TP030002^0:h00P2^0030002^0:h00L2^0030002^0:h00P2

^005001/66`HK1P000030=@00`000[P2^0080[P00`000[P2^0070[P00`000[P2^0070[P20002K1P5

0?D00`000[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P00`00K1P000060CD00`000[P2^006

0[P00`000[P2^0070[P00`000[P2^0070[P00`000EH1EP050EH00`000[P2^0020[P00`000[P2^002

0[P01@000[P2^0:h00001Goo00<007ooOol0:7oo000^Ool00`00Oomoo`03Ool00`000780LP070780

0`000780LP0507801@000780LP1b000010:h00<000:h0[P00`:h00<000:h0[P00P:h0P0016`H0`2B

00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P020:h00D006`HK1Q/600000<0e0030002^0:h

00P2^0030002^0:h00L2^0030002^0:h00L2^0D000@0m@030002^0:h00L2^0030002^0:h00L2^003

0002^0:h00L2^003001/600000H1=@030002^0:h00H2^0030002^0:h00L2^0030002^0:h00L2^003

0001EP5F00D1EP030002^0:h0082^0030002^0:h0082^0030002^0:h0082^003001oogoo009oo`03

001oogoo02Qoo`00;Woo00<007ooOol00goo00<0001b07801`1b00<0001b07802@1b00<000:h0[P0

0P:h00<000:h0[P00`:h00<000:h0[P00P:h0P0016`H0`2B00<000:h0[P020:h00<000:h0[P01`:h

00<000:h0[P020:h00D006`HK1Q/600000<0e0030002^0:h00P2^0030002^0:h00L2^0030002^0:h

00L2^080009/60D0m@030002^0:h00L2^0030002^0:h00L2^0030002^0:h00L2^003001/600000H1

=@030002^0:h00H2^0030002^0:h00L2^0030002^0:h00L2^0<000D1EP030002^0:h0082^0030002

^0:h0082^0030002^0:h0082^003001oogoo00=oo`03001oogoo02Moo`00;Woo00<007ooOol00goo

00<0001b07801`1b00<0001b07802@1b00<000:h0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h

00<006`HK1P00f`H0`2B00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P020:h00D006`HK1Q/

600000<0e0030002^0:h00P2^0030002^0:h00L2^0030002^0:h00L2^080009/60D0m@030002^0:h

00L2^0030002^0:h00L2^0030002^0:h00L2^003001/600000H1=@030002^0:h00H2^0030002^0:h

00L2^0030002^0:h00L2^003001/66`H00D1EP030002^0:h0082^0030002^0:h0082^0030002^0:h

0082^003001oogoo00=oo`03001oogoo02Moo`00;Woo00<007ooOol00Woo00<0001b0780201b00<0

001b07801@1b00D0001b0780LP0000@2^0030002^0:h00<2^0030002^0:h0082^003001/66`H00=/

60<0TP030002^0:h00P2^0030002^0:h00L2^0030002^0:h00P2^0D000<0e0030002^0:h00P2^003

0002^0:h00L2^0030002^0:h00L2^080009/60D0m@030002^0:h00L2^0030002^0:h00L2^0030002

^0:h00L2^003001/600000H1=@030002^0:h00H2^0030002^0:h00L2^0030002^0:h00L2^003001/

66`H00D1EP030002^0:h0082^0030002^0:h0082^0030002^0:h0082^003001oogoo009oo`8002Uo

o`00<goo00<0001b0780201b00<0001b07801@1b00D0001b0780LP0000@2^0030002^0:h00<2^003

0002^0:h0082^003001/66`H00=/60<0TP030002^0:h00P2^0030002^0:h00L2^0030002^0:h00P2

^005001/66`HK1P000030=@00`000[P2^0080[P00`000[P2^0070[P00`000[P2^0070[P20002K1P5

0?D00`000[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P300060CD00`000[P2^0060[P00`00

0[P2^0070[P00`000[P2^0070[P00`00K1Q/60050EH00`000[P2^0020[P00`000[P2^0020[P00`00

0[P2^0020[P01000Oomoogoo0`00:Goo000cOol00`000780LP0807800`000780LP0507801@000780

LP1b000010:h00<000:h0[P00`:h00<000:h0[P00P:h00<006`HK1P00f`H0`2B00<000:h0[P020:h

00<000:h0[P01`:h00<000:h0[P020:h00D006`HK1Q/600000<0e0030002^0:h00P2^0030002^0:h

00L2^0030002^0:h00L2^080009/60D0m@030002^0:h00L2^0030002^0:h00L2^0030002^0:h00L2

^004001/600000050CD00`000[P2^0060[P00`000[P2^0070[P00`000[P2^0070[P00`00K1Q/6005

0EH00`000[P2^0020[P00`000[P2^0020[P00`000[P2^0020[P00`00Oomoo`03Ool00`00Oomoo`0W

Ool002ioo`03001oogoo009oo`030000LP1b00P0LP030000LP1b00D0LP050000LP1b078000040[P0

0`000[P2^0030[P00`000[P2^0020[P30003K1P309800`000[P2^0080[P00`000[P2^0070[P00`00

0[P2^0080[P01@00K1Q/66`H00000`3D00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h

0P000V`H1@3e00<000:h0[P01`:h00<000:h0[P01`:h00<000:h0[P01`:h00<006`H00001P4e00<0

00:h0[P01P:h00<000:h0[P01`:h00<000:h0[P01`:h00<006`HK1P01@5F00<000:h0[P00P:h00<0

00:h0[P00P:h00<000:h0[P00P:h00<007ooOol00goo00<007ooOol09goo000^Ool00`00Oomoo`02

Ool00`000780LP0807800`000780LP0907800`000[P2^0020[P00`000[P2^0030[P00`000[P2^002

0[P00`00K1Q/6003000309800`000[P2^0080[P00`000[P2^0070[P00`000[P2^0080[P01000K1Q/

6000103D00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h0P000V`H1@3e00<000:h0[P0

1`:h00<000:h0[P01`:h00<000:h0[P01`:h00<006`H00001P4e00<000:h0[P01P:h00<000:h0[P0

1`:h00<000:h0[P01`:h00<006`HK1P01@5F00<000:h0[P00P:h00<000:h0[P00P:h00<000:h0[P0

0P:h00<007ooOol00goo00<007ooOol09goo000^Ool00`00Oomoo`02Ool00`000780LP0807800`00

0780LP0907800`000[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P00`00K1Q/6003K1P30980

0`000[P2^0080[P00`000[P2^0070[P00`000[P2^0080[P01000K1Q/6000103D00<000:h0[P020:h

00<000:h0[P01`:h00<000:h0[P01`:h1@00103e00<000:h0[P01`:h00<000:h0[P01`:h00<000:h

0[P01`:h00<006`H00001P4e00<000:h0[P01P:h00<000:h0[P01`:h00<000:h0[P01`:h00<006`H

K1P01@5F00<000:h0[P00P:h00<000:h0[P00P:h00<000:h0[P00P:h00<007ooOol00goo00<007oo

Ool09goo000^Ool00`00Oomoo`02Ool00`000780LP0807800`000780LP0407800`000780LP020780

0`000[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P00`00K1Q/6003K1P309800`000[P2^008

0[P00`000[P2^0070[P00`000[P2^0080[P01000K1Q/6000103D00<000:h0[P020:h00<000:h0[P0

1`:h00<000:h0[P01`:h0P000V`H00<2^03e0?D00P3e00<000:h0[P01`:h00<000:h0[P01`:h00<0

00:h0[P01`:h00<006`H00001P4e00<000:h0[P01P:h00<000:h0[P01`:h00<000:h0[P01`:h0`00

1@5F00<000:h0[P00P:h00<000:h0[P00P:h00<000:h0[P00P:h00<007ooOol00goo00<007ooOol0

9goo000cOol00`000780LP0807800`000780LP0407800`000780LP0207800`000[P2^0020[P00`00

0[P2^0030[P00`000[P2^0020[P00`00K1Q/6003K1P309800`000[P2^0080[P00`000[P2^0070[P0

0`000[P2^0080[P01000K1Q/6000103D00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h

0P000V`H1@3e00<000:h0[P01`:h00<000:h0[P01`:h00<000:h0[P01`:h00<006`H00001P4e00<0

00:h0[P01P:h00<000:h0[P01`:h00<000:h00001`:h00<006`HK1P01@5F00<000:h0[P00P:h00<0

00:h0[P00P:h00<000:h0[P00P:h00<007ooOol00goo00<007ooOol09goo000cOol00`000780LP08

07800`000780LP0407800`000780LP0207800`000[P2^0020[P00`000[P2^0030[P00`000[P2^002

0[P00`00K1Q/6003K1P309800`000[P2^0080[P00`000[P2^0070[P00`000[P2^0080[P500030=@0

0`000[P2^0080[P00`000[P2^0070[P00`000[P2^0070[P20002K1P50?D00`000[P2^0070[P00`00

0[P2^0070[P00`000[P2^0080[P200060CD00`000[P2^0060[P00`000[P2^0070[P00`000[P2^007

0[P00`00K1Q/60050EH00`000[P2^0020[P00`000[P2^0020[P00`000[P2^0020[P00`00Oomoo`03

Ool00`00Oomoo`0;Ool5000017oo000000004goo000cOol00`000780LP0807800`000780LP040780

0`000780LP02078400000`:h000000040[P00`000[P2^0020[P00`00K1Q/6003K1P309800`000[P2

^0080[P00`000[P2^0070[P00`000[P2^0080[P01000K1Q/6000103D00<000:h0[P020:h00<000:h

0[P01`:h00<000:h0[P01`:h00H006`H001/603e0[P30?D00`000[P2^0070[P00`000[P2^0070[P0

0`000[P2^0070[P300060CD00`000[P2^0060[P00`000[P2^0070[P00`000[P2^0070[P00`00K1Q/

60050EH00`000[P2^0020[P00`000[P2^0020[P00`000[P2^0020[P01000Oomoogoo0`003Woo00@0

07ooOol000Aoo`03001oogoo011oo`00;Woo00<007ooOol00Woo00<0001b0780201b00<0001b0780

101b00D0001b0780LP0000@3O`P000@2^003001/66`H00=/60<0TP030002^0:h00P2^0030002^0:h

00L2^0030002^0:h00P2^004001/66`H00040=@00`000[P2^0080[P00`000[P2^0070[P00`000[P2

^0070[P01000K1P006`H1@3e00<000:h0[P01`:h00<000:h0[P01`:h00<000:h0[P020:h0`001@4e

00<000:h0[P01`:h00<000:h0[P01P:h00<000:h0[P01`:h00<006`HK1P01@5F00<000:h0[P00P:h

00<000:h0[P00P:h00<000:h0[P00P:h00<007ooOol00goo00<007ooOol03Goo00<007ooOol01Goo

00<007ooOol03goo000^Ool00`00Oomoo`02Ool00`000780LP0807800`000780LP0807800`000gl3

O`020gl00`000gl3O`030gl00`000gl000060003K1P309800`000[P2^0080[P00`000[P2^0070[P0

0`000[P2^0080[P01000K1Q/6000103D00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h

00@006`H001/60D0m@030002^0:h00L2^0030002^0:h00L2^0030002^0:h00P2^08000H1=@030002

^0:h00L2^0030002^0:h00L2^0030002^0:h00H2^0800003K1P1EP5F00<1EP030002^0:h0082^003

0002^0:h0082^0030002^0:h0082^003001oogoo00=oo`03001oogoo00Aoo`L000=oo`03001oogoo

00Aoo`03001oogoo00moo`00;Woo00<007ooOol00Woo00<0001b0780201b00<0001b07801`1b00<0

00=o0gl00P=o00<000=o0gl010=o00<000=o0gl00`=o00<006`HK1P00`000`2B1P001@:h00<000:h

0[P01`:h00<000:h0[P020:h00@006`HK1P000@0e0030002^0:h00P2^0030002^0:h00L2^0030002

^0:h00L2^004001/6000K1P20?D010:h0?D0m@002@:h00<000:h0[P01`:h00<000:h0[P020:h0P00

1P4e00<000:h0[P01`:h00<000:h0[P01`:h00<000:h0[P01`:h00<006`H0EH0105F00<000:h0[P0

0P:h00<000:h0[P00P:h00<000:h0[P00P:h00<007ooOol00goo00<007ooOol03goo00<007ooOol0

0goo00<007ooOol03goo000^Ool00`00Oomoo`02Ool00`000780LP0807800`000780LP0407801000

0780LP0010=o00<000=o0gl00`=o00<000=o0gl00`=o0P001F`H0P2B00<000=o0gl010=o2P001@:h

00<000:h0[P020:h00@006`HK1P000@0e0030002^0:h00P2^0030002^0:h00L2^0030002^0:h00L2

^0D000@0m@030002^0:h00L2^0030002^0:h00L2^0030002^0:h00P2^08000H1=@030002^0:h00L2

^0030002^0:h00L2^0030002^0:h00L2^003001/605F00D1EP050002^0:h0[P000040[P00`000[P2

^0020[P00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool003=oo`03

0000LP1b00P0LP030000LP1b00@0LP030000LP0000@3O`030003O`=o00@3O`030003O`=o00<3O`03

K1P006`H00A/6080TP030003O`=o00P3O`030003O`=o00<3O`/000D2^004001/66`H00040=@00`00

0[P2^0080[P00`000[P2^0070[P00`000[P2^0070[P01000K1P006`H1@3e00<000:h0[P01`:h00<0

00:h0[P01`:h00<000:h0[P020:h00<006`H00001@4e00<000:h0[P01`:h00<000:h0[P01`:h00<0

00:h0[P01P:h0`001P5F00<000:h0[P00P:h00D000:h0[P2^00000@2^003001oogoo00=oo`03001o

ogoo00moo`03001oogoo008001=oo`00<goo00<0001b0780201b00<0001b0780101b0P0010=o00<0

00=o0gl010=o00<000=o0gl00`=o00<006`H00001F`H00<0TP000gl02P=o00<000=o0gl01`=o00<0

00=o0gl010=o1P000V`H00<0003D0=@00P3D00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P0

1`:h00@006`H001/60<0m@030[P0m@0000T2^0030002^0:h00L2^0030002^0:h00P2^003001/6000

00D1=@030002^0:h00L2^0030002^0:h00L2^0030002^0:h00L2^003001/605F00D1EP030002^0:h

0082^0050002^0:h0[P000040[P00`00Oomoo`03Ool00`00Oomoo`0;Ool01@00Oomoogoo00000Woo

00<007ooOol04Woo000^Ool00`00Oomoo`02Ool00`000780LP0807800`000780LP04078200040gl0

0`000gl3O`030gl00`000gl3O`040gl2K1P00`00K1Q/6003K1P00`2B0003O`090gl00`000gl3O`08

0gl00`000gl3O`080gl300000f`H000000030=@400070[P00`000[P2^0070[P00`000[P2^0070[P0

1000K1P006`H1@3e00<000:h0[P01`:h00<000:h0[P01`:h00<000:h0[P020:h00<006`H00001@4e

00<000:h0[P01`:h00<000:h0[P01`:h00<000:h0[P01`:h00<006`H0EH01@5F00<000:h0[P00P:h

00D000:h0[P2^00000@2^003001oogoo00=oo`03001oogoo00aoo`<000Aoo`<0015oo`00;Woo00<0

07ooOol00Woo00<0001b0780201b00<0001b0780101b00<000=o0gl00P=o00<000=o0gl010=o00<0

00=o0gl00`=o00@006`HK1P000E/60030003O`=o00P3O`030003O`=o00P3O`030003O`=o00T3O`03

001/66`H00<00080e0030003O`=o0083O`P000T2^0030002^0:h00L2^004001/6000K1P50?D00`00

0[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P200000f`H0001=@040CD00`000[P2^0070[P0

0`000[P2^0070[P00`000[P2^0070[P00`00K1P1EP050EH00`000[P2^0020[P01@000[P2^0:h0000

10:h00<007ooOol00Woo0P00:Goo000]Ool00`00Oomoo`03Ool00`000780LP0807800`000780LP04

07800`000gl3O`020gl00`000gl3O`030gl00`000gl3O`030gl01@00K1Q/66`H00001F`H00<000=o

0gl01`=o00<000=o0gl020=o00<000=o0gl02@=o0P000f`H00D0003D0=@0e00000/3O`T000030[P0

00:h00P2^004001/6000K1P40?D00`:h0002^0080[P00`000[P2^0070[P00`000[P2^0080[P30005

0CD00`000[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P00`00K1P1EP050EH00`000[P2^002

0[P01@000[P2^0:h000010:h00<007ooOol00goo00<007ooOol09goo000]Ool00`00Oomoo`03Ool0

0`000780LP0707800`000780LP04078200030gl00`000gl3O`040gl00`000gl3O`030gl60003K1P0

0`000gl3O`080gl00`000gl3O`080gl00`000gl3O`080gl00`00K1P00003K1P010000=@0e0002`=o

00<000=o0gl01`=o20000`:h00@006`H001/60D0m@030002^0:h00L2^0030002^0:h00L2^0030002

^0:h00P2^003001/600000D1=@030002^0:h00L2^0030002^0:h00L2^0030002^0:h00L2^003001/

605F00D1EP030002^0:h0082^0050002^0:h0[P000040[P00`00Oomoo`03Ool00`00Oomoo`0WOol0

03=oo`030000LP1b00L0LP030000LP1b00<0LP030003O`000083O`030003O`=o00@3O`030003O`=o

00<3O`03001L7e`O009L7`H000T3O`030003O`=o00P3O`030003O`=o00P3O`04001/66`H0003K1P0

0`000=@0000;0gl00`000gl3O`080gl00`000gl3O`050gl400000f`H001/60050?D00`000[P2^007

0[P00`000[P2^0070[P00`000[P2^0080[P00`00K1P000050CD00`000[P2^0070[P00`000[P2^007

0[P00`000[P2^0070[P00`00K1P1EP050EH00`000[P2^0020[P00`000[P2^0020[P01@000[P2^0:h

00001Goo00<007ooOol09goo000cOol00`000780LP0707800`000780LP0307800`000gl000020gl0

0`000gl3O`030gl00`000gl3O`040gl01@00G1mL7e`O000015`O00<000=o0gl01`=o00<000=o0gl0

2@=o00<000=o0gl020=o00@006`HK1P000=/608000`3O`030003O`=o00L3O`030003O`=o00P3O`H0

00@0m@@000H2^0030002^0:h00L2^0030002^0:h00P2^003001/600000D1=@030002^0:h00L2^003

0002^0:h00L2^0030002^0:h00L2^003001/605F00D1EP030002^0:h0082^0030002^0:h0082^003

0002^0:h0082^003001oogoo009oo`03001oogoo02Moo`00;Goo00<007ooOol00goo00<0001b0780

1`1b00<0001b07800P1b00H000=o0gl000=o00060gl00`000gl3O`030gl00`00G1mL7`02G1l00`00

G1mL7`02G1l00`000gl3O`070gl00`000gl000080gl00`000gl3O`080gl01@00K1Q/66`H00000f`H

0P002`=o00<000=o0gl020=o00<000=o0gl020=o00D006`HK1P006`H00@0m@030003O`=o0083O`P0

00P2^0030002^0:h00P2^003001/600000D1=@030002^0:h00L2^0030002^0:h00L2^0030002^0:h

00L2^08000H1EP030002^0:h0082^0030002^0:h0082^0030002^0:h0082^003001oogoo009oo`03

001oogoo02Moo`00;Goo00<007ooOol00goo00<0001b07801`1b00<0001b07800P1b00<000=o0gl0

0P=o00<000=o0gl00`=o00<000=o0gl00`=o0P000e`O00<005`OG1l00U`O00<000=o0gl01`=o00<0

00=o0gl020=o00<000=o0gl020=o0P000f`H00D006`HK1Q/600000/3O`030003O`=o00P3O`030003

O`=o00P3O`80009/6003001/603e0080m@8000T3O`030003O`=o00X000T2^003001/600000D1=@03

0002^0:h00L2^0030002^0:h00L2^0030002^0:h00L2^003001/605F00D1EP030002^0:h0082^003

0002^0:h0082^0030002^0:h0082^003001oogoo009oo`03001oogoo02Moo`00;Goo00<007ooOol0

0goo00<0001b07801`1b00D0001b0780LP0000@3O`030003O`=o00@3O`030003O`=o00<3O`05001L

7e`OG1l00004G1l00`000gl3O`070gl00`000gl3O`090gl00`000gl3O`080gl70002K1P00`000gl3

O`080gl00`000gl3O`080gl00`000gl3O`080gl00`00K1P00002K1P00`00K1P0m@020?D00`000gl3

O`080gl00`000gl3O`070gl900030[P00`00K1P000050CD00`000[P2^0070[P00`000[P2^0070[P0

0`000[P2^0070[P00`00K1P1EP050EH00`000[P2^0020[P00`000[P2^0020[P00`000[P2^0020[P0

0`00Oomoo`02Ool00`00Oomoo`0WOol002eoo`03001oogoo00=oo`030000LP1b00L0LP050000LP1b

078000030gl200050gl00`000gl3O`020gl20004G1l00`00G1mL7`02G1l00`000gl3O`060gl00`00

0gl3O`090gl00`000gl3O`080gl20003G1l600090gl00`000gl3O`080gl00`000gl3O`080gl20000

1V`H001/66`H001/6080m@030003O`=o00P3O`030003O`=o00L3O`030003O`=o00L3O`@00003K1P0

004e00@1=@030002^0:h00L2^0030002^0:h00L2^0030002^0:h00L2^003001/605F00D1EP030002

^0:h0082^0030002^0:h0082^0030002^0:h0082^004001oogooOol3000XOol003=oo`030000LP1b

00L0LP040000LP1b00040gl00`000gl3O`040gl00`000gl3O`020gl20003G1l00`00G1mL7`02G1l0

0`000gl3O`070gl00`000gl3O`080gl00`000gl3O`080gl00`0071<00003G1l01@00G1mL7e`O0000

2P=o00<000=o0gl020=o00<000=o0gl020=o0P0000Q/6000K1Q/6000K1P0m@002P=o00<000=o0gl0

20=o00<000=o0gl01`=o0`0000=/600000001@4e1@001@:h00<000:h0[P01`:h00<000:h0[P01`:h

00<006`H00001@5F00<000:h0[P00P:h00<000:h0[P00P:h00<000:h0[P00P:h00<007ooOol00Woo

0P00:7oo000cOol00`000780LP0707800`00078000040gl200050gl00`000gl3O`030gl50004G1l0

0`000gl3O`070gl00`000gl3O`090gl00`000gl3O`080gl20003G1l00`00G1mL7`02G1l00`000gl3

O`070gl00`000gl3O`080gl00`000gl3O`080gl00`00K1P000020002K1P01000K1P000002@=o00<0

00=o0gl020=o00<000=o0gl01@=o0P000P=o00D006`HK1Q/600000@1=@030003O`=o00<3O`X000D2

^0030002^0:h00L2^003001/600000D1EP030002^0:h0082^0030002^0:h0082^0030002^0:h0082

^003001oogoo009oo`8002Qoo`00<goo00<0001b07801`1b00<0001b000010=o0P0010=o00<000=o

0gl00`=o0P000e`O1P0020=o00<000=o0gl02@=o00<000=o0gl020=o0P000e`O00<005`OG1l00U`O

00<000=o0gl01`=o00<000=o0gl020=o00<000=o0gl02@=o1@000V`H00<006`H00002@=o0P002@=o

00<000=o0gl00`=o0P0010=o0P000f`H00D0004e0CD1=@0000X3O`030003O`=o00<3O`X000D2^003

001/600000D1EP030002^0:h0082^0030002^0:h0082^0030002^0:h0082^003001oogoo009oo`80

02Qoo`00;Goo00<007ooOol00goo00<0001b07801`1b0P0010=o00<000=o000010=o00<000=o0gl0

0P=o0P000e`O00<005`OG1l00U`O00<000=o0gl01`=o00<000=o0gl020=o00<000=o0gl020=o0P00

15`O00D005`OG1mL7`0000T3O`030003O`=o00P3O`030003O`=o00T3O`03001L7e`O00P000T3O`03

0003O`=o00L3O`050003O`=o0gl000070gl00`00K1P00003K1P010000CD1=@002P=o00<000=o0gl0

20=o00<000=o0gl00`=o1P0000=/60000EH0105F00<000:h0[P00P:h00<000:h0[P00P:h00<000:h

0[P00P:h00<007ooOol00Woo0P00:7oo000]Ool00`00Oomoo`03Ool00`000780LP07078200040gl0

0`000gl3O`030gl00`000gl3O`030gl00`00G1mL7`02G1l01@00G1mL7e`O00002@=o00<000=o0gl0

2@=o00<000=o0gl020=o0P000e`O00D005`OG1mL7`0000X3O`030003O`=o00P3O`030003O`=o00P3

O`06001L7e`O001L7`000U`O00<005`O00002@=o00<000=o0gl01`=o00<000=o00002@=o00@006`H

K1P000=/60030001=@0000X3O`030003O`=o00P3O`030003O`=o00P3O`@000D1EP@000030[P000:h

00<2^0030002^0:h0082^003001oogoo00=oo`03001oogoo02Ioo`00;Goo00<007ooOol00goo00<0

001b07801`1b20000`=o0P0010=o0P000e`O00<005`OG1l00U`O00<000=o0gl01P=o00<000=o0gl0

2@=o00<000=o0gl020=o1P0015`O00<000=o0gl01`=o00<000=o0gl020=o00<000=o0gl020=o0P00

00AL7`00G1l0009L7`03001L7`0000T3O`030003O`=o00P3O`030003O`=o00P3O`05001/66`HK1P0

0003K1P2000:0gl00`000gl3O`080gl00`000gl3O`080gl01@00K1Q/66`H0000105F00<000=o0gl0

0P=o20000`:h00<007ooOol00goo00<007ooOol09Woo000]Ool00`00Oomoo`03Ool00`000780LP06

07800`000gl3O`020gl010000gl3O`=o2P000e`O00<005`OG1l00U`O00<000=o0gl01P=o00<000=o

0gl02P=o00<000=o0gl01`=o0P0015`O1P0020=o00<000=o0gl020=o00<000=o0gl02@=o00X005`O

G1l005`O001L7`00G1l000T3O`030003O`=o00P3O`030003O`=o00P3O`8000=/6005001/66`HK1P0

000:0gl00`000gl3O`080gl00`000gl3O`020gl00`000gl3O`040gl01@00K1Q/66`H00000`5F00<0

00=o0gl00`=o00<000=o0gl00P=o00<000=o0gl010001Goo00<007ooOol09Woo000cOol00`000780

LP0607800`000gl3O`020gl01`000gl3O`=o0003O`0000D3O`8000=L7`04001L7e`OG1l300070gl0

0`000gl3O`090gl00`000gl3O`080gl20003G1l01@00G1mL7e`O00002@=o00<000=o0gl020=o00<0

00=o0gl02@=o00H005`OG1l005`O0002G1l00`00G1l000090gl00`000gl3O`070gl00`000gl3O`08

0gl00`00;1D000040003K1P00`000gl3O`030gl01@000gl3O`=o00002P=o00<000=o0gl02@=o0P00

0f`H00@0005F0EH000D3O`030003O`=o0083O`030003O`=o00<3O`03001oogoo00=oo`8002Qoo`00

<Woo00<0001b07801P1b00<000=o0gl00P=o00<000=o0gl00P=o00<000=o000010=o00<D4P000000

0`0015`O00<000=o0gl020002P=o00<000=o0gl020=o0P000e`O00<005`OG1l00U`O00<000=o0gl0

1`=o00<000=o0gl020=o00<000=o0gl01`=o0P000U`O00<005`O00000U`O00<005`O00002@=o00<0

00=o0gl01`=o00<000=o0gl020=o00<002`E00000e`O1P001@=o00@000=o0gl000X3O`030003O`=o

00T3O`03001/600000=/60030001EP0000D3O`030003O`=o0083O`030003O`=o00<3O`03001oogoo

00Eoo`03001oogoo02Ioo`00;Goo00<007ooOol00Woo00<0001b07801P1b00<000=o0gl00P=o00<0

00=o0gl00P=o0P000P=o00@000=o0gl000=L7`H000P3O`030003O`=o00P000030gl0000000T3O`80

00AL7`05001L7e`OG1l000090gl00`000gl3O`080gl00`000gl3O`080gl2000015`O001L7`000U`O

00<005`O00002@=o00<000=o0gl01`=o00<000=o0gl020=o00<002`E00000e`O00<005`OG1l00U`O

00<000=o0gl010=o00<000=o00002P=o00<000=o0gl02@=o00@006`HK1P000=/608000D3O`030003

O`=o00<3O`030003O`=o0083O`03001oogoo00Ioo`03001oogoo02Ioo`00;Goo00<007ooOol00Woo

00<0001b07801@1b00<000=o0gl00P=o00<000=o0gl00`=o00<000=o00000`=o00<D4P00G1l00U`O

00D005`OG1mL7`0000T3O`030003O`=o00P3O`P000@3O`03001L7e`O009L7`05001L7e`OG1l00009

0gl00`000gl3O`080gl00`000gl3O`080gl;00090gl00`000gl3O`070gl00`000gl3O`080gl00`00

;1D00003G1l00`00G1mL7`02G1l00`000gl3O`050gl2000:0gl00`000gl3O`090gl01@00K1Q/66`H

00000f`H00<000=o0gl00`=o00<000=o0gl00`=o00<000=o0gl00P=o00<007ooOol01goo00<007oo

Ool09Woo000]Ool00`00Oomoo`02Ool00`000780LP0507800`000gl3O`020gl00`000gl3O`030gl0

0`000gl3O`020gl00a@B001L7`02G1l00`00G1mL7`02G1l00`000gl3O`060gl00`000gl3O`090gl0

0`000gl3O`030gl00`000gl000040003G1l01@00G1mL7e`O00002@=o00<000=o0gl020=o00<000=o

0gl02@=o00X005`OG1l005`O001L7`00G1l000T3O`030003O`=o00P3O`030003O`=o00L3O`03000/

5@0000AL7`05001L7e`OG1l000080gl200090gl00`000gl3O`090gl00c0F000000030003K1P00`00

0gl3O`020gl00`000gl3O`020gl200040gl00`00Oomoo`08Ool00`00Oomoo`0VOol002eoo`03001o

ogoo009oo`030000LP1b00@0LP030003O`=o0083O`030003O`=o00<3O`030003O`=o00<3O`05001L

7e`OG1l00004G1l00`000gl3O`060gl00`000gl3O`0:0gl00`000gl3O`030gl010000gl3O`=o1`00

0e`O10001@=o0P002P=o00<000=o0gl020=o00X005`OG1l005`O001L7`00G1l000T3O`030003O`=o

00P3O`030003O`=o00L3O`<000AL7`03001L7e`O009L7`030003O`=o00D3O`030003O`0000P3O`03

0003O`=o00T3O`03<1H005`O00=L7`D000<3O`030003O`=o00<3O`030003O`=o0083O`03001oogoo

00Uoo`03001oogoo02Ioo`00<Woo00<0001b0780101b00<000=o0gl00P=o00<000=o0gl00P=o0P00

0`=o00<001@B00000e`O00D005`OG1mL7`0000T3O`030003O`=o00T3O`030003O`=o00<3O`040003

O`=o0gl20004G1l500040gl:00050gl2000:0gl02P00G1mL7`00G1l005`O001L7`002@=o00<000=o

0gl020=o00<000=o0gl020=o0P0015`O00<005`OG1l00U`O00<000=o0gl01@=o00@000=o0gl000P3

O`030003O`=o00P3O`03<1H005`O00=L7`05001L7e`OG1l000030gl00`000gl3O`030gl00`000gl3

O`020gl00`00Oomoo`0:Ool00`00Oomoo`0VOol0039oo`030000LP1b00<0LP030003O`=o0083O`03

0003O`=o00<3O`8000<3O`8000=L7`03001L7e`O009L7`030003O`=o00H3O`030003O`=o00T3O`03

0003O`=o00P3O`0371<005`O009L7`05001L7e`OG1l000090gl00`000gl3O`030gl:00060gl20000

15`O001L7`000U`O00<005`O00002@=o00<000=o0gl01`=o00<000=o0gl020=o1`000e`O0P001`=o

00<000=o0gl02@=o00<000=o0gl020=o00<`5P00G1l00e`O00D005`OG1mL7`0000<3O`030003O`=o

00<3O`030003O`=o0083O`03001oogoo00]oo`03001oogoo02Ioo`00;Goo00<007ooOol00Woo00<0

001b07800P1b00<000=o0gl00P=o00<000=o0gl00`=o00<000=o00000`=o1@0015`O00<000=o0gl0

1P=o00<000=o0gl02@=o00<000=o0gl020=o00<L4`00G1l00U`O00<005`OG1l00U`O00<000=o0gl0

1`=o00<000=o0gl01`=o00<000=o0gl00`=o1`000U`O00L005`O001L7`00G1l000090gl00`000gl3

O`070gl00`000gl3O`080gl00`00;1D00003G1l600080gl00`000gl3O`080gl00`000gl3O`080gl0

0c0F001L7`03G1l01@00G1mL7e`O00000`=o00<000=o0gl00`=o00<000=o0gl00P=o00<007ooOol0

2goo0P00:7oo000]Ool00`00Oomoo`02Ool00`000780LP0207800`000gl3O`020gl00`000gl3O`03

0gl00`000gl3O`020gl20003G1l600080gl00`000gl3O`090gl00`000gl3O`070gl20004G1l01@00

G1mL7e`O00002@=o00<000=o0gl01`=o00<000=o0gl02@=o100000IL7`00G1l005`O00090gl00`00

0gl3O`080gl00`000gl3O`070gl30003G1l00`00G1mL7`02G1l00`000gl3O`060gl00`000gl3O`08

0gl00`000gl3O`070gl00`00<1H00004G1l01@00G1mL7e`O00000`=o00<000=o0gl00`=o00@000=o

0gl3O`8000moo`03001oogoo02Ioo`00;7oo00<007ooOol00goo00D0001b0780LP0000@3O`030003

O`=o00<3O`030003O`=o0083O`03518005`O009L7`03001L7e`O009L7`030003O`=o00H3O`030003

O`=o00T3O`030003O`=o00L3O`8000AL7`05001L7e`OG1l000090gl00`000gl3O`080gl00`000gl3

O`080gl00`00G1mL7`0700040gl6000:0gl00`000gl3O`070gl00`00;1D00003G1l00`00G1mL7`02

G1l00`000gl3O`060gl00`000gl3O`080gl00`000gl3O`080gl20004G1l01@00G1mL7e`O00000`=o

00<000=o0gl00`=o00D000=o0gl3O`00015oo`03001oogoo02Ioo`00;7oo00<007ooOol00goo00D0

001b0780LP0000@3O`030003O`=o0083O`030003O`=o00<3O`05518005`OG1l00004G1l00`000gl3

O`070gl00`000gl3O`080gl00`000gl3O`080gl20003G1l01@00G1mL7e`O00002@=o00<000=o0gl0

20=o00<000=o0gl020=o00X005`OG1l005`O001L7`00G1l000T3O`030003O`=o00<3O`H000T3O`03

000/5@0000AL7`05001L7e`OG1l000080gl00`000gl3O`080gl00`000gl3O`080gl00c0F00000002

00000e`O001L7`02G1l01@000gl3O`=o00001@=o00D000=o0gl3O`00019oo`03001oogoo02Ioo`00

<Woo00@0001b078000@3O`030003O`=o00<3O`040003O`=o0gl30003G1l00`00G1mL7`02G1l00`00

0gl3O`060gl00`000gl3O`080gl00`000gl3O`080gl00a`C000000030004G1l00`000gl3O`070gl0

0`000gl3O`070gl00`000gl3O`080gl2000025`O001L7`00G1l005`O00090gl00`000gl3O`080gl0

0`000gl3O`030gl70004G1l00`00G1mL7`02G1l00`000gl3O`050gl00`000gl3O`080gl00`000gl3

O`080gl00c0F001L7`02G1l600030gl00`000gl3O`020gl200030gl00`00Oomoo`0AOol00`00Oomo

o`0VOol0039oo`040000LP1b00040gl00`000gl3O`020gl00`000gl3O`020gl20003G1l400000e`O

0003O`070gl00`000gl3O`090gl00`000gl3O`070gl20004G1l500090gl00`000gl3O`070gl00`00

0gl3O`080gl200001U`O001L7`00G1l0009L7`030003O`=o00H3O`030003O`=o00P3O`030003O`=o

00L3O`<000AL7`03001L7e`O009L7`<000D3O`030003O`=o00P3O`030003O`=o00P3O`03<1H005`O

009L7`03001L7e`O009L7`050003O`=o0gl000040gl00`000gl3O`020gl00`00Oomoo`0BOol00`00

Oomoo`0VOol0039oo`030000LP0000@3O`030003O`=o0083O`030003O`=o0083O`<0009L7`8000<2

^0P00083O`030003O`=o00P3O`030003O`=o00L3O`03000L4`0000=L7`05001L7e`OG1l000090gl0

0`000gl3O`080gl00`000gl3O`070gl20002G1l01`00G1l005`O001L7`0000T3O`030003O`=o00L3

O`030003O`=o00L3O`03000/5@0000D000AL7`040003O`=o0gl900060gl00`000gl3O`080gl00c0F

001L7`02G1l00`00G1mL7`02G1l01@000gl3O`=o000010=o00<000=o0gl00P=o00<007ooOol04goo

00<007ooOol09Woo000/Ool00`00Oomoo`03Ool00`00078000040gl00`000gl3O`020gl00`000gl3

O`020gl700040[P00`000[P2^0030[P700060gl00`000gl3O`080gl00a`C001L7`02G1l00`00G1mL

7`02G1l00`000gl3O`060gl00`000gl3O`080gl00`000gl3O`070gl20002G1l01`00G1l005`O001L

7`0000T3O`030003O`=o00L3O`030003O`=o00L3O`03000/5@0000AL7`H000L3O`030003O`=o00<3

O`X000H3O`03<1H005`O009L7`03001L7e`O009L7`050003O`=o0gl000040gl00`000gl3O`020gl0

0`00Oomoo`0DOol00`00Oomoo`04Ool3000OOol002aoo`03001oogoo00=oo`8000@3O`030003O`=o

0083O`030003O`=o0083O`03001oogoo009oo`030000LP0000@2^0030002^0:h00<2^0030002^0:h

0082^0030003O`=o00D3O`D000D3O`0371<005`O009L7`03001L7e`O009L7`030003O`=o00L3O`03

0003O`=o00L3O`030003O`=o00P3O`@00006G1l005`O001L7`002@=o00<000=o0gl01`=o00<000=o

0gl020=o0P0015`O00<005`OG1l00U`O00<000=o0gl01@=o00<000=o0gl020=o00<000=o0gl00`=o

1@0000<`5P00G1l00U`O00<005`OG1l00U`O00D000=o0gl3O`0000@3O`030003O`=o0083O`03001o

ogoo01=oo`<000Eoo`05001oogooOol0000NOol002aoo`03001oogoo00=oo`8000@3O`050003O`=o

0gl000040gl00`00Oomoo`03Ool00`00078000040[P00`000[P2^0030[P00`000[P2^0020[P00`00

0gl3O`040gl300030[P80002G1l01@00G1mL7e`O00002@=o00<000=o0gl01`=o00<000=o0gl020=o

00<T5000G1l0200020=o00<000=o0gl01`=o00<000=o0gl020=o0P0015`O00<005`OG1l00U`O00<0

00=o0gl01@=o00<000=o0gl020=o00<000=o0gl020=o0P000e`O00<005`OG1l00U`O0P0000<3O`00

000010=o00<000=o0gl00P=o00<007ooOol05Woo00<007ooOol00goo00D007ooOomoo`0001ioo`00

;7oo00<007ooOol00goo1`000`=o00<000=o0gl00P=o00H007ooOol007oo000207800`000[P2^002

0[P00`000[P2^0030[P00`000[P2^0020[P00`000gl3O`030gl010000gl000002P:h2@000P=o00<0

00=o0gl00P=o00<000=o0gl020=o00<000=o0gl01`=o0P0000IL7`00G1l005`O0002G1l00`000gl3

O`060gl00`000gl3O`080gl00`000gl3O`070gl00`00;1D00003G1l00`00G1mL7`02G1l00`000gl3

O`050gl00`000gl3O`080gl00`000gl3O`080gl00c0F000000040003G1l00`000gl3O`0700040gl0

0`00Oomoo`0GOol00`00Oomoo`03Ool01@00Oomoogoo00003goo1`0027oo000iOol80003Ool20003

07800`000[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P00`000gl3O`020gl01@000gl0002B

00002P:h00<000:h0[P01P:h20002@=o00<000=o0gl01`=o0P0000IL7`00G1l005`O0002G1l00`00

0gl3O`060gl00`000gl3O`080gl00`000gl3O`070gl30003G1l00`00G1mL7`02G1l00`000gl3O`05

0gl00`000gl3O`080gl00`000gl3O`080gl00c0F001L7`02G1l600030gl00`000gl3O`020gl00`00

0gl00003000JOol00`00Oomoo`03Ool01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0

1Woo0014Ool2000307800`000[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P200030gl30000

0`2B0002^0090[P00`000[P2^0080[P00`000[P2^0030[P500030gl00`000gl3O`070gl20002G1l0

1`00G1l005`O001L7`0000P3O`030003O`=o00P3O`030003O`=o00L3O`03000/5@0000@000AL7`03

0003O`=o00D3O`030003O`=o00P3O`030003O`=o00P3O`03<1H005`O009L7`03001L7e`O009L7`05

0003O`=o0gl000040gl00`000gl3O`020gl00`00Oomoo`0IOol20004Ool01@00Oomoogoo000047oo

00<007ooOol00Woo00<007ooOol01Woo000/Ool00`00Oomoo`0EOol00`000780LP0207800`000[P2

^0020[P00`000[P2^0030[P00`000[P2^0020[P7000209800`000[P2^0080[P00`000[P2^0080[P0

0`000[P2^0070[P010000gl3O`001@=o1`0000=L7`00G1l00`0000=L7`000gl020=o00<000=o0gl0

1`=o00<000=o0gl01`=o00<002`E000015`O1@0020=o00<000=o0gl01`=o00<000=o0gl020=o00<`

5P00G1l00U`O00<005`OG1l00U`O00D000=o0gl3O`0000@3O`030003O`=o0083O`03001oogoo01Yo

o`8000Aoo`05001oogooOol0000AOol00`00Oomoo`0:Ool002aoo`03001oogoo01Aoo`030000LP1b

00<0LP030002^0:h0082^0030002^0:h00<2^0030002^0:h0082^08000=/60800080TP030002^0:h

00P2^0030002^0:h00P2^0030002^0:h00L2^0030003O`0000D3O`8000D2^0X000H3O`8000T3O`03

0003O`=o00P3O`8000AL7`03001L7e`O009L7`030003O`=o00D3O`030003O`=o00L3O`030003O`=o

00P3O`03<1H005`O009L7`03001L7e`O009L7`050003O`=o0gl000040gl00`000gl3O`020gl00`00

Oomoo`0LOol00`00Oomoo`02Ool01@00Oomoogoo00004Woo00<007ooOol02Goo000/Ool00`00Oomo

o`0DOol00`000780LP0307800`000[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P00`00K1Q/

6002K1P01@000980TP2B00002P:h00<000:h0[P020:h00<000:h0[P01`:h0P001@=o00<0003D0000

2P:h00<000:h0[P00P:h2`001@=o00<000=o0gl020=o0P0015`O00<005`OG1l00U`O00<000=o0gl0

1@=o00<000=o0gl01`=o00<000=o0gl020=o0P000e`O00<005`OG1l00U`O00D000=o0gl3O`0000@3

O`030003O`=o0083O`03001oogoo01eoo`03001oogoo00=oo`<001=oo`03001oogoo00Uoo`00;7oo

00<007ooOol04goo00<0001b0000101b00<000:h0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h

00<006`HK1P00V`H102B00<000:h0[P020:h00<000:h0[P020:h00<000:h0[P01`:h0P0010=o0P00

00<0e0000[P02@:h00<000:h0[P01`:h00<000:h0[P00`:h1P002@=o00<002`E00000e`O00<005`O

G1l00U`O00<000=o0gl01@=o00<000=o0gl01`=o00<000=o0gl020=o00<`5P0000000`0015`O00<0

00=o0gl00P0010=o00<000=o0gl00P=o00<007ooOol07Goo0P0077oo00<007ooOol027oo0012Ool0

0`000780000407800`000[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P00`00K1Q/6002K1P4

09800`000[P2^0080[P00`000[P2^0080[P00`000[P2^0070[P500001@=o0000e03D00002P:h00<0

00:h0[P01`:h00<000:h0[P020:h00<000=o0gl01@=o1P0000=L7`00G1l00e`O00<000=o0gl01@=o

00<000=o0gl01`=o00<000=o0gl020=o0S0F00<005`OG1l01P000P=o00<000=o0gl00`=o00<000=o

0gl00P=o00<007ooOol07goo00<007ooOol05goo00D007ooOomoo`0000Uoo`00@Goo00@0001b0780

00@0LP030002^0:h0082^0030002^0:h00<2^0030002^0:h0082^003001/66`H009/60@0TP030002

^0:h00P2^0030002^0:h00P2^0030002^0:h00L2^004001/66`HK1P200030=@00`000[P2^0080[P0

0`000[P2^0070[P00`000[P2^0080[P00`000gl3O`040gl200050[P:00030gl00`000gl3O`070gl0

0`000gl3O`080gl2<1H01000G1mL7`001E`O00<000=o00001@=o00<000=o0gl00P=o00<007ooOol0

87oo00<007ooOol05goo1P0027oo000/Ool00`00Oomoo`0AOol01@000780LP1b0000101b00<000:h

0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h00<006`HK1P00V`H102B00<000:h0[P020:h00<0

00:h0[P020:h00<000:h0[P01`:h00D006`HK1Q/600000@0e0030002^0:h00P2^0030002^0:h00L2

^0030002^0:h00P2^0030003O`=o00<3O`030000m@0000X2^0030002^0:h0082^0X00083O`030003

O`=o00P3O`8`5P04001L7e`O0005G1l00`000gl000050gl00`000gl3O`020gl00`00Oomoo`0QOol0

0`00Oomoo`0UOol002aoo`03001oogoo015oo`030000LP1b00H0LP030002^0:h0082^0030002^0:h

00<2^0030002^0:h0082^003001/66`H009/60@0TP030002^0:h00P2^0030002^0:h00P2^0030002

^0:h00L2^005001/66`HK1P000040=@00`000[P2^0080[P00`000[P2^0070[P00`000[P2^0080[P0

0`000gl3O`020gl010000?D0m@002P:h00<000:h0[P01`:h00<000:h0[P00P:h1P001P=o0S0F00@0

05`OG1l000EL7`030003O`0000D3O`030003O`=o0083O`03001oogoo029oo`03001oogoo02Eoo`00

;7oo00<007ooOol047oo00<0001b07801`1b00<000:h0[P00P:h00<000:h0[P00`:h00<000:h0[P0

0P:h1P000`2B00<000:h0[P020:h00<000:h0[P020:h00<000:h0[P01`:h00D006`HK1Q/600000@0

e0030002^0:h00P2^0030002^0:h00L2^0030002^0:h00P2^0@000050gl0003e0?D0000:0[P00`00

0[P2^0070[P00`000[P2^0070[P00`000gl3O`030gl00`00<1H000050003G1l00`000gl000050gl0

0`000gl3O`020gl00`00Oomoo`0SOol00`00Oomoo`0UOol002aoo`03001oogoo00moo`030000LP1b

00P0LP030002^0:h0082^0030002^0:h00<2^0030002^0:h0082^003001/66`H009/60@0TP030002

^0:h00P2^0030002^0:h00P2^0030002^0:h00L2^005001/66`HK1P000040=@00`000[P2^0080[P0

0`000[P2^0070[P00`000[P2^0080[P200000f`H000000030?D00`000[P2^0080[P00`000[P2^007

0[P00`000[P2^0070[P00`000gl3O`020gl500040[P;00040gl00`00Oomoo`0TOol00`00Oomoo`0U

Ool003ioo`030000LP1b00<0LP030000LP1b0080LP030002^0:h0082^0030002^0:h00<2^0030002

^0:h0082^003001/66`H009/60@0TP030002^0:h00P2^0030002^0:h00P2^0030002^0:h00L2^005

001/66`HK1P000040=@00`000[P2^0080[P00`000[P2^0070[P00`000[P2^0080[P200000f`H0000

m@030?D00`000[P2^0080[P00`000[P2^0070[P00`000[P2^0070[P01P000gl3O`=o001oo`800003

0CD000:h00P2^0030002^0:h0082^0X0029oo`03001oogoo02Eoo`00?Goo00<0001b0780101b00<0

001b07800P1b00<000:h0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h00<006`HK1P00V`H102B

00<000:h0[P020:h00<000:h0[P020:h00<000:h0[P01`:h00D006`HK1Q/600000@0e0030002^0:h

00P2^0030002^0:h00L2^0030002^0:h00P2^0800003K1P0m@3e00<0m@030002^0:h00P2^0030002

^0:h00L2^0030002^0:h00L2^0040003O`=o0002Ool010000CD1=@002@:h00<000:h0[P01`:h00<0

00:h0[P00P:h1P0077oo00<007ooOol09Goo000mOol00`000780LP0407801@000780LP1b00001@:h

00<000:h0[P00`:h00<000:h0[P00P:h00<006`HK1P00V`H102B00<000:h0[P020:h00<000:h0[P0

20:h00<000:h0[P01`:h0P000V`H0P000`3D00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P0

20:h0P0000=/603e0?D00`3e00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h00<000=o

00000Woo00D0004e0CD1=@0000T2^0030002^0:h00L2^0030002^0:h00L2^003001oogoo00Eoo`@0

009oo`03001oogoo00]oo`8002Moo`00;7oo00<007ooOol03Goo00<0001b07801@1b00D0001b0780

LP0000@2^0030002^0:h00@2^0030002^0:h0082^003001/66`H009/60@0TP030002^0:h00P2^003

0002^0:h00P2^0030002^0:h00L2^003001/6000008000@0e0030002^0:h00P2^0030002^0:h00L2

^0030002^0:h00P2^0800003K1P0m@3e00<0m@030002^0:h00P2^0030002^0:h00L2^0030002^0:h

00L2^0D000@1=@030002^0:h00L2^0030002^0:h00L2^0030002^0:h00L2^003001oogoo00Aoo`80

00<2^0P000Uoo`03001oogoo02Eoo`00;7oo00<007ooOol037oo0P002`1b00<000:h0[P00P:h00<0

00:h0[P00`:h00<000:h0[P00P:h0P0016`H102B00<000:h0[P020:h00<000:h0[P020:h00<000:h

0[P01`:h00D006`HK1Q/600000@0e0030002^0:h00P2^0030002^0:h00L2^0030002^0:h00P2^080

0003K1P0m@3e00<0m@030002^0:h00P2^0030002^0:h00L2^0030002^0:h00L2^004001/60000005

0CD00`000[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P00`00Oomoo`03Ool00`000EH00004

0[P00`000[P2^0020[P00`000[P000030005Ool00`00Oomoo`0UOol002aoo`03001oogoo00aoo`80

00/0LP030002^0:h0082^0030002^0:h00<2^0030002^0:h0082^08000A/60@0TP030002^0:h00P2

^0030002^0:h00P2^0030002^0:h00L2^005001/66`HK1P000040=@00`000[P2^0080[P00`000[P2

^0070[P00`000[P2^0080[P200000f`H0?D0m@030?D00`000[P2^0080[P00`000[P2^0070[P00`00

0[P2^0070[P01000K1Q/60001@4e00<000:h0[P01`:h00<000:h0[P01`:h00<000:h0[P01`:h00<0

07ooOol00Woo00@0005F0EH000@2^0030002^0:h0082^0030002^0:h0082^003001oogoo00=oo`03

001oogoo02Eoo`00;7oo00<007ooOol02goo00<0001b00001`1b00D0001b0780LP0000@2^0030002

^0:h00<2^0030002^0:h0082^0<000=/60@0TP030002^0:h00P2^0030002^0:h00P2^0030002^0:h

00L2^005001/66`HK1P000040=@00`000[P2^0080[P00`000[P2^0070[P00`000[P2^0080[P20000

0f`H0?D0m@030?D00`000[P2^0080[P00`000[P2^0070[P00`000[P2^0070[P01000K1Q/60001@4e

00<000:h0[P01`:h00<000:h0[P01`:h00<000:h0[P01`:h00D007ooOomoo`0000<1EP030002^0:h

0082^0030002^0:h0082^0030002^0:h0082^003001oogoo00=oo`03001oogoo02Eoo`00>Goo00@0

001b078000L0LP050000LP1b078000040[P00`000[P2^0030[P00`000[P2^0020[P2000016`H0000

0000102B00<000:h0[P020:h00<000:h0[P020:h00<000:h0[P01`:h00L006`HK1Q/60000=@3O`02

0=@00`000[P2^0080[P00`000[P2^0070[P00`000[P2^0080[P400040?D00`000[P2^0080[P00`00

0[P2^0070[P00`000[P2^0070[P01000K1Q/60001@4e00<000:h0[P01`:h00<000:h0[P01`:h00<0

00:h0[P01`:h1000105F00<000:h0[P00P:h00<000:h0[P00P:h00<000:h0[P00P:h00<007ooOol0

0goo00<007ooOol09Goo000iOol010000780LP001P1b00<0001b07800P1b00<000:h0[P00P:h00<0

00:h0[P00`:h00<000:h0[P00P:h0P0016`H102B00<000:h0[P020:h00<000:h0[P020:h00<000:h

0[P01`:h00D006`HK1Q/600000@0e0030002^0:h00P2^0030002^0:h00L2^0030002^0:h00P2^080

0003K1P0m@3e00<0m@030002^0:h00P2^0030002^0:h00L2^0030002^0:h00L2^004001/66`H0005

0CD00`000[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P00`00K1P000050EH00`000[P2^002

0[P00`000[P2^0020[P00`000[P2^0020[P00`00Oomoo`03Ool00`00Oomoo`0UOol002]oo`03001o

ogoo00Yoo`050000LP1b0780000607800`000780LP0207800`000[P2^0020[P00`000[P2^0030[P0

0`000[P2^0020[P20004K1P409800`000[P2^0080[P00`000[P2^0080[P00`000[P2^0070[P01@00

K1Q/66`H0000103D00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P020:h0P001P3e00<000:h

0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h00@006`HK1P000D1=@030002^0:h00L2^0030002

^0:h00L2^0030002^0:h00L2^003001/66`H00D1EP030002^0:h0082^0030002^0:h0082^0030002

^0:h0082^003001oogoo00=oo`03001oogoo02Eoo`00:goo00<007ooOol02Goo00<0001b07800P1b

00<0001b07802@1b00<000:h0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h0P0016`H102B00<0

00:h0[P020:h00<000:h0[P020:h00<000:h0[P01`:h00D006`HK1Q/600000@0e0030002^0:h00P2

^0030002^0:h00L2^0030002^0:h00P2^0800003K1P0m@3e00<0m@030002^0:h00P2^0030002^0:h

00L2^0030002^0:h00L2^0040001=F`H00050CD00`000[P2^0070[P00`000[P2^0070[P00`000[P2

^0070[P00`00K1Q/60050EH00`000[P2^0020[P00`000[P2^0020[P00`000[P2^0020[P00`00Oomo

o`02Ool2000WOol002]oo`03001oogoo00Uoo`030000LP1b0080LP030000LP1b00T0LP030002^0:h

0082^0030002^0:h00<2^0030002^0:h0082^08000A/60@0TP030002^0:h00P2^0030002^0:h00P2

^0030002^0:h00L2^0D000@0e0030002^0:h00P2^0030002^0:h00L2^0030002^0:h00P2^0800003

K1P0m@3e00<0m@030002^0:h00P2^0030002^0:h00L2^0030002^0:h00L2^0@000D1=@030002^0:h

00L2^0030002^0:h00L2^0030002^0:h00L2^003001/66`H00D1EP030002^0:h0082^0030002^0:h

0082^0030002^0:h0082^003001oogoo00=oo`03001oogoo02Eoo`00:goo00<007ooOol027oo00<0

001b07800`1b00<0001b0780101b00<0001b07800P1b00<000:h0[P00P:h00<000:h0[P00`:h00<0

00:h0[P00P:h00<006`HK1P00f`H102B00<000:h0[P020:h00<000:h0[P020:h00<000:h0[P01`:h

00D006`HK1Q/600000@0e0030002^0:h00P2^0030002^0:h00L2^0030002^0:h00P2^0800003K1P0

m@3e00<0m@030002^0:h00P2^0030002^0:h00L2^0030002^0:h00L2^004001/66`H00050CD00`00

0[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P00`00K1Q/60050EH00`000[P2^0020[P00`00

0[P2^0020[P00`000[P2^0020[P00`00Oomoo`03Ool00`00Oomoo`0UOol003Eoo`030000LP1b00@0

LP030000LP1b00@0LP030000LP1b0080LP030002^0:h0082^0030002^0:h00<2^0030002^0:h0082

^003001/66`H00=/60@0TP030002^0:h00P2^0030002^0:h00P2^0030002^0:h00L2^006001/66`H

K1P000:h0`3D00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P020:h0P0000=/603e0?D00`3e

00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h00@006`HK1P000D1=@030002^0:h00L2

^0030002^0:h00L2^0030002^0:h00L2^003001/66`H00D1EP030002^0:h0082^0030002^0:h0082

^0030002^0:h0082^003001oogoo00=oo`03001oogoo02Eoo`00=Goo00<0001b0780101b00<0001b

0780101b00<0001b07800P1b00<000:h0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h00<006`H

K1P00f`H102B00<000:h0[P020:h00<000:h0[P020:h00<000:h0[P01`:h00D006`HK1Q/600000@0

e0030002^0:h00P2^0030002^0:h00L2^0030002^0:h00P2^0800003K1P0m@3e00<0m@030002^0:h

00P2^0030002^0:h00L2^0030002^0:h00L2^004001/66`H00050CD00`000[P2^0070[P00`000[P2

^0070[P00`000[P2^0070[P00`00K1Q/60050EH00`000[P2^0020[P00`000[P2^0020[P00`000[P2

^0020[P00`00Oomoo`03Ool00`00Oomoo`0UOol002]oo`03001oogoo00Ioo`030000LP1b00D0LP03

0000LP1b00@0LP030000LP1b0080LP030002^0:h0082^0030002^0:h00<2^0030002^0:h0082^0<0

00=/60@0TP030002^0:h00P2^0030002^0:h00P2^0030002^0:h00L2^005001/66`HK1P000040=@0

0`000[P2^0080[P00`000[P2^0070[P00`000[P2^0080[P400040?D00`000[P2^0080[P00`000[P2

^0070[P00`000[P2^0070[P01000K1Q/60001@4e00<000:h0[P01`:h00<000:h0[P01`:h00<000:h

0[P01`:h0`001P5F00D000:h0[P2^00000@2^0030002^0:h0082^003001oogoo00=oo`03001oogoo

02Eoo`00:goo00<007ooOol01Goo00<0001b07801P1b00<0001b07802@1b00<000:h0[P00P:h00<0

00:h0[P00`:h00<000:h0[P00P:h00<006`HK1P00`00102B00<000:h0[P020:h00<000:h0[P020:h

00<000:h0[P01`:h00D006`HK1Q/600000@0e0030002^0:h00P2^0030002^0:h00L2^0030002^0:h

00P2^0800003K1P0m@3e00<0m@030002^0:h00P2^0030002^0:h00L2^0030002^0:h00L2^004001/

66`H00050CD00`000[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P00`00K1Q/60060EH00`00

0[P2^0020[P00`000[P2^0020[P01@000[P2^0:h00001Goo00<007ooOol09Goo000[Ool00`00Oomo

o`05Ool00`000780LP0607800`000780LP0907800`000[P2^0020[P00`000[P2^0030[P00`000[P2

^0020[P00`00K1Q/6003K1P409800`000[P2^0080[P00`000[P2^0080[P00`000[P2^0070[P01@00

K1Q/66`H0000103D00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P020:h0P0000=/603e0?D0

0`3e00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P020:h00<006`H00001@4e00<000:h0[P0

1`:h00<000:h0[P01`:h00<000:h0[P01`:h00<006`HK1P01P5F00<000:h0[P00P:h00<000:h0[P0

0P:h00<000:h0[P00P:h00<007ooOol00goo00<007ooOol097oo000[Ool00`00Oomoo`04Ool00`00

0780LP0707800`000780LP0907800`000[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P00`00

K1Q/6003K1P409800`000[P2^0080[P00`000[P2^0080[P00`000[P2^0070[P01@00K1Q/66`H0000

103D00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P020:h0P0000=/603e0?D00`3e00<000:h

0[P020:h00<000:h0[P01`:h00<000:h0[P020:h00<006`H00001@4e00<000:h0[P01`:h00<000:h

0[P01`:h00<000:h0[P01`:h00<006`HK1P01P5F00<000:h0[P00P:h00<000:h0[P00P:h00<000:h

0[P00P:h00L007ooOomoo`00Ool0000VOol0035oo`030000LP1b00P0LP030000LP1b00@0LP030000

LP1b0080LP030002^0:h0082^0030002^0:h00<2^0030002^0:h0082^003001/66`H00=/60@0TP03

0002^0:h00P2^0030002^0:h00P2^0030002^0:h00L2^080009/60030000e03D0080e0030002^0:h

00P2^0030002^0:h00L2^0030002^0:h00P2^0800003K1P0m@3e00<0m@030002^0:h00P2^0030002

^0:h00L2^0030002^0:h00P2^0<000D1=@030002^0:h00P2^0030002^0:h00H2^0030002^0:h00L2

^003001/66`H00H1EP030002^0:h0082^0030002^0:h0082^0030002^0:h0082^003001oogoo009o

o`8002Ioo`00<Goo00<0001b0780201b00<0001b0780101b00<0001b07800P1b00<000:h0[P00P:h

00<000:h0[P00`:h00<000:h0[P00P:h00<006`HK1P00f`H102B00<000:h0[P020:h00<000:h0[P0

20:h00<000:h0[P01`:h00<006`H00000P00103D00<000:h0[P020:h00<000:h0[P01`:h00<000:h

0[P020:h0P0000=/603e0?D00`3e00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P020:h00<0

06`H00001@4e00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P01P:h00<006`HK1P01P5F00<0

00:h0[P00P:h00<000:h0[P00P:h00<000:h0[P00P:h00<007ooOol00goo00<007ooOol097oo000`

Ool00`000780LP0907800`000780LP0407800`000780LP0207800`000[P2^0020[P00`000[P2^003

0[P00`000[P2^0020[P00`00K1Q/6003K1P409800`000[P2^0080[P00`000[P2^0080[P00`000[P2

^0070[P01@00K1Q/66`H0000103D00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P020:h0P00

00=/603e0?D00`3e00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P020:h00<006`H00001@4e

00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h00<006`H0EH01@5F00<000:h0[P00P:h

00<000:h0[P00P:h00<000:h0[P00P:h00<007ooOol00goo00<007ooOol097oo000[Ool00`00Oomo

o`02Ool00`000780LP0907800`000780LP0407800`000780LP0207800`000[P2^0020[P00`000[P2

^0030[P00`000[P2^0020[P00`00K1Q/6003K1P409800`000[P2^0080[P00`000[P2^0080[P00`00

0[P2^0070[P01@00K1Q/66`H0000103D00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P020:h

0P0000=/603e0?D00`3e00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P020:h00<006`H0000

1@4e00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h00<006`H0EH01@5F00<000:h0[P0

0P:h00<000:h0[P00P:h00<000:h0[P00P:h00<007ooOol00goo00<007ooOol097oo000[Ool00`00

Oomoo`02Ool00`000780LP0807800`000780LP0:07800`000[P2^0020[P00`000[P2^0030[P00`00

0[P2^0020[P00`00K1Q/6003K1P409800`000[P2^0080[P00`000[P2^0080[P00`000[P2^0070[P0

1@00K1Q/66`H0000103D00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P020:h0P000V`H103e

00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P020:h00<006`H00001@4e00<000:h0[P020:h

00<000:h0[P01`:h00<000:h0[P01`:h0P001P5F00<000:h0[P00P:h00<000:h0[P00P:h00<000:h

0[P00P:h00<007ooOol00goo00<007ooOol097oo000[Ool00`00Oomoo`02Ool00`000780LP080780

0`000780LP0:07800`000[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P6000409800`000[P2

^0080[P00`000[P2^0080[P00`000[P2^0070[P01@00K1Q/66`H0000103D00<000:h0[P020:h00<0

00:h0[P01`:h00<000:h0[P020:h1000103e00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P0

20:h00<006`H00001@4e00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h00<006`H0EH0

1@5F00<000:h0[P00P:h00<000:h0[P00P:h00<000:h0[P00P:h00<007ooOol00goo00<007ooOol0

97oo000[Ool00`00Oomoo`02Ool00`000780LP0807800`000780LP0507800`000780LP0207800`00

0[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P00`00K1Q/6003K1P309800`000[P2^0090[P0

0`000[P2^0080[P00`000[P2^0070[P01@00K1Q/66`H0000103D00<000:h0[P020:h00<000:h0[P0

1`:h00<000:h0[P020:h0P000V`H103e00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P020:h

00<006`H00001@4e00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h00<006`H0EH01@5F

00<000:h0[P00P:h00<000:h0[P00P:h00<000:h0[P00P:h00<007ooOol00goo00<007ooOol097oo

000`Ool00`000780LP0807800`000780LP0507800`000780LP0207800`000[P2^0020[P00`000[P2

^0030[P00`000[P2^0020[P00`00K1Q/6003K1P309800`000[P2^0080[P00`000[P2^0090[P00`00

0[P2^0070[P01@00K1Q/66`H0000103D00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P020:h

0P000V`H103e00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P020:h00<006`H00001@4e00<0

00:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h00<006`H0EH01@5F00<000:h0[P00P:h00<0

00:h0[P00P:h00<000:h0[P00P:h00<007ooOol00goo00<007ooOol00goo1@0000Aoo`00000001Qo

o`00<7oo00<0001b0780201b00<0001b07801@1b00<0001b07800P1b00<000:h0[P00P:h00<000:h

0[P00`:h00<000:h0[P00P:h00<006`HK1P00f`H0`2B00<000:h0[P020:h00<000:h0[P020:h00<0

00:h0[P020:h00D006`HK1Q/600000@0e0030002^0:h00P2^0030002^0:h00L2^0030002^0:h00P2

^080009/60@0m@030002^0:h00P2^0030002^0:h00L2^0030002^0:h00P2^003001/600000D1=@03

0002^0:h00P2^0030002^0:h00L2^0030002^0:h00L2^003001/605F00D1EP030002^0:h0082^003

0002^0:h0082^0030002^0:h0082^004001oogooOol30006Ool01000Oomoo`0017oo00<007ooOol0

5Goo000[Ool00`00Oomoo`02Ool00`000780LP0807800`000780LP0507800`000780LP0207800`00

0[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P00`00K1Q/6003K1P309800`000[P2^0080[P0

0`000[P2^0080[P00`000[P2^0080[P500040=@00`000[P2^0080[P00`000[P2^0070[P00`000[P2

^0080[P20002K1P40?D00`000[P2^0080[P00`000[P2^0070[P00`000[P2^0080[P300050CD00`00

0[P2^0080[P00`000[P2^0070[P00`000[P2^0070[P00`00K1P1EP050EH00`000[P2^0020[P00`00

0[P2^0020[P00`000[P2^0020[P00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00

Oomoo`0DOol002]oo`03001oogoo009oo`030000LP1b00P0LP030000LP1b00X0LP030002^0:h0082

^0030002^0:h00<2^0030002^0:h0082^003001/66`H00=/60<0TP030002^0:h00P2^0030002^0:h

00P2^0030002^0:h00P2^005001/66`HK1P000040=@00`000[P2^0080[P00`000[P2^0070[P00`00

0[P2^0080[P20002K1P40?D00`000[P2^0080[P00`000[P2^0070[P00`000[P2^0080[P00`00K1P0

00050CD00`000[P2^0080[P00`000[P2^0070[P00`000[P2^0070[P00`00K1P1EP050EH00`000[P2

^0020[P00`000[P2^0020[P00`000[P2^0020[P00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomo

o`04Ool00`00Oomoo`0DOol002]oo`03001oogoo009oo`030000LP1b00P0LP030000LP1b00X0LP03

0002^0:h0082^0030002^0:h00<2^0030002^0:h0082^003001/66`H00=/60<0TP030002^0:h00P2

^0030002^0:h00P2^0030002^0:h00P2^005001/66`HK1P000040=@00`000[P2^0070[P00`000[P2

^0080[P00`000[P2^0080[P20002K1P40?D00`000[P2^0080[P00`000[P2^0070[P00`000[P2^008

0[P00`00K1P000050CD00`000[P2^0080[P00`000[P2^0070[P00`000[P2^0070[P00`00K1P1EP05

0EH00`000[P2^0020[P00`000[P2^0020[P00`000[P2^0020[P00`00Oomoo`03Ool00`00Oomoo`07

Ool00`00Oomoo`03Ool00`00Oomoo`0DOol002]oo`03001oogoo009oo`030000LP1b00P0LP030000

LP1b00D0LP030000LP1b0080LP030002^0:h0082^0030002^0:h00<2^0030002^0:h0082^003001/

66`H00=/60<0TP030002^0:h00P2^0030002^0:h00P2^0030002^0:h00P2^005001/66`HK1P00004

0=@00`000[P2^0070[P00`000[P2^0080[P00`000[P2^0080[P20002K1P40?D00`000[P2^0080[P0

0`000[P2^0070[P00`000[P2^0080[P00`00K1P000050CD00`000[P2^0080[P00`000[P2^0070[P0

0`000[P2^0070[P300050EH00`000[P2^0020[P00`000[P2^0020[P00`000[P2^0020[P00`00Oomo

o`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0EOol0031oo`030000LP1b00P0LP03

0000LP1b00D0LP030000LP1b0080LP030002^0:h0082^0030002^0:h00<2^0030002^0:h0082^080

00A/60<0TP030002^0:h00P2^0030002^0:h00P2^0030002^0:h00P2^005001/66`HK1P000040=@0

0`000[P2^0070[P00`000[P2^0080[P00`000[P2^0080[P400040?D00`000[P2^0080[P00`000[P2

^0070[P00`000[P2^0080[P00`00K1P000050CD00`000[P2^0080[P00`000[P2^0070[P00`000[P2

^0070[P00`00K1P000050EH00`000[P2^0020[P00`000[P2^0020[P00`000[P2^0020[P00`00Oomo

o`03Ool00`00Oomoo`07Ool00`00Oomoo`02000HOol0031oo`030000LP1b00P0LP030000LP1b00D0

LP030000LP1b0080LP030002^0:h0082^0030002^0:h00<2^0030002^0:h0082^0H000<0TP030002

^0:h00P2^0030002^0:h00P2^0030002^0:h00P2^005001/66`HK1P000040=@00`000[P2^0070[P0

0`000[P2^0080[P00`000[P2^0080[P20002K1P40?D00`000[P2^0080[P00`000[P2^0070[P00`00

0[P2^0080[P00`00K1P000050CD00`000[P2^0080[P00`000[P2^0070[P00`000[P2^0070[P00`00

K1P000050EH00`000[P2^0020[P00`000[P2^0020[P00`000[P2^0020[P00`00Oomoo`03Ool00`00

Oomoo`03Ool01@00Oomoogoo00000Woo00<007ooOol05goo000ZOol00`00Oomoo`03Ool00`000780

LP0807800`000780LP0507800`000780LP0207800`000[P2^0020[P00`000[P2^0030[P00`000[P2

^0020[P00`00G1mL7`02G1l409800`000[P2^0080[P00`000[P2^0080[P00`000[P2^0080[P01@00

K1Q/66`H0000103D00<000:h0[P01`:h00<000:h0[P020:h00<000:h0[P020:h0P000V`H1@3e00<0

00:h0[P01`:h00<000:h0[P01`:h00<000:h0[P020:h00<006`H00001@4e00<000:h0[P020:h00<0

00:h0[P01`:h00<000:h0[P01`:h00<006`H00001@5F00<000:h0[P00P:h00<000:h0[P00P:h00<0

00:h0[P00P:h00<007ooOol00goo00<007ooOol017oo0`0017oo0`005Woo000ZOol00`00Oomoo`03

Ool00`000780LP0807800`000780LP0:07800`000[P2^0020[P00`000[P2^0030[P00`000[P2^002

0[P01000G1mL7e`O1@2B00<000:h0[P020:h00<000:h0[P020:h00<000:h0[P020:h00D006`HK1Q/

600000@0e0030002^0:h00L2^0030002^0:h00P2^0030002^0:h00P2^080009/60D0m@030002^0:h

00L2^0030002^0:h00L2^0030002^0:h00P2^003001/600000D1=@030002^0:h00P2^0030002^0:h

00L2^0030002^0:h00L2^003001/600000D1EP030002^0:h0082^0030002^0:h0082^0030002^0:h

0082^003001oogoo009oo`8002Ioo`00:Woo00<007ooOol00goo00<0001b0780201b00<0001b0780

2P1b00<000:h0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h00<005`OG1l01P2B00<000:h0[P0

20:h00<000:h0[P020:h00<000:h0[P020:h00D006`HK1Q/600000@0e0030002^0:h00L2^0030002

^0:h00P2^0030002^0:h00P2^080009/60D0m@030002^0:h00L2^0030002^0:h00P2^0030002^0:h

00L2^0<000D1=@030002^0:h00P2^0030002^0:h00L2^0030002^0:h00L2^003001/600000D1EP03

0002^0:h0082^0030002^0:h0082^0030002^0:h0082^003001oogoo00=oo`03001oogoo02Aoo`00

:Woo00<007ooOol00goo00<0001b0780201b00<0001b07800P1b00<0001b07801@1b00<000:h0[P0

0P:h00<000:h0[P00`:h00<000:h0[P00P:h00<005`O09801P2B00<000:h0[P020:h00<000:h0[P0

20:h00<000:h0[P020:h1@00103D00<000:h0[P01`:h00<000:h0[P020:h00<000:h0[P020:h0P00

0V`H1@3e00<000:h0[P01`:h00<000:h0[P020:h00<000:h0[P01`:h00<006`H00001@4e00<000:h

0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h00<006`H00001@5F00<000:h0[P00P:h00<000:h

0[P00P:h00<000:h0[P00P:h00<007ooOol00goo00<007ooOol097oo000`Ool00`000780LP080780

0`000780LP02078010000780LP00101b00<000:h0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h

00<005`O09801P2B00<000:h0[P020:h00<000:h0[P020:h00<000:h0[P020:h00@005`OG1l000D0

e0030002^0:h00L2^0030002^0:h00P2^0030002^0:h00P2^080009/60D0m@030002^0:h00L2^003

0002^0:h00P2^0030002^0:h00L2^003001/600000D1=@8000T2^0030002^0:h00L2^0030002^0:h

00L2^003001/600000D1EP030002^0:h0082^0030002^0:h0082^0030002^0:h0082^003001oogoo

00=oo`03001oogoo02Aoo`00<7oo00<0001b0780201b00<0001b07800P1b00@0001b078000@0LP03

0002^0:h0082^0030002^0:h00<2^0030002^0:h0082^0030000TP2B00H0TP030002^0:h00P2^003

0002^0:h00P2^0030002^0:h00P2^003001L7`0000H0e0030002^0:h00L2^0030002^0:h00P2^003

0002^0:h00P2^080009/60D0m@030002^0:h00L2^0030002^0:h00P2^0030002^0:h00L2^003001/

600000H1=@030002^0:h00L2^0030002^0:h00L2^0030002^0:h00L2^003001/600000D1EP030002

^0:h0082^0030002^0:h0082^0030002^0:h0082^003001oogoo00=oo`03001oogoo02Aoo`00;goo

00<0001b07802@1b00<0001b07800P1b00@0001b078000@0LP030002^0:h0082^0030002^0:h00<2

^0030002^0:h0082^0030000TP2B00H0TP030002^0:h00P2^0030002^0:h00P2^0030002^0:h00P2

^08000L0e0030002^0:h00L2^0030002^0:h00P2^0030002^0:h00P2^080009/60D0m@030002^0:h

00L2^0030002^0:h00P2^0030002^0:h00L2^003001/600000H1=@030002^0:h00L2^0030002^0:h

00L2^0030002^0:h00L2^0<000D1EP030002^0:h0082^0030002^0:h0082^0030002^0:h0082^003

001oogoo00=oo`03001oogoo02Aoo`00:Woo00<007ooOol00Woo00<0001b07802@1b00<0001b0780

1@1b00<0001b07800P1b00<000:h0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h00<0002B0980

1P2B00<000:h0[P020:h00<000:h0[P020:h00<000:h0[P020:h00<0003D0=@01P3D00<000:h0[P0

1`:h00<000:h0[P020:h00<000:h0[P020:h10001@3e00<000:h0[P01`:h00<000:h0[P020:h00<0

00:h0[P01`:h00<006`H00001P4e00<000:h0[P01`:h00<000:h0[P01`:h00<000:h0[P01`:h00<0

06`H00001P5F00D000:h0[P2^00000@2^0030002^0:h0082^003001oogoo00=oo`03001oogoo02Ao

o`00:Woo00<007ooOol00Woo00<0001b07802@1b00<0001b07802@1b00<000:h0[P00`:h00<000:h

0[P00`:h00<000:h0[P00P:h00<0002B09801P2B00<000:h0[P020:h00<000:h0[P020:h00<000:h

0[P020:h00<0003D0=@01P3D00<000:h0[P01`:h00<000:h0[P020:h00<000:h0[P020:h00<005`O

0?D01P3e00<000:h0[P01`:h00<000:h0[P020:h00<000:h0[P01`:h00<006`H00001P4e00<000:h

0[P01`:h00<000:h0[P01`:h00<000:h0[P01`:h00<006`H00001P5F00<000:h0[P00P:h00<000:h

0[P00P:h00D000:h0[P2^00000Eoo`03001oogoo02Aoo`00:Woo00<007ooOol00Woo00<0001b0780

2@1b00<0001b07802@1b00<000:h0[P00P:h00<000:h0[P010:h00<000:h0[P00P:h00<0002B0980

1P2B00<000:h0[P020:h00<000:h0[P020:h00<000:h0[P020:h00<0003D0=@01P3D00<000:h0[P0

1`:h00<000:h0[P020:h00<000:h0[P020:h00<0003e0?D01P3e00<000:h0[P01`:h00<000:h0[P0

20:h00<000:h0[P01`:h00<006`H00001P4e00<000:h0[P01`:h00<000:h0[P01`:h00<000:h0[P0

1`:h00<006`H00001P5F00<000:h0[P00P:h00<000:h0[P00P:h00<000:h0[P00P:h00<007ooOol0

0Woo00<007ooOol097oo000ZOol00`00Oomoo`02Ool00`000780LP0907800`000780LP0407800`00

0780LP0207800`000[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P2000809800`000[P2^008

0[P00`000[P2^0080[P00`000[P2^0080[P00`000=@0e0060=@00`000[P2^0070[P00`000[P2^008

0[P00`000[P2^0080[P00`000?D0m@060?D00`000[P2^0070[P00`000[P2^0080[P00`000[P2^007

0[P00`00K1P000060CD00`000[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P00`00K1P00006

0EH00`000[P2^0020[P00`000[P2^0020[P00`000[P2^0020[P01000Oomoogoo0`009Goo000_Ool0

0`000780LP0907800`000780LP0407800`000780LP0207800`000[P2^0020[P00`000[P2^0030[P0

0`000[P2^0020[P00`000980TP0709800`000[P2^0080[P00`000[P2^0080[P00`000[P2^0080[P0

0`000=@0e0060=@00`000[P2^0070[P00`000[P2^0080[P00`000[P2^0080[P00`000?D0m@060?D0

0`000[P2^0070[P00`000[P2^0080[P00`000[P2^0070[P300060CD00`000[P2^0070[P00`000[P2

^0070[P00`000[P2^0070[P00`00K1P000060EH00`000[P2^0020[P00`000[P2^0020[P00`000[P2

^0020[P00`00Oomoo`03Ool00`00Oomoo`0SOol002moo`030000LP1b00T0LP030000LP1b00@0LP03

0000LP1b0080LP030002^0:h0082^0030002^0:h00<2^0030002^0:h0082^0030000TP2B00L0TP03

0002^0:h00P2^0030002^0:h00P2^0030002^0:h00P2^0030000e03D00H0e0030002^0:h00L2^003

0002^0:h00P2^0030002^0:h00P2^0030000m@3e00H0m@030002^0:h00L2^0030002^0:h00P2^003

0002^0:h00L2^08000L1=@030002^0:h00L2^0030002^0:h00L2^0030002^0:h00L2^003001/6000

00H1EP030002^0:h0082^0030002^0:h0082^0030002^0:h0082^003001oogoo00=oo`03001oogoo

02=oo`00:Woo00<007ooOol00Woo00<0001b07802@1b00<0001b0780101b00<0001b07800P1b00<0

00:h0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h00<0002B09801`2B00<000:h0[P020:h00<0

00:h0[P020:h00<000:h0[P020:h00<0003D0=@01P3D00<000:h0[P01`:h00<000:h0[P020:h00<0

00:h0[P020:h00<0003e0?D01P3e00<000:h0[P01`:h00<000:h0[P020:h00<000:h0[P01`:h00<0

004e0CD01P4e00<000:h0[P01`:h00<000:h0[P01`:h00<000:h0[P01`:h00<006`H00001P5F00<0

00:h0[P00P:h00<000:h0[P00P:h00<000:h0[P00P:h00<007ooOol00goo00<007ooOol08goo000Z

Ool00`00Oomoo`02Ool00`000780LP0907800`000780LP0907800`000[P2^0020[P00`000[P2^003

0[P00`000[P2^0020[P00`000980TP0709800`000[P2^0080[P00`000[P2^0080[P00`000[P2^008

0[P00`000=@0e0060=@00`000[P2^0070[P00`000[P2^0080[P00`000[P2^0080[P00`000?D0m@06

0?D00`000[P2^0070[P00`000[P2^0080[P00`000[P2^0070[P00`000CD1=@060CD00`000[P2^007

0[P00`000[P2^0070[P00`000[P2^0070[P300060EH00`000[P2^0020[P00`000[P2^0020[P00`00

0[P2^0020[P00`00Oomoo`03Ool00`00Oomoo`0SOol002Yoo`03001oogoo009oo`030000LP1b00T0

LP030000LP1b00T0LP030002^0:h0082^0030002^0:h00<2^0030002^0:h0082^0030000TP2B00L0

TP030002^0:h00P2^0030002^0:h00P2^0030002^0:h00P2^0030000e03D00H0e0030002^0:h00L2

^0030002^0:h00P2^0030002^0:h00P2^0030000m@3e00H0m@030002^0:h00L2^0030002^0:h00P2

^0030002^0:h00L2^0030001=@4e00H1=@030002^0:h00L2^0030002^0:h00L2^0030002^0:h00L2

^0030001EP5F00H1EP030002^0:h0082^0030002^0:h0082^0030002^0:h0082^003001oogoo00=o

o`03001oogoo02=oo`00:Woo00<007ooOol00Woo00<0001b07802@1b00<0001b0780101b00<0001b

07800P1b00<000:h0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h00<0002B09801`2B00<000:h

0[P020:h00<000:h0[P020:h00<000:h0[P020:h00<0003D0=@01P3D00<000:h0[P01`:h00<000:h

0[P020:h00<000:h0[P020:h00<0003e0?D01P3e00<000:h0[P01`:h00<000:h0[P020:h00<000:h

0[P01`:h00<0004e0CD01P4e00<000:h0[P01`:h00<000:h0[P01`:h00<000:h0[P01`:h00<0005F

0EH01P5F00<000:h0[P00P:h00<000:h0[P00P:h00<000:h0[P00P:h00<007ooOol00goo00<007oo

Ool08goo000_Ool00`000780LP0907800`000780LP0407800`000780LP0207800`000[P2^0020[P0

0`000[P2^0030[P00`000[P2^0020[P00`000980TP0709800`000[P2^0080[P00`000[P2^0080[P0

0`000[P2^0080[P00`000=@0e0060=@00`000[P2^0070[P00`000[P2^0080[P00`000[P2^0080[P0

0`000?D0m@060?D00`000[P2^0070[P00`000[P2^0080[P00`000[P2^0070[P00`000CD1=@060CD0

0`000[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P00`000EH1EP060EH00`000[P2^0020[P0

0`000[P2^0020[P00`000[P2^0020[P00`00Oomoo`03Ool00`00Oomoo`0SOol002moo`030000LP1b

00T0LP030000LP1b00@0LP030000LP1b0080LP030002^0:h0082^0030002^0:h00<2^0030002^0:h

0082^0030000TP2B00L0TP030002^0:h00P2^0030002^0:h00P2^0030002^0:h00P2^0030000e03D

00H0e0030002^0:h00L2^0030002^0:h00P2^0030002^0:h00P2^0030000m@3e00H0m@030002^0:h

00L2^0030002^0:h00P2^0030002^0:h00L2^0030001=@4e00H1=@030002^0:h00L2^0030002^0:h

00L2^0030002^0:h00L2^0030001EP5F00H1EP030002^0:h0082^0030002^0:h0082^0030002^0:h

0082^003001oogoo009oo`8002Eoo`00:Woo00<007ooOol00Woo00<0001b07802@1b00<0001b0780

101b00<0001b07800P1b00<000:h0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h00<0002B0980

1`2B00<000:h0[P020:h00<000:h0[P020:h00<000:h0[P020:h00<0003D0=@01P3D00<000:h0[P0

1`:h00<000:h0[P020:h00<000:h0[P020:h00<0003e0?D01P3e00<000:h0[P01`:h00<000:h0[P0

20:h00<000:h0[P01`:h00<0004e0CD01P4e00<000:h0[P01`:h00<000:h0[P01`:h00<000:h0[P0

1`:h00<0005F0EH01P5F00<000:h0[P00P:h00<000:h0[P00P:h00<000:h0[P00P:h00<007ooOol0

0goo00<007ooOol08goo000ZOol00`00Oomoo`02Ool00`000780LP0907800`000780LP0907800`00

0[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P00`000980TP0709800`000[P2^0080[P00`00

0[P2^0080[P00`000[P2^0080[P00`000=@0e0060=@00`000[P2^0070[P00`000[P2^0080[P00`00

0[P2^0080[P00`000?D0m@060?D00`000[P2^0070[P00`000[P2^0080[P00`000[P2^0070[P00`00

0CD1=@060CD00`000[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P00`000EH1EP060EH00`00

0[P2^0020[P00`000[P2^0020[P00`000[P2^0020[P00`00Oomoo`03Ool00`00Oomoo`0SOol002Yo

o`03001oogoo009oo`030000LP1b00T0LP030000LP1b00T0LP030002^0:h0082^0030002^0:h00<2

^0030002^0:h0082^0030000TP2B00L0TP030002^0:h00P2^0030002^0:h00P2^0030002^0:h00P2

^0030000e03D00H0e0030002^0:h00L2^0030002^0:h00P2^0030002^0:h00P2^0030000m@3e00H0

m@030002^0:h00L2^0030002^0:h00P2^0030002^0:h00L2^0030001=@4e00H1=@030002^0:h00L2

^0030002^0:h00L2^0030002^0:h00L2^0030001EP5F00H1EP030002^0:h0082^0030002^0:h0082

^0030002^0:h0082^003001oogoo00=oo`03001oogoo02=oo`00:Woo00<007ooOol00Woo00<0001b

07802@1b00<0001b07802@1b00<000:h0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h00<0002B

09801`2B00<000:h0[P020:h00<000:h0[P020:h00<000:h0[P020:h00<0003D0=@01P3D00<000:h

0[P01`:h00<000:h0[P020:h00<000:h0[P020:h00<0003e0?D01P3e00<000:h0[P01`:h00<000:h

0[P020:h00<000:h0[P020:h00<0004e0CD01@4e00<000:h0[P01`:h00<000:h0[P01`:h00<000:h

0[P01`:h00<0005F0EH01P5F00<000:h0[P00P:h00<000:h0[P00P:h00<000:h0[P00P:h00<007oo

Ool00goo00<007ooOol08goo000_Ool00`000780LP0907800`000780LP0407800`000780LP020780

0`000[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P00`000980TP0709800`000[P2^0080[P0

0`000[P2^0080[P00`000[P2^0080[P00`000=@0e0060=@00`000[P2^0070[P00`000[P2^0080[P0

0`000[P2^0080[P00`000?D0m@060?D00`000[P2^0070[P00`000[P2^0080[P00`000[P2^0080[P0

0`000CD1=@050CD00`000[P2^0070[P00`000[P2^0070[P00`000[P2^0070[P00`000EH1EP060EH0

0`000[P2^0020[P00`000[P2^0020[P00`000[P2^0020[P00`00Oomoo`03Ool00`00Oomoo`0SOol0

02moo`030000LP1b00T0LP030000LP1b00@0LP030000LP1b0080LP030002^0:h0082^0030002^0:h

00<2^0030002^0:h0082^0030000TP2B00L0TP030002^0:h00P2^0030002^0:h00P2^0030002^0:h

00P2^0030000e03D00H0e0030002^0:h00L2^0030002^0:h00P2^0030002^0:h00P2^0030000m@3e

00H0m@030002^0:h00L2^0030002^0:h00P2^0030002^0:h00P2^0030001=@4e00D1=@030002^0:h

00P2^0030002^0:h00H2^0030002^0:h00L2^0030001EP5F00H1EP030002^0:h0082^0030002^0:h

0082^0030002^0:h0082^003001oogoo00=oo`03001oogoo02=oo`00;goo00<0001b07802@1b00<0

001b0780101b00<0001b07800P1b00<000:h0[P00P:h00<000:h0[P00`:h00<000:h0[P00P:h00<0

002B09801`2B00<000:h0[P020:h00<000:h0[P020:h00<000:h0[P020:h00<0003D0=@01P3D00<0

00:h0[P01`:h00<000:h0[P020:h00<000:h0[P020:h00<0003e0?D01P3e00<000:h0[P01`:h00<0

00:h0[P020:h00<000:h0[P020:h00<0004e0CD01@4e00<000:h0[P020:h00<000:h0[P01`:h00<0

00:h0[P01`:h00<0005F0EH01@5F00<000:h0[P00P:h00<000:h0[P00P:h00<000:h0[P00P:h00<0

07ooOol00goo00<007ooOol08goo000ZOol00`00Oomoo`02Ool00`000780LP0907800`000780LP04

07800`000780LP0207800`000[P2^0020[P00`000[P2^0030[P00`000[P2^0020[P00`000980TP07

09800`000[P2^0080[P00`000[P2^0080[P00`000[P2^0080[P00`000=@0e0060=@00`000[P2^007

0[P00`000[P2^0080[P00`000[P2^0080[P00`000?D0m@060?D00`000[P2^0070[P00`000[P2^008

0[P00`000[P2^0080[P00`000CD1=@050CD00`000[P2^0080[P00`000[P2^0070[P00`000[P2^007

0[P00`000EH1EP050EH00`000[P2^0020[P00`000[P2^0020[P00`000[P2^0020[P00`00Oomoo`03

Ool00`00Oomoo`0SOol002Yoo`03001oogoo009oo`030000LP1b00P0LP030000LP1b00X0LP030002

^0:h0082^0030002^0:h00<2^0030002^0:h0082^0030000TP2B00L0TP030002^0:h00P2^0030002

^0:h00P2^0030002^0:h00P2^0030000e03D00H0e0030002^0:h00L2^0030002^0:h00P2^0030002

^0:h00P2^0030000m@3e00H0m@030002^0:h00L2^0030002^0:h00P2^0030002^0:h00P2^0030001

=@4e00D1=@030002^0:h00P2^0030002^0:h00L2^0030002^0:h00L2^0030001EP5F00D1EP030002

^0:h0082^0030002^0:h0082^0030002^0:h0082^003001oogoo009oo`8002Eoo`00:Goo00<007oo

Ool00goo00<0001b0780201b00<0001b07802P1b100000<2^000000010:h00<000:h0[P00P:h00<0

002B09801`2B00<000:h0[P020:h00<000:h0[P020:h00<000:h0[P020:h00<0003D0=@01P3D00<0

00:h0[P01`:h00<000:h0[P020:h00<000:h0[P020:h00<0003e0?D01P3e00<000:h0[P01`:h00<0

00:h0[P020:h00<000:h0[P020:h00<0004e0CD01@4e00<000:h0[P020:h00<000:h0[P01`:h00<0

00:h0[P01`:h00<0005F0EH01@5F00<000:h0[P00P:h00<000:h0[P00P:h00<000:h0[P00P:h00<0

07ooOol00goo00<007ooOol08goo000YOol00`00Oomoo`03Ool00`000780LP0807800`000780LP05

07801@000780LP1b000010>O200010:h00<0002B09801`2B00<000:h0[P020:h00<000:h0[P020:h

00<000:h0[P020:h00<0003D0=@01P3D00<000:h0[P01`:h00<000:h0[P020:h00<000:h0[P020:h

00<0003e0?D01P3e00<000:h0[P01`:h00<000:h0[P020:h00<000:h0[P020:h00<0004e0CD01@4e

00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h00<0005F0EH01@5F00<000:h0[P00P:h

00<000:h0[P00P:h00<000:h0[P00P:h00<007ooOol00goo00<007ooOol08goo000_Ool00`000780

LP0807800`000780LP0507801@000780LP1b000010>O00<000>O0il00`>O00<000>O000010002@2B

00<000:h0[P020:h00<000:h0[P020:h00<000:h0[P020:h00<0003D0=@01P3D00<000:h0[P01`:h

00<000:h0[P020:h00<000:h0[P020:h00<0003e0?D01P3e00<000:h0[P01`:h00<000:h0[P020:h

00<000:h0[P020:h00<0004e0CD01@4e00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h

00<0005F0EH01@5F00<000:h0[P00P:h00<000:h0[P00P:h00<000:h0[P00P:h00<007ooOol00goo

00<007ooOol08goo000_Ool00`000780LP0807800`000780LP05078010000780LP0010>O00<000>O

0il00`>O00<000>O0il00`>O00<0002B0980202B1P001@:h00<000:h0[P020:h00<000:h0[P020:h

00<0003D0=@01P3D00<000:h0[P01`:h00<000:h0[P020:h00<000:h0[P020:h00<0003e0?D01P3e

00<000:h0[P01`:h00<000:h0[P020:h00<000:h0[P020:h00<0004e0CD01@4e00<000:h0[P020:h

00<000:h0[P01`:h00<000:h0[P01`:h00<0005F0EH01@5F00<000:h0[P00P:h00<000:h0[P00P:h

00<000:h0[P00P:h00<007ooOol00goo00<007ooOol08goo000YOol00`00Oomoo`03Ool00`000780

LP0807800`000780LP05078300000`>O000000020il00`000il3W`030il00`000il3W`020il00`00

0980TP0809800`000il3W`040il;00050[P00`000[P2^0080[P00`000=@0e0060=@00`000[P2^007

0[P00`000[P2^0080[P00`000[P2^0080[P00`000?D0m@060?D00`000[P2^0070[P00`000[P2^008

0[P00`000[P2^0080[P00`000CD1=@050CD00`000[P2^0080[P00`000[P2^0070[P00`000[P2^007

0[P00`000EH1EP050EH00`000[P2^0020[P00`000[P2^0020[P00`000[P2^0020[P00`00Oomoo`03

Ool00`00Oomoo`0SOol002Uoo`03001oogoo00=oo`030000LP1b00P0LP030000LP1b00@0LP030000

LP0000@3W`800083W`@000D3W`030000TP2B00L0TP030003W`>O00T3W`030003W`>O00@3W`/000D2

^0030000e03D00H0e0030002^0:h00L2^0030002^0:h00P2^0030002^0:h00P2^0030000m@3e00H0

m@030002^0:h00L2^0030002^0:h00P2^0030002^0:h00P2^0030001=@4e00D1=@030002^0:h00P2

^0030002^0:h00L2^0030002^0:h00L2^0030001EP5F00H1EP050002^0:h0[P000040[P00`000[P2

^0020[P00`00Oomoo`03Ool00`00Oomoo`0SOol002Uoo`03001oogoo00=oo`030000LP1b00P0LP03

0000LP1b00<0LP040000LP1b00040il00`000il3W`030il010000il3W`>O10000`2B100000<0TP00

0il02P>O00<000>O0il02@>O00<000>O0il010>O1P00203D1P0010:h00<000:h0[P020:h00<000:h

0[P020:h00<0003e0?D01P3e00<000:h0[P01`:h00<000:h0[P020:h00<000:h0[P020:h00<0004e

0CD01@4e00<000:h0[P020:h00<000:h0[P01`:h00<000:h0[P01`:h00<0005F0EH01P5F00<000:h

0[P00P:h00<000:h0[P00P:h00D000:h0[P2^00000Eoo`03001oogoo02=oo`00:Goo00<007ooOol0

0goo00<0001b0780201b00<0001b07800`1b00<0001b000010>O00<000>O0il00`>O00<000>O0il0

0`>O00<0002B09801`2B00<000>O00000`000P>O1@002`>O00<000>O0il02@>O00<0003D0=@01P3D

00<000>O0il00`>O2`001@:h00<000:h0[P020:h00<0003e0?D01P3e00<000:h0[P01`:h00<000:h

0[P020:h00<000:h0[P020:h00<0004e0CD01@4e00<000:h0[P020:h00<000:h0[P01`:h00<000:h

0[P01`:h00<0005F0EH01P5F00<000:h0[P00P:h00<000:h0[P00P:h00<000:h0[P00P:h00<007oo

Ool00Woo0P001Goo0`0017oo0`005Goo000_Ool00`000780LP0807800`000780LP0207800`000780

00050il00`000il3W`020il00`000il3W`030il00`000980TP070982000:0il010000il3W`>O1000

0P>O0`002`>O00<0003D0=@01P3D00<000>O0il020>O00<000>O0il010>O2`001@:h00<0003e0?D0

1P3e00<000:h0[P01`:h00<000:h0[P020:h00<000:h0[P020:h00<0004e0CD01@4e00<000:h0[P0

20:h00<000:h0[P01`:h00<000:h0[P01`:h00<0005F0EH01P5F00<000:h0[P00P:h00<000:h0[P0

0P:h00<000:h0[P00P:h00@007ooOomoo`<000Qoo`04001oogoo0003Ool00`00Oomoo`0BOol002mo

o`030000LP1b00P0LP030000LP1b00<0LP030003W`>O00<3W`030003W`>O0083W`030003W`>O00@3

W`030000TP2B00H0TP8000/3W`030003W`>O00P3W`<00083W`@000<3W`8000L0e0030003W`>O00P3

W`030003W`>O00T3W`030003W`>O00@3W`H000P0m@030002^0:h00L2^0030002^0:h00P2^0030002

^0:h00P2^0030001=@4e00D1=@030002^0:h00P2^0030002^0:h00L2^0030002^0:h00L2^0030001

EP5F00H1EP030002^0:h0082^0030002^0:h0082^0030002^0:h0082^003001oogoo009oo`8000Uo

o`03001oo`0000=oo`03001oogoo019oo`00:Goo00<007ooOol00goo00<0001b0780201b00@0001b

07800080LP030003W`>O0083W`030003W`>O00<3W`030003W`>O00<3W`8000L0TP8000/3W`030003

W`>O00P3W`030003W`>O00T3W`030000e03D00800080e0@000T3W`030003W`>O00T3W`030003W`>O

00T3W`030000m@3e00L0m@H000@2^0030002^0:h00P2^0030002^0:h00P2^0030001=@4e00D1=@03

0002^0:h00P2^0030002^0:h00L2^0030002^0:h00L2^0030001EP5F00H1EP030002^0:h0082^003

0002^0:h0082^0030002^0:h0082^003001oogoo00=oo`03001oogoo00Moo`03001oo`0000=oo`03

001oogoo019oo`00:Goo00<007ooOol00goo00<0001b0780201b00<0001b00000P1b00<000>O0il0

0P>O00<000>O0il00`>O00<000>O0il00`>O00<0002B00001P2B0P002`>O00<000>O0il020>O00<0

00>O0il02@>O00<0003D0=@01P3D00<000>O0il00P>O10000P>O1@001`>O00<000>O0il02@>O00<0

003e0?D01`3e00<000>O0il010>O2P001@:h00<000:h0[P020:h00<0004e0CD01@4e00<000:h0[P0

20:h00<000:h0[P01`:h00<000:h0[P01`:h00<0005F0EH01P5F00<000:h0[P00P:h00<000:h0[P0

0P:h00<000:h0[P00P:h00<007ooOol00goo00<007ooOol01goo00<007oo00000goo00<007ooOol0

4Woo000YOol00`00Oomoo`03Ool00`000780LP0807801@000780001b00001@>O00<000>O0il00P>O

00<000>O0il00`>O00@0002B098000H0TP030003W`>O00T3W`030003W`>O00P3W`030003W`>O00T3

W`030000e03D00H0e0030003W`>O00P3W`030003W`>O00D3W`D000030il0000000P3W`030000m@3e

00L0m@030003W`>O00P3W`030003W`>O00@3W`/000D2^0030001=@4e00D1=@030002^0:h00P2^003

0002^0:h00L2^0030002^0:h00L2^0030001EP5F00H1EP030002^0:h0082^0030002^0:h0082^003

0002^0:h0082^003001oogoo00=oo`03001oogoo00Ioo`04001oogoo0003Ool00`00Oomoo`0BOol0

02Uoo`03001oogoo00=oo`030000LP1b00P0LP800080LP030003W`>O0083W`030003W`>O0083W`03

0003W`>O00@3W`040000TP2B000509800`000il3W`090il00`000il3W`080il00`000il3W`090il0

0`000=@0e0060=@00`000il3W`080il00`000il3W`090il00`000il3W`020il200020il500020?D2

00030?D2000:0il00`000il3W`090il00`000il3W`040il600070CD00`000[P2^0080[P00`000[P2

^0070[P00`000[P2^0070[P00`000EH1EP060EH00`000[P2^0020[P00`000[P2^0020[P00`000[P2

^0020[P00`00Oomoo`03Ool00`00Oomoo`04Ool20003Ool01@00Oomoogoo000057oo000_Ool00`00

0780LP08078010000780LP0010>O00<000>O0il00P>O00<000>O0il010>O00D0002B0980TP0000@0

TP030003W`>O00T3W`030003W`>O00T3W`030003W`>O00P3W`8000L0e0030003W`>O00P3W`030003

W`>O00T3W`030003W`>O00T3W`030000m@3e00@0m@P00083W`800083W`030003W`>O00T3W`030003

W`>O00T3W`030001=@4e00H1=@P000<2^0030002^0:h00L2^0030002^0:h00L2^0030001EP5F00H1

EP030002^0:h0082^0030002^0:h0082^0030002^0:h0082^003001oogoo00=oo`03001oogoo00Ao

o`03001oogoo009oo`05001oogooOol0000DOol002ioo`030000LP1b00T0LP030000LP0000@3W`03

0003W`>O0083W`030003W`>O00@3W`030000TP2B0080TP050000TP2B0980000;0il00`000il3W`09

0il00`000il3W`080il00`000=@000070=@00`000il3W`070il00`000il3W`090il00`000il3W`09

0il00`000?D0m@060?D00`000il3W`080il300020il400040il00`000il3W`090il00`000CD1=@06

0CD00`000il3W`060il@00070[P00`000EH1EP060EH00`000[P2^0020[P00`000[P2^0020[P00`00

0[P2^0020[P00`00Oomoo`03Ool00`00Oomoo`05Ool30002Ool3000EOol002ioo`030000LP1b00P0

LP<000D3W`030003W`>O0083W`030003W`>O00<3W`030000TP2B00<0TP030000TP2B008000X3W`03

0003W`>O00T3W`030003W`>O00P3W`040000e03D00060=@00`000il3W`080il00`000il3W`080il0

0`000il3W`090il00`000?D0m@060?D00`000il3W`080il00`000il3W`090il400020il400020il2

00080CD00`000il3W`090il00`000il3W`080il00`000il3W`0800080EH00`000[P2^0020[P00`00

0[P2^0020[P00`000[P2^0020[P00`00Oomoo`02Ool2000TOol002Uoo`03001oogoo009oo`030000

LP1b00L0LP040000LP0000040il00`000il3W`020il00`000il3W`040il00`000980TP0309801000

098000002`>O00<000>O0il020>O00<000>O0il020>O00H0003D0=@0e0000[P40=@00`000il3W`08

0il00`000il3W`080il00`000il3W`090il00`000?D0m@060?D00`000il3W`080il00`000il3W`09

0il00`000il3W`090il00`000CD0000300020CD3000:0il2000:0il00`000il3W`070il00`000EH1

EP070EH400000`:h0002^0030[P00`000[P2^0020[P00`00Oomoo`03Ool00`00Oomoo`0ROol002Uo

o`03001oogoo009oo`030000LP1b00H0LP030000LP1b00P00083W`8000D3W`030000TP2B00@0TP03

0000TP0000/3W`030003W`>O00P3W`030003W`>O00P3W`030000e03D0080e0030000e03D0080e003

0003W`>O00P3W`030003W`>O00P3W`030003W`>O00T3W`030000m@3e00H0m@030003W`>O00P3W`03

0003W`>O00T3W`030003W`>O00T3W`030001=@4e00H1=@040003W`0000020il400020il300080il2

00080il200080EH200040il800030[P00`00Oomoo`03Ool00`00Oomoo`0ROol002Uoo`03001oogoo

009oo`030000LP1b00P0LP030003W`>O0083W`040003W`>O0il900070982000;0il00`000il3W`08

0il00`000il3W`080il00`000=@0e0030=@01@000=@0e03D00002P>O00<000>O0il020>O00<000>O

0il02@>O0P001`3e00<000>O0il020>O00<000>O0il02@>O00<000>O0il02@>O00<0004e0CD01P4e

00<000>O0il02@>O00@000>O0il3W`800083W`@00083W`8000D3W`8000P1EP8000@3W`8000@3W`03

0003W`>O00@000Eoo`03001oogoo029oo`00:Goo00<007ooOol00Woo00<0001b07801`1b00<000>O

0il00P>O00<000>O0il00P>O00<000>O0il010>O00<0002B09801P2B20000`>O0P002P>O00<000>O

0il020>O00<0003D0=@0103D00@0003D0=@000X3W`030003W`>O00P3W`030003W`>O00T3W`030000

m@0000H0m@030003W`>O00P3W`030003W`>O00T3W`030003W`>O00T3W`030001=@4e00H1=@030003

W`>O00T3W`030003W`>O00P3W`030003W`>O00<3W`800083W`D000D1EP030003W`>O00<3W`030003

W`>O0083W`8000@3W`8000Ioo`03001oogoo029oo`00;Woo00<0001b0780101b00@0001b078000@3

W`030003W`>O0083W`030003W`>O00<3W`030000TP2B00H0TP030003W`>O00H3Wa0000T3W`030000

e03D00D0e0030000e00000X3W`030003W`>O00P3W`030003W`>O00T3W`040000m@3e00040?D2000:

0il01@000il3W`>O00001`>O00<000>O0il020>O0P001`4e0P002P>O0P002@>O0P002@>O00<0005F

0EH01@5F10000P>O10000`>O00<000>O0il00`>O00<007ooOol01Woo00<007ooOol08Woo000^Ool0

0`000780LP03078010000780LP0010>O00<000>O0il00P>O00<000>O0il010>O00<0002B09801@2B

00<000>O0il02@>O00<000>O0il020>O00<000>O0il02@00203D0P002P>O00<000>O0il020>O00<0

00>O0il02@>O00D0003e0?D0m@0000<0m@8000X3W`030003W`>O00T3W`030003W`>O00P3W`030001

=@4e00H1=@8000X3W`030003W`>O00P3W`030003W`>O00L3W`8000P1EP8000@3W`8000@3W`D00004

0il000000007Ool00`00Oomoo`0ROol002Uoo`03001oogoo009oo`030000LP1b0080LP040000LP1b

00040il00`000il3W`020il00`000il3W`040il00`000980TP0609800`000il3W`080il00`000il3

W`080il00`000il3W`080il00`000=@0e0070=@600050il00`000il3W`080il00`000il3W`090il0

0`000?D0m@020?D010000?D0m@002P>O0P002`>O00<000>O0il020>O0P001`4e00<000>O0il02@>O

00<000>O0il020>O00<000>O0il01`>O0P00205F00<000>O0il00`>O00<000>O0il00P>O0P0010>O

0P000goo0P000Woo100097oo000YOol00`00Oomoo`02Ool00`000780LP0407800`000il3W`020il0

0`000il3W`020il00`000il3W`040il00`000980TP0609800`000il3W`080il00`000il3W`080il0

0`000il3W`080il00`000=@0e0070=@00`000il3W`040il:00050il00`000il3W`090il00`000?D0

m@030?D00`000?D000070il010000il3W`002`>O0P002P>O00<0004e00001P4e00<000>O0il02@>O

00<000>O0il01`>O0P002@>O00<0005F0EH01P5F0P0010>O0P0010>O00<000>O0il00`>O00<007oo

Ool02Goo00<007ooOol08goo000XOol00`00Oomoo`03Ool00`000780LP0307800`000il3W`030il0

0`000il3W`020il00`000il3W`030il2000709800`000il3W`090il00`000il3W`070il00`000il3

W`080il00`000=@0e0070=@00`000il3W`080il00`000il3W`040il:00060il00`000?D0m@040?D2

000:0il00`000il3W`090il00`000il3W`090il010000CD1=@001@4e00<000>O0il020>O0P002@>O

00<000>O0il020>O00<0005F0EH01P5F0P0010>O00<000>O0il00`>O00<000>O0il00P>O0P002goo

00<007ooOol097oo000XOol00`00Oomoo`03Ool01`000780LP1b0000LP0000@3W`030003W`>O0083

W`030003W`>O00<3W`03001oo`0000H0TP030003W`>O00T3W`030003W`>O00P3W`030003W`>O00L3

W`030000e03D00L0e0030003W`>O00P3W`030003W`>O00P3W`030003W`>O00@3W`H000L0m@H000D3

W`030003W`>O00T3W`030003W`>O00P3W`8000<1=@030001=@4e0081=@030003W`>O00P3W`030003

W`>O00P3W`030003W`>O00L3W`8000P1EP030003W`>O00<3W`030003W`>O0083W`8000@3W`03001o

ogoo039oo`00;Woo00H0001b0780001b00040il00`000il3W`020il00`000il3W`030il01000Oomo

o`001@2B00<000>O0il02@>O00<000>O0il020>O00<000>O0il020>O00<0003D0=@01P3D00<000>O

0il020>O00<000>O0il020>O00<000>O0il02@>O00<0003e0?D01@3e00<000>O0il010>O2P001P>O

00<000>O0il020>O00<0004e0CD00`4e00<0004e0CD00P002P>O00<000>O0il01`>O0P002@>O0`00

1`5F00<000>O0il00P>O0P0010>O00<000>O0il00`>O00<007ooOol02Goo00<007ooOol09goo000^

Ool01@000780001b000010>O00<000>O0il00P>O00<000>O0il010>O00@007ooOol000@0TP8000X3

W`030003W`>O00P3W`030003W`>O00P3W`030000e03D00H0e0030003W`>O00P3W`030003W`>O00P3

W`030003W`>O00T3W`030000m@3e00D0m@030003W`>O00P3W`030003W`>O00@3W`X000H3W`030001

=@4e00@1=@030001=@0000/3W`030003W`>O00L3W`030003W`>O00P3W`040001EP5F00050EH20004

0il00`000il3W`030il00`000il3W`020il2000;Ool00`00Oomoo`0XOol002Qoo`03001oogoo00=o

o`040000LP1b00050il00`000il3W`020il00`000il3W`030il01@00Oomoogoo0000102B00<000>O

0il020>O00<000>O0il020>O00<000>O0il020>O00<0003D0=@01P3D00<000>O0il020>O00<000>O

0il020>O00<000>O0il02@>O00<0003e0?D01@3e00<000>O0il020>O00<000>O0il02@>O00<000>O

0il00`>O1P001`4e0P002P>O0P002@>O00<000>O0il020>O00D0005F0EH1EP0000@1EP030003W`>O

0083W`8000@3W`8000@3W`03001oogoo00Yoo`03001oogoo02Uoo`00:7oo00<007ooOol00goo00<0

001b00001@>O00<000>O0il00P>O00<000>O0il00`>O00<007ooOol00Woo00D0002B0980TP0000X3

W`030003W`>O00P3W`030003W`>O00P3W`8000L0e0030003W`>O00P3W`030003W`>O00P3W`030003

W`>O00T3W`030000m@3e00D0m@030003W`>O00P3W`030003W`>O00T3W`030003W`>O00P3W`030001

=@4e00H1=@P00083W`8000T3W`8000T3W`8000@1EP050001EP5F0EH000040il00`000il3W`030il0

0`000il3W`020il2000iOol002Qoo`03001oogoo00=oo`030000LP0000@3W`030003W`>O0083W`03

0003W`>O00<3W`03001oogoo00=oo`040000TP2B000:0il00`000il3W`080il00`000il3W`080il0

0`00Ool000060=@00`000il3W`080il00`000il3W`080il00`000il3W`090il00`000?D0m@050?D0

0`000il3W`080il00`000il3W`090il00`000il3W`080il00`000CD1=@060CD00`000il3W`060il?

00080il00`000EH1EP040EH010000EH0000010>O00<000>O0il00`>O00<000>O0il00P>O00<007oo

Ool02Goo0P00;Woo000XOol00`00Oomoo`02Ool300040il00`000il3W`020il00`000il3W`030il0

0`00Oomoo`04Ool00`000980000:0il00`000il3W`080il00`000il3W`080il01000Oomoo`001@3D

00<000>O0il020>O00<000>O0il020>O00<000>O0il02@>O00<0003e0?D01@3e00<000>O0il020>O

00<000>O0il020>O0P002@>O0P001`4e0P002P>O00<000>O0il01`>O00@000>O0il3W`P000L1EP80

00@3W`8000@3W`8000@3W`03001oogoo00Qoo`80031oo`00;7oo00<007oo00000`0000<3W`000000

10>O00<000>O0il00`>O00<007ooOol017oo0`002P>O00<000>O0il01`>O00<000>O0il020>O00D0

07ooOomoo`0000@0e0030003W`>O00P3W`030003W`>O00P3W`030003W`>O00T3W`030000m@3e00D0

m@030003W`>O00P3W`030003W`>O00P3W`030003W`>O00P3W`030001=@4e00H1=@030003W`>O00P3

W`8000T3W`030003W`>O00P3W`030001EP5F00H1EPP00083W`8000@3W`8003eoo`00<Woo200010>O

00<007ooOol01Goo0P002P>O00<000>O0il020>O00<000>O0il01`>O00<007ooOol00Woo00D0003D

0=@0e00000X3W`030003W`>O00P3W`030003W`>O00P3W`8000H0m@8000X3W`030003W`>O00P3W`03

0003W`>O00P3W`030001=@4e00H1=@030003W`>O00P3W`030003W`>O00L3W`8000T3W`8000L1EP80

00@3W`040003W`>O0il8000;Ool00`00Oomoo`0aOol003Yoo`@000Qoo`D000H3W`030003W`>O00P3

W`030003W`>O00P3W`03001oogoo009oo`040000e03D000:0il00`000il3W`080il00`000il3W`08

0il00`00Ool000050?D00`000il3W`080il2000:0il00`000il3W`080il00`000CD1=@050CD2000:

0il00`000il3W`070il00`000il3W`080il00`000EH1EP060EH00`000il3W`020il200040il20004

0il00`00Oomoo`08Ool2000dOol002Qoo`03001oo`00021oo`X000H3W`030003W`>O00P3W`03001o

ogoo00=oo`030000e00000X3W`030003W`>O00P3W`030003W`>O00P3W`04001oogoo00040?D00`00

0il3W`080il00`000il3W`090il00`000il3W`080il00`000CD1=@050CD00`000il3W`080il20009

0il00`000il3W`080il00`000EH1EP060EH00`000il3W`020il00`000il3W`030il00`000il3W`02

0il2000:Ool00`00Oomoo`0dOol002Qoo`8002]oo`X000H3W`03001oogoo00Aoo`8000X3W`030003

W`>O00P3W`030003W`>O00P3W`05001oogooOol000030?D00`000il3W`080il00`000il3W`090il0

0`000il3W`070il200070CD00`000il3W`080il00`000il3W`080il00`000il3W`080il00`000EH1

EP050EH200040il00`000il3W`030il00`000il3W`020il00`00Oomoo`11Ool002Qoo`8003Eoo`H0

00Moo`D000H3W`030003W`>O00P3W`030003W`>O00P3W`03001oogoo009oo`040000m@3e000:0il0

0`000il3W`090il00`000il3W`070il200070CD00`000il3W`080il00`000il3W`080il00`000il3

W`070il200070EH00`000il3W`030il00`000il3W`020il200040il00`00Oomoo`09Ool00`00Oomo

o`0fOol002Yoo`80009oo`@000=oo`8003Yoo`X000H3W`030003W`>O00P3W`03001oogoo00=oo`03

0000m@0000X3W`030003W`>O00P3W`8000T3W`03001oo`0000D1=@8000X3W`030003W`>O00L3W`80

00T3W`030001EP5F00H1EP030003W`>O0083W`8000@3W`030003W`>O0083W`8000Yoo`8003Uoo`00

=goo0P000Woo10000Woo0P00>7oo2P001P>O00<007ooOol017oo0P002P>O00<000>O0il020>O00<0

00>O0il020>O00@007ooOol000@1=@030003W`>O00P3W`8000T3W`030003W`>O00P3W`030001EP5F

00D1EP8000@3W`030003W`>O00<3W`030003W`>O0083W`03001oogoo00Uoo`03001oogoo03Uoo`00

@goo0P000goo10000Woo0P00=Goo1P001goo1@001P>O00<000>O0il020>O00<000>O0il020>O00D0

07ooOomoo`0000<1=@030003W`>O00P3W`030003W`>O00P3W`030003W`>O00L3W`8000L1EP030003

W`>O00<3W`030003W`>O0083W`8000@3W`03001oogoo04Ioo`00D7oo0P000Woo10000goo0P00>Woo

2P001P>O00<000>O0il01`>O0P0017oo00@0004e000000X3W`030003W`>O00P3W`030003W`>O00L3

W`03001oo`0000H1EP030003W`>O0083W`8000@3W`030003W`>O0083W`8000Yoo`03001oogoo03ao

o`00GGoo0P000Woo10000Woo0P00>7oo2P001@>O00<007ooOol017oo0P002P>O0P002P>O00<000>O

0il01`>O00@007ooOol000@1EP8000@3W`030003W`>O00<3W`030003W`>O0083W`03001oogoo00Qo

o`8003moo`00JGoo0P000goo10000Woo0P00=Goo1@001goo1@001P>O00<000>O0il020>O0P002@>O

00D007ooOomoo`0000<1EP030003W`>O00<3W`030003W`>O0083W`8000@3W`03001oogoo04Yoo`00

MWoo0P000Woo10000Woo0P00>Woo2P001P>O00<000>O0il01`>O0P0017oo00@0005F0EH000D3W`03

0003W`>O0083W`030003W`>O0083W`8000Uoo`03001oogoo045oo`00PWoo0`000Woo10000Woo0P00

=goo2P001@>O00<007ooOol017oo0`0010>O0P0010>O00<000>O0il00P>O00<007ooOol027oo00<0

07ooOol0@Woo002?Ool20002Ool50002Ool2000dOol50007Ool400000`>O000000040il200040il2

0009Ool00`00Oomoo`13Ool009aoo`80009oo`@0009oo`8003Qoo`L000@3W`800003Ool007oo04io

o`00Z7oo0`000Woo10000Woo0P00<Woo10002Woo00<007ooOol0AWoo002eOol20002Ool50002Ool2

000bOol00`00Oomoo`17Ool00<9oo`80009oo`@002Aoo`03001oogoo009oo`03001oogoo04Qoo`00

c7oo10000goo10005goo00<007ooOol0CGoo003IOol40002Ool4000;Ool00`00Ool0001=Ool00>Io

o`@0009oo`@004ioo`00ogoo?goo003oOoloOol00?moocmoo`00ogoo?goo003oOoloOol00?moocmo

o`00ogoo?goo003oOoloOol00?moocmoo`00ogoo?goo003oOoloOol00?moocmoo`00ogoo?goo003o

OoloOol00?moocmoo`00ogoo?goo003oOoloOol00?moocmoo`00ogoo?goo003oOoloOol00?moocmo

o`00ogoo?goo003oOoloOol00?moocmoo`00ogoo?goo003oOoloOol00?moocmoo`00ogoo?goo003o

OoloOol00?moocmoo`00ogoo?goo003oOoloOol00?moocmoo`00ogoo?goo003oOoloOol00?moocmo

o`00ogoo?goo0000\

\>"],

  ImageRangeCache->{{{0, 317}, {317, 0}} -> {-5.00005*^-06, -5.00005*^-06, 

  0.00315461, 0.00315461}}]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{



Cell["Solve", "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell["\<\

The following instructions Solve for the magnetization of each sub-block \

which constitutes the Undulator.\

\>", "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[CellGroupData[{



Cell[TextData[{

  "t0=AbsoluteTime[];\nre=",

  StyleBox["RadSolve",

    FontColor->RGBColor[1, 0, 0]],

  "[Grp,0.0003,300];\nt1=AbsoluteTime[];\n\nPrint[\"Solved  in :   \

\",Round[t1-t0],\"  seconds\"];\nPrint[\"Number of Iterations : \",re[[4]]];\n\

Print[\"Average Stability of Magnetization at the last iteration : \

\",N[re[[1]],2],\"  T\"];\nPrint[\"Maximum Absolute Magnetization at the last \

iteration : \",N[re[[2]],4],\"  T\"];\nPrint[\"Maximum H vector at the last \

iteration : \",N[re[[3]],4],\"  T\"];\nPrint[\"\"];\nPrint[\"Central Field \

Bz(0,0,0) : \",N[",

  StyleBox["radFld",

    FontColor->RGBColor[1, 0, 0]],

  "[Grp,\"Bz\",zer],4],\"  T\"];"

}], "Input",

  AspectRatioFixed->True],



Cell[BoxData[

    InterpretationBox[

      \("Solved  in :   "\[InvisibleSpace]2\[InvisibleSpace]"  seconds"\),

      SequenceForm[ "Solved  in :   ", 2, "  seconds"],

      Editable->False]], "Print"],



Cell[BoxData[

    InterpretationBox[\("Number of Iterations : "\[InvisibleSpace]65\),

      SequenceForm[ "Number of Iterations : ", 65],

      Editable->False]], "Print"],



Cell[BoxData[

    InterpretationBox[

      RowBox[{

      \("Average Stability of Magnetization at the last iteration : "\), 

        "\[InvisibleSpace]", 

        StyleBox["0.000291754598481917639`",

          StyleBoxAutoDelete->True,

          PrintPrecision->2], "\[InvisibleSpace]", \("  T"\)}],

      SequenceForm[ 

      "Average Stability of Magnetization at the last iteration : ",

         .0002917545984819177, "  T"],

      Editable->False]], "Print"],



Cell[BoxData[

    InterpretationBox[

      RowBox[{

      \("Maximum Absolute Magnetization at the last iteration : "\), 

        "\[InvisibleSpace]", 

        StyleBox["2.11419547569727095`",

          StyleBoxAutoDelete->True,

          PrintPrecision->4], "\[InvisibleSpace]", \("  T"\)}],

      SequenceForm[ 

      "Maximum Absolute Magnetization at the last iteration : ", 

        2.114195475697271, "  T"],

      Editable->False]], "Print"],



Cell[BoxData[

    InterpretationBox[

      RowBox[{

      \("Maximum H vector at the last iteration : "\), "\[InvisibleSpace]", 

        StyleBox["1.02662142426610336`",

          StyleBoxAutoDelete->True,

          PrintPrecision->4], "\[InvisibleSpace]", \("  T"\)}],

      SequenceForm[ 

      "Maximum H vector at the last iteration : ", 1.0266214242661034, "  T"],

      

      Editable->False]], "Print"],



Cell[BoxData[

    \(""\)], "Print"],



Cell[BoxData[

    InterpretationBox[

      RowBox[{\("Central Field Bz(0,0,0) : "\), "\[InvisibleSpace]", 

        StyleBox["0.48165765837022878`",

          StyleBoxAutoDelete->True,

          PrintPrecision->4], "\[InvisibleSpace]", \("  T"\)}],

      SequenceForm[ "Central Field Bz(0,0,0) : ", .48165765837022878, "  T"],

      Editable->False]], "Print"]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{



Cell[TextData["Plot the Magnetic Field"], "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[CellGroupData[{



Cell[TextData[{

  StyleBox["RadPlotOptions",

    FontColor->RGBColor[1, 0, 0]],

  "[];\nPlot[",

  StyleBox["radFld",

    FontColor->RGBColor[1, 0, 0]],

  "[Grp,\"Bz\",{0,y,0}],{y,-(Nper+1)/2*per,(Nper+1)/2*per}\n\

,AxesOrigin->{0,0}\n,FrameLabel->{\"Y [mm]\",\"Bz [T]\",\"X = Z = \

0\",\"\"}];"

}], "Input",

  AspectRatioFixed->True],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Times findfont 12  scalefont  setfont

% Scaling calculations

0.5 0.00690131 0.321553 0.584991 [

[.08592 -0.0125 -12.5 -15 ]

[.08592 -0.0125 12.5 0 ]

[.22395 -0.0125 -12.5 -15 ]

[.22395 -0.0125 12.5 0 ]

[.36197 -0.0125 -12.5 -15 ]

[.36197 -0.0125 12.5 0 ]

[.5 -0.0125 -5 -15 ]

[.5 -0.0125 5 0 ]

[.63803 -0.0125 -8 -15 ]

[.63803 -0.0125 8 0 ]

[.77605 -0.0125 -8 -15 ]

[.77605 -0.0125 8 0 ]

[.91408 -0.0125 -8 -15 ]

[.91408 -0.0125 8 0 ]

[ 0 0 -0.125 0 ]

[.5 -0.0125 -21.5 -30 ]

[.5 -0.0125 21.5 -15 ]

[-0.0125 .08756 -28 -7.5 ]

[-0.0125 .08756 0 7.5 ]

[-0.0125 .20456 -28 -7.5 ]

[-0.0125 .20456 0 7.5 ]

[-0.0125 .32155 -10 -7.5 ]

[-0.0125 .32155 0 7.5 ]

[-0.0125 .43855 -19 -7.5 ]

[-0.0125 .43855 0 7.5 ]

[-0.0125 .55555 -19 -7.5 ]

[-0.0125 .55555 0 7.5 ]

[ 0 0 -0.125 0 ]

[-0.01875 .30902 -64 -7.5 ]

[-0.01875 .30902 -28 7.5 ]

[ 0 .61803 .125 0 ]

[.5 .63053 -27 0 ]

[.5 .63053 27 15 ]

[ 1 0 .125 0 ]

[ -0.0005 -0.0005 0 0 ]

[ 1.0005 .61853 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 .5 r

.25 Mabswid

.08592 0 m

.08592 .61803 L

s

.22395 0 m

.22395 .61803 L

s

.36197 0 m

.36197 .61803 L

s

.5 0 m

.5 .61803 L

s

.63803 0 m

.63803 .61803 L

s

.77605 0 m

.77605 .61803 L

s

.91408 0 m

.91408 .61803 L

s

0 .08756 m

1 .08756 L

s

0 .20456 m

1 .20456 L

s

0 .32155 m

1 .32155 L

s

0 .43855 m

1 .43855 L

s

0 .55555 m

1 .55555 L

s

0 g

.08592 0 m

.08592 .00625 L

s

gsave

.08592 -0.0125 -73.5 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(60) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.22395 0 m

.22395 .00625 L

s

gsave

.22395 -0.0125 -73.5 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(40) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.36197 0 m

.36197 .00625 L

s

gsave

.36197 -0.0125 -73.5 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(20) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.5 0 m

.5 .00625 L

s

gsave

.5 -0.0125 -66 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.63803 0 m

.63803 .00625 L

s

gsave

.63803 -0.0125 -69 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(20) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.77605 0 m

.77605 .00625 L

s

gsave

.77605 -0.0125 -69 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(40) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.91408 0 m

.91408 .00625 L

s

gsave

.91408 -0.0125 -69 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(60) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

.12043 0 m

.12043 .00375 L

s

.15493 0 m

.15493 .00375 L

s

.18944 0 m

.18944 .00375 L

s

.25845 0 m

.25845 .00375 L

s

.29296 0 m

.29296 .00375 L

s

.32747 0 m

.32747 .00375 L

s

.39648 0 m

.39648 .00375 L

s

.43099 0 m

.43099 .00375 L

s

.46549 0 m

.46549 .00375 L

s

.53451 0 m

.53451 .00375 L

s

.56901 0 m

.56901 .00375 L

s

.60352 0 m

.60352 .00375 L

s

.67253 0 m

.67253 .00375 L

s

.70704 0 m

.70704 .00375 L

s

.74155 0 m

.74155 .00375 L

s

.81056 0 m

.81056 .00375 L

s

.84507 0 m

.84507 .00375 L

s

.87957 0 m

.87957 .00375 L

s

.05141 0 m

.05141 .00375 L

s

.01691 0 m

.01691 .00375 L

s

.94859 0 m

.94859 .00375 L

s

.98309 0 m

.98309 .00375 L

s

.25 Mabswid

0 0 m

1 0 L

s

gsave

.5 -0.0125 -82.5 -34 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(Y) show

%%IncludeResource: font Math2

%%IncludeFont: Math2

/Math2 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

74.625000 14.625000 moveto

(@) show

78.562500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(mm) show

%%IncludeResource: font Math2

%%IncludeFont: Math2

/Math2 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

97.312500 14.625000 moveto

(D) show

101.250000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math2

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math2

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math2

%%DocumentFonts: + font Times-Roman

grestore

0 .08756 m

.00625 .08756 L

s

gsave

-0.0125 .08756 -89 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.4) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

0 .20456 m

.00625 .20456 L

s

gsave

-0.0125 .20456 -89 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.2) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

0 .32155 m

.00625 .32155 L

s

gsave

-0.0125 .32155 -71 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

0 .43855 m

.00625 .43855 L

s

gsave

-0.0125 .43855 -80 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.2) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

0 .55555 m

.00625 .55555 L

s

gsave

-0.0125 .55555 -80 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.4) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

0 .11681 m

.00375 .11681 L

s

0 .14606 m

.00375 .14606 L

s

0 .17531 m

.00375 .17531 L

s

0 .2338 m

.00375 .2338 L

s

0 .26305 m

.00375 .26305 L

s

0 .2923 m

.00375 .2923 L

s

0 .3508 m

.00375 .3508 L

s

0 .38005 m

.00375 .38005 L

s

0 .4093 m

.00375 .4093 L

s

0 .4678 m

.00375 .4678 L

s

0 .49705 m

.00375 .49705 L

s

0 .5263 m

.00375 .5263 L

s

0 .05831 m

.00375 .05831 L

s

0 .02906 m

.00375 .02906 L

s

0 .5848 m

.00375 .5848 L

s

0 .61405 m

.00375 .61405 L

s

.25 Mabswid

0 0 m

0 .61803 L

s

gsave

-0.01875 .30902 -125 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(Bz) show

%%IncludeResource: font Math2

%%IncludeFont: Math2

/Math2 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

79.312500 14.625000 moveto

(@) show

83.250000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(T) show

%%IncludeResource: font Math2

%%IncludeFont: Math2

/Math2 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

90.562500 14.625000 moveto

(D) show

94.500000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math2

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math2

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math2

%%DocumentFonts: + font Times-Roman

grestore

.08592 .61178 m

.08592 .61803 L

s

.22395 .61178 m

.22395 .61803 L

s

.36197 .61178 m

.36197 .61803 L

s

.5 .61178 m

.5 .61803 L

s

.63803 .61178 m

.63803 .61803 L

s

.77605 .61178 m

.77605 .61803 L

s

.91408 .61178 m

.91408 .61803 L

s

.125 Mabswid

.12043 .61428 m

.12043 .61803 L

s

.15493 .61428 m

.15493 .61803 L

s

.18944 .61428 m

.18944 .61803 L

s

.25845 .61428 m

.25845 .61803 L

s

.29296 .61428 m

.29296 .61803 L

s

.32747 .61428 m

.32747 .61803 L

s

.39648 .61428 m

.39648 .61803 L

s

.43099 .61428 m

.43099 .61803 L

s

.46549 .61428 m

.46549 .61803 L

s

.53451 .61428 m

.53451 .61803 L

s

.56901 .61428 m

.56901 .61803 L

s

.60352 .61428 m

.60352 .61803 L

s

.67253 .61428 m

.67253 .61803 L

s

.70704 .61428 m

.70704 .61803 L

s

.74155 .61428 m

.74155 .61803 L

s

.81056 .61428 m

.81056 .61803 L

s

.84507 .61428 m

.84507 .61803 L

s

.87957 .61428 m

.87957 .61803 L

s

.05141 .61428 m

.05141 .61803 L

s

.01691 .61428 m

.01691 .61803 L

s

.94859 .61428 m

.94859 .61803 L

s

.98309 .61428 m

.98309 .61803 L

s

.25 Mabswid

0 .61803 m

1 .61803 L

s

gsave

.5 .63053 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

74.625000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

85.437500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(Z) show

95.625000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

106.437500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

112.437500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.99375 .08756 m

1 .08756 L

s

.99375 .20456 m

1 .20456 L

s

.99375 .32155 m

1 .32155 L

s

.99375 .43855 m

1 .43855 L

s

.99375 .55555 m

1 .55555 L

s

.125 Mabswid

.99625 .11681 m

1 .11681 L

s

.99625 .14606 m

1 .14606 L

s

.99625 .17531 m

1 .17531 L

s

.99625 .2338 m

1 .2338 L

s

.99625 .26305 m

1 .26305 L

s

.99625 .2923 m

1 .2923 L

s

.99625 .3508 m

1 .3508 L

s

.99625 .38005 m

1 .38005 L

s

.99625 .4093 m

1 .4093 L

s

.99625 .4678 m

1 .4678 L

s

.99625 .49705 m

1 .49705 L

s

.99625 .5263 m

1 .5263 L

s

.99625 .05831 m

1 .05831 L

s

.99625 .02906 m

1 .02906 L

s

.99625 .5848 m

1 .5848 L

s

.99625 .61405 m

1 .61405 L

s

.25 Mabswid

1 0 m

1 .61803 L

s

.001 w

0 .32155 m

1 .32155 L

s

.5 0 m

.5 .61803 L

s

.002 w

.02381 .30008 m

.02605 .30028 L

.02846 .30055 L

.03279 .30118 L

.03793 .30221 L

.04262 .30346 L

.0475 .30515 L

.05281 .30749 L

.06244 .31341 L

.06751 .31756 L

.07308 .32312 L

.08435 .33804 L

.0948 .35696 L

.10458 .37952 L

.14335 .50302 L

.15346 .53486 L

.15879 .54939 L

.16449 .56235 L

.1673 .56762 L

.16995 .57181 L

.17253 .57512 L

.1749 .57747 L

.17607 .57837 L

.17716 .57906 L

.1783 .57962 L

.17955 .58004 L

.18082 .58026 L

.18198 .58028 L

.18262 .58021 L

.18331 .58008 L

.18458 .57968 L

.18579 .57909 L

.18691 .57839 L

.18942 .5762 L

.19164 .5736 L

.19398 .57019 L

.19893 .56076 L

.20435 .54729 L

.21523 .51179 L

.22536 .4712 L

.2644 .28555 L

.28432 .188 L

.2948 .13914 L

.3059 .09202 L

.31581 .05668 L

.32106 .04154 L

.32395 .03447 L

.3267 .02868 L

.32918 .02427 L

.33188 .02038 L

Mistroke

.33307 .01898 L

.33434 .0177 L

.33552 .01671 L

.33661 .01597 L

.33782 .01535 L

.33912 .01491 L

.34027 .01473 L

.34148 .01474 L

.34257 .01493 L

.34358 .01526 L

.34469 .01579 L

.34588 .01656 L

.34846 .0189 L

.35118 .02239 L

.35608 .03116 L

.36135 .04394 L

.36716 .06162 L

.3873 .14395 L

.42755 .34662 L

.44607 .43968 L

.45655 .48888 L

.46629 .53003 L

.47682 .56671 L

.48141 .57933 L

.48637 .59022 L

.48911 .5949 L

.49163 .59832 L

.49404 .60077 L

.49525 .6017 L

.49659 .60248 L

.49731 .6028 L

.49801 .60303 L

.4993 .60328 L

.50003 .60332 L

.5007 .60328 L

.50144 .60317 L

.50222 .60297 L

.50351 .60244 L

.50472 .60172 L

.50605 .6007 L

.50748 .59932 L

.50987 .59638 L

.51243 .59239 L

.51704 .58306 L

.52252 .56868 L

.5275 .55285 L

.54859 .46524 L

.58854 .26381 L

.60683 .17188 L

.61724 .12329 L

Mistroke

.62697 .0827 L

.63654 .04994 L

.64191 .03562 L

.64683 .02557 L

.6495 .02141 L

.65199 .01843 L

.65341 .0171 L

.65471 .01615 L

.65543 .01572 L

.65621 .01535 L

.65694 .01507 L

.65761 .01489 L

.65884 .01472 L

.65999 .01475 L

.66125 .01501 L

.66195 .01526 L

.6626 .01554 L

.66389 .01629 L

.6653 .01738 L

.66786 .02006 L

.6702 .02329 L

.67272 .02758 L

.67727 .03734 L

.68765 .0681 L

.70866 .15494 L

.74982 .35568 L

.77037 .45251 L

.78038 .49491 L

.78947 .52835 L

.79402 .54264 L

.79895 .55588 L

.80322 .56521 L

.80791 .57299 L

.81048 .5761 L

.81288 .57824 L

.81421 .5791 L

.81543 .57968 L

.8161 .57992 L

.81682 .58011 L

.81751 .58023 L

.81815 .58028 L

.81939 .58024 L

.82055 .58001 L

.8216 .57966 L

.82273 .57912 L

.82396 .57835 L

.82527 .57733 L

.8276 .57498 L

.83016 .57166 L

.83258 .56783 L

Mistroke

.83711 .55902 L

.84729 .53269 L

.86564 .4723 L

.88391 .41186 L

.8943 .3824 L

.90404 .35939 L

.91359 .34135 L

.92387 .32664 L

.9295 .32041 L

.93485 .31553 L

.94012 .3116 L

.9449 .30869 L

.95275 .30505 L

.95706 .30356 L

.96112 .30244 L

.96464 .30165 L

.96836 .30099 L

.97244 .30044 L

.97619 .30008 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  Evaluatable->False,

  AspectRatioFixed->True,

  ImageSize->{353, 217},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0000fA000`40O003h00OogooHWoo003oOomR

Ool00?moof9oo`00ogooHWoo003:Ool3000EOol3001lOol00<Yoo`03001oogoo01Moo`03001oogoo

07Yoo`00`7oo0`001goo00@007ooOomoo`<00004Ool00000Ool5000017oo000007oo0P0017oo00<0

07ooOol0NWoo0031Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0

009oo`04001oogoo0005Ool00`00Oomoo`1jOol00<5oo`03001oogoo00Ioo`03001oogoo009oo`04

001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo07Yoo`00`Goo00<007oo

Ool01Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00<0

07ooOol0NWoo0030Ool00`00Ool00007Ool00`00Oomoo`02Ool200001Goo000007oo00000Woo0P00

00Eoo`00001oo`0000Eoo`03001oogoo07Yoo`00`7oo00<007oo00001goo00@007ooOomoo`800005

Ool007ooOol00002Ool200001Goo001oogoo00001Woo00<007ooOol0NWoo0030Ool01000Oomoo`00

1Woo00<007ooOol05goo00<007ooOol0NWoo002oOol00`00Oomoo`02Ool00`00Oomoo`03Ool3000E

Ool3001lOol00;ioo`<0009oo`<009]oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003o

OomROol00?moof9oo`00Hgoo0`000goo0`007Woo00<007ooOol00`006goo1@000Woo0`006goo0`00

7Woo1@000Woo0`007Woo00<007ooOol00`0077oo0`000goo0`007Goo001ROol01`00Oomoogoo001o

o`0000=oo`03001oogoo01]oo`03001oo`0000=oo`03001oogoo01Uoo`06001oogoo001oo`000goo

00<007ooOol05goo00D007ooOomoo`0001ioo`06001oogoo001oo`000goo00<007ooOol06goo00<0

07oo00000goo00<007ooOol067oo00L007ooOomoo`00Ool00003Ool00`00Oomoo`0JOol0069oo`07

001oogooOol007oo00000goo00<007ooOol05goo1`000goo00<007ooOol06Woo00D007ooOomoo`00

00=oo`03001oogoo01Moo`05001oogooOol0000OOol01@00Oomoogoo00000goo00<007ooOol05goo

1`000goo00<007ooOol067oo00L007ooOomoo`00Ool00003Ool00`00Oomoo`0JOol005Yoo`L00003

Ool007oo009oo`03001oo`0000=oo`03001oogoo011oo`P000=oo`03001oo`0000=oo`03001oogoo

015oo`L000=oo`04001oogoo0003Ool00`00Oomoo`0GOol01@00Oomoogoo000087oo00@007ooOol0

00=oo`03001oogoo01Moo`07001oogooOol007oo00000goo00<007ooOol067oo00L007ooOomoo`00

Ool00003Ool00`00Oomoo`0JOol0069oo`80009oo`03001oo`0000=oo`03001oogoo01Qoo`06001o

ogoo001oo`000goo00<007ooOol077oo00<007oo00000goo00<007ooOol05goo00D007ooOomoo`00

025oo`03001oo`0000=oo`03001oogoo01Qoo`06001oogoo001oo`000goo00<007ooOol067oo0P00

0Woo00<007oo00000goo00<007ooOol06Woo001ROol01000Ool000000Woo00D007ooOomoo`0001]o

o`05001oo`00Ool00003Ool00`00Oomoo`0LOol00`00Ool00003Ool00`00Oomoo`0GOol01@00Oomo

ogoo00008Goo00<007oo00000goo00<007ooOol06Goo00D007oo001oo`0000=oo`03001oogoo01Qo

o`04001oo`000002Ool01@00Oomoogoo000077oo001SOol00`00Oomoo`02Ool01@00Oomoogoo0000

6goo00D007oo001oo`0000=oo`03001oogoo01aoo`03001oo`0000=oo`03001oogoo01Moo`05001o

ogooOol0000QOol00`00Ool00003Ool00`00Oomoo`0IOol01@00Ool007oo00000goo00<007ooOol0

6Goo00<007ooOol00Woo00D007ooOomoo`0001aoo`00I7oo00D007ooOomoo`0000=oo`03001oogoo

01Yoo`800003Ool007oo009oo`03001oogoo01Qoo`07001oogooOol007oo00000goo00<007ooOol0

5goo00D007ooOomoo`0001eoo`07001oogooOol007oo00000goo00<007ooOol06Woo0P0000=oo`00

Ool00Woo00<007ooOol06Woo00D007ooOomoo`0000=oo`03001oogoo01Yoo`00IGoo0P000Woo0`00

7Woo00<007ooOol00`0077oo0`000goo0`006goo0`007goo0`000goo0`007Woo00<007ooOol00`00

7Woo0P000Woo0`007Goo003oOomROol00?moof9oo`00ogooHWoo003oOomROol004eoool000`000Uo

o`00CGoo00D007ooOomoo`0000Uoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03

001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03

001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Ioo`03

001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03

001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03

001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo009oo`03

001oogoo00Moo`00CGoo00<007ooOol057oo00<03gooOol08Woo00<03gooOol08Goo00<03gooOol0

8Woo00<007ooOol08Woo00<03gooOol08Goo00<03gooOol08Woo00<03gooOol057oo00<007ooOol0

1goo001=Ool00`00Oomoo`0DOol00`0?Oomoo`0ROol00`0?Oomoo`0QOol00`0?Oomoo`0ROol00`00

Oomoo`0ROol00`0?Oomoo`0QOol00`0?Oomoo`0ROol00`0?Oomoo`0DOol00`00Oomoo`07Ool004eo

o`03001oogoo01Aoo`0300moogoo029oo`0300moogoo01Yoo`@000=oo`0300moogoo029oo`03001o

ogoo029oo`0400moogooOol4000LOol00`0?Oomoo`0ROol00`0?Oomoo`0DOol00`00Oomoo`07Ool0

04eoo`03001oogoo01Aoo`0300moogoo029oo`0300moogoo01Uoo`8000=oo`04001oogoo00lTOol0

0`00Oomoo`0ROol0100?Oomoo`0017oo00<007ooOol06Goo00<03gooOol08Woo00<03gooOol057oo

00<007ooOol01goo001=Ool00`00Oomoo`0DOol00`0?Oomoo`0ROol00`0?Oomoo`0IOol00`00Oomo

o`02Ool01000Oomoo`0?97oo00<007ooOol08Woo00@03gooOol000Aoo`03001oogoo01Uoo`0300mo

ogoo029oo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo00<007ooOol057oo00<03gooOol08Woo

00<03gooOol067oo00<007ooOol017oo00<007oo00l097oo00<007ooOol08Woo00<03goo00001Woo

00<007ooOol067oo00<03gooOol08Woo00<03gooOol057oo00<007ooOol01goo001=Ool2000EOol0

0`0?Oomoo`0ROol00`0?Oomoo`0GOol00`00Oomoo`06Ool00`0000moo`0SOol00`00Oomoo`0ROol0

0`0?001oo`06Ool00`00Oomoo`0HOol00`0?Oomoo`0ROol00`0?Oomoo`0COol20009Ool004eoo`03

001oogoo01Aoo`0300moogoo029oo`0300moogoo01Moo`03001oogoo00Ioo`0300003goo02=oo`03

001oogoo029oo`0300l007oo00Moo`03001oogoo01Moo`0300moogoo029oo`0300moogoo01Aoo`03

001oogoo00Moo`00CGoo00<007ooOol057oo00<03gooOol08Woo00<03gooOol05Woo00<007ooOol0

1goo00<0000?Ool08goo00<007ooOol08Woo00<007ooOol01goo00<007ooOol05goo00<03gooOol0

8Woo00<03gooOol057oo00<007ooOol01goo001=Ool00`00Oomoo`0DOol00`0?Oomoo`0ROol00`0?

Oomoo`0FOol00`00Oomoo`08Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`07Ool00`00

Oomoo`0GOol00`0?Oomoo`0ROol00`0?Oomoo`0DOol00`00Oomoo`07Ool004eoo`03001oogoo01Ao

o`0300moogoo029oo`0300moogoo01Ioo`03001oogoo00Qoo`03001oogoo029oo`03001oogoo025o

o`0300003goo00Uoo`03001oogoo01Ioo`0300moogoo029oo`0300moogoo01Aoo`03001oogoo00Mo

o`00CGoo00<007ooOol057oo00<03gooOol08Woo00<03gooOol05Goo00<007ooOol02Goo00<007oo

Ool08Woo00<007ooOol08Goo00<0000?Ool02Goo00<007ooOol05Woo00<03gooOol08Woo00<03goo

Ool057oo00<007ooOol01goo001=Ool00`00Oomoo`0DOol00`0?Oomoo`0ROol00`0?Oomoo`0EOol0

0`00Oomoo`09Ool00`0?001oo`0ROol00`00Oomoo`0QOol00`0000moo`09Ool00`00Oomoo`0FOol0

0`0?Oomoo`0ROol00`0?Oomoo`0DOol00`00Oomoo`07Ool004eoo`8001Eoo`0300moogoo029oo`03

00moogoo01Eoo`03001oogoo00Uoo`0300l007oo029oo`03001oogoo025oo`0300003goo00Yoo`03

001oogoo01Eoo`0300moogoo029oo`0300moogoo01=oo`8000Uoo`00CGoo00<007ooOol057oo00<0

3gooOol08Woo00<03gooOol05Goo00<007ooOol02Goo00<03goo00008Woo00<007ooOol087oo00<0

07oo00l02goo00<007ooOol05Goo00<03gooOol08Woo00<03gooOol057oo00<007ooOol01goo001=

Ool00`00Oomoo`0DOol00`0?Oomoo`0ROol00`0?Oomoo`0DOol00`00Oomoo`0:Ool00`0?Ool0000R

Ool00`00Oomoo`0POol00`00Ool03`0<Ool00`00Oomoo`0DOol00`0?Oomoo`0ROol00`0?Oomoo`0D

Ool00`00Oomoo`07Ool004eoo`03001oogoo01Aoo`0300moogoo029oo`0300moogoo01Aoo`03001o

ogoo00Yoo`0300moo`00029oo`03001oogoo021oo`03001oo`0?00aoo`03001oogoo01Aoo`0300mo

ogoo029oo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo00<007ooOol057oo00<03gooOol08Woo

00<03gooOol057oo00<007ooOol02Woo00@03gooOol0025oo`03001oogoo021oo`03001oo`0?00ao

o`03001oogoo01Aoo`0300moogoo029oo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo00<007oo

Ool057oo00<03gooOol08Woo00<03gooOol04goo00<007ooOol02goo00@03gooOol0025oo`03001o

ogoo01moo`04001oogoo00l<Ool00`00Oomoo`0DOol00`0?Oomoo`0ROol00`0?Oomoo`0DOol00`00

Oomoo`07Ool003Uoo`<000=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo01Aoo`0300mo

ogoo029oo`0300moogoo01=oo`03001oogoo00]oo`0400moogoo000QOol00`00Oomoo`0OOol01000

Oomoo`0?3Goo00<007ooOol04goo00<03gooOol08Woo00<03gooOol057oo00<007ooOol01goo000h

Ool01@00Oomoogoo000027oo00<007ooOol01Goo00<007ooOol057oo00<03gooOol08Woo00<03goo

Ool04goo00<007ooOol02goo00@03gooOol0025oo`03001oogoo01moo`04001oogoo00l=Ool00`00

Oomoo`0COol00`0?Oomoo`0ROol00`0?Oomoo`0DOol00`00Oomoo`07Ool003Qoo`05001oogooOol0

0004Ool60006Ool3001>00l00`0000l03`0@00l00`0000l03`0N00l00`0000l03`0O00l00`0000l0

3`0>00l00`0000l03`1=00l30009Ool0035oo`P000=oo`03001oogoo009oo`05001oogooOol00007

Ool00`00Oomoo`0DOol00`0?Oomoo`0ROol00`0?Oomoo`0BOol00`00Oomoo`0<Ool01@0?Oomoogoo

000087oo00<007ooOol07Woo00D007ooOomoo`0?00eoo`03001oogoo01=oo`0300moogoo029oo`03

00moogoo01Aoo`03001oogoo00Moo`00>7oo00D007ooOomoo`0000Eoo`04001oogoo0007Ool00`00

Oomoo`0DOol00`0?Oomoo`0ROol00`0?Oomoo`0BOol00`00Oomoo`0<Ool01@0?Oomoogoo000087oo

00<007ooOol07Woo00D007ooOomoo`0?00ioo`03001oogoo019oo`0300moogoo029oo`0300moogoo

01Aoo`03001oogoo00Moo`00>7oo00D007ooOomoo`0000Ioo`03001oo`0000Moo`03001oogoo01Ao

o`0300moogoo029oo`0300moogoo019oo`03001oogoo00aoo`0500moogooOol0000POol00`00Oomo

o`0NOol01@00Oomoogoo00l03Woo00<007ooOol04Woo00<03gooOol08Woo00<03gooOol057oo00<0

07ooOol01goo000hOol01@00Oomoogoo00001Woo00<007oo00001goo00<007ooOol057oo00<03goo

Ool08Woo00<03gooOol04Goo00<007ooOol03Goo00D03gooOomoo`00021oo`03001oogoo01ioo`05

001oogooOol03`0>Ool00`00Oomoo`0BOol00`0?Oomoo`0ROol00`0?Oomoo`0DOol00`00Oomoo`07

Ool003Qoo`05001oogooOol00007Ool20007Ool00`00Oomoo`0DOol00`0?Oomoo`0ROol00`0?Oomo

o`0AOol00`00Oomoo`0=Ool00`0?Oomoo`02Ool00`00Oomoo`0MOol00`00Oomoo`0MOol00`00Oomo

o`02Ool00`0?Oomoo`0<Ool00`00Oomoo`0BOol00`0?Oomoo`0ROol00`0?Oomoo`0DOol00`00Oomo

o`07Ool003Uoo`<000Uoo`03001oogoo00Eoo`03001oogoo01Aoo`0300moogoo029oo`0300moogoo

015oo`03001oogoo00eoo`0300moogoo009oo`03001oogoo01eoo`03001oogoo01eoo`03001oogoo

009oo`0300moogoo00aoo`03001oogoo019oo`0300moogoo029oo`0300moogoo01Aoo`03001oogoo

00Moo`00CGoo00<007ooOol057oo00<03gooOol08Woo00<03gooOol04Goo00<007ooOol03Goo00<0

3gooOol00Woo00<007ooOol07Goo00<007ooOol07Goo00<007ooOol00Woo00<03gooOol03Goo00<0

07ooOol04Goo00<03gooOol08Woo00<03gooOol057oo00<007ooOol01goo001=Ool2000EOol00`0?

Oomoo`0ROol00`0?Oomoo`0@Ool00`00Oomoo`0>Ool00`0?Oomoo`02Ool00`00Oomoo`0MOol00`00

Oomoo`0MOol00`00Oomoo`02Ool00`0?Oomoo`0=Ool00`00Oomoo`0AOol00`0?Oomoo`0ROol00`0?

Oomoo`0COol20009Ool004eoo`03001oogoo01Aoo`0300moogoo029oo`0300moogoo011oo`03001o

ogoo00ioo`0300moogoo00=oo`03001oogoo01aoo`03001oogoo01aoo`03001oogoo00=oo`0300mo

ogoo00eoo`03001oogoo015oo`0300moogoo029oo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo

00<007ooOol057oo00<03gooOol08Woo00<03gooOol047oo00<007ooOol03Woo00<03gooOol00goo

00<007ooOol077oo00<007ooOol077oo00<007ooOol00goo00<03gooOol03Goo00<007ooOol04Goo

00<03gooOol08Woo00<03gooOol057oo00<007ooOol01goo001=Ool00`00Oomoo`0DOol00`0?Oomo

o`0ROol00`0?Oomoo`0@Ool00`00Oomoo`0>Ool00`0?Oomoo`03Ool00`00Oomoo`0LOol00`00Oomo

o`0LOol00`00Oomoo`03Ool00`0?Oomoo`0=Ool00`00Oomoo`0AOol00`0?Oomoo`0ROol00`0?Oomo

o`0DOol00`00Oomoo`07Ool004eoo`03001oogoo01Aoo`0300moogoo029oo`0300moogoo00moo`03

001oogoo00moo`0300moogoo00=oo`03001oogoo01aoo`03001oogoo01aoo`03001oogoo00=oo`03

00moogoo00ioo`03001oogoo011oo`0300moogoo029oo`0300moogoo01Aoo`03001oogoo00Moo`00

CGoo00<007ooOol057oo00<03gooOol08Woo00<03gooOol03goo00<007ooOol03goo00<03gooOol0

17oo00<007ooOol06goo00<007ooOol06goo00<007ooOol017oo00<03gooOol03Woo00<007ooOol0

47oo00<03gooOol08Woo00<03gooOol057oo00<007ooOol01goo001=Ool00`00Oomoo`0DOol00`0?

Oomoo`0ROol00`0?Oomoo`0?Ool00`00Oomoo`0?Ool00`0?Oomoo`04Ool00`00Oomoo`0KOol00`00

Oomoo`0KOol00`00Oomoo`04Ool00`0?Oomoo`0>Ool00`00Oomoo`0@Ool00`0?Oomoo`0ROol00`0?

Oomoo`0DOol00`00Oomoo`07Ool004eoo`03001oogoo01Aoo`0300moogoo029oo`0300moogoo00mo

o`03001oogoo00moo`0300moogoo00Aoo`03001oogoo01]oo`03001oogoo01]oo`03001oogoo00Ao

o`0300moogoo00ioo`03001oogoo011oo`0300moogoo029oo`0300moogoo01Aoo`03001oogoo00Mo

o`00CGoo0P005Goo00<03gooOol08Woo00<03gooOol03goo00<007ooOol03goo00<03gooOol017oo

00<007ooOol06goo00<007ooOol06goo00<007ooOol017oo00<03gooOol03goo00<007ooOol03goo

00<03gooOol08Woo00<03gooOol04goo0P002Goo001=Ool00`00Oomoo`0DOol00`0?Oomoo`0ROol0

0`0?Oomoo`0?Ool00`00Oomoo`0?Ool00`0?Oomoo`04Ool00`00Oomoo`0KOol00`00Oomoo`0JOol0

0`00Oomoo`05Ool00`0?Oomoo`0?Ool00`00Oomoo`0?Ool00`0?Oomoo`0ROol00`0?Oomoo`0DOol0

0`00Oomoo`07Ool004eoo`03001oogoo01Aoo`0300moogoo029oo`0300moogoo00ioo`03001oogoo

011oo`0300moogoo00Eoo`03001oogoo01Yoo`03001oogoo01Yoo`03001oogoo00Eoo`0300moogoo

00moo`03001oogoo00moo`0300moogoo029oo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo00<0

07ooOol057oo00<03gooOol08Woo00<03gooOol03Woo00<007ooOol047oo00<03gooOol01Goo00<0

07ooOol06Woo00<007ooOol06Woo00<007ooOol01Goo00<03gooOol03goo00<007ooOol03goo00<0

3gooOol08Woo00<03gooOol057oo00<007ooOol01goo001=Ool00`00Oomoo`0DOol00`0?Oomoo`0R

Ool00`0?Oomoo`0>Ool00`00Oomoo`0@Ool00`0?Oomoo`05Ool00`00Oomoo`0JOol00`00Oomoo`0J

Ool00`00Oomoo`05Ool00`0?Oomoo`0?Ool00`00Oomoo`0?Ool00`0?Oomoo`0ROol00`0?Oomoo`0D

Ool00`00Oomoo`07Ool004eoo`03001oogoo01Aoo`0300moogoo029oo`0300moogoo00ioo`03001o

ogoo011oo`0300moogoo00Eoo`03001oogoo01Yoo`03001oogoo01Uoo`03001oogoo00Ioo`0300mo

ogoo011oo`03001oogoo00ioo`0300moogoo029oo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo

00<007ooOol057oo00<03gooOol08Woo00<03gooOol03Woo00<007ooOol047oo00<03gooOol01Goo

00<007ooOol06Woo00<007ooOol06Goo00<007ooOol01Woo00<03gooOol047oo00<007ooOol03Woo

00<03gooOol08Woo00<03gooOol057oo00<007ooOol01goo001=Ool2000EOol00`0?Oomoo`0ROol0

0`0?Oomoo`0>Ool00`00Oomoo`0@Ool00`0?Oomoo`06Ool00`00Oomoo`0IOol00`00Oomoo`0IOol0

0`00Oomoo`06Ool00`0?Oomoo`0@Ool00`00Oomoo`0>Ool00`0?Oomoo`0ROol00`0?Oomoo`0COol2

0009Ool004eoo`03001oogoo01Aoo`0300moogoo029oo`0300moogoo00eoo`03001oogoo015oo`03

00moogoo00Ioo`03001oogoo01Uoo`03001oogoo01Uoo`03001oogoo00Ioo`0300moogoo011oo`03

001oogoo00ioo`0300moogoo029oo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo00<007ooOol0

57oo00<03gooOol08Woo00<03gooOol03Goo00<007ooOol04Goo00<03gooOol01Woo00<007ooOol0

6Goo00<007ooOol06Goo00<007ooOol01Woo00<03gooOol047oo00<007ooOol03Woo00<03gooOol0

8Woo00<03gooOol057oo00<007ooOol01goo001=Ool00`00Oomoo`0DOol00`0?Oomoo`0ROol00`0?

Oomoo`0=Ool00`00Oomoo`0AOol00`0?Oomoo`06Ool00`00Oomoo`0IOol00`00Oomoo`0HOol00`00

Oomoo`07Ool00`0?Oomoo`0AOol00`00Oomoo`0=Ool00`0?Oomoo`0ROol00`0?Oomoo`0DOol00`00

Oomoo`07Ool004eoo`03001oogoo01Aoo`0300moogoo029oo`0300moogoo00eoo`03001oogoo015o

o`0300moogoo00Ioo`03001oogoo01Uoo`03001oogoo01Qoo`03001oogoo00Moo`0300moogoo015o

o`03001oogoo00eoo`0300moogoo029oo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo00<007oo

Ool057oo00<03gooOol08Woo00<03gooOol03Goo00<007ooOol04Goo00<03gooOol01goo00<007oo

Ool067oo00<007ooOol067oo00<007ooOol01goo00<03gooOol04Goo00<007ooOol03Goo00<03goo

Ool08Woo00<03gooOol057oo00<007ooOol01goo000iOol30003Ool00`00Ool000040007Ool00`00

Oomoo`0DOol00`0?Oomoo`0ROol00`0?Oomoo`0=Ool00`00Oomoo`0AOol00`0?Oomoo`07Ool00`00

Oomoo`0HOol00`00Oomoo`0HOol00`00Oomoo`07Ool00`0?Oomoo`0AOol00`00Oomoo`0=Ool00`0?

Oomoo`0ROol00`0?Oomoo`0DOol00`00Oomoo`07Ool003Qoo`05001oogooOol00005Ool01000Oomo

o`001goo00<007ooOol057oo00<03gooOol08Woo00<03gooOol037oo00<007ooOol04Woo00<03goo

Ool01goo00<007ooOol067oo00<007ooOol067oo00<007ooOol01goo00<03gooOol04Goo00<007oo

Ool03Goo00<03gooOol08Woo00<03gooOol057oo00<007ooOol01goo000hOol01@00Oomoogoo0000

1Woo00<007ooOol01goo0`00B00?00<0000?00l0700?00<0000?00l0600?00<0000?00l05`0?00<0

000?00l07@0?00<0000?00l0AP0?0`002Goo000aOol80003Ool00`00Oomoo`05Ool00`00Oomoo`06

Ool00`00Oomoo`0DOol00`0?Oomoo`0ROol00`0?Oomoo`0<Ool00`00Oomoo`0BOol00`0?Oomoo`07

Ool00`00Oomoo`0HOol00`00Oomoo`0GOol00`00Oomoo`08Ool00`0?Oomoo`0BOol00`00Oomoo`0<

Ool00`0?Oomoo`0ROol00`0?Oomoo`0DOol00`00Oomoo`07Ool003Qoo`05001oogooOol00008Ool0

0`00Oomoo`05Ool00`00Oomoo`0DOol00`0?Oomoo`0ROol00`0?Oomoo`0<Ool00`00Oomoo`0BOol0

0`0?Oomoo`08Ool00`00Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`08Ool00`0?Oomoo`0BOol0

0`00Oomoo`0<Ool00`0?Oomoo`0ROol00`0?Oomoo`0DOol00`00Oomoo`07Ool003Qoo`05001oogoo

Ool00008Ool00`00Oomoo`05Ool00`00Oomoo`0DOol00`0?Oomoo`0ROol00`0?Oomoo`0;Ool00`00

Oomoo`0COol00`0?Oomoo`08Ool00`00Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`08Ool00`0?

Oomoo`0BOol00`00Oomoo`0<Ool00`0?Oomoo`0ROol00`0?Oomoo`0DOol00`00Oomoo`07Ool003Qo

o`05001oogooOol00008Ool00`00Oomoo`05Ool00`00Oomoo`0DOol00`0?Oomoo`0ROol00`0?Oomo

o`0;Ool00`00Oomoo`0COol00`0?Oomoo`08Ool00`00Oomoo`0GOol00`00Oomoo`0FOol00`00Oomo

o`09Ool00`0?Oomoo`0COol00`00Oomoo`0;Ool00`0?Oomoo`0ROol00`0?Oomoo`0DOol00`00Oomo

o`07Ool003Qoo`05001oogooOol00004Ool01@00Oomoogoo00001goo00<007ooOol057oo00<03goo

Ool08Woo00<03gooOol02goo00<007ooOol04goo00<03gooOol027oo00<007ooOol05goo00<007oo

Ool05Woo00<007ooOol02Goo00<03gooOol04goo00<007ooOol02goo00<03gooOol08Woo00<03goo

Ool057oo00<007ooOol01goo000iOol30006Ool30008Ool00`00Oomoo`0DOol00`0?Oomoo`0ROol0

0`0?Oomoo`0;Ool00`00Oomoo`0COol00`0?Oomoo`08Ool00`00Oomoo`0GOol00`00Oomoo`0FOol0

0`00Oomoo`09Ool00`0?Oomoo`0COol00`00Oomoo`0;Ool00`0?Oomoo`0ROol00`0?Oomoo`0DOol0

0`00Oomoo`07Ool004eoo`03001oogoo01Aoo`0300moogoo029oo`0300moogoo00Yoo`03001oogoo

01Aoo`0300moogoo00Uoo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo00Uoo`0300moogoo

01=oo`03001oogoo00]oo`0300moogoo029oo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo0P00

5Goo00<03gooOol08Woo00<03gooOol02Woo00<007ooOol057oo00<03gooOol02Goo00<007ooOol0

5Woo00<007ooOol05Woo00<007ooOol02Goo00<03gooOol04goo00<007ooOol02goo00<03gooOol0

8Woo00<03gooOol04goo0P002Goo001=Ool00`00Oomoo`0DOol00`0?Oomoo`0ROol00`0?Oomoo`0:

Ool00`00Oomoo`0DOol00`0?Oomoo`09Ool00`00Oomoo`0FOol00`00Oomoo`0EOol00`00Oomoo`0:

Ool00`0?Oomoo`0DOol00`00Oomoo`0:Ool00`0?Oomoo`0ROol00`0?Oomoo`0DOol00`00Oomoo`07

Ool004eoo`03001oogoo01Aoo`0300moogoo029oo`0300moogoo00Yoo`03001oogoo01Aoo`0300mo

ogoo00Uoo`03001oogoo01Ioo`03001oogoo01Eoo`03001oogoo00Yoo`0300moogoo01Aoo`03001o

ogoo00Yoo`0300moogoo029oo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo00<007ooOol057oo

00<03gooOol08Woo00<03gooOol02Woo00<007ooOol057oo00<03gooOol02Goo00<007ooOol05Woo

00<007ooOol05Goo00<007ooOol02Woo00<03gooOol057oo00<007ooOol02Woo00<03gooOol08Woo

00<03gooOol057oo00<007ooOol01goo001=Ool00`00Oomoo`0DOol00`0?Oomoo`0ROol00`0?Oomo

o`09Ool00`00Oomoo`0EOol00`0?Oomoo`0:Ool00`00Oomoo`0EOol00`00Oomoo`0EOol00`00Oomo

o`0:Ool00`0?Oomoo`0DOol00`00Oomoo`0:Ool00`0?Oomoo`0ROol00`0?Oomoo`0DOol00`00Oomo

o`07Ool004eoo`03001oogoo01Aoo`0300moogoo029oo`0300moogoo00Uoo`03001oogoo01Eoo`03

00moogoo00Yoo`03001oogoo01Eoo`03001oogoo01Eoo`03001oogoo00Yoo`0300moogoo01Aoo`03

001oogoo00Yoo`0300moogoo029oo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo00<007ooOol0

57oo00<03gooOol08Woo00<03gooOol02Goo00<007ooOol05Goo00<03gooOol02Woo00<007ooOol0

5Goo00<007ooOol057oo00<007ooOol02goo00<03gooOol05Goo00<007ooOol02Goo00<03gooOol0

8Woo00<03gooOol057oo00<007ooOol01goo001=Ool00`00Oomoo`0DOol00`0?Oomoo`0ROol00`0?

Oomoo`09Ool00`00Oomoo`0EOol00`0?Oomoo`0:Ool00`00Oomoo`0EOol00`00Oomoo`0DOol00`00

Oomoo`0;Ool00`0?Oomoo`0EOol00`00Oomoo`09Ool00`0?Oomoo`0ROol00`0?Oomoo`0DOol00`00

Oomoo`07Ool004eoo`8001Eoo`0300moogoo029oo`0300moogoo00Qoo`03001oogoo01Ioo`0300mo

ogoo00]oo`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo00]oo`0300moogoo01Eoo`03001o

ogoo00Uoo`0300moogoo029oo`0300moogoo01=oo`8000Uoo`00CGoo00<007ooOol057oo00<03goo

Ool08Woo00<03gooOol027oo00<007ooOol05Woo00<03gooOol02goo00<007ooOol057oo00<007oo

Ool057oo00<007ooOol02goo00<03gooOol05Goo00<007ooOol02Goo00<03gooOol08Woo00<03goo

Ool057oo00<007ooOol01goo001=Ool00`00Oomoo`0DOol00`0?Oomoo`0ROol00`0?Oomoo`08Ool0

0`00Oomoo`0FOol00`0?Oomoo`0;Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0;Ool0

0`0?Oomoo`0EOol00`00Oomoo`09Ool00`0?Oomoo`0ROol00`0?Oomoo`0DOol00`00Oomoo`07Ool0

04eoo`03001oogoo01Aoo`0300moogoo029oo`0300moogoo00Qoo`03001oogoo01Ioo`0300moogoo

00]oo`03001oogoo01Aoo`03001oogoo01=oo`03001oogoo00aoo`0300moogoo01Ioo`03001oogoo

00Qoo`0300moogoo029oo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo00<007ooOol057oo00<0

3gooOol08Woo00<03gooOol01goo00<007ooOol05goo00<03gooOol02goo00<007ooOol057oo00<0

07ooOol04goo00<007ooOol037oo00<03gooOol05Woo00<007ooOol027oo00<03gooOol08Woo00<0

3gooOol057oo00<007ooOol01goo001=Ool00`00Oomoo`0DOol00`0?Oomoo`0ROol00`0?Oomoo`07

Ool00`00Oomoo`0GOol00`0?Oomoo`0<Ool00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0<

Ool00`0?Oomoo`0FOol00`00Oomoo`08Ool00`0?Oomoo`0ROol00`0?Oomoo`0DOol00`00Oomoo`07

Ool004eoo`03001oogoo01Aoo`0300moogoo029oo`0300moogoo00Moo`03001oogoo01Moo`0300mo

ogoo00aoo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo00aoo`0300moogoo01Ioo`03001o

ogoo00Qoo`0300moogoo029oo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo00<007ooOol057oo

00<03gooOol08Woo00<03gooOol01goo00<007ooOol05goo00<03gooOol037oo00<007ooOol04goo

00<007ooOol04goo00<007ooOol037oo00<03gooOol05Woo00<007ooOol027oo00<03gooOol08Woo

00<03gooOol057oo00<007ooOol01goo000JOol3000:Ool3000SOol2000EOol00`0?Oomoo`0ROol0

0`0?Oomoo`07Ool00`00Oomoo`0GOol00`0?Oomoo`0<Ool00`00Oomoo`0COol00`00Oomoo`0COol0

0`00Oomoo`0<Ool00`0?Oomoo`0GOol00`00Oomoo`07Ool00`0?Oomoo`0ROol00`0?Oomoo`0COol2

0009Ool001Yoo`03001oogoo00aoo`03001oogoo025oo`03001oogoo01Aoo`0300moogoo029oo`03

00moogoo00Ioo`03001oogoo01Qoo`0300moogoo00aoo`03001oogoo01=oo`03001oogoo019oo`03

001oogoo00eoo`0300moogoo01Moo`03001oogoo00Moo`0300moogoo029oo`0300moogoo01Aoo`03

001oogoo00Moo`002Woo1P000Woo1@000goo00<007ooOol00goo0`001Woo00<007ooOol08Goo00<0

07ooOol00goo1@0037oo00<03gooOol08Woo00<03gooOol01Woo00<007ooOol067oo00<03gooOol0

3Goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol03Goo00<03gooOol05goo00<007ooOol0

1goo00<03gooOol08Woo00<03gooOol02Woo1@001Goo00<007ooOol01goo000;Ool00`00Oomoo`02

Ool01000Oomoo`000Woo00D007ooOomoo`0000Ioo`03001oogoo00Eoo`03001oogoo025oo`03001o

ogoo00Qoo`<000Uoo`0300moogoo029oo`0300moogoo00Ioo`03001oogoo01Qoo`0300moogoo00eo

o`03001oogoo019oo`03001oogoo019oo`03001oogoo00eoo`0300moogoo01Moo`03001oogoo00Mo

o`0300moogoo029oo`0300moogoo00Moo`<000Yoo`03001oogoo00Moo`002goo00<007ooOol00Woo

00D007ooOomoo`0000Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo025oo`03001oogoo

00]oo`8000Moo`0300moogoo029oo`0300moogoo00Ioo`03001oogoo01Qoo`0300moogoo00eoo`03

001oogoo019oo`03001oogoo019oo`03001oogoo00eoo`0300moogoo01Qoo`03001oogoo00Ioo`03

00moogoo029oo`0300moogoo00Eoo`8000eoo`03001oogoo00Moo`002goo00<007ooOol00Woo00D0

07ooOomoo`0000Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo01Moo`<000Moo`03001o

ogoo00eoo`8000Eoo`0300moogoo029oo`0300moogoo00Ioo`03001oogoo01Qoo`0300moogoo00eo

o`03001oogoo019oo`03001oogoo019oo`03001oogoo00eoo`0300moogoo01Qoo`03001oogoo00Io

o`0300moogoo029oo`0300moogoo00Aoo`03001oogoo00eoo`03001oogoo00Moo`002goo1@000Woo

00@007ooOol000Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo01Ioo`05001oogooOol0

0006Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`0?Oomoo`0ROol00`0?Oomoo`05Ool00`00Oomo

o`0IOol00`0?Oomoo`0=Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0>Ool00`0?Oomo

o`0HOol00`00Oomoo`06Ool00`0?Oomoo`0ROol00`0?Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomo

o`07Ool000]oo`05001oogooOol00002Ool50003Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00

Oomoo`0FOol01@00Oomoogoo00001Wooo`0030002Goo000;Ool01@00Oomoogoo00002Woo00<007oo

Ool017oo00<007ooOol01Goo00<007ooOol05Woo00D007ooOomoo`0000Ioo`03001oogoo011oo`05

001oogooOol03`0TOol00`0?Oomoo`05Ool00`00Oomoo`0IOol00`0?Oomoo`0>Ool00`00Oomoo`0A

Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`0?Oomoo`0HOol00`00Oomoo`06Ool00`0?Oomoo`0R

Ool0100?Oomoo`004goo00<007ooOol01goo000;Ool01@00Oomoogoo00002Woo0`0000Eoo`00Oomo

o`00009oo`03001oogoo00<001Qoo`05001oogooOol00006Ool00`00Oomoo`0AOol01000Oomoo`0?

97oo00<03gooOol01Goo00<007ooOol06Goo00<03gooOol03Woo00<007ooOol04Goo00<007ooOol0

4Goo00<007ooOol03Woo00<03gooOol06Goo00<007ooOol01Goo00<03gooOol08Woo00@03gooOol0

01=oo`03001oogoo00Moo`002Woo1@003goo1`007Goo00D007ooOomoo`0000Ioo`03001oogoo015o

o`04001oogoo00lTOol00`0?Oomoo`05Ool00`00Oomoo`0IOol00`0?Oomoo`0>Ool00`00Oomoo`0A

Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`0?Oomoo`0IOol00`00Oomoo`05Ool00`0?Oomoo`0R

Ool00`0?Ool0000DOol00`00Oomoo`07Ool0049oo`05001oogooOol00006Ool00`00Oomoo`0BOol0

0`00Ool03`0TOol00`0?Oomoo`04Ool00`00Oomoo`0JOol00`0?Oomoo`0>Ool00`00Oomoo`0AOol0

0`00Oomoo`0@Ool00`00Oomoo`0?Ool00`0?Oomoo`0IOol00`00Oomoo`05Ool00`0?Oomoo`0ROol0

0`0?001oo`0DOol00`00Oomoo`07Ool0049oo`05001oogooOol00006Ool00`00Oomoo`0COol00`00

00moo`0SOol00`0?Oomoo`04Ool00`00Oomoo`0JOol00`0?Oomoo`0?Ool00`00Oomoo`0@Ool00`00

Oomoo`0@Ool00`00Oomoo`0?Ool00`0?Oomoo`0IOol00`00Oomoo`05Ool00`0?Oomoo`0ROol00`0?

001oo`0DOol00`00Oomoo`07Ool004=oo`<000Moo`03001oogoo01Aoo`03001oogoo029oo`0300mo

ogoo00Aoo`03001oogoo01Yoo`0300moogoo00moo`03001oogoo011oo`03001oogoo011oo`03001o

ogoo00moo`0300moogoo01Uoo`03001oogoo00Eoo`0300moogoo029oo`03001oogoo01Aoo`03001o

ogoo00Moo`00CGoo00<007ooOol057oo00<007ooOol08Woo00<03gooOol017oo00<007ooOol06Woo

00<03gooOol03goo00<007ooOol047oo00<007ooOol047oo00<007ooOol03goo00<03gooOol06Woo

00<007ooOol017oo00<03gooOol08Goo00<0000?Ool05Goo00<007ooOol01goo001=Ool2000EOol0

0`0?001oo`0ROol00`0?Oomoo`04Ool00`00Oomoo`0JOol00`0?Oomoo`0?Ool00`00Oomoo`0@Ool0

0`00Oomoo`0@Ool00`00Oomoo`0?Ool00`0?Oomoo`0JOol00`00Oomoo`04Ool00`0?Oomoo`0POol0

0`00Ool03`0EOol20009Ool004eoo`03001oogoo01Aoo`0300l007oo029oo`0300moogoo00=oo`03

001oogoo01]oo`0300moogoo00moo`03001oogoo011oo`03001oogoo011oo`03001oogoo00moo`03

00moogoo01Yoo`03001oogoo00Aoo`0300moogoo021oo`03001oo`0?01Ioo`03001oogoo00Moo`00

CGoo00<007ooOol057oo00<03goo00008Woo00<03gooOol00goo00<007ooOol06goo00<03gooOol0

47oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<03gooOol06Woo00<007ooOol0

17oo00<03gooOol07goo00@007ooOol03aIoo`03001oogoo00Moo`00CGoo00<007ooOol057oo00<0

3goo00008Woo00<03gooOol00goo00<007ooOol06goo00<03gooOol047oo00<007ooOol03goo00<0

07ooOol03goo00<007ooOol047oo00<03gooOol06Woo00<007ooOol017oo00<03gooOol07goo00@0

07ooOol03aIoo`03001oogoo00Moo`00CGoo00<007ooOol057oo00@03gooOol0025oo`0300moogoo

00=oo`03001oogoo01]oo`0300moogoo011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo

011oo`0300moogoo01]oo`03001oogoo00=oo`0300moogoo01ioo`05001oogooOol03`0FOol00`00

Oomoo`07Ool004eoo`03001oogoo01Aoo`0400moogoo000QOol00`0?Oomoo`03Ool00`00Oomoo`0K

Ool00`0?Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`0?Oomoo`0K

Ool00`00Oomoo`03Ool00`0?Oomoo`0NOol01@00Oomoogoo00l05Woo00<007ooOol01goo001=Ool0

0`00Oomoo`0DOol01@0?Oomoogoo000087oo00<03gooOol00Woo00<007ooOol077oo00<03gooOol0

47oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<03gooOol06goo00<007ooOol0

0goo00<03gooOol07Woo00D007ooOomoo`0?01Ioo`03001oogoo00Moo`00CGoo00<007ooOol057oo

00D03gooOomoo`00021oo`0300moogoo009oo`03001oogoo01aoo`0300moogoo015oo`03001oogoo

00ioo`03001oogoo00ioo`03001oogoo015oo`0300moogoo01]oo`03001oogoo00=oo`0300moogoo

01ioo`05001oogooOol03`0FOol00`00Oomoo`07Ool004eoo`8001Eoo`0300moogoo009oo`03001o

ogoo01eoo`0300moogoo009oo`03001oogoo01aoo`0300moogoo015oo`03001oogoo00ioo`03001o

ogoo00ioo`03001oogoo015oo`0300moogoo01aoo`03001oogoo009oo`0300moogoo01eoo`03001o

ogoo009oo`0300moogoo01=oo`8000Uoo`00CGoo00<007ooOol057oo00<03gooOol00Woo00<007oo

Ool07Goo00<03gooOol00Woo00<007ooOol077oo00<03gooOol04Goo00<007ooOol03Woo00<007oo

Ool03Woo00<007ooOol04Goo00<03gooOol077oo00<007ooOol00Woo00<03gooOol07Goo00<007oo

Ool00Woo00<03gooOol057oo00<007ooOol01goo001=Ool00`00Oomoo`0DOol00`0?Oomoo`03Ool0

0`00Oomoo`0LOol01@0?Oomoogoo00007goo00<03gooOol04Goo00<007ooOol03Woo00<007ooOol0

3Woo00<007ooOol04Goo00<03gooOol077oo00<007ooOol00Woo00<03gooOol07Goo00<007ooOol0

0Woo00<03gooOol057oo00<007ooOol01goo001=Ool00`00Oomoo`0DOol00`0?Oomoo`03Ool00`00

Oomoo`0LOol01@0?Oomoogoo00007goo00<03gooOol04Goo00<007ooOol03Woo00<007ooOol03Woo

00<007ooOol04Goo00<03gooOol077oo00<007ooOol00Woo00<03gooOol077oo00<007ooOol00goo

00<03gooOol057oo00<007ooOol01goo001=Ool00`00Oomoo`0DOol00`0?Oomoo`03Ool00`00Oomo

o`0LOol01@0?Oomoogoo00007goo00<03gooOol04Woo00<007ooOol03Goo00<007ooOol03Woo00<0

07ooOol04Goo00<03gooOol07Goo00D007ooOomoo`0?01ioo`03001oogoo00=oo`0300moogoo01Ao

o`03001oogoo00Moo`00CGoo00<007ooOol057oo00<03gooOol017oo00<007ooOol06goo00D03goo

Oomoo`0001moo`0300moogoo019oo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo019oo`03

00moogoo01eoo`05001oogooOol03`0MOol00`00Oomoo`04Ool00`0?Oomoo`0DOol00`00Oomoo`07

Ool004eoo`03001oogoo01Aoo`0300moogoo00Aoo`03001oogoo01]oo`0500moogooOol0000OOol0

0`0?Oomoo`0BOol00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0BOol00`0?Oomoo`0MOol0

1@00Oomoogoo00l07Goo00<007ooOol017oo00<03gooOol057oo00<007ooOol01goo001=Ool00`00

Oomoo`0DOol00`0?Oomoo`04Ool00`00Oomoo`0KOol0100?Oomoo`0087oo00<03gooOol04Woo00<0

07ooOol03Goo00<007ooOol03Goo00<007ooOol04Woo00<03gooOol07Goo00D007ooOomoo`0?01ao

o`03001oogoo00Eoo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo0P005Goo00<03gooOol017oo

00<007ooOol06goo00@03gooOol0021oo`0300moogoo019oo`03001oogoo00eoo`03001oogoo00eo

o`03001oogoo019oo`0300moogoo01eoo`05001oogooOol03`0LOol00`00Oomoo`05Ool00`0?Oomo

o`0COol20009Ool004eoo`03001oogoo01Aoo`0300moogoo00Eoo`03001oogoo01Yoo`0400moogoo

000POol00`0?Oomoo`0COol00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0BOol00`0?Oomo

o`0NOol01000Oomoo`0?77oo00<007ooOol01Goo00<03gooOol057oo00<007ooOol01goo001=Ool0

0`00Oomoo`0DOol00`0?Oomoo`05Ool00`00Oomoo`0JOol0100?Oomoo`0087oo00<03gooOol04goo

00<007ooOol037oo00<007ooOol037oo00<007ooOol04goo00<03gooOol07Woo00@007ooOol03a]o

o`03001oogoo00Ioo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo00<007ooOol057oo00<03goo

Ool01Goo00<007ooOol06Woo00@03gooOol0021oo`0300moogoo01=oo`03001oogoo00aoo`03001o

ogoo00aoo`03001oogoo01=oo`0300moogoo01ioo`04001oogoo00lKOol00`00Oomoo`06Ool00`0?

Oomoo`0DOol00`00Oomoo`07Ool004eoo`03001oogoo01Aoo`0300moogoo00Ioo`03001oogoo01Uo

o`0300moo`00025oo`0300moogoo01=oo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo01=o

o`0300moogoo01ioo`04001oogoo00lKOol00`00Oomoo`06Ool00`0?Oomoo`0DOol00`00Oomoo`07

Ool003Yoo`<000=oo`03001oo`0000@000Ioo`03001oogoo01Aoo`0300moogoo00Ioo`03001oogoo

01Uoo`0300moo`00025oo`0300moogoo01=oo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo

01=oo`0300moogoo01moo`03001oo`0?01Yoo`03001oogoo00Moo`0300moogoo01Aoo`03001oogoo

00Moo`00>Goo00D007ooOomoo`0000Eoo`04001oogoo0006Ool00`00Oomoo`0DOol00`0?Oomoo`06

Ool00`00Oomoo`0IOol00`0?Ool0000QOol00`0?Oomoo`0DOol00`00Oomoo`0;Ool00`00Oomoo`0<

Ool00`00Oomoo`0COol00`0?Oomoo`0OOol00`00Ool03`0JOol00`00Oomoo`07Ool00`0?Oomoo`0D

Ool00`00Oomoo`07Ool003Uoo`05001oogooOol00006Ool00`00Oomoo`06Ool3000N00l00`0000l0

3`0J00l00`0000l03`0f00l00`0000l03`0;00l00`0000l03`0;00l00`0000l03`0f00l00`0000l0

3`0J00l00`0000l03`0L00l30009Ool003Uoo`05001oogooOol00007Ool00`00Oomoo`05Ool00`00

Oomoo`0DOol00`0?Oomoo`07Ool00`00Oomoo`0HOol00`0?Ool0000QOol00`0?Oomoo`0DOol00`00

Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0DOol00`0?Oomoo`0OOol00`00Ool03`0IOol00`00

Oomoo`08Ool00`0?Oomoo`0DOol00`00Oomoo`07Ool003Uoo`05001oogooOol00008Ool00`00Oomo

o`04Ool00`00Oomoo`0DOol00`0?Oomoo`07Ool00`00Oomoo`0HOol00`0?001oo`0QOol00`0?Oomo

o`0DOol00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0DOol00`0?Oomoo`0POol00`0000mo

o`0HOol00`00Oomoo`08Ool00`0?Oomoo`0DOol00`00Oomoo`07Ool003Uoo`05001oogooOol00008

Ool00`00Oomoo`04Ool00`00Oomoo`0DOol00`0?Oomoo`07Ool00`00Oomoo`0HOol00`0?001oo`0Q

Ool00`0?Oomoo`0DOol00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0DOol00`0?Oomoo`0P

Ool00`0000moo`0HOol00`00Oomoo`08Ool00`0?Oomoo`0DOol00`00Oomoo`07Ool003Uoo`05001o

ogooOol00008Ool00`00Oomoo`04Ool00`00Oomoo`0DOol00`0?Oomoo`08Ool00`00Oomoo`0GOol0

0`0?001oo`0QOol00`0?Oomoo`0DOol00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0DOol0

0`0?Oomoo`0POol00`0000moo`0HOol00`00Oomoo`08Ool00`0?Oomoo`0DOol00`00Oomoo`07Ool0

03Uoo`05001oogooOol00004Ool01@00Oomoogoo00001Woo00<007ooOol057oo00<03gooOol027oo

00<007ooOol05goo00<03`00Ool08Goo00<03gooOol05Goo00<007ooOol02Woo00<007ooOol02goo

00<007ooOol057oo00<03gooOol087oo00<0000?Ool05goo00<007ooOol02Goo00<03gooOol057oo

00<007ooOol01goo000jOol30006Ool30007Ool00`00Oomoo`0DOol00`0?Oomoo`08Ool00`00Oomo

o`0GOol00`0?001oo`0QOol00`0?Oomoo`0EOol00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomo

o`0EOol00`0?Oomoo`0POol00`0000moo`0GOol00`00Oomoo`09Ool00`0?Oomoo`0DOol00`00Oomo

o`07Ool004eoo`03001oogoo01Aoo`0300moogoo00Uoo`03001oogoo01Ioo`03001oogoo025oo`03

00moogoo01Eoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo01Eoo`0300moogoo025oo`03

001oogoo01Ioo`03001oogoo00Uoo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo0P005Goo00<0

3gooOol02Goo00<007ooOol05Woo00<007ooOol08Goo00<03gooOol05Goo00<007ooOol02Woo00<0

07ooOol02Woo00<007ooOol05Goo00<03gooOol08Goo00<007ooOol05Goo00<007ooOol02Woo00<0

3gooOol04goo0P002Goo001=Ool00`00Oomoo`0DOol00`0?Oomoo`09Ool00`00Oomoo`0FOol00`00

Oomoo`0QOol00`0?Oomoo`0EOol00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0EOol00`0?

Oomoo`0QOol00`00Oomoo`0EOol00`00Oomoo`0:Ool00`0?Oomoo`0DOol00`00Oomoo`07Ool004eo

o`03001oogoo01Aoo`0300moogoo00Yoo`03001oogoo01Eoo`03001oogoo025oo`0300moogoo01Eo

o`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo01Ioo`0300moogoo025oo`03001oogoo01Eo

o`03001oogoo00Yoo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo00<007ooOol057oo00<03goo

Ool02Woo00<007ooOol057oo00<0000?Ool08Woo00<03gooOol05Woo00<007ooOol02Goo00<007oo

Ool02Goo00<007ooOol05Woo00<03gooOol08Goo00<007ooOol057oo00<007ooOol02goo00<03goo

Ool057oo00<007ooOol01goo001=Ool00`00Oomoo`0DOol00`0?Oomoo`0:Ool00`00Oomoo`0DOol0

0`0000moo`0ROol00`0?Oomoo`0FOol00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0FOol0

0`0?Oomoo`0QOol00`00Oomoo`0DOol00`00Oomoo`0;Ool00`0?Oomoo`0DOol00`00Oomoo`07Ool0

04eoo`03001oogoo01Aoo`0300moogoo00Yoo`03001oogoo01Aoo`0300003goo029oo`0300moogoo

01Ioo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo01Ioo`0300moogoo025oo`0300l007oo

01Aoo`03001oogoo00]oo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo00<007ooOol057oo00<0

3gooOol02goo00<007ooOol04goo00<0000?Ool08Woo00<03gooOol05Woo00<007ooOol02Goo00<0

07ooOol027oo00<007ooOol05goo00<03gooOol08Goo00<03`00Ool04goo00<007ooOol037oo00<0

3gooOol057oo00<007ooOol01goo001=Ool00`00Oomoo`0DOol00`0?Oomoo`0;Ool00`00Oomoo`0B

Ool00`00Ool03`0SOol00`0?Oomoo`0FOol00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`0G

Ool00`0?Oomoo`0QOol00`0?001oo`0COol00`00Oomoo`0<Ool00`0?Oomoo`0DOol00`00Oomoo`07

Ool004eoo`8001Eoo`0300moogoo00]oo`03001oogoo019oo`03001oo`0?02=oo`0300moogoo01Mo

o`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo01Moo`0300moogoo025oo`0300l007oo01=o

o`03001oogoo00aoo`0300moogoo01=oo`8000Uoo`00CGoo00<007ooOol057oo00<03gooOol037oo

00<007ooOol04Goo00<007oo00l08goo00<03gooOol05goo00<007ooOol027oo00<007ooOol027oo

00<007ooOol05goo00<03gooOol08Goo00<03goo00004Woo00<007ooOol03Goo00<03gooOol057oo

00<007ooOol01goo001=Ool00`00Oomoo`0DOol00`0?Oomoo`0<Ool00`00Oomoo`0AOol00`00Ool0

3`0SOol00`0?Oomoo`0GOol00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0HOol00`0?Oomo

o`0QOol00`0?Ool0000BOol00`00Oomoo`0=Ool00`0?Oomoo`0DOol00`00Oomoo`07Ool004eoo`03

001oogoo01Aoo`0300moogoo00aoo`03001oogoo011oo`04001oogoo00lSOol00`0?Oomoo`0GOol0

0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0HOol00`0?Oomoo`0QOol00`0?Ool0000BOol0

0`00Oomoo`0=Ool00`0?Oomoo`0DOol00`00Oomoo`07Ool004eoo`03001oogoo01Aoo`0300moogoo

00eoo`03001oogoo00moo`04001oogoo00lSOol00`0?Oomoo`0HOol00`00Oomoo`07Ool00`00Oomo

o`07Ool00`00Oomoo`0HOol00`0?Oomoo`0QOol0100?Oomoo`004Goo00<007ooOol03Goo00<03goo

Ool057oo00<007ooOol01goo001=Ool00`00Oomoo`0DOol00`0?Oomoo`0=Ool00`00Oomoo`0?Ool0

1000Oomoo`0?8goo00<03gooOol067oo00<007ooOol01goo00<007ooOol01goo00<007ooOol067oo

00<03gooOol08Goo00@03gooOol0011oo`03001oogoo00ioo`0300moogoo01Aoo`03001oogoo00Mo

o`00CGoo00<007ooOol057oo00<03gooOol03Goo00<007ooOol03Woo00D007ooOomoo`0?02=oo`03

00moogoo01Qoo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo01Uoo`0300moogoo025oo`04

00moogoo000@Ool00`00Oomoo`0>Ool00`0?Oomoo`0DOol00`00Oomoo`07Ool004eoo`03001oogoo

01Aoo`0300moogoo00ioo`03001oogoo00eoo`05001oogooOol03`0SOol00`0?Oomoo`0HOol00`00

Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0IOol00`0?Oomoo`0QOol01@0?Oomoogoo00003goo

00<007ooOol03Woo00<03gooOol057oo00<007ooOol01goo001=Ool2000EOol00`0?Oomoo`0>Ool0

0`00Oomoo`0=Ool01@00Oomoogoo00l08goo00<03gooOol06Goo00<007ooOol01Woo00<007ooOol0

1Woo00<007ooOol06Goo00<03gooOol08Goo00D03gooOomoo`0000ioo`03001oogoo00moo`0300mo

ogoo01=oo`8000Uoo`00CGoo00<007ooOol057oo00<03gooOol03goo00<007ooOol02goo00<007oo

Ool00Woo00<03gooOol08Goo00<03gooOol06Goo00<007ooOol01Woo00<007ooOol01Woo00<007oo

Ool06Goo00<03gooOol08Goo00D03gooOomoo`0000ioo`03001oogoo00moo`0300moogoo01Aoo`03

001oogoo00Moo`00CGoo00<007ooOol057oo00<03gooOol03goo00<007ooOol02goo00<007ooOol0

0Woo00<03gooOol08Goo00<03gooOol06Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol0

6Woo00<03gooOol08Goo00D03gooOomoo`0000ioo`03001oogoo00moo`0300moogoo01Aoo`03001o

ogoo00Moo`00CGoo00<007ooOol057oo00<03gooOol03goo00<007ooOol02goo00<007ooOol00Woo

00<03gooOol08Goo00<03gooOol06Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol06Woo

00<03gooOol08Goo00<03gooOol00Woo00<007ooOol02Woo00<007ooOol047oo00<03gooOol057oo

00<007ooOol01goo001=Ool00`00Oomoo`0DOol00`0?Oomoo`0?Ool00`00Oomoo`0:Ool00`00Oomo

o`03Ool00`0?Oomoo`0QOol00`0?Oomoo`0JOol00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo

o`0JOol00`0?Oomoo`0QOol00`0?Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`0@Ool00`0?Oomo

o`0DOol00`00Oomoo`07Ool003Yoo`<000=oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo

01Aoo`0300moogoo011oo`03001oogoo00Uoo`03001oogoo00=oo`0300moogoo025oo`0300moogoo

01Yoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo01Yoo`0300moogoo025oo`0300moogoo

009oo`03001oogoo00Yoo`03001oogoo011oo`0300moogoo01Aoo`03001oogoo00Moo`00>Goo00D0

07ooOomoo`0000Qoo`03001oogoo00Aoo`03001oogoo01Aoo`0300moogoo011oo`03001oogoo00Uo

o`03001oogoo00=oo`0300moogoo025oo`0300moogoo01Yoo`03001oogoo00Eoo`03001oogoo00Ao

o`03001oogoo01]oo`0300moogoo025oo`0300moogoo009oo`03001oogoo00Yoo`03001oogoo011o

o`0300moogoo01Aoo`03001oogoo00Moo`00>Goo00D007ooOomoo`0000Aoo`H000Eoo`03001oogoo

01Aoo`0300moogoo015oo`03001oogoo00Moo`03001oogoo00Aoo`0300moogoo025oo`0300moogoo

01]oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo01]oo`0300moogoo025oo`0300moogoo

00=oo`03001oogoo00Qoo`03001oogoo015oo`0300moogoo01Aoo`03001oogoo00Moo`00>Goo00D0

07ooOomoo`0000Aoo`05001oogooOol00006Ool3000X00l00`0000l03`0700l00`0000l03`1600l0

0`0000l03`0400l00`0000l03`0400l00`0000l03`1500l00`0000l03`0800l00`0000l03`0V00l3

0009Ool003Uoo`05001oogooOol00005Ool01000Oomoo`001Woo00<007ooOol057oo00<03gooOol0

4Woo00<007ooOol01Woo00<007ooOol017oo00<03gooOol08Goo00<03gooOol06goo00<007ooOol0

17oo00<007ooOol00goo00<007ooOol077oo00<03gooOol08Goo00<03gooOol017oo00<007ooOol0

1Woo00<007ooOol04Woo00<03gooOol057oo00<007ooOol01goo000iOol01@00Oomoogoo00001Woo

00<007oo00001Woo00<007ooOol057oo00<03gooOol04Woo00<007ooOol01Goo00<007ooOol01Goo

00<03gooOol08Goo00<03gooOol077oo00<007ooOol00goo00<007ooOol00goo00<007ooOol077oo

00<03gooOol08Goo00<03gooOol01Goo00<007ooOol01Goo00<007ooOol04Woo00<03gooOol057oo

00<007ooOol01goo000iOol01@00Oomoogoo00001Woo00<007oo00001Woo00<007ooOol057oo00<0

3gooOol04Woo00<007ooOol01Goo00<007ooOol01Goo00<03gooOol08Goo00<03gooOol077oo00<0

07ooOol00goo00<007ooOol00goo00<007ooOol077oo00<03gooOol08Goo00<03gooOol01Goo00<0

07ooOol017oo00<007ooOol04goo00<03gooOol057oo00<007ooOol01goo000iOol01@00Oomoogoo

00001goo0P001Woo00<007ooOol057oo00<03gooOol04goo00<007ooOol00goo00<007ooOol01Woo

00<03gooOol08Goo00<03gooOol077oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol07Goo

00<03gooOol08Goo00<03gooOol01Woo00<007ooOol00goo00<007ooOol04goo00<03gooOol057oo

00<007ooOol01goo000jOol30009Ool00`00Oomoo`04Ool00`00Oomoo`0DOol00`0?Oomoo`0DOol0

1@00Oomoogoo00002Goo00<03gooOol08Goo00<03gooOol07Goo00<007ooOol00Woo00<007ooOol0

0Woo00<007ooOol07Goo00<03gooOol08Goo00<03gooOol01Woo00@007ooOomoo`8001Ioo`0300mo

ogoo01Aoo`03001oogoo00Moo`00CGoo00<007ooOol057oo00<03gooOol05Goo10002Goo00<03goo

Ool08Goo00<03gooOol07Goo00<007ooOol00Woo00D007ooOomoo`00021oo`0300moogoo025oo`03

00moogoo00Moo`@001Moo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo0P005Goo00<03gooOol0

8Woo00<03gooOol08Goo00<03gooOol07Goo00<007ooOol00Woo00D007ooOomoo`00021oo`0300mo

ogoo025oo`0300moogoo029oo`0300moogoo01=oo`8000Uoo`00CGoo00<007ooOol057oo00<03goo

Ool08Woo00<03gooOol08Goo00<03gooOol07Woo00D007ooOomoo`00009oo`03001oogoo01moo`03

00moogoo025oo`0300moogoo029oo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo00<007ooOol0

57oo00<03gooOol08Woo00<03gooOol08Goo00<03gooOol07Woo00D007ooOomoo`00009oo`03001o

ogoo01moo`0300moogoo025oo`0300moogoo029oo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo

00<007ooOol057oo00<03gooOol08Woo00<03gooOol08Goo00<03gooOol07goo00@007ooOol0009o

o`03001oogoo01moo`0300moogoo025oo`0300moogoo029oo`0300moogoo01Aoo`03001oogoo00Mo

o`00CGoo00<007ooOol057oo00<03gooOol08Woo00<03gooOol08Goo00<03gooOol087oo00D007oo

001oo`00029oo`0300moogoo025oo`0300moogoo029oo`0300moogoo01Aoo`03001oogoo00Moo`00

CGoo00<007ooOol057oo00<03gooOol08Woo00<03gooOol08Goo00<03gooOol087oo1@008Woo00<0

3gooOol08Goo00<03gooOol08Woo00<03gooOol057oo00<007ooOol01goo001=Ool00`00Oomoo`0D

Ool00`0?Oomoo`0ROol00`0?Oomoo`0QOol00`0?Oomoo`0ROol00`00Oomoo`0ROol00`0?Oomoo`0Q

Ool00`0?Oomoo`0ROol00`0?Oomoo`0DOol00`00Oomoo`07Ool004eoo`03001oogoo01Aoo`0300mo

ogoo029oo`0300moogoo025oo`0300moogoo029oo`03001oogoo029oo`0300moogoo025oo`0300mo

ogoo029oo`0300moogoo01Aoo`03001oogoo00Moo`00CGoo0P000Woo00<007ooOol01goo00<007oo

Ool01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01goo00<007oo

Ool01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007oo

Ool01goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007oo

Ool01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007oo

Ool01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007oo

Ool01Woo00<007ooOol01Woo00@007ooOomoo`8000Uoo`00CGooo`0030002Goo003oOomROol00?mo

of9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00^Goo0`00

0Woo0`003Woo1`003goo0`00NGoo002jOol00`00Oomoo`02Ool00`00Oomoo`04Ool70003Ool00`00

Oomoo`02Ool00`00Oomoo`03Ool70002Ool01@00Oomoogoo0000N7oo002kOol01000Oomoo`004Goo

00<007ooOol00Woo00<007ooOol037oo00D007ooOomoo`0007Qoo`00_7oo0P004goo00<007ooOol0

47oo00D007ooOomoo`0007Qoo`00_Goo00<007ooOol01Woo1`001Goo00<007ooOol01Woo1`000Woo

00D007ooOomoo`0007Qoo`00_7oo0P0057oo00<007ooOol03goo00D007ooOomoo`0007Qoo`00^goo

00@007ooOol001Aoo`03001oogoo00ioo`05001oogooOol0001hOol00;Yoo`03001oogoo009oo`03

001oogoo00ioo`05001oogooOol0000?Ool01@00Oomoogoo0000N7oo002iOol30002Ool3000?Ool6

000?Ool3001iOol00?moof9oo`00\

\>"],

  ImageRangeCache->{{{0, 352}, {216, 0}} -> {-114.659, -0.763891, 0.544889, 

  0.00642821}}]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{



Cell[TextData["Checking the Magnetic Material"], "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[StyleBox[

"This cell presents a plot of the Magnetization vs Field Strength for the \

materials in use. Note that the NdFeB is anisotropic.",

  Evaluatable->False,

  AspectRatioFixed->True]], "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[CellGroupData[{



Cell[TextData[{

  StyleBox["RadPlotOptions",

    FontColor->RGBColor[1, 0, 0]],

  "[];\nPlot[",

  StyleBox["radMatMvsH",

    FontColor->RGBColor[1, 0, 0]],

  "[Pole, \"mz\", {0,0,hz}],{hz,-0.01,0.01}\n,FrameLabel->\"Xc06 \"\n\

,AxesLabel->{\"H\",\"M\"}\n];\n",

  StyleBox["\n",

    FontSlant->"Italic",

    FontColor->GrayLevel[0.0588235]],

  "Plot[\n{",

  StyleBox["radMatMvsH",

    FontColor->RGBColor[1, 0, 0]],

  "[Magnet, \"mz\", {0,0,h}]\n,",

  StyleBox["radMatMvsH",

    FontColor->RGBColor[1, 0, 0]],

  "[Magnet, \"my\", {0,h,0}]}\n,{h,-1,1}\n,FrameLabel->\"NdFeB\"\n\

,AxesLabel->{\"H\",\"M\"}\n];"

}], "Input",

  AspectRatioFixed->True],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Times findfont 12  scalefont  setfont

% Scaling calculations

0.5 47.6191 0.309017 0.165043 [

[.02381 -0.0125 -17 -15 ]

[.02381 -0.0125 17 0 ]

[.2619 -0.0125 -20 -15 ]

[.2619 -0.0125 20 0 ]

[.5 -0.0125 -5 -15 ]

[.5 -0.0125 5 0 ]

[.7381 -0.0125 -15.5 -15 ]

[.7381 -0.0125 15.5 0 ]

[.97619 -0.0125 -12.5 -15 ]

[.97619 -0.0125 12.5 0 ]

[ 0 0 -0.125 0 ]

[-0.0125 .06145 -28 -7.5 ]

[-0.0125 .06145 0 7.5 ]

[-0.0125 .14397 -19 -7.5 ]

[-0.0125 .14397 0 7.5 ]

[-0.0125 .2265 -28 -7.5 ]

[-0.0125 .2265 0 7.5 ]

[-0.0125 .30902 -10 -7.5 ]

[-0.0125 .30902 0 7.5 ]

[-0.0125 .39154 -19 -7.5 ]

[-0.0125 .39154 0 7.5 ]

[-0.0125 .47406 -10 -7.5 ]

[-0.0125 .47406 0 7.5 ]

[-0.0125 .55658 -19 -7.5 ]

[-0.0125 .55658 0 7.5 ]

[ 0 0 -0.125 0 ]

[-0.01875 .30902 -61 -7.5 ]

[-0.01875 .30902 -28 7.5 ]

[ 0 .61803 .125 0 ]

[ 1 0 .125 0 ]

[1.025 .30902 0 -7.5 ]

[1.025 .30902 13 7.5 ]

[.5 .64303 -7.5 0 ]

[.5 .64303 7.5 15 ]

[ -0.0005 -0.0005 0 0 ]

[ 1.0005 .61853 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 .5 r

.25 Mabswid

.2619 0 m

.2619 .61803 L

s

.5 0 m

.5 .61803 L

s

.7381 0 m

.7381 .61803 L

s

0 .06145 m

1 .06145 L

s

0 .14397 m

1 .14397 L

s

0 .2265 m

1 .2265 L

s

0 .30902 m

1 .30902 L

s

0 .39154 m

1 .39154 L

s

0 .47406 m

1 .47406 L

s

0 .55658 m

1 .55658 L

s

0 g

.02381 0 m

.02381 .00625 L

s

gsave

.02381 -0.0125 -78 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.01) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.2619 0 m

.2619 .00625 L

s

gsave

.2619 -0.0125 -81 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.005) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.5 0 m

.5 .00625 L

s

gsave

.5 -0.0125 -66 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.7381 0 m

.7381 .00625 L

s

gsave

.7381 -0.0125 -76.5 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.005) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.97619 0 m

.97619 .00625 L

s

gsave

.97619 -0.0125 -73.5 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.01) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

.07143 0 m

.07143 .00375 L

s

.11905 0 m

.11905 .00375 L

s

.16667 0 m

.16667 .00375 L

s

.21429 0 m

.21429 .00375 L

s

.30952 0 m

.30952 .00375 L

s

.35714 0 m

.35714 .00375 L

s

.40476 0 m

.40476 .00375 L

s

.45238 0 m

.45238 .00375 L

s

.54762 0 m

.54762 .00375 L

s

.59524 0 m

.59524 .00375 L

s

.64286 0 m

.64286 .00375 L

s

.69048 0 m

.69048 .00375 L

s

.78571 0 m

.78571 .00375 L

s

.83333 0 m

.83333 .00375 L

s

.88095 0 m

.88095 .00375 L

s

.92857 0 m

.92857 .00375 L

s

.25 Mabswid

0 0 m

1 0 L

s

0 .06145 m

.00625 .06145 L

s

gsave

-0.0125 .06145 -89 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.5) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

0 .14397 m

.00625 .14397 L

s

gsave

-0.0125 .14397 -80 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

0 .2265 m

.00625 .2265 L

s

gsave

-0.0125 .2265 -89 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

0 .30902 m

.00625 .30902 L

s

gsave

-0.0125 .30902 -71 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

0 .39154 m

.00625 .39154 L

s

gsave

-0.0125 .39154 -80 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

0 .47406 m

.00625 .47406 L

s

gsave

-0.0125 .47406 -71 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

0 .55658 m

.00625 .55658 L

s

gsave

-0.0125 .55658 -80 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.5) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

0 .07796 m

.00375 .07796 L

s

0 .09446 m

.00375 .09446 L

s

0 .11097 m

.00375 .11097 L

s

0 .12747 m

.00375 .12747 L

s

0 .16048 m

.00375 .16048 L

s

0 .17698 m

.00375 .17698 L

s

0 .19349 m

.00375 .19349 L

s

0 .20999 m

.00375 .20999 L

s

0 .243 m

.00375 .243 L

s

0 .2595 m

.00375 .2595 L

s

0 .27601 m

.00375 .27601 L

s

0 .29251 m

.00375 .29251 L

s

0 .32552 m

.00375 .32552 L

s

0 .34203 m

.00375 .34203 L

s

0 .35853 m

.00375 .35853 L

s

0 .37503 m

.00375 .37503 L

s

0 .40804 m

.00375 .40804 L

s

0 .42455 m

.00375 .42455 L

s

0 .44105 m

.00375 .44105 L

s

0 .45756 m

.00375 .45756 L

s

0 .49056 m

.00375 .49056 L

s

0 .50707 m

.00375 .50707 L

s

0 .52357 m

.00375 .52357 L

s

0 .54008 m

.00375 .54008 L

s

0 .04495 m

.00375 .04495 L

s

0 .02844 m

.00375 .02844 L

s

0 .01194 m

.00375 .01194 L

s

0 .57309 m

.00375 .57309 L

s

0 .58959 m

.00375 .58959 L

s

0 .60609 m

.00375 .60609 L

s

.25 Mabswid

0 0 m

0 .61803 L

s

gsave

-0.01875 .30902 -122 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(Xc06) show

91.875000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.02381 .61178 m

.02381 .61803 L

s

.2619 .61178 m

.2619 .61803 L

s

.5 .61178 m

.5 .61803 L

s

.7381 .61178 m

.7381 .61803 L

s

.97619 .61178 m

.97619 .61803 L

s

.125 Mabswid

.07143 .61428 m

.07143 .61803 L

s

.11905 .61428 m

.11905 .61803 L

s

.16667 .61428 m

.16667 .61803 L

s

.21429 .61428 m

.21429 .61803 L

s

.30952 .61428 m

.30952 .61803 L

s

.35714 .61428 m

.35714 .61803 L

s

.40476 .61428 m

.40476 .61803 L

s

.45238 .61428 m

.45238 .61803 L

s

.54762 .61428 m

.54762 .61803 L

s

.59524 .61428 m

.59524 .61803 L

s

.64286 .61428 m

.64286 .61803 L

s

.69048 .61428 m

.69048 .61803 L

s

.78571 .61428 m

.78571 .61803 L

s

.83333 .61428 m

.83333 .61803 L

s

.88095 .61428 m

.88095 .61803 L

s

.92857 .61428 m

.92857 .61803 L

s

.25 Mabswid

0 .61803 m

1 .61803 L

s

.99375 .06145 m

1 .06145 L

s

.99375 .14397 m

1 .14397 L

s

.99375 .2265 m

1 .2265 L

s

.99375 .30902 m

1 .30902 L

s

.99375 .39154 m

1 .39154 L

s

.99375 .47406 m

1 .47406 L

s

.99375 .55658 m

1 .55658 L

s

.125 Mabswid

.99625 .07796 m

1 .07796 L

s

.99625 .09446 m

1 .09446 L

s

.99625 .11097 m

1 .11097 L

s

.99625 .12747 m

1 .12747 L

s

.99625 .16048 m

1 .16048 L

s

.99625 .17698 m

1 .17698 L

s

.99625 .19349 m

1 .19349 L

s

.99625 .20999 m

1 .20999 L

s

.99625 .243 m

1 .243 L

s

.99625 .2595 m

1 .2595 L

s

.99625 .27601 m

1 .27601 L

s

.99625 .29251 m

1 .29251 L

s

.99625 .32552 m

1 .32552 L

s

.99625 .34203 m

1 .34203 L

s

.99625 .35853 m

1 .35853 L

s

.99625 .37503 m

1 .37503 L

s

.99625 .40804 m

1 .40804 L

s

.99625 .42455 m

1 .42455 L

s

.99625 .44105 m

1 .44105 L

s

.99625 .45756 m

1 .45756 L

s

.99625 .49056 m

1 .49056 L

s

.99625 .50707 m

1 .50707 L

s

.99625 .52357 m

1 .52357 L

s

.99625 .54008 m

1 .54008 L

s

.99625 .04495 m

1 .04495 L

s

.99625 .02844 m

1 .02844 L

s

.99625 .01194 m

1 .01194 L

s

.99625 .57309 m

1 .57309 L

s

.99625 .58959 m

1 .58959 L

s

.99625 .60609 m

1 .60609 L

s

.25 Mabswid

1 0 m

1 .61803 L

s

.001 w

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(H) show

71.625000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.5 0 m

.5 .61803 L

s

gsave

.5 .64303 -68.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(M) show

73.687500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.002 w

.02381 .01472 m

.06244 .01709 L

.10458 .0199 L

.14415 .02281 L

.18221 .02596 L

.22272 .02983 L

.26171 .03423 L

.30316 .03986 L

.34309 .04647 L

.3815 .05424 L

.40134 .05917 L

.41147 .06222 L

.42237 .06629 L

.4276 .06872 L

.43257 .07147 L

.43741 .07469 L

.4419 .07833 L

.45065 .08795 L

.45527 .09494 L

.4602 .10438 L

.46556 .11762 L

.47049 .13317 L

.4759 .15471 L

.48161 .18312 L

.50178 .32259 L

.51198 .39608 L

.52165 .45184 L

.53032 .48765 L

.53522 .50256 L

.53975 .51355 L

.54463 .52294 L

.54921 .5299 L

.55399 .53568 L

.55926 .54072 L

.56933 .54767 L

.57499 .55056 L

.58018 .5528 L

.5991 .55898 L

.6198 .56409 L

.66036 .57219 L

.69941 .57855 L

.74091 .58413 L

.78089 .58858 L

.81936 .59221 L

.86027 .59557 L

.89968 .59843 L

.93756 .60094 L

.97619 .60332 L

s

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  Evaluatable->False,

  AspectRatioFixed->True,

  ImageSize->{282, 174},

  ImageMargins->{{34, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000[Q000`40O003h00Oogoo6goo003oOolK

Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00

ogoo6goo003oOolKOol00?mooa]oo`00?goo0`000goo00<007ooOol00`000goo0`006Woo0`000goo

00<007ooOol00`000goo0`000Woo0`007goo0`008Woo0`000goo00<007ooOol00`000goo0`000Woo

0`006goo0`000goo00<007ooOol00`000goo0`0047oo000nOol01@00Oomoogoo000017oo00D007oo

Oomoo`0000=oo`03001oogoo01Qoo`05001oogooOol00004Ool01`00Oomoogoo001oo`0000=oo`03

001oogoo009oo`03001oogoo01]oo`05001oogooOol0000POol01@00Oomoogoo000017oo00L007oo

Oomoo`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`0GOol01@00Oomoogoo000017oo00D007oo

Oomoo`0000=oo`03001oogoo00moo`00?Woo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool0

0`00Oomoo`0HOol01@00Oomoogoo000017oo00L007ooOomoo`00Ool00003Ool00`00Oomoo`03Ool0

0`00Oomoo`0JOol01@00Oomoogoo000087oo00D007ooOomoo`0000Aoo`07001oogooOol007oo0000

0goo00<007ooOol00goo00<007ooOol05Woo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool0

0`00Oomoo`0?Ool003Moo`P000=oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0A

Ool80003Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00=oo`03001oogoo

01Yoo`05001oogooOol0000POol01@00Oomoogoo000017oo00L007ooOomoo`00Ool00003Ool00`00

Oomoo`03Ool00`00Oomoo`0FOol01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`03001oogoo

00moo`00?Woo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool00`00Oomoo`0HOol01@00Oomo

ogoo000017oo00L007ooOomoo`00Ool00003Ool00`00Oomoo`03Ool00`00Oomoo`0JOol01@00Oomo

ogoo000087oo00D007ooOomoo`0000Aoo`07001oogooOol007oo00000goo00<007ooOol00goo00<0

07ooOol05Woo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool00`00Oomoo`0?Ool003ioo`05

001oogooOol00004Ool01@00Oomoogoo00000goo00<007ooOol067oo00D007ooOomoo`0000Aoo`07

001oogooOol007oo00000goo00<007ooOol00Woo00<007ooOol06goo00D007ooOomoo`00021oo`05

001oogooOol00004Ool01`00Oomoogoo001oo`0000=oo`03001oogoo009oo`03001oogoo01Moo`05

001oogooOol00004Ool01@00Oomoogoo00000goo00<007ooOol03goo000nOol01@00Oomoogoo0000

17oo00D007ooOomoo`0000=oo`03001oogoo01Qoo`05001oogooOol00004Ool01`00Oomoogoo001o

o`0000=oo`03001oogoo008001ioo`05001oogooOol0000POol01@00Oomoogoo000017oo00L007oo

Oomoo`00Ool00003Ool00`00Oomoo`02000JOol01@00Oomoogoo000017oo00D007ooOomoo`0000=o

o`03001oogoo00moo`00?Woo00D007ooOomoo`0000Aoo`05001oogooOol00002Ool2000JOol01@00

Oomoogoo000017oo00L007ooOomoo`00Ool00003Ool01000Oomoo`007goo00D007ooOomoo`00021o

o`05001oogooOol00004Ool01`00Oomoogoo001oo`0000=oo`04001oogoo000KOol01@00Oomoogoo

000017oo00D007ooOomoo`00009oo`80015oo`00?goo0`001Woo0`0017oo00<007ooOol06Goo0`00

1Woo0`000goo0`0017oo0`007Goo0`008Woo0`001Woo0`000goo0`0017oo0`006Goo0`001Woo0`00

17oo00<007ooOol03goo003oOolKOol00?mooa]oo`00ogoo6goo0010Ooo8000BOol0041oo`03001o

ogoo009oo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001o

ogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Moo`03001o

ogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001o

ogoo00Moo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001o

ogoo00Moo`03001oogoo009oo`03001oogoo011oo`00@7oo00<007ooOol00Woo00<007ooOol0;7oo

00<007ooOol0;7oo00<007ooOol0;Goo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol047oo

0010Ool20003Ool4000[Ool00`0?Oomoo`0/Ool00`00Oomoo`0]Ool00`0?Oomoo`0`Ool2000BOol0

041oo`03001oogoo00Iooa0001]oo`0300moogoo02aoo`03001oogoo02eoo`0300moogoo035oo`03

001oogoo011oo`00@7oo00<007ooOol05Woo20004goo00<03gooOol0;7oo00<007ooOol0;Goo00<0

3gooOol0<Goo00<007ooOol047oo0010Ool2000OOol?0004Ool00`0?Oomoo`0/Ool00`00Oomoo`0]

Ool00`0?Oomoo`0`Ool2000BOol0041oo`03001oogoo02eoo`P002]oo`03001oogoo02eoo`0300mo

ogoo035oo`03001oogoo011oo`00@7oo00<007ooOol0<Goo00@03gooOomoo`H002Eoo`03001oogoo

02eoo`0300moogoo035oo`03001oogoo011oo`00@7oo0P00<Woo00<03gooOol01goo10008Goo00<0

07ooOol0;Goo00<03gooOol0<7oo0P004Woo0010Ool00`00Oomoo`0aOol00`0?Oomoo`0;Ool6000K

Ool00`00Oomoo`0]Ool00`0?Oomoo`0aOol00`00Oomoo`0@Ool002eoo`<000=oo`03001oo`000080

00Qoo`03001oogoo035oo`0300moogoo015oo`H001Eoo`03001oogoo02eoo`0300moogoo035oo`03

001oogoo011oo`00;Woo00<007ooOol01goo00<007ooOol01Goo00<007ooOol0<Goo00<03gooOol0

5goo0`004Woo00<007ooOol0;Goo00<03gooOol0<Goo00<007ooOol047oo000^Ool00`00Oomoo`08

Ool00`00Oomoo`04Ool2001?00l2000@00l00`0000l03`1O00l3000BOol002Eoo`L0009oo`03001o

ogoo00Qoo`03001oogoo00Aoo`03001oogoo035oo`0300moogoo01aoo`<000eoo`03001oogoo02eo

o`0300moogoo035oo`03001oogoo011oo`00;Woo00<007ooOol027oo00<007ooOol017oo00<007oo

Ool0<Goo00<03gooOol07goo0P002goo00<007ooOol0;Goo00<03gooOol0<Goo00<007ooOol047oo

000^Ool00`00Oomoo`07Ool00`00Oomoo`05Ool2000bOol00`0?Oomoo`0QOol00`00Oomoo`08Ool0

0`00Oomoo`0]Ool00`0?Oomoo`0`Ool2000BOol002ioo`03001oogoo00Eoo`8000Qoo`03001oogoo

035oo`0300moogoo029oo`03001oogoo00Moo`03001oogoo02eoo`0300moogoo035oo`03001oogoo

011oo`00;Goo0P001goo00<007ooOol01goo00<007ooOol0<Goo00<03gooOol08goo00<007ooOol0

1Woo00<007ooOol0;Goo00<03gooOol0<Goo00<007ooOol047oo000^Ool00`00Oomoo`06Ool30006

Ool2000bOol00`0?Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`0]Ool00`0?Oomoo`0`Ool2000B

Ool0041oo`03001oogoo035oo`0300moogoo02Aoo`03001oogoo00Eoo`03001oogoo02eoo`0300mo

ogoo035oo`03001oogoo011oo`00@7oo00<007ooOol0<Goo00<03gooOol097oo00<007ooOol01Goo

00<007ooOol0;Goo00<03gooOol0<Goo00<007ooOol047oo0010Ool2000bOol00`0?Oomoo`0UOol0

0`00Oomoo`04Ool00`00Oomoo`0]Ool00`0?Oomoo`0`Ool2000BOol0041oo`03001oogoo035oo`03

00moogoo02Eoo`03001oogoo00Aoo`03001oogoo02eoo`0300moogoo035oo`03001oogoo011oo`00

@7oo00<007ooOol0<Goo00<03gooOol09Woo00<007ooOol00goo00<007ooOol0;Goo00<03gooOol0

<Goo00<007ooOol047oo0010Ool00`00Oomoo`0aOol00`0?Oomoo`0VOol00`00Oomoo`03Ool00`00

Oomoo`0]Ool00`0?Oomoo`0aOol00`00Oomoo`0@Ool0041oo`80039oo`0300moogoo02Moo`03001o

ogoo009oo`03001oogoo02eoo`0300moogoo031oo`80019oo`00=Woo0`001goo00<007ooOol0<Goo

00<03gooOol09goo00<007ooOol00Woo00<007ooOol0;Goo00<03gooOol0<Goo00<007ooOol047oo

000gOol00`00Oomoo`06Ool00`00Oomoo`0aOol00`0?Oomoo`0WOol00`00Oomoo`02Ool00`00Oomo

o`0]Ool00`0?Oomoo`0aOol00`00Oomoo`0@Ool003Moo`03001oogoo00Ioo`8005`03`0300003`0?

00803`0300003`0?05l03`<0019oo`00;Woo1`000Woo00<007ooOol01Woo00<007ooOol0<Goo00<0

3gooOol0:7oo00D007ooOomoo`0002moo`0300moogoo035oo`03001oogoo011oo`00=goo00<007oo

Ool01Woo00<007ooOol0<Goo00<03gooOol0:7oo00D007ooOomoo`0002moo`0300moogoo035oo`03

001oogoo011oo`00=goo00<007ooOol01Woo0P00<Woo00<03gooOol0:7oo00D007ooOomoo`0002mo

o`0300moogoo031oo`80019oo`00=goo00<007ooOol01Woo00<007ooOol0<Goo00<03gooOol0:7oo

00D007ooOomoo`0002moo`0300moogoo035oo`03001oogoo011oo`00=Woo0P0027oo00<007ooOol0

<Goo00<03gooOol0:7oo00D007ooOomoo`0002moo`0300moogoo035oo`03001oogoo011oo`00=goo

00<007ooOol01Woo00<007ooOol0<Goo00<03gooOol0:Goo00@007ooOol002moo`0300moogoo035o

o`03001oogoo011oo`00@7oo0P00<Woo00<03gooOol0:Goo00@007ooOol002moo`0300moogoo031o

o`80019oo`00@7oo00<007ooOol0<Goo00<03gooOol0:Goo00@007ooOol002moo`0300moogoo035o

o`03001oogoo011oo`00@7oo00<007ooOol0<Goo00<03gooOol0:Goo00@007ooOol002moo`0300mo

ogoo035oo`03001oogoo011oo`00@7oo0P00<Woo00<03gooOol0:Goo00@007ooOol002moo`0300mo

ogoo031oo`80019oo`00@7oo00<007ooOol0<Goo00<03gooOol0:Goo00@007ooOol002moo`0300mo

ogoo035oo`03001oogoo011oo`00@7oo00<007ooOol0<Goo00<03gooOol0:Woo00<007oo0000;goo

00<03gooOol0<Goo00<007ooOol047oo0010Ool2000bOol00`0?Oomoo`0ZOol00`00Ool0000_Ool0

0`0?Oomoo`0`Ool2000BOol002eoo`<000=oo`03001oo`00008000Qoo`03001oogoo035oo`0300mo

ogoo02Yoo`03001oo`0002moo`0300moogoo035oo`03001oogoo011oo`00;7oo00D007ooOomoo`00

00Moo`03001oogoo00Eoo`03001oogoo035oo`0300moogoo02Yoo`03001oo`0002moo`0300moogoo

035oo`03001oogoo011oo`00;7oo00D007ooOomoo`0000Qoo`03001oogoo00Aoo`8005l03`030000

3`0006403`<0019oo`009Goo20000goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol0<Goo

00<03gooOol0:Woo00<007oo0000;goo00<03gooOol0<Goo00<007ooOol047oo000/Ool01@00Oomo

ogoo000027oo00<007ooOol017oo00<007ooOol0<Goo00<03gooOol0:Woo00<007oo0000;goo00<0

3gooOol0<Goo00<007ooOol047oo000/Ool01@00Oomoogoo00001goo00<007ooOol01Goo00<007oo

Ool0<Goo00<03gooOol0:goo0P00;goo00<03gooOol0<Goo00<007ooOol047oo000/Ool01@00Oomo

ogoo00001Goo0P0027oo0P00<Woo00<03gooOol0:goo0P00;goo00<03gooOol0<7oo0P004Woo000/

Ool01@00Oomoogoo00001Goo00<007ooOol01goo00<007ooOol0<Goo00<03gooOol0:goo0P00;goo

00<03gooOol0<Goo00<007ooOol047oo000]Ool30007Ool30006Ool00`00Oomoo`0aOol00`0?Oomo

o`0[Ool2000_Ool00`0?Oomoo`0aOol00`00Oomoo`0@Ool0041oo`80039oo`0300moogoo02]oo`80

02moo`0300moogoo031oo`80019oo`00@7oo00<007ooOol0<Goo00<03gooOol0:goo0P00;goo00<0

3gooOol0<Goo00<007ooOol047oo0010Ool00`00Oomoo`0aOol00`0?Oomoo`0/Ool00`00Oomoo`0]

Ool00`0?Oomoo`0aOol00`00Oomoo`0@Ool0041oo`80039oo`0300moogoo02aoo`03001oogoo02eo

o`0300moogoo031oo`80019oo`00@7oo00<007ooOol0<Goo00<03gooOol0;7oo00<007ooOol0;Goo

00<03gooOol0<Goo00<007ooOol047oo0010Ool00`00Oomoo`0aOol00`0?Oomoo`0/Ool00`00Oomo

o`0]Ool00`0?Oomoo`0aOol00`00Oomoo`0@Ool0041oo`80039oo`0300moogoo02aoo`03001oogoo

02eoo`0300moogoo031oo`80019oo`00@7oo00<007ooOol0<Goo00<03gooOol0;7oo00<007ooOol0

;Goo00<03gooOol0<Goo00<007ooOol047oo0002Ool30002Ool30002Ool20003Ool30003Ool3000M

Ool30006Ool00`00Oomoo`0aOol00`0?Oomoo`0/Ool00`00Oomoo`0]Ool00`0?Oomoo`0aOol00`00

Oomoo`04Ool30002Ool30004Ool000=oo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003

Ool00`00Ool00003Ool00`00Oomoo`0IOol01@00Oomoogoo00001Goo00<007ooOol0<Goo00<03goo

Ool0;7oo0P00;Woo00<03gooOol0<Goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00goo

0004Ool01000Oomoo`000goo00<007ooOol00Woo00L007ooOomoo`00Ool00003Ool00`00Oomoo`0I

Ool01@00Oomoogoo00001Goob0001goo00<007ooOol00Woo00<007ooOol00goo0005Ool20004Ool0

0`00Oomoo`02Ool01`00Oomoogoo001oo`0000=oo`03001oogoo01Uoo`05001oogooOol00005Ool0

0`00Oomoo`0aOol00`0?Oomoo`0/Ool2000^Ool00`0?Oomoo`0aOol00`00Oomoo`05Ool00`00Oomo

o`02Ool00`00Oomoo`03Ool000Ioo`03001oogoo009oo`06001oogoo001oo`000goo00@007oo0000

009oo`03001oogoo01Uoo`05001oogooOol00005Ool00`00Oomoo`0aOol00`0?Oomoo`0/Ool2000^

Ool00`0?Oomoo`0aOol00`00Oomoo`05Ool60005Ool000Eoo`8000Eoo`<00003Ool007oo009oo`04

001oo`00Ool2000LOol01@00Oomoogoo00001Goo0P00<Woo00<03gooOol0;7oo0P00;Woo00<03goo

Ool0<7oo0P001goo00<007ooOol00Woo00<007ooOol00goo0004Ool01000Oomoo`0027oo00D007oo

Oomoo`00009oo`03001oogoo01aoo`05001oogooOol00005Ool00`00Oomoo`0aOol00`0?Oomoo`0/

Ool2000^Ool00`0?Oomoo`0aOol00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`03Ool000=o

o`03001oogoo009oo`03001oogoo00Eoo`05001oogooOol00003Ool00`00Oomoo`0KOol01@00Oomo

ogoo00001Goo00<007ooOol0<Goo00<03gooOol0;7oo0P00;Woo00<03gooOol0<Goo00<007ooOol0

1Goo00<007ooOol00Woo00<007ooOol00goo0002Ool30002Ool30007Ool30005Ool2000LOol30006

Ool2000bOol00`0?Oomoo`0/Ool00`00Ool0000]Ool00`0?Oomoo`0`Ool20006Ool30002Ool30004

Ool0041oo`03001oogoo035oo`0300moogoo02aoo`03001oo`0002eoo`0300moogoo035oo`03001o

ogoo011oo`00@7oo00<007ooOol0<Goo00<03gooOol0;7oo00<007oo0000;Goo00<03gooOol0<Goo

00<007ooOol047oo0010Ool00`00Oomoo`0aOol00`0?Oomoo`0/Ool00`00Ool0000]Ool00`0?Oomo

o`0aOol00`00Oomoo`0@Ool0041oo`80039oo`0300moogoo02aoo`03001oo`0002eoo`0300moogoo

031oo`80019oo`00@7oo00<007ooOol0<Goo00<03gooOol0;7oo00<007oo0000;Goo00<03gooOol0

<Goo00<007ooOol047oo0010Ool00`00Oomoo`0aOol00`0?Oomoo`0/Ool00`00Ool0000]Ool00`0?

Oomoo`0aOol00`00Oomoo`0@Ool0041oo`80039oo`0300moogoo02aoo`03001oo`0002eoo`0300mo

ogoo031oo`80019oo`00;Woo0`000goo00<007oo00000P001goo00<007ooOol0<Goo00<03gooOol0

;7oo00@007ooOol002aoo`0300moogoo035oo`03001oogoo011oo`00;Goo00D007ooOomoo`0000Mo

o`03001oogoo00Aoo`03001oogoo035oo`0300moogoo02aoo`04001oogoo000/Ool00`0?Oomoo`0a

Ool00`00Oomoo`0@Ool002eoo`05001oogooOol00008Ool00`00Oomoo`03Ool2001Q00l0100000l0

3`00GP0?0`004Woo000]Ool01@00Oomoogoo000027oo00<007ooOol00goo00<007ooOol0<Goo00<0

3gooOol0;7oo00@007ooOol002aoo`0300moogoo035oo`03001oogoo011oo`00;Goo00D007ooOomo

o`0000Qoo`03001oogoo00=oo`03001oogoo035oo`0300moogoo02aoo`04001oogoo000/Ool00`0?

Oomoo`0aOol00`00Oomoo`0@Ool002eoo`05001oogooOol00007Ool00`00Oomoo`04Ool2000bOol0

0`0?Oomoo`0/Ool01000Oomoo`00;7oo00<03gooOol0<7oo0P004Woo000]Ool01@00Oomoogoo0000

1Goo0P001goo00<007ooOol0<Goo00<03gooOol0;7oo00D007ooOomoo`0002]oo`0300moogoo035o

o`03001oogoo011oo`00;Goo00D007ooOomoo`0000Eoo`03001oogoo00Ioo`03001oogoo035oo`03

00moogoo02aoo`05001oogooOol0000[Ool00`0?Oomoo`0aOol00`00Oomoo`0@Ool002ioo`<000Mo

o`<000Eoo`03001oogoo035oo`0300moogoo02aoo`05001oogooOol0000[Ool00`0?Oomoo`0aOol0

0`00Oomoo`0@Ool0041oo`80039oo`0300moogoo02aoo`05001oogooOol0000[Ool00`0?Oomoo`0`

Ool2000BOol0041oo`03001oogoo035oo`0300moogoo02aoo`05001oogooOol0000[Ool00`0?Oomo

o`0aOol00`00Oomoo`0@Ool0041oo`03001oogoo035oo`0300moogoo02aoo`05001oogooOol0000[

Ool00`0?Oomoo`0aOol00`00Oomoo`0@Ool0041oo`80039oo`0300moogoo02aoo`03001oogoo009o

o`03001oogoo02Qoo`0300moogoo031oo`80019oo`00@7oo00<007ooOol0<Goo00<03gooOol0;7oo

00<007ooOol00Woo00<007ooOol0:7oo00<03gooOol0<Goo00<007ooOol047oo0010Ool00`00Oomo

o`0aOol00`0?Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0XOol00`0?Oomoo`0aOol00`00Oomo

o`0@Ool0041oo`80039oo`0300moogoo02aoo`03001oogoo009oo`03001oogoo02Qoo`0300moogoo

031oo`80019oo`00=goo0`001Woo00<007ooOol0<Goo00<03gooOol0;7oo00<007ooOol00Woo00<0

07ooOol0:7oo00<03gooOol0<Goo00<007ooOol047oo000hOol00`00Oomoo`05Ool00`00Oomoo`0a

Ool00`0?Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0XOol00`0?Oomoo`0aOol00`00Oomoo`0@

Ool003Qoo`03001oogoo00Eoo`8006403`0300003`0?00<03`0300003`0?05T03`<0019oo`00>7oo

00<007ooOol01Goo00<007ooOol0<Goo00<03gooOol0;7oo00<007ooOol00goo00<007ooOol09goo

00<03gooOol0<Goo00<007ooOol047oo000hOol00`00Oomoo`05Ool00`00Oomoo`0aOol00`0?Oomo

o`0/Ool00`00Oomoo`03Ool00`00Oomoo`0WOol00`0?Oomoo`0aOol00`00Oomoo`0@Ool003Qoo`03

001oogoo00Eoo`03001oogoo035oo`0300moogoo02aoo`03001oogoo00=oo`03001oogoo02Moo`03

00moogoo035oo`03001oogoo011oo`00>7oo00<007ooOol01Goo0P00<Woo00<03gooOol0;7oo00<0

07ooOol00goo00<007ooOol09goo00<03gooOol0<7oo0P004Woo000gOol20007Ool00`00Oomoo`0a

Ool00`0?Oomoo`0/Ool00`00Oomoo`04Ool00`00Oomoo`0VOol00`0?Oomoo`0aOol00`00Oomoo`0@

Ool003Qoo`03001oogoo00Eoo`03001oogoo035oo`0300moogoo02aoo`03001oogoo00Aoo`03001o

ogoo02Ioo`0300moogoo035oo`03001oogoo011oo`00@7oo0P00<Woo00<03gooOol0;7oo00<007oo

Ool017oo00<007ooOol09Woo00<03gooOol0<7oo0P004Woo0010Ool00`00Oomoo`0aOol00`0?Oomo

o`0/Ool00`00Oomoo`05Ool00`00Oomoo`0UOol00`0?Oomoo`0aOol00`00Oomoo`0@Ool0041oo`03

001oogoo035oo`0300moogoo02aoo`03001oogoo00Eoo`03001oogoo02Eoo`0300moogoo035oo`03

001oogoo011oo`00@7oo0P00<Woo00<03gooOol0;7oo00<007ooOol01Woo00<007ooOol097oo00<0

3gooOol0<7oo0P004Woo0010Ool00`00Oomoo`0aOol00`0?Oomoo`0/Ool00`00Oomoo`06Ool00`00

Oomoo`0TOol00`0?Oomoo`0aOol00`00Oomoo`0@Ool0041oo`03001oogoo035oo`0300moogoo02ao

o`03001oogoo00Moo`03001oogoo02=oo`0300moogoo035oo`03001oogoo011oo`00@7oo00<007oo

Ool0<Goo00<03gooOol0;7oo00<007ooOol027oo00<007ooOol08Woo00<03gooOol0<Goo00<007oo

Ool047oo0010Ool2000bOol00`0?Oomoo`0/Ool00`00Oomoo`09Ool00`00Oomoo`0QOol00`0?Oomo

o`0`Ool2000BOol002ioo`<000=oo`03001oo`00008000Moo`03001oogoo035oo`0300moogoo02ao

o`03001oogoo00Yoo`80025oo`0300moogoo035oo`03001oogoo011oo`00;goo00<007ooOol01goo

00<007ooOol017oo00<007ooOol0<Goo00<03gooOol0;7oo00<007ooOol037oo0`007Woo00<03goo

Ool0<Goo00<007ooOol047oo000_Ool00`00Oomoo`08Ool00`00Oomoo`03Ool2001Q00l00`0000l0

3`0?00l4001<00l3000BOol002moo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo035oo`03

00moogoo02aoo`03001oogoo01=oo`@001Ioo`0300moogoo035oo`03001oogoo011oo`00;goo00<0

07ooOol027oo00<007ooOol00goo00<007ooOol0<Goo00<03gooOol0;7oo00<007ooOol05goo1000

4Woo00<03gooOol0<Goo00<007ooOol047oo000_Ool00`00Oomoo`07Ool00`00Oomoo`04Ool2000b

Ool00`0?Oomoo`0/Ool00`00Oomoo`0KOol6000<Ool00`0?Oomoo`0`Ool2000BOol002moo`03001o

ogoo00Eoo`8000Moo`03001oogoo035oo`0300moogoo02aoo`03001oogoo025oo`P000Aoo`0300mo

ogoo035oo`03001oogoo011oo`00;Woo0P001goo00<007ooOol01Woo00<007ooOol0<Goo00<03goo

Ool0;7oo00<007ooOol0:Goo2000<7oo00<007ooOol047oo000_Ool00`00Oomoo`06Ool30005Ool2

000bOol00`0?Oomoo`0/Ool00`00Oomoo`0]Ool0100?Oomoogoo20009goo0P004Woo0010Ool00`00

Oomoo`0aOol00`0?Oomoo`0/Ool00`00Oomoo`0]Ool00`0?Oomoo`09Ool8000POol00`00Oomoo`0@

Ool0041oo`03001oogoo035oo`0300moogoo02aoo`03001oogoo02eoo`0300moogoo015ooa00011o

o`03001oogoo011oo`00@7oo00<007ooOol0<Goo00<03gooOol0;7oo00<007ooOol0;Goo00<03goo

Ool08Goo300017oo00<007ooOol047oo0010Ool2000bOol00`0?Oomoo`0/Ool00`00Oomoo`0]Ool0

0`0?Oomoo`0`Ool2000BOol0041oo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Moo`03

001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03

001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03

001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Ioo`03

001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo011oo`00

@7oob0004Woo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003o

OolKOol00?mooa]oo`00ogoo6goo002NOol30002Ool00`00Oomoo`03001aOol009moo`05001oogoo

Ool00003Ool00`00Oomoo`1`Ool009moo`06001oogoo001oo`000Woo00<007ooOol0L7oo002OOol0

1P00Oomoo`00Ool0009oo`03001oogoo071oo`00Wgoo00H007ooOol007oo0002Ool00`00Oomoo`1`

Ool009moo`03001oo`0000=oo`03001oo`00079oo`00Wgoo00<007oo00000goo00<007oo0000LWoo

002OOol20005Ool2001bOol009ioo`<000Eoo`<0075oo`00ogoo6goo003oOolKOol00?mooa]oo`00

ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00001\

\>"],

  ImageRangeCache->{{{0, 281}, {173, 0}} -> {-0.0173531, -2.60485, 

  0.000105889, 0.0305516}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Times findfont 12  scalefont  setfont

% Scaling calculations

0.5 0.476191 0.533345 0.411611 [

[.02381 -0.0125 -9.5 -15 ]

[.02381 -0.0125 9.5 0 ]

[.2619 -0.0125 -14 -15 ]

[.2619 -0.0125 14 0 ]

[.5 -0.0125 -5 -15 ]

[.5 -0.0125 5 0 ]

[.7381 -0.0125 -9.5 -15 ]

[.7381 -0.0125 9.5 0 ]

[.97619 -0.0125 -5 -15 ]

[.97619 -0.0125 5 0 ]

[ 0 0 -0.125 0 ]

[-0.0125 .03941 -28 -7.5 ]

[-0.0125 .03941 0 7.5 ]

[-0.0125 .12173 -19 -7.5 ]

[-0.0125 .12173 0 7.5 ]

[-0.0125 .20406 -28 -7.5 ]

[-0.0125 .20406 0 7.5 ]

[-0.0125 .28638 -28 -7.5 ]

[-0.0125 .28638 0 7.5 ]

[-0.0125 .3687 -28 -7.5 ]

[-0.0125 .3687 0 7.5 ]

[-0.0125 .45102 -28 -7.5 ]

[-0.0125 .45102 0 7.5 ]

[-0.0125 .53335 -10 -7.5 ]

[-0.0125 .53335 0 7.5 ]

[-0.0125 .61567 -19 -7.5 ]

[-0.0125 .61567 0 7.5 ]

[ 0 0 -0.125 0 ]

[-0.01875 .30902 -67 -7.5 ]

[-0.01875 .30902 -28 7.5 ]

[ 0 .61803 .125 0 ]

[ 1 0 .125 0 ]

[1.025 .53335 0 -7.5 ]

[1.025 .53335 13 7.5 ]

[.5 .64303 -7.5 0 ]

[.5 .64303 7.5 15 ]

[ -0.0005 -0.0005 0 0 ]

[ 1.0005 .61853 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 .5 r

.25 Mabswid

.2619 0 m

.2619 .61803 L

s

.5 0 m

.5 .61803 L

s

.7381 0 m

.7381 .61803 L

s

0 .03941 m

1 .03941 L

s

0 .12173 m

1 .12173 L

s

0 .20406 m

1 .20406 L

s

0 .28638 m

1 .28638 L

s

0 .3687 m

1 .3687 L

s

0 .45102 m

1 .45102 L

s

0 .53335 m

1 .53335 L

s

0 g

.02381 0 m

.02381 .00625 L

s

gsave

.02381 -0.0125 -70.5 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.2619 0 m

.2619 .00625 L

s

gsave

.2619 -0.0125 -75 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.5 0 m

.5 .00625 L

s

gsave

.5 -0.0125 -66 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.7381 0 m

.7381 .00625 L

s

gsave

.7381 -0.0125 -70.5 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.97619 0 m

.97619 .00625 L

s

gsave

.97619 -0.0125 -66 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

.07143 0 m

.07143 .00375 L

s

.11905 0 m

.11905 .00375 L

s

.16667 0 m

.16667 .00375 L

s

.21429 0 m

.21429 .00375 L

s

.30952 0 m

.30952 .00375 L

s

.35714 0 m

.35714 .00375 L

s

.40476 0 m

.40476 .00375 L

s

.45238 0 m

.45238 .00375 L

s

.54762 0 m

.54762 .00375 L

s

.59524 0 m

.59524 .00375 L

s

.64286 0 m

.64286 .00375 L

s

.69048 0 m

.69048 .00375 L

s

.78571 0 m

.78571 .00375 L

s

.83333 0 m

.83333 .00375 L

s

.88095 0 m

.88095 .00375 L

s

.92857 0 m

.92857 .00375 L

s

.25 Mabswid

0 0 m

1 0 L

s

0 .03941 m

.00625 .03941 L

s

gsave

-0.0125 .03941 -89 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.2) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

0 .12173 m

.00625 .12173 L

s

gsave

-0.0125 .12173 -80 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

0 .20406 m

.00625 .20406 L

s

gsave

-0.0125 .20406 -89 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.8) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

0 .28638 m

.00625 .28638 L

s

gsave

-0.0125 .28638 -89 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.6) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

0 .3687 m

.00625 .3687 L

s

gsave

-0.0125 .3687 -89 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.4) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

0 .45102 m

.00625 .45102 L

s

gsave

-0.0125 .45102 -89 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.2) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

0 .53335 m

.00625 .53335 L

s

gsave

-0.0125 .53335 -71 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

0 .61567 m

.00625 .61567 L

s

gsave

-0.0125 .61567 -80 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.2) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

0 .05999 m

.00375 .05999 L

s

0 .08057 m

.00375 .08057 L

s

0 .10115 m

.00375 .10115 L

s

0 .14231 m

.00375 .14231 L

s

0 .1629 m

.00375 .1629 L

s

0 .18348 m

.00375 .18348 L

s

0 .22464 m

.00375 .22464 L

s

0 .24522 m

.00375 .24522 L

s

0 .2658 m

.00375 .2658 L

s

0 .30696 m

.00375 .30696 L

s

0 .32754 m

.00375 .32754 L

s

0 .34812 m

.00375 .34812 L

s

0 .38928 m

.00375 .38928 L

s

0 .40986 m

.00375 .40986 L

s

0 .43044 m

.00375 .43044 L

s

0 .4716 m

.00375 .4716 L

s

0 .49218 m

.00375 .49218 L

s

0 .51276 m

.00375 .51276 L

s

0 .55393 m

.00375 .55393 L

s

0 .57451 m

.00375 .57451 L

s

0 .59509 m

.00375 .59509 L

s

0 .01883 m

.00375 .01883 L

s

.25 Mabswid

0 0 m

0 .61803 L

s

gsave

-0.01875 .30902 -128 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.187500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(NdFeB) show

97.562500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.02381 .61178 m

.02381 .61803 L

s

.2619 .61178 m

.2619 .61803 L

s

.5 .61178 m

.5 .61803 L

s

.7381 .61178 m

.7381 .61803 L

s

.97619 .61178 m

.97619 .61803 L

s

.125 Mabswid

.07143 .61428 m

.07143 .61803 L

s

.11905 .61428 m

.11905 .61803 L

s

.16667 .61428 m

.16667 .61803 L

s

.21429 .61428 m

.21429 .61803 L

s

.30952 .61428 m

.30952 .61803 L

s

.35714 .61428 m

.35714 .61803 L

s

.40476 .61428 m

.40476 .61803 L

s

.45238 .61428 m

.45238 .61803 L

s

.54762 .61428 m

.54762 .61803 L

s

.59524 .61428 m

.59524 .61803 L

s

.64286 .61428 m

.64286 .61803 L

s

.69048 .61428 m

.69048 .61803 L

s

.78571 .61428 m

.78571 .61803 L

s

.83333 .61428 m

.83333 .61803 L

s

.88095 .61428 m

.88095 .61803 L

s

.92857 .61428 m

.92857 .61803 L

s

.25 Mabswid

0 .61803 m

1 .61803 L

s

.99375 .03941 m

1 .03941 L

s

.99375 .12173 m

1 .12173 L

s

.99375 .20406 m

1 .20406 L

s

.99375 .28638 m

1 .28638 L

s

.99375 .3687 m

1 .3687 L

s

.99375 .45102 m

1 .45102 L

s

.99375 .53335 m

1 .53335 L

s

.99375 .61567 m

1 .61567 L

s

.125 Mabswid

.99625 .05999 m

1 .05999 L

s

.99625 .08057 m

1 .08057 L

s

.99625 .10115 m

1 .10115 L

s

.99625 .14231 m

1 .14231 L

s

.99625 .1629 m

1 .1629 L

s

.99625 .18348 m

1 .18348 L

s

.99625 .22464 m

1 .22464 L

s

.99625 .24522 m

1 .24522 L

s

.99625 .2658 m

1 .2658 L

s

.99625 .30696 m

1 .30696 L

s

.99625 .32754 m

1 .32754 L

s

.99625 .34812 m

1 .34812 L

s

.99625 .38928 m

1 .38928 L

s

.99625 .40986 m

1 .40986 L

s

.99625 .43044 m

1 .43044 L

s

.99625 .4716 m

1 .4716 L

s

.99625 .49218 m

1 .49218 L

s

.99625 .51276 m

1 .51276 L

s

.99625 .55393 m

1 .55393 L

s

.99625 .57451 m

1 .57451 L

s

.99625 .59509 m

1 .59509 L

s

.99625 .01883 m

1 .01883 L

s

.25 Mabswid

1 0 m

1 .61803 L

s

.001 w

0 .53335 m

1 .53335 L

s

gsave

1.025 .53335 -61 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(H) show

71.625000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.5 0 m

.5 .61803 L

s

gsave

.5 .64303 -68.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(M) show

73.687500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.002 w

.02381 .46337 m

.06244 .46905 L

.10458 .47524 L

.14415 .48105 L

.18221 .48665 L

.22272 .4926 L

.26171 .49833 L

.30316 .50442 L

.34309 .51029 L

.3815 .51593 L

.42237 .52194 L

.46172 .52772 L

.49955 .53328 L

.53984 .5392 L

.57861 .5449 L

.61984 .55095 L

.65954 .55679 L

.69774 .5624 L

.73838 .56837 L

.77751 .57412 L

.81909 .58023 L

.85916 .58612 L

.89771 .59179 L

.93871 .59781 L

.97619 .60332 L

s

.02381 .01472 m

.06244 .01672 L

.10458 .0189 L

.14415 .02096 L

.18221 .02293 L

.22272 .02503 L

.26171 .02705 L

.30316 .0292 L

.34309 .03127 L

.3815 .03327 L

.42237 .03539 L

.46172 .03743 L

.49955 .03939 L

.53984 .04148 L

.57861 .04349 L

.61984 .04563 L

.65954 .04769 L

.69774 .04967 L

.73838 .05177 L

.77751 .0538 L

.81909 .05596 L

.85916 .05804 L

.89771 .06004 L

.93871 .06216 L

.97619 .06411 L

s

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  Evaluatable->False,

  AspectRatioFixed->True,

  ImageSize->{282, 174},

  ImageMargins->{{34, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000[Q000`40O003h00Oogoo6goo003oOolK

Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00

ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol004eoo`<002Ioo`<000=oo`03001o

o`00008002=oo`<002Moo`<000=oo`03001oo`00008002Moo`<001Moo`00CWoo00<007ooOol097oo

00D007ooOomoo`0000Moo`03001oogoo01moo`05001oogooOol0000UOol01@00Oomoogoo00001goo

00<007ooOol09Goo00<007ooOol05Woo001>Ool00`00Oomoo`0TOol01@00Oomoogoo000027oo00<0

07ooOol07Woo00D007ooOomoo`0002Eoo`05001oogooOol00008Ool00`00Oomoo`0TOol00`00Oomo

o`0FOol004Aoo`L000=oo`03001oogoo01eoo`P000=oo`03001oogoo00Ioo`03001oogoo01ioo`05

001oogooOol0000UOol01@00Oomoogoo000027oo00<007ooOol097oo00<007ooOol05Woo001>Ool0

0`00Oomoo`0TOol01@00Oomoogoo000027oo00<007ooOol07Woo00D007ooOomoo`0002Eoo`05001o

ogooOol00008Ool00`00Oomoo`0TOol00`00Oomoo`0FOol004ioo`03001oogoo02Aoo`05001oogoo

Ool00007Ool00`00Oomoo`0OOol01@00Oomoogoo00009Goo00D007ooOomoo`0000Moo`03001oogoo

02Eoo`03001oogoo01Ioo`00CWoo00<007ooOol097oo00D007ooOomoo`0000Eoo`80029oo`05001o

ogooOol0000UOol01@00Oomoogoo00001Goo0P00:7oo00<007ooOol05Woo001=Ool2000VOol01@00

Oomoogoo00001Goo00<007ooOol08Goo00D007ooOomoo`0002Eoo`05001oogooOol00005Ool00`00

Oomoo`0VOol2000HOol004ioo`03001oogoo02Eoo`<000Moo`<0025oo`<002Moo`<000Moo`<002Io

o`03001oogoo01Ioo`00ogoo6goo003oOolKOol00?mooa]oo`00AWoo`P004Woo0016Ool00`00Oomo

o`02Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo

o`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo

o`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo

o`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo

o`06Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool004Ioo`03001oogoo031oo`0300moogoo02Yoo`03

001oogoo02]oo`0300moogoo031oo`03001oogoo011oo`00AWoo00<007ooOol00Woo1000:Woo00<0

3gooOol0:Woo00<007ooOol0:goo00<03gooOol0<7oo00<007ooOol047oo0016Ool20007OolG000C

Ool00`0?Oomoo`0ZOol00`00Oomoo`0[Ool00`0?Oomoo`0_Ool2000BOol004Ioo`03001oogoo01eo

oaL002Uoo`03001oogoo02]oo`0300moogoo031oo`03001oogoo011oo`00<goo0`000goo00<007oo

000010001Woo00<007ooOol0<7oo00@03gooOomoo`l001Yoo`03001oogoo02]oo`0300moogoo031o

o`03001oogoo011oo`00=7oo00<007ooOol01Goo00@007ooOol000Ioo`03001oogoo031oo`0300mo

ogoo011ooaL000=oo`03001oogoo02]oo`0300moogoo031oo`03001oogoo011oo`00=7oo00<007oo

Ool01Woo00<007ooOol01Woo0P00F`0?3`00D`0?0`004Woo000[Ool70002Ool00`00Oomoo`07Ool0

0`00Oomoo`05Ool00`00Oomoo`0`Ool00`0?Oomoo`0ZOol00`00Oomoo`09OolG000;Ool00`0?Oomo

o`0`Ool00`00Oomoo`0@Ool003Aoo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo031oo`03

00moogoo02Yoo`03001oogoo021oo`l002moo`03001oogoo011oo`00=7oo00<007ooOol027oo00<0

07ooOol017oo00<007ooOol0<7oo00<03gooOol0:Woo00<007ooOol0:goo00@03gooOomooaP001Mo

o`03001oogoo011oo`00=7oo00<007ooOol027oo00<007ooOol017oo0P00<Goo00<03gooOol0:Woo

00<007ooOol0:goo00<03gooOol06Goo3`001goo0P004Woo000cOol20006Ool01@00Oomoogoo0000

1Woo00<007ooOol0<7oo00<03gooOol0:Woo00<007ooOol0:goo00<03gooOol0:7oo100017oo00<0

07ooOol047oo000dOol00`00Oomoo`05Ool30007Ool00`00Oomoo`0`Ool00`0?Oomoo`0ZOol00`00

Oomoo`0[Ool00`0?Oomoo`0`Ool00`00Oomoo`0@Ool004Ioo`03001oogoo031oo`0300moogoo02Yo

o`03001oogoo02]oo`0300moogoo031oo`03001oogoo011oo`00AWoo0P00<Goo00<03gooOol0:Woo

00<007ooOol0:goo00<03gooOol0;goo0P004Woo0016Ool00`00Oomoo`0`Ool00`0?Oomoo`0ZOol0

0`00Oomoo`0[Ool00`0?Oomoo`0`Ool00`00Oomoo`0@Ool004Ioo`03001oogoo031oo`0300moogoo

02Yoo`03001oogoo02]oo`0300moogoo031oo`03001oogoo011oo`00AWoo00<007ooOol0<7oo00<0

3gooOol0:Woo00<007ooOol0:goo00<03gooOol0<7oo00<007ooOol047oo0016Ool2000aOol00`0?

Oomoo`0ZOol00`00Oomoo`0[Ool00`0?Oomoo`0_Ool2000BOol004Ioo`03001oogoo031oo`0300mo

ogoo02Yoo`03001oogoo02]oo`0300moogoo031oo`03001oogoo011oo`00?7oo0`001goo00<007oo

Ool0<7oo00<03gooOol0:Woo00<007ooOol0:goo00<03gooOol0<7oo00<007ooOol047oo000mOol0

0`00Oomoo`06Ool00`00Oomoo`0`Ool00`0?Oomoo`0ZOol00`00Oomoo`0[Ool00`0?Oomoo`0`Ool0

0`00Oomoo`0@Ool003eoo`03001oogoo00Ioo`8005h03`0300003`0?05`03`<0019oo`00=7oo1`00

0Woo00<007ooOol01Woo00<007ooOol0<7oo00<03gooOol0:Woo00<007ooOol0:goo00<03gooOol0

<7oo00<007ooOol047oo000mOol00`00Oomoo`06Ool00`00Oomoo`0`Ool00`0?Oomoo`0ZOol00`00

Oomoo`0[Ool00`0?Oomoo`0`Ool00`00Oomoo`0@Ool003eoo`03001oogoo00Ioo`03001oogoo031o

o`0300moogoo02Yoo`03001oogoo02]oo`0300moogoo031oo`03001oogoo011oo`00?Goo00<007oo

Ool01Woo0P00<Goo00<03gooOol0:Woo00<007ooOol0:goo00<03gooOol0;goo0P004Woo000lOol2

0008Ool00`00Oomoo`0`Ool00`0?Oomoo`0ZOol00`00Oomoo`0[Ool00`0?Oomoo`0`Ool00`00Oomo

o`0@Ool003eoo`03001oogoo00Ioo`03001oogoo031oo`0300moogoo02Yoo`03001oogoo02]oo`03

00moogoo031oo`03001oogoo011oo`00AWoo00<007ooOol0<7oo00<03gooOol0:Woo00<007ooOol0

:goo00<03gooOol0<7oo00<007ooOol047oo0016Ool2000aOol00`0?Oomoo`0ZOol00`00Oomoo`0[

Ool00`0?Oomoo`0_Ool2000BOol004Ioo`03001oogoo031oo`0300moogoo02Yoo`03001oogoo02]o

o`0300moogoo031oo`03001oogoo011oo`00AWoo00<007ooOol0<7oo00<03gooOol0:Woo00<007oo

Ool0:goo00<03gooOol0<7oo00<007ooOol047oo0016Ool00`00Oomoo`0`Ool00`0?Oomoo`0ZOol0

0`00Oomoo`0[Ool00`0?Oomoo`0`Ool00`00Oomoo`0@Ool004Ioo`80035oo`0300moogoo02Yoo`03

001oogoo02]oo`0300moogoo02moo`80019oo`00<goo0`000goo00<007ooOol00`001goo00<007oo

Ool0<7oo00<03gooOol0:Woo00<007ooOol0:goo00<03gooOol0<7oo00<007ooOol047oo000bOol0

1@00Oomoogoo000017oo00D007ooOomoo`0000Ioo`03001oogoo031oo`0300moogoo02Yoo`03001o

ogoo02]oo`0300moogoo031oo`03001oogoo011oo`00<Woo00D007ooOomoo`0000Aoo`05001oogoo

Ool00006Ool00`00Oomoo`0`Ool00`0?Oomoo`0ZOol00`00Oomoo`0[Ool00`0?Oomoo`0`Ool00`00

Oomoo`0@Ool002]oo`P000=oo`03001oogoo00=oo`03001oo`0000Moo`8005h03`0300003`0?05`0

3`<0019oo`00<Woo00D007ooOomoo`0000Ioo`03001oogoo00Ioo`03001oogoo031oo`0300moogoo

02Yoo`03001oogoo02]oo`0300moogoo031oo`03001oogoo011oo`00<Woo00D007ooOomoo`0000Eo

o`03001oo`0000Moo`03001oogoo031oo`0300moogoo02Yoo`03001oogoo02]oo`0300moogoo031o

o`03001oogoo011oo`00<Woo00D007ooOomoo`0000Aoo`05001oogooOol00006Ool00`00Oomoo`0`

Ool00`0?Oomoo`0ZOol00`00Oomoo`0[Ool00`0?Oomoo`0`Ool00`00Oomoo`0@Ool0039oo`05001o

ogooOol00004Ool01@00Oomoogoo00001Woo0P00<Goo00<03gooOol0:Woo00<007ooOol0:goo00<0

3gooOol0;goo0P004Woo000cOol30006Ool30007Ool00`00Oomoo`0`Ool00`0?Oomoo`0ZOol00`00

Oomoo`0[Ool00`0?Oomoo`0`Ool00`00Oomoo`0@Ool004Ioo`03001oogoo031oo`0300moogoo02Yo

o`03001oogoo02]oo`0300moogoo031oo`03001oogoo011oo`00AWoo00<007ooOol0<7oo00<03goo

Ool0:Woo00<007ooOol0:goo00<03gooOol0<7oo00<007ooOol047oo0016Ool2000aOol00`0?Oomo

o`0ZOol00`00Oomoo`0[Ool00`0?Oomoo`0_Ool2000BOol004Ioo`03001oogoo031oo`0300moogoo

02Yoo`03001oogoo02]oo`0300moogoo031oo`03001oogoo011oo`00AWoo00<007ooOol0<7oo00<0

3gooOol0:Woo00<007ooOol0:goo00<03gooOol0<7oo00<007ooOol047oo0016Ool2000aOol00`0?

Oomoo`0ZOol00`00Oomoo`0[Ool00`0?Oomoo`0_Ool2000BOol004Ioo`03001oogoo031oo`0300mo

ogoo02Yoo`03001oogoo02]oo`0300moogoo031oo`03001oogoo011oo`00<goo0`000goo00<007oo

Ool00`001goo00<007ooOol0<7oo00<03gooOol0:Woo00<007ooOol0:goo00<03gooOol0<7oo00<0

07ooOol047oo000bOol01@00Oomoogoo000017oo00D007ooOomoo`0000Ioo`03001oogoo031oo`03

00moogoo02Yoo`03001oogoo02]oo`0300moogoo031oo`03001oogoo011oo`00<Woo00D007ooOomo

o`0000Aoo`05001oogooOol00006Ool2001N00l00`0000l03`1L00l3000BOol002]oo`P000=oo`03

001oogoo009oo`05001oogooOol00006Ool00`00Oomoo`0`Ool00`0?Oomoo`0ZOol00`00Oomoo`0[

Ool00`0?Oomoo`0`Ool00`00Oomoo`0@Ool0039oo`05001oogooOol00004Ool20002Ool00`00Oomo

o`04Ool00`00Oomoo`0`Ool00`0?Oomoo`0ZOol00`00Oomoo`0[Ool00`0?Oomoo`0`Ool00`00Oomo

o`0@Ool0009oo`<000=oo`04001oogooOol80005Ool20002Ool6000?Ool01@00Oomoogoo000017oo

00@007oo000000Moo`03001oogoo031oo`0300moogoo02Yoo`03001oogoo02]oo`0300moogoo031o

o`03001oogoo011oo`000goo00<007ooOol00Woo00@007ooOol000=oo`04001oogoo0005Ool01000

Oomoo`000Woo00<007ooOol00Woo00<007ooOol037oo00D007ooOomoo`0000Eoo`03001oogoo00Mo

o`80035oo`0300moogoo02Yoo`03001oogoo02]oo`0300moogoo02moo`80019oo`000goo00@007oo

Oomoo`80009oo`05001oogooOol00002Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`02

Ool00`00Oomoo`0<Ool01@00Oomoogoo00001Woo00<007ooOol01Woo00<007ooOol0<7oo00<03goo

Ool0:Woo00<007ooOol0:goo00<03gooOol0<7oo00<007ooOol047oo0003Ool01P00Oomoo`00Ool0

009oo`05001oogooOol00002Ool01000Oomoo`000Woo10000Woo00<007ooOol00Woo00<007ooOol0

3Goo0`0027oo0P001Woo00<007ooOol0<7oo00<03gooOol0:Woo00<007ooOol0:goo00<03gooOol0

<7oo00<007ooOol047oo0003Ool01P00Oomoo`00Ool0009oo`03001oogoo0080009oo`@0009oo`04

001oogoo0002Ool5000SOol00`00Oomoo`0`Ool00`0?Oomoo`0ZOol00`00Oomoo`0[Ool00`0?Oomo

o`0`Ool00`00Oomoo`0@Ool000=oo`03001oo`00009oo`04001oogooOol200001Goo001oogoo0000

0Woo00@007ooOomoo`8000=oo`05001oogooOol0000SOol2000aOol00`0?Oomoo`0ZOol00`00Oomo

o`0[Ool00`0?Oomoo`0_Ool2000BOol000=oo`8000=oo`03001oogoo00Aoo`04001oogoo000;Ool0

1@00Oomoogoo00008goo00<007ooOol0<7oo00<03gooOol0:Woo00<007ooOol0:goo00<03gooOol0

<7oo00<007ooOol047oo0003Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01000Oomoo`000goo00<0

07ooOol01Goo00D007ooOomoo`0002=oo`03001oogoo031oo`0300moogoo02Yoo`03001oogoo02]o

o`0300moogoo031oo`03001oogoo011oo`000Woo0P000goo0`0017oo0P0000=oo`00000010001Woo

1@0097oo00<007ooOol0<7oo00<03gooOol0:Woo00<007ooOol0:goo00<03gooOol0<7oo00<007oo

Ool047oo0016Ool2000aOol00`0?Oomoo`0ZOol00`00Oomoo`0[Ool00`0?Oomoo`0_Ool2000BOol0

04Ioo`03001oogoo031oo`0300moogoo02Yoo`03001oogoo02]oo`0300moogoo031oo`03001oogoo

011oo`00<goo0`000goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0<7oo00<03gooOol0

:Woo00<007ooOol0:goo00<03gooOol0<7oo00<007ooOol047oo000bOol01@00Oomoogoo000027oo

00<007ooOol017oo00<007ooOol0<7oo00<03gooOol0:Woo00<007ooOol0:goo00<03gooOol0<7oo

00<007ooOol047oo000bOol01@00Oomoogoo000017oo1P001Goo0P00GP0?00<0000?00l0G00?0`00

4Woo000[Ool80003Ool00`00Oomoo`02Ool01@00Oomoogoo00001Woo00<007ooOol0<7oo00<03goo

Ool0:Woo00<007ooOol0:goo00<03gooOol0<7oo00<007ooOol047oo000bOol01@00Oomoogoo0000

1Goo00@007ooOol000Ioo`03001oogoo031oo`0300moogoo02Yoo`03001oogoo02]oo`0300moogoo

031oo`03001oogoo011oo`00<Woo00D007ooOomoo`0000Ioo`03001oo`0000Ioo`03001oogoo031o

o`0300moogoo02Yoo`03001oogoo02]oo`0300moogoo031oo`03001oogoo011oo`00<Woo00D007oo

Oomoo`0000Ioo`03001oo`0000Ioo`80035oo`0300moogoo02Yoo`03001oogoo02]oo`0300moogoo

02moo`80019oo`00<Woo00D007ooOomoo`0000Moo`8000Ioo`03001oogoo031oo`0300moogoo02Yo

o`03001oogoo02]oo`0300moogoo031oo`03001oogoo011oo`00<goo0`002Goo00<007ooOol017oo

00<007ooOol0<7oo00<03gooOol0:Woo00<007ooOol0:goo00<03gooOol0<7oo00<007ooOol047oo

0016Ool00`00Oomoo`0`Ool00`0?Oomoo`0ZOol00`00Oomoo`0[Ool00`0?Oomoo`0`Ool00`00Oomo

o`0@Ool004Ioo`80035oo`0300moogoo02Yoo`03001oogoo02]oo`0300moogoo02moo`80019oo`00

AWoo00<007ooOol0<7oo00<03gooOol0:Woo00<007ooOol0:goo00<03gooOol0<7oo00<007ooOol0

47oo0016Ool00`00Oomoo`0`Ool00`0?Oomoo`0ZOol00`00Oomoo`0[Ool00`0?Oomoo`0`Ool00`00

Oomoo`0@Ool004Ioo`03001oogoo031oo`0300moogoo02Yoo`03001oogoo02]oo`0300moogoo031o

o`03001oogoo011oo`00AWoo0P00<Goo00<03gooOol0:Woo00<007ooOol0:goo00<03gooOol0;goo

0P004Woo0016Ool00`00Oomoo`0`Ool00`0?Oomoo`0ZOol00`00Oomoo`0[Ool00`0?Oomoo`0`Ool0

0`00Oomoo`0@Ool003=oo`<000=oo`03001oo`0000@000Ioo`03001oogoo031oo`0300moogoo02Yo

o`03001oogoo02]oo`0300moogoo031oo`03001oogoo011oo`00<Woo00D007ooOomoo`0000Eoo`04

001oogoo0006Ool00`00Oomoo`0`Ool00`0?Oomoo`0ZOol00`00Oomoo`0[Ool00`0?Oomoo`0`Ool0

0`00Oomoo`0@Ool0039oo`05001oogooOol00006Ool00`00Oomoo`06Ool2001N00l00`0000l03`1L

00l3000BOol002]oo`P000=oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo031oo`0300mo

ogoo02Yoo`03001oogoo02]oo`0300moogoo031oo`03001oogoo011oo`00<Woo00D007ooOomoo`00

00Qoo`03001oogoo00Aoo`03001oogoo031oo`0300moogoo02Yoo`03001oogoo02]oo`0300moogoo

031oo`03001oogoo011oo`00<Woo00D007ooOomoo`0000Qoo`03001oogoo00Aoo`03001oogoo009o

o`@002Yoo`0300moogoo02Yoo`03001oogoo02]oo`0300moogoo031oo`03001oogoo011oo`00<Woo

00D007ooOomoo`0000Qoo`03001oogoo00Aoo`8000Moo`L002=oo`0300moogoo02Yoo`03001oogoo

02]oo`0300moogoo02moo`80019oo`00<Woo00D007ooOomoo`0000Aoo`05001oogooOol00006Ool0

0`00Oomoo`0=Ool8000KOol00`0?Oomoo`0ZOol00`00Oomoo`0[Ool00`0?Oomoo`0`Ool00`00Oomo

o`0@Ool003=oo`<000Ioo`<000Moo`03001oogoo01Eoo`P001=oo`0300moogoo02Yoo`03001oogoo

02]oo`0300moogoo031oo`03001oogoo011oo`00AWoo00<007ooOol07Goo1`0037oo00<03gooOol0

:Woo00<007ooOol0:goo00<03gooOol0<7oo00<007ooOol047oo0016Ool2000UOol80004Ool00`0?

Oomoo`0ZOol00`00Oomoo`0[Ool00`0?Oomoo`0_Ool2000BOol004Ioo`03001oogoo02aoo`P002Uo

o`03001oogoo02]oo`0300moogoo031oo`03001oogoo011oo`00AWoo00<007ooOol0<7oo00@03goo

Oomoo`D002Aoo`03001oogoo02]oo`0300moogoo031oo`03001oogoo011oo`00AWoo00<007ooOol0

<7oo00<03gooOol01Woo100087oo00<007ooOol0:goo00<03gooOol0<7oo00<007ooOol047oo0016

Ool2000aOol00`0?Oomoo`0:Ool6000JOol00`00Oomoo`0[Ool00`0?Oomoo`0_Ool2000BOol004Io

o`03001oogoo031oo`0300moogoo011oo`P0019oo`03001oogoo02]oo`0300moogoo031oo`03001o

ogoo011oo`00?Goo0`001Woo00<007ooOol0<7oo00<03gooOol067oo1`002goo00<007ooOol0:goo

00<03gooOol0<7oo00<007ooOol017oo0`000Woo0`0017oo000lOol01@00Oomoogoo00001Goo00<0

07ooOol0<7oo00<03gooOol07goo20000goo00<007ooOol0:goo00<03gooOol0<7oo00<007ooOol0

1Goo00<007ooOol00Woo00<007ooOol00goo000lOol01@00Oomoogoo00001Goo`P001goo00<007oo

Ool00Woo00<007ooOol00goo000lOol01@00Oomoogoo00001Goo00<007ooOol0<7oo00<03gooOol0

:Woo00@007ooOomoo`P0029oo`0300moogoo031oo`03001oogoo00Eoo`03001oogoo009oo`03001o

ogoo00=oo`00?7oo00D007ooOomoo`0000Eoo`03001oogoo031oo`0300moogoo02Yoo`03001oogoo

00Uoo`P001Yoo`0300moogoo031oo`03001oogoo00Eoo`H000Eoo`00?7oo00D007ooOomoo`0000Eo

o`03001oogoo031oo`0300moogoo02Yoo`03001oogoo015oo`D001Eoo`0300moogoo031oo`03001o

ogoo00Eoo`03001oogoo009oo`03001oogoo00=oo`00?7oo00D007ooOomoo`0000Eoo`80035oo`03

00moogoo02Yoo`03001oogoo01Ioo`@0015oo`0300moogoo02moo`8000Moo`03001oogoo009oo`03

001oogoo00=oo`00?7oo00D007ooOomoo`0000Eoo`03001oogoo031oo`0300moogoo02Yoo`03001o

ogoo01Yoo`H000]oo`0300moogoo031oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00=o

o`00?Goo0`001Woo00<007ooOol0<7oo00<03gooOol0:Woo00<007ooOol087oo1`0017oo00<03goo

Ool0<7oo00<007ooOol017oo0`000Woo0`0017oo0016Ool00`00Oomoo`0`Ool00`0?Oomoo`0ZOol0

0`00Oomoo`0WOol8000_Ool00`00Oomoo`0@Ool004Ioo`80035oo`0300moogoo02Yoo`03001oogoo

02]oo`0400moogooOol8000VOol2000BOol004Ioo`03001oogoo031oo`0300moogoo02Yoo`03001o

ogoo02]oo`0300moogoo00Uoo`P001moo`03001oogoo011oo`00AWoo00<007ooOol0<7oo00<03goo

Ool0:Woo00<007ooOol0:goo00<03gooOol04Goo20005goo00<007ooOol047oo0016Ool00`00Oomo

o`0`Ool00`0?Oomoo`0ZOol00`00Oomoo`0[Ool00`0?Oomoo`0IOol7000@Ool00`00Oomoo`0@Ool0

04Ioo`80035oo`0300moogoo02Yoo`03001oogoo02]oo`0300moogoo021oo`P000Moo`80019oo`00

AWoo00<007ooOol0<7oo00<03gooOol0:Woo00<007ooOol0:goo00<03gooOol0:7oo100017oo00<0

07ooOol047oo000dOol30003Ool00`00Ool000040005Ool00`00Oomoo`0`Ool00`0?Oomoo`0ZOol0

0`00Oomoo`0[Ool00`0?Oomoo`0`Ool00`00Oomoo`0@Ool003=oo`05001oogooOol00005Ool01000

Oomoo`001Goo00<007ooOol00Woo00<007ooOol0:goo00<007ooOol0:Woo00<007ooOol0:goo00<0

07ooOol0:goo00<007ooOol00Woo00<007ooOol047oo000cOol01@00Oomoogoo00001Woo00<007oo

Ool01Goo`P004Woo000cOol01@00Oomoogoo00001goo00<007ooOol0f7oo000cOol01@00Oomoogoo

000027oo00<007ooOol0egoo000cOol01@00Oomoogoo000027oo00<007ooOol0egoo000cOol01@00

Oomoogoo000027oo00<007ooOol0egoo000cOol01@00Oomoogoo000017oo00D007ooOomoo`000=Uo

o`00=7oo0`001Woo0`00fWoo003oOolKOol00?mooa]oo`00ogoo6goo002QOol30002Ool00`00Oomo

o`03001^Ool00:9oo`05001oogooOol00003Ool00`00Oomoo`1]Ool00:9oo`06001oogoo001oo`00

0Woo00<007ooOol0KGoo002ROol01P00Oomoo`00Ool0009oo`03001oogoo06eoo`00XWoo00H007oo

Ool007oo0002Ool00`00Oomoo`1]Ool00:9oo`03001oo`0000=oo`03001oo`0006moo`00XWoo00<0

07oo00000goo00<007oo0000Kgoo002ROol20005Ool2001_Ool00:5oo`<000Eoo`<006ioo`00ogoo

6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol0

0?mooa]oo`00ogoo6goo0000\

\>"],

  ImageRangeCache->{{{0, 281}, {173, 0}} -> {-1.82002, -1.62109, 0.0109049, 

  0.0126159}}]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{



Cell["Optimizing Parameters", "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[{

  StyleBox[

  "In this section, some iterations are made on solving and computing the \

peak field of the undulator as a function of the horizontal width of the \

pole. The segmentation in the pole and magnet has been set to",

    Evaluatable->False,

    AspectRatioFixed->True],

  " {1,1,1} resulting in a quick but inaccurate computation."

}], "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[CellGroupData[{



Cell[TextData[{

  "gap=20;Nper=2;per=46;gapoffset=1;\t\nlp={45,5,25};np={1,1,1};cp={1,0,1};   \

 \t\nll=per/2-lp[[2]];\nlm={65,ll,45};nm={1,1,1};cm={0,1,1};\t\t\n\n\

F[]:=Module[{},\n",

  StyleBox["radUtiDelAll",

    FontColor->RGBColor[1, 0, 0]],

  "[];\nmm=",

  StyleBox["RadMatNdFeB",

    FontColor->RGBColor[1, 0, 0]],

  "[];\nmp=",

  StyleBox["RadMatAFK502",

    FontColor->RGBColor[1, 0, 0]],

  "[];\nGrp=und[];\nre=",

  StyleBox["RadSolve",

    FontColor->RGBColor[1, 0, 0]],

  "[Grp,0.001,1000];\nN[",

  StyleBox["radFld",

    FontColor->RGBColor[1, 0, 0]],

  "[Grp,\"Bz\",{0,0,0}],5]\n]\n\nt=Table[{y,(lp[[1]]=y;F[])},{y,4,40,5}];\n\

ListPlot[t,PlotJoined->True,AxesLabel->{\"Pole Width\",\"Peak Field\"}];"

}], "Input",

  AspectRatioFixed->True],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Times findfont 12  scalefont  setfont

% Scaling calculations

-0.085034 0.0272109 -1.31117 3.7427 [

[.05102 -0.0125 -5 -15 ]

[.05102 -0.0125 5 0 ]

[.18707 -0.0125 -8 -15 ]

[.18707 -0.0125 8 0 ]

[.32313 -0.0125 -8 -15 ]

[.32313 -0.0125 8 0 ]

[.45918 -0.0125 -8 -15 ]

[.45918 -0.0125 8 0 ]

[.59524 -0.0125 -8 -15 ]

[.59524 -0.0125 8 0 ]

[.73129 -0.0125 -8 -15 ]

[.73129 -0.0125 8 0 ]

[.86735 -0.0125 -8 -15 ]

[.86735 -0.0125 8 0 ]

[ 0 0 -0.125 0 ]

[-0.0125 .09234 -31 -7.5 ]

[-0.0125 .09234 0 7.5 ]

[-0.0125 .18591 -19 -7.5 ]

[-0.0125 .18591 0 7.5 ]

[-0.0125 .27947 -31 -7.5 ]

[-0.0125 .27947 0 7.5 ]

[-0.0125 .37304 -25 -7.5 ]

[-0.0125 .37304 0 7.5 ]

[-0.0125 .46661 -31 -7.5 ]

[-0.0125 .46661 0 7.5 ]

[-0.0125 .56018 -19 -7.5 ]

[-0.0125 .56018 0 7.5 ]

[ 0 0 -0.125 0 ]

[ 0 .61803 .125 0 ]

[ 1 0 .125 0 ]

[1.025 -0.00123 0 -7.5 ]

[1.025 -0.00123 59 7.5 ]

[.05102 .64303 -27.5 0 ]

[.05102 .64303 27.5 15 ]

[ -0.0005 -0.00173 0 0 ]

[ 1.0005 .61853 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 .5 r

.25 Mabswid

.05102 0 m

.05102 .61803 L

s

.18707 0 m

.18707 .61803 L

s

.32313 0 m

.32313 .61803 L

s

.45918 0 m

.45918 .61803 L

s

.59524 0 m

.59524 .61803 L

s

.73129 0 m

.73129 .61803 L

s

.86735 0 m

.86735 .61803 L

s

0 .09234 m

1 .09234 L

s

0 .18591 m

1 .18591 L

s

0 .27947 m

1 .27947 L

s

0 .37304 m

1 .37304 L

s

0 .46661 m

1 .46661 L

s

0 .56018 m

1 .56018 L

s

0 g

.05102 0 m

.05102 .00625 L

s

gsave

.05102 -0.0125 -66 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(5) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.18707 0 m

.18707 .00625 L

s

gsave

.18707 -0.0125 -69 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(10) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.32313 0 m

.32313 .00625 L

s

gsave

.32313 -0.0125 -69 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(15) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.45918 0 m

.45918 .00625 L

s

gsave

.45918 -0.0125 -69 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(20) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.59524 0 m

.59524 .00625 L

s

gsave

.59524 -0.0125 -69 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(25) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.73129 0 m

.73129 .00625 L

s

gsave

.73129 -0.0125 -69 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(30) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.86735 0 m

.86735 .00625 L

s

gsave

.86735 -0.0125 -69 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(35) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

.07823 0 m

.07823 .00375 L

s

.10544 0 m

.10544 .00375 L

s

.13265 0 m

.13265 .00375 L

s

.15986 0 m

.15986 .00375 L

s

.21429 0 m

.21429 .00375 L

s

.2415 0 m

.2415 .00375 L

s

.26871 0 m

.26871 .00375 L

s

.29592 0 m

.29592 .00375 L

s

.35034 0 m

.35034 .00375 L

s

.37755 0 m

.37755 .00375 L

s

.40476 0 m

.40476 .00375 L

s

.43197 0 m

.43197 .00375 L

s

.48639 0 m

.48639 .00375 L

s

.51361 0 m

.51361 .00375 L

s

.54082 0 m

.54082 .00375 L

s

.56803 0 m

.56803 .00375 L

s

.62245 0 m

.62245 .00375 L

s

.64966 0 m

.64966 .00375 L

s

.67687 0 m

.67687 .00375 L

s

.70408 0 m

.70408 .00375 L

s

.7585 0 m

.7585 .00375 L

s

.78571 0 m

.78571 .00375 L

s

.81293 0 m

.81293 .00375 L

s

.84014 0 m

.84014 .00375 L

s

.89456 0 m

.89456 .00375 L

s

.92177 0 m

.92177 .00375 L

s

.94898 0 m

.94898 .00375 L

s

.97619 0 m

.97619 .00375 L

s

.02381 0 m

.02381 .00375 L

s

.25 Mabswid

0 0 m

1 0 L

s

0 .09234 m

.00625 .09234 L

s

gsave

-0.0125 .09234 -92 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.375) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

0 .18591 m

.00625 .18591 L

s

gsave

-0.0125 .18591 -80 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.4) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

0 .27947 m

.00625 .27947 L

s

gsave

-0.0125 .27947 -92 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.425) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

0 .37304 m

.00625 .37304 L

s

gsave

-0.0125 .37304 -86 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.45) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

0 .46661 m

.00625 .46661 L

s

gsave

-0.0125 .46661 -92 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.475) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

0 .56018 m

.00625 .56018 L

s

gsave

-0.0125 .56018 -80 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

0 .01748 m

.00375 .01748 L

s

0 .0362 m

.00375 .0362 L

s

0 .05491 m

.00375 .05491 L

s

0 .07363 m

.00375 .07363 L

s

0 .11105 m

.00375 .11105 L

s

0 .12977 m

.00375 .12977 L

s

0 .14848 m

.00375 .14848 L

s

0 .16719 m

.00375 .16719 L

s

0 .20462 m

.00375 .20462 L

s

0 .22333 m

.00375 .22333 L

s

0 .24205 m

.00375 .24205 L

s

0 .26076 m

.00375 .26076 L

s

0 .29819 m

.00375 .29819 L

s

0 .3169 m

.00375 .3169 L

s

0 .33561 m

.00375 .33561 L

s

0 .35433 m

.00375 .35433 L

s

0 .39175 m

.00375 .39175 L

s

0 .41047 m

.00375 .41047 L

s

0 .42918 m

.00375 .42918 L

s

0 .4479 m

.00375 .4479 L

s

0 .48532 m

.00375 .48532 L

s

0 .50404 m

.00375 .50404 L

s

0 .52275 m

.00375 .52275 L

s

0 .54146 m

.00375 .54146 L

s

0 .57889 m

.00375 .57889 L

s

0 .5976 m

.00375 .5976 L

s

0 .61632 m

.00375 .61632 L

s

.25 Mabswid

0 0 m

0 .61803 L

s

.05102 .61178 m

.05102 .61803 L

s

.18707 .61178 m

.18707 .61803 L

s

.32313 .61178 m

.32313 .61803 L

s

.45918 .61178 m

.45918 .61803 L

s

.59524 .61178 m

.59524 .61803 L

s

.73129 .61178 m

.73129 .61803 L

s

.86735 .61178 m

.86735 .61803 L

s

.125 Mabswid

.07823 .61428 m

.07823 .61803 L

s

.10544 .61428 m

.10544 .61803 L

s

.13265 .61428 m

.13265 .61803 L

s

.15986 .61428 m

.15986 .61803 L

s

.21429 .61428 m

.21429 .61803 L

s

.2415 .61428 m

.2415 .61803 L

s

.26871 .61428 m

.26871 .61803 L

s

.29592 .61428 m

.29592 .61803 L

s

.35034 .61428 m

.35034 .61803 L

s

.37755 .61428 m

.37755 .61803 L

s

.40476 .61428 m

.40476 .61803 L

s

.43197 .61428 m

.43197 .61803 L

s

.48639 .61428 m

.48639 .61803 L

s

.51361 .61428 m

.51361 .61803 L

s

.54082 .61428 m

.54082 .61803 L

s

.56803 .61428 m

.56803 .61803 L

s

.62245 .61428 m

.62245 .61803 L

s

.64966 .61428 m

.64966 .61803 L

s

.67687 .61428 m

.67687 .61803 L

s

.70408 .61428 m

.70408 .61803 L

s

.7585 .61428 m

.7585 .61803 L

s

.78571 .61428 m

.78571 .61803 L

s

.81293 .61428 m

.81293 .61803 L

s

.84014 .61428 m

.84014 .61803 L

s

.89456 .61428 m

.89456 .61803 L

s

.92177 .61428 m

.92177 .61803 L

s

.94898 .61428 m

.94898 .61803 L

s

.97619 .61428 m

.97619 .61803 L

s

.02381 .61428 m

.02381 .61803 L

s

.25 Mabswid

0 .61803 m

1 .61803 L

s

.99375 .09234 m

1 .09234 L

s

.99375 .18591 m

1 .18591 L

s

.99375 .27947 m

1 .27947 L

s

.99375 .37304 m

1 .37304 L

s

.99375 .46661 m

1 .46661 L

s

.99375 .56018 m

1 .56018 L

s

.125 Mabswid

.99625 .01748 m

1 .01748 L

s

.99625 .0362 m

1 .0362 L

s

.99625 .05491 m

1 .05491 L

s

.99625 .07363 m

1 .07363 L

s

.99625 .11105 m

1 .11105 L

s

.99625 .12977 m

1 .12977 L

s

.99625 .14848 m

1 .14848 L

s

.99625 .16719 m

1 .16719 L

s

.99625 .20462 m

1 .20462 L

s

.99625 .22333 m

1 .22333 L

s

.99625 .24205 m

1 .24205 L

s

.99625 .26076 m

1 .26076 L

s

.99625 .29819 m

1 .29819 L

s

.99625 .3169 m

1 .3169 L

s

.99625 .33561 m

1 .33561 L

s

.99625 .35433 m

1 .35433 L

s

.99625 .39175 m

1 .39175 L

s

.99625 .41047 m

1 .41047 L

s

.99625 .42918 m

1 .42918 L

s

.99625 .4479 m

1 .4479 L

s

.99625 .48532 m

1 .48532 L

s

.99625 .50404 m

1 .50404 L

s

.99625 .52275 m

1 .52275 L

s

.99625 .54146 m

1 .54146 L

s

.99625 .57889 m

1 .57889 L

s

.99625 .5976 m

1 .5976 L

s

.99625 .61632 m

1 .61632 L

s

.25 Mabswid

1 0 m

1 .61803 L

s

.001 w

0 -0.00123 m

1 -0.00123 L

s

gsave

1.025 -0.00123 -61 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(Pole) show

87.250000 14.625000 moveto

(Width) show

117.250000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.05102 0 m

.05102 .61803 L

s

gsave

.05102 .64303 -88.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(Peak) show

89.187500 14.625000 moveto

(Field) show

113.625000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.002 w

.02381 .01472 m

.15986 .26027 L

.29592 .43849 L

.43197 .54518 L

.56803 .59654 L

.70408 .60332 L

.84014 .58755 L

.97619 .56001 L

s

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  Evaluatable->False,

  AspectRatioFixed->True,

  ImageSize->{282, 174},

  ImageMargins->{{34, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000[Q000`40O003h00Oogoo6goo003oOolK

Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00

ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolK

Ool002Moo`<001Aoo`<000=oo`<0011oo`<0009oo`<0011oo`D0009oo`<000moo`D00004Ool00000

000@Ool40003Ool3000?Ool40002Ool3001GOol002Yoo`03001oogoo019oo`05001oogooOol00003

Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool01P00Oomoo`00Ool000=oo`03001o

ogoo00eoo`04001oogoo0004Ool00`00Oomoo`0AOol00`00Ool00003Ool00`00Oomoo`0@Ool00`00

Oomoo`02Ool00`00Oomoo`1DOol002]oo`03001oogoo015oo`05001oogooOol00003Ool00`00Oomo

o`0>Ool00`00Oomoo`05Ool00`00Oomoo`0>Ool01@00Oomoogoo00000goo00<007ooOol03Woo00<0

07ooOol01Goo00<007ooOol047oo00<007oo00000goo00<007ooOol047oo00<007ooOol00goo00<0

07ooOol0Dgoo000[Ool00`00Oomoo`0AOol01@00Oomoogoo00000goo00<007ooOol03Woo00<007oo

Ool01Goo00<007ooOol03goo00@007ooOol000=oo`03001oogoo00moo`03001oogoo00Aoo`03001o

ogoo011oo`03001oo`0000=oo`03001oogoo011oo`03001oogoo00=oo`03001oogoo05=oo`00:goo

00<007ooOol04Goo00D007ooOomoo`0000=oo`03001oogoo00ioo`03001oogoo00Eoo`03001oogoo

011oo`03001oo`0000=oo`03001oogoo011oo`03001oogoo00=oo`03001oogoo00ioo`80009oo`05

001oogooOol0000@Ool20006Ool00`00Oomoo`1COol002Yoo`03001oogoo019oo`05001oogooOol0

0003Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Ool00003Ool00`00Oomo

o`0@Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool01000Oomoo`000goo00<007ooOol03goo00<007oo

Ool00goo00<007ooOol0E7oo000XOol2000EOol01@00Oomoogoo00000goo00<007ooOol03Woo00<0

07ooOol00Woo0P0057oo00<007oo00000goo00<007ooOol047oo00<007ooOol00P0057oo00<007oo

00000goo00<007ooOol047oo00<007ooOol00P00Egoo000XOol00`00Oomoo`0COol20003Ool01@00

Oomoogoo00003goo0P0017oo00<007ooOol03goo00L007ooOomoo`00Ool00003Ool00`00Oomoo`0<

Ool01@00Oomoogoo00000Woo00<007ooOol03goo00L007ooOomoo`00Ool00003Ool00`00Oomoo`0<

Ool01@00Oomoogoo00000Woo00<007ooOol0EWoo000YOol3000COol00`00Oomoo`02Ool3000AOol0

0`00Oomoo`03Ool3000?Ool30003Ool3000@Ool30004Ool3000?Ool30003Ool3000@Ool30004Ool3

001EOol00?mooa]oo`00h7oo0`001Goo0`000Woo0`0000=oo`00000027oo00D007ooOomoo`0000=o

o`<00003Ool0000000<00004Ool00000Ool300000goo00000004Ool00>5oo`03001oogoo00=oo`05

001oogooOol00002Ool00`00Ool00002Ool00`00Oomoo`05Ool01@00Oomoogoo000017oo00<007oo

00000goo00@007ooOol000=oo`04001oogoo0005Ool0025ookT000Moo`03001oogoo00=oo`05001o

ogooOol00002Ool00`00Ool00009Ool20002Ool20004Ool00`00Ool00003Ool01000Oomoo`000goo

00@007ooOol000Eoo`008Goo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo009oo`03

001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03

001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03

001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03

001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03

001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03

001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03

001oogoo00=oo`03001oogoo009oo`05001oogooOol00007Ool00`00Oomoo`03Ool01@00Oomoogoo

00000Woo00<007oo00000`001Woo00L007oo001oo`00Ool00003Ool00`00Ool00003Ool01000Oomo

o`000goo00@007ooOol000Eoo`008Goo00<007ooOol01Woo00<007ooOol05Woo00<03gooOol05Woo

00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo

00<007ooOol01Goo10000Woo00D007ooOomoo`00009oo`03001oo`00009oo`03001oogoo00Aoo`07

001oo`00Ool007oo00000goo00<007oo00000Woo0P000Woo00@007ooOomoo`800003Ool007oo00Ao

o`008Goo00D007ooOomoo`0000Aoo`03001oogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`03

00moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Eoo`8000Moo`05001oogoo

Ool00002Ool30003Ool00`00Oomoo`020006Ool01@00Oomoogoo00000Woo00<007ooOol00P000Woo

0P0000=oo`00Ool00`000Woo00<007oo00001Woo000QOol00`00Oomoo`02Ool01@00Oomoogoo0000

67oo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol0

5Woo00<03gooOol05Woo00<007ooOol01Goo00D007ooOomoo`0000Qoo`03001oogoo00Qoo`05001o

ogooOol00003Ool00`00Oomoo`06Ool01000Oomoo`000goo00<007ooOol01Woo000QOol00`00Oomo

o`02Ool01@00Oomoogoo000067oo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<0

3gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<007ooOol01Goo00D007ooOomoo`0000Qo

o`03001oogoo00Qoo`05001oogooOol00003Ool00`00Oomoo`06Ool01000Oomoo`000goo00<007oo

Ool01Woo000QOol00`00Oomoo`03Ool01000Oomoo`0067oo00<03gooOol05Woo00<03gooOol05Woo

00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<007ooOol017oo

1@0027oo0P002Goo0`0000Eoo`00000007oo00<00003Ool007oo00=oo`8000Eoo`8000Qoo`008Goo

00<007ooOol00goo00@007ooOol001Qoo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Io

o`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Eoo`80041oo`008Goo00<007ooOol017oo

00<007oo000067oo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo

00<03gooOol05Woo00<03gooOol05Woo00<007ooOol0?Woo000QOol00`00Oomoo`04Ool00`00Ool0

000HOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomo

o`0FOol00`0?Oomoo`0FOol00`00Oomoo`0nOol0025oo`03001oogoo00Eoo`8001Qoo`0300moogoo

01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo

01Eoo`80041oo`008Goo00<007ooOol01Goo0P0067oo00<03gooOol05Woo00<03gooOol05Woo00<0

3gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<007ooOol0?Woo000Q

Ool00`00Oomoo`06Ool00`00Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0F

Ool00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`00Oomoo`0nOol0025oo`03001o

ogoo00Ioo`8001Moo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Io

o`0300moogoo01Ioo`0300moogoo01Ioo`03001oogoo03ioo`008Goo00<007ooOol01Woo0P005goo

00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo

00<03gooOol05Goo0P00@7oo0003Ool30003Ool00`00Ool000030004Ool01000Oomoogoo0`001goo

00<007ooOol01Woo00<007oo00005Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo

00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<007ooOol0?Woo0002Ool01@00Oomo

ogoo000027oo00D007ooOomoo`0000Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oo`0001Io

o`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Io

o`0300moogoo01Ioo`03001oogoo03ioo`000Woo00D007ooOomoo`0000Qoo`03001oogoo009oo`03

001oogoo00Aoo`03001oogoo00=oo`8000L03`0400003`0?002Z00l20010Ool0009oo`05001oogoo

Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`06Ool01000

Oomoo`005Goo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<0

3gooOol05Woo00<03gooOol05Woo00<007ooOol0?Woo0002Ool01@00Oomoogoo00001Woo0P001Goo

00<007ooOol017oo00<007ooOol00goo00<007ooOol01Woo00D007ooOomoo`0001Aoo`0300moogoo

01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo

01Ioo`03001oogoo03ioo`000Woo00D007ooOomoo`0000Moo`03001oogoo00=oo`03001oogoo00=o

o`03001oogoo00Aoo`03001oogoo00Ioo`05001oogooOol0000DOol00`0?Oomoo`0FOol00`0?Oomo

o`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0EOol20010Ool0

009oo`05001oogooOol00008Ool00`00Oomoo`03Ool00`00Oomoo`020007Ool00`00Oomoo`06Ool0

0`00Oomoo`02Ool00`00Oomoo`0AOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol0

0`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`00Oomoo`0nOol0009oo`05001oogoo

Ool00004Ool01`00Oomoogoo001oo`0000=oo`04001oogoo0008Ool00`00Oomoo`06Ool00`00Oomo

o`03Ool00`00Oomoo`0@Ool00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomo

o`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`00Oomoo`0nOol000=oo`<000Ioo`<000=oo`@0

00=oo`<000Eoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo011oo`0300moogoo01Ioo`03

00moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`03

001oogoo03ioo`008Goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol03goo00<03gooOol0

5Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol0

5Goo0P00@7oo000QOol00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool00`0?Oomoo`0F

Ool00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0F

Ool00`00Oomoo`0nOol0025oo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00ioo`0300mo

ogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300mo

ogoo01Ioo`03001oogoo03ioo`008Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol03Woo

00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo

00<03gooOol05Goo0P00@7oo000QOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0=Ool0

0`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol0

0`0?Oomoo`0FOol00`00Oomoo`0nOol0025oo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo

00eoo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo

01Ioo`0300moogoo01Ioo`03001oogoo03ioo`008Goo00<007ooOol01Woo00<007ooOol01goo00<0

07ooOol037oo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<0

3gooOol05Woo00<03gooOol05Woo00<007ooOol0?Woo000QOol00`00Oomoo`06Ool00`00Oomoo`08

Ool00`00Oomoo`0;Ool00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0F

Ool00`0?Oomoo`0FOol00`0?Oomoo`0EOol20010Ool000moo`<000=oo`03001oogoo00=oo`03001o

ogoo00=oo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00]oo`0300moogoo01Ioo`0300mo

ogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`03001o

ogoo03ioo`003Woo00D007ooOomoo`0000Qoo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo

00Uoo`03001oogoo00Yoo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo

01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`03001oogoo03ioo`003Woo00D007ooOomoo`0000Ao

o`H000Aoo`8000L03`0300003`0?00T03`0300003`0?09l03`80041oo`003Woo00D007ooOomoo`00

00Aoo`05001oogooOol00005Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`0?

Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?

Oomoo`0FOol00`00Oomoo`0nOol000ioo`05001oogooOol00005Ool01000Oomoo`001Goo00<007oo

Ool01Woo00<007ooOol02Woo00<007ooOol02Goo00<03gooOol05Woo00<03gooOol05Woo00<03goo

Ool05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<007ooOol0?Woo000>Ool0

1@00Oomoogoo00001Woo00<007oo00001Goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol0

27oo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol0

5Woo00<03gooOol05Woo00<007ooOol0?Woo000>Ool01@00Oomoogoo00001Woo00<007oo00001Goo

00<007ooOol01Woo00<007ooOol02goo00<007ooOol027oo00<03gooOol05Woo00<03gooOol05Woo

00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Goo0P00@7oo000>Ool0

1@00Oomoogoo00001goo0P001Goo00<007ooOol01Woo00<007ooOol037oo00<007ooOol01goo00<0

3gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<0

3gooOol05Woo00<007ooOol0?Woo000?Ool30009Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00

Oomoo`0=Ool00`00Oomoo`06Ool00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?

Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`00Oomoo`0nOol0025oo`03001oogoo00Io

o`03001oogoo00eoo`03001oogoo00Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Io

o`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Eoo`80041oo`008Goo00<007ooOol01Woo

00<007ooOol03Woo00<007ooOol01Goo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo

00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<007ooOol0?Woo000QOol00`00Oomo

o`06Ool00`00Oomoo`0>Ool00`00Oomoo`05Ool00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomo

o`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`00Oomoo`0nOol0025oo`03

001oogoo00Ioo`03001oogoo00moo`03001oogoo00Aoo`0300moogoo01Ioo`0300moogoo01Ioo`03

00moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`03001oogoo03ioo`00

8Goo00<007ooOol01Woo00<007ooOol03goo00<007ooOol017oo00<03gooOol05Woo00<03gooOol0

5Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Goo0P00@7oo000Q

Ool00`00Oomoo`06Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool00`0?Oomoo`0FOol00`0?Oomoo`0F

Ool00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`00Oomoo`0n

Ool0025oo`03001oogoo00Ioo`03001oogoo011oo`03001oogoo00=oo`0300moogoo01Ioo`0300mo

ogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`03001o

ogoo03ioo`008Goo00<007ooOol01Woo00<007ooOol04Goo00<007ooOol00Woo00<03gooOol05Woo

00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Goo

0P00@7oo0003Ool30003Ool00`00Oomoo`03Ool00`00Ool00004000017oo000000001goo00<007oo

Ool01Woo00<007ooOol04Woo00D007ooOomoo`0?01Qoo`0300moogoo01Ioo`0300moogoo01Ioo`03

00moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`03001oogoo03ioo`000Woo00D007ooOomo

o`0000Qoo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00

Oomoo`0COol01000Oomoo`0?67oo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<0

3gooOol05Woo00<03gooOol05Woo00<007ooOol0?Woo0002Ool01@00Oomoogoo000017oo1P000Woo

00<007ooOol01Goo00<007ooOol00goo0P001`0?00<0000?00l04`0?00<0000?00l0U@0?0P00@7oo

0002Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00=o

o`03001oogoo00Ioo`03001oogoo01Aoo`03001oo`0?01Qoo`0300moogoo01Ioo`0300moogoo01Io

o`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`03001oogoo03ioo`000Woo00D007oo

Oomoo`0000Eoo`04001oogoo0005Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`06Ool0

0`00Oomoo`0EOol00`0000moo`0GOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol0

0`0?Oomoo`0FOol00`0?Oomoo`0FOol00`00Oomoo`0nOol0009oo`05001oogooOol00006Ool00`00

Ool00005Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`0FOol00`00

Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?

Oomoo`0FOol00`00Oomoo`0nOol0009oo`05001oogooOol00006Ool00`00Ool00005Ool00`00Oomo

o`020007Ool00`00Oomoo`06Ool00`00Oomoo`0FOol00`00Oomoo`0FOol00`0?Oomoo`0FOol00`0?

Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0EOol20010Ool0009oo`05001o

ogooOol00007Ool200000goo001oo`02Ool01000Oomoo`0027oo00<007ooOol01Woo00<007ooOol0

5Woo00<03`00Ool05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol0

5Woo00<03gooOol05Woo00<007ooOol0?Woo0003Ool30009Ool00`00Oomoo`030004Ool30005Ool0

0`00Oomoo`06Ool00`00Oomoo`0FOol00`0?Ool0000FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol0

0`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`00Oomoo`0nOol0025oo`03001oogoo

00Ioo`03001oogoo01Ioo`0400moogoo000EOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomo

o`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0EOol20010Ool0025oo`03001oogoo00Ioo`03001oogoo

01Ioo`0400moogoo000EOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomo

o`0FOol00`0?Oomoo`0FOol00`00Oomoo`0nOol0025oo`03001oogoo00Ioo`03001oogoo01Ioo`05

00moogooOol0000DOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0F

Ool00`0?Oomoo`0FOol00`00Oomoo`0nOol0025oo`03001oogoo00Ioo`03001oogoo01Ioo`0300mo

ogoo009oo`03001oogoo015oo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300mo

ogoo01Ioo`0300moogoo01Ioo`03001oogoo03ioo`008Goo00<007ooOol01Woo00<007ooOol05Woo

00<03gooOol00goo00<007ooOol047oo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo

00<03gooOol05Woo00<03gooOol05Goo0P00@7oo000QOol00`00Oomoo`06Ool00`00Oomoo`0FOol0

0`0?Oomoo`03Ool00`00Oomoo`0@Ool00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol0

0`0?Oomoo`0FOol00`0?Oomoo`0FOol00`00Oomoo`0nOol0025oo`03001oogoo00Ioo`03001oogoo

01Ioo`0300moogoo00Aoo`03001oogoo00moo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo

01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`03001oogoo03ioo`008Goo00<007ooOol01Woo00<0

07ooOol05Woo00<03gooOol01Goo00<007ooOol03Woo00<03gooOol05Woo00<03gooOol05Woo00<0

3gooOol05Woo00<03gooOol05Woo00<03gooOol05Goo0P00@7oo000QOol00`00Oomoo`06Ool00`00

Oomoo`0FOol00`0?Oomoo`06Ool00`00Oomoo`0=Ool00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?

Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`00Oomoo`0nOol000Uoo`<000=oo`03001o

ogoo00=oo`03001oo`00008000Moo`03001oogoo00Ioo`03001oogoo01Ioo`0300moogoo00Ioo`03

001oogoo00eoo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`03

00moogoo01Ioo`03001oogoo03ioo`0027oo00D007ooOomoo`0000Qoo`03001oogoo009oo`03001o

ogoo00Aoo`03001oogoo00Ioo`03001oogoo01Ioo`0300moogoo00Moo`03001oogoo00aoo`0300mo

ogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`03001o

ogoo03ioo`0027oo00D007ooOomoo`0000Aoo`H000Aoo`03001oogoo00=oo`8000L03`0300003`0?

02403`0300003`0?08L03`80041oo`0027oo00D007ooOomoo`0000Aoo`05001oogooOol00005Ool0

0`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`0FOol00`0?Oomoo`09Ool00`00Oomoo`0:Ool0

0`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol0

0`00Oomoo`0nOol000Qoo`05001oogooOol00005Ool01000Oomoo`001Goo00<007ooOol00goo00<0

07ooOol01Woo00<007ooOol05Woo00<03gooOol02Goo00<007ooOol02Woo00<03gooOol05Woo00<0

3gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<007ooOol0?Woo0008

Ool01@00Oomoogoo00001Woo00<007oo000017oo00<007ooOol017oo00<007ooOol01Woo00<007oo

Ool05Woo00<03gooOol02Woo00<007ooOol02Goo00<03gooOol05Woo00<03gooOol05Woo00<03goo

Ool05Woo00<03gooOol05Woo00<03gooOol05Goo0P00@7oo0008Ool01@00Oomoogoo00001Woo00<0

07oo00000Woo0P001goo00<007ooOol01Woo00<007ooOol05Woo00<03gooOol02goo00<007ooOol0

27oo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol0

5Woo00<007ooOol0?Woo0008Ool01@00Oomoogoo00001goo0P000Woo00<007ooOol01Woo00<007oo

Ool01Woo00<007ooOol05Woo00<03gooOol037oo00<007ooOol01goo00<03gooOol05Woo00<03goo

Ool05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<007ooOol0?Woo0009Ool3

0009Ool01000Oomoogoo0`001Goo00<007ooOol01Woo00<007ooOol05Woo00<03gooOol037oo00<0

07ooOol01goo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<0

3gooOol05Woo00<007ooOol0?Woo000QOol00`00Oomoo`06Ool00`00Oomoo`0FOol00`0?Oomoo`0=

Ool00`00Oomoo`06Ool00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0F

Ool00`0?Oomoo`0EOol20010Ool0025oo`03001oogoo00Ioo`03001oogoo01Ioo`0300moogoo00io

o`03001oogoo00Eoo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Io

o`0300moogoo01Ioo`03001oogoo03ioo`008Goo00<007ooOol01Woo00<007ooOol05Woo00<03goo

Ool03goo00<007ooOol017oo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03goo

Ool05Woo00<03gooOol05Woo00<007ooOol0?Woo000QOol00`00Oomoo`06Ool00`00Oomoo`0FOol0

0`0?Oomoo`0?Ool00`00Oomoo`04Ool00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol0

0`0?Oomoo`0FOol00`0?Oomoo`0EOol20010Ool0025oo`03001oogoo00Ioo`03001oogoo01Ioo`03

00moogoo011oo`03001oogoo00=oo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`03

00moogoo01Ioo`0300moogoo01Ioo`03001oogoo03ioo`008Goo00<007ooOol01Woo00<007ooOol0

5Woo00<03gooOol04Goo00<007ooOol00Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol0

5Woo00<03gooOol05Woo00<03gooOol05Woo00<007ooOol0?Woo000QOol00`00Oomoo`06Ool00`00

Oomoo`0FOol00`0?Oomoo`0BOol01@00Oomoogoo00l067oo00<03gooOol05Woo00<03gooOol05Woo

00<03gooOol05Woo00<03gooOol05Goo0P00@7oo000QOol00`00Oomoo`06Ool00`00Oomoo`0FOol0

0`0?Oomoo`0COol200000goo00moo`0GOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0F

Ool00`0?Oomoo`0FOol00`00Oomoo`0nOol000=oo`<000=oo`03001oogoo00=oo`05001oogooOol0

0003Ool30007Ool00`00Oomoo`06Ool00`00Oomoo`0FOol00`0?Oomoo`0EOol00`0000moo`0GOol0

0`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`00Oomoo`0nOol0

009oo`05001oogooOol00008Ool01@00Oomoogoo00001Woo00<007ooOol017oo00<007ooOol01Woo

00<007ooOol05Woo00<03gooOol05Woo00<007ooOol05Woo00<03gooOol05Woo00<03gooOol05Woo

00<03gooOol05Woo00<03gooOol05Woo00<007ooOol0?Woo0002Ool01@00Oomoogoo000017oo1P00

0goo00<007ooOol017oo00<007ooOol00goo0P001`0?00<0000?00l0<00?0P00N@0?0P00@7oo0002

Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00=oo`03

001oogoo00Ioo`03001oogoo01Ioo`0300moogoo01Ioo`0400moogoo000EOol00`0?Oomoo`0FOol0

0`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`00Oomoo`0nOol0009oo`05001oogoo

Ool00005Ool01000Oomoo`0017oo00<007ooOol017oo00<007ooOol00goo00<007ooOol01Woo00<0

07ooOol05Woo00<03gooOol05Woo00D03gooOomoo`0001Aoo`0300moogoo01Ioo`0300moogoo01Io

o`0300moogoo01Ioo`0300moogoo01Ioo`03001oogoo03ioo`000Woo00D007ooOomoo`0000Ioo`03

001oo`0000Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo01Ioo`03

00moogoo01Ioo`0300moogoo009oo`80019oo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo

01Ioo`0300moogoo01Eoo`80041oo`000Woo00D007ooOomoo`0000Ioo`03001oo`0000Eoo`03001o

ogoo008000Moo`03001oogoo00Ioo`03001oogoo01Ioo`0300moogoo01Ioo`0300moogoo00Aoo`03

001oogoo00moo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`03

001oogoo03ioo`000Woo00D007ooOomoo`0000Moo`800003Ool007oo009oo`04001oogoo0008Ool0

0`00Oomoo`06Ool00`00Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`05Ool00`00Oomoo`0>Ool0

0`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`00Oomoo`0nOol0

00=oo`<000Uoo`03001oogoo00@000=oo`<000Eoo`03001oogoo00Ioo`03001oogoo01Ioo`0300mo

ogoo01Ioo`0300moogoo00Ioo`8000ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Io

o`0300moogoo01Ioo`03001oogoo03ioo`008Goo00<007ooOol01Woo00<007ooOol05Woo00<03goo

Ool05Woo00<03gooOol027oo00<007ooOol02goo00<03gooOol05Woo00<03gooOol05Woo00<03goo

Ool05Woo00<03gooOol05Goo0P00@7oo000QOol00`00Oomoo`06Ool00`00Oomoo`0FOol00`0?Oomo

o`0FOol00`0?Oomoo`09Ool00`00Oomoo`0:Ool00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomo

o`0FOol00`0?Oomoo`0FOol00`00Oomoo`0nOol0025oo`03001oogoo00Ioo`03001oogoo01Ioo`03

00moogoo01Ioo`0300moogoo00Yoo`8000Yoo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo

01Ioo`0300moogoo01Ioo`03001oogoo03ioo`008Goo00<007ooOol01Woo00<007ooOol05Woo00<0

3gooOol05Woo00<03gooOol037oo00<007ooOol01goo00<03gooOol05Woo00<03gooOol05Woo00<0

3gooOol05Woo00<03gooOol05Goo0P00@7oo000QOol00`00Oomoo`06Ool00`00Oomoo`0FOol00`0?

Oomoo`0FOol00`0?Oomoo`0=Ool00`00Oomoo`06Ool00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?

Oomoo`0FOol00`0?Oomoo`0FOol00`00Oomoo`0nOol0025oo`03001oogoo00Ioo`03001oogoo01Io

o`0300moogoo01Ioo`0300moogoo00ioo`8000Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300mo

ogoo01Ioo`0300moogoo01Ioo`03001oogoo03ioo`008Goo00<007ooOol01Woo00<007ooOol05Woo

00<03gooOol05Woo00<03gooOol047oo00<007ooOol00goo00<03gooOol05Woo00<03gooOol05Woo

00<03gooOol05Woo00<03gooOol05Woo00<007ooOol0?Woo000QOol00`00Oomoo`06Ool00`00Oomo

o`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0AOol20003Ool00`0?Oomoo`0FOol00`0?Oomoo`0FOol0

0`0?Oomoo`0FOol00`0?Oomoo`0EOol20010Ool000moo`<000=oo`03001oo`00008000Moo`03001o

ogoo00Ioo`03001oogoo01Ioo`0300moogoo01Ioo`0300moogoo01=oo`800003Ool03goo01Moo`03

00moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`03001oogoo03ioo`003Woo00D007ooOomo

o`0000Moo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo01Ioo`0300moogoo01Ioo`0300mo

ogoo01Eoo`<001Moo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`03001oogoo03io

o`003Woo00D007ooOomoo`0000Qoo`03001oogoo00=oo`8000L03`0300003`0?04X03`8005X03`<0

00803`80041oo`003Woo00D007ooOomoo`0000Qoo`03001oogoo00=oo`03001oogoo00Ioo`03001o

ogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0400moogooOol3000BOol00`0?Oomoo`0FOol0

0`0?Oomoo`0FOol00`0?Oomoo`0;Ool50006Ool00`00Oomoo`0nOol000ioo`05001oogooOol00008

Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0F

Ool00`0?Oomoo`04Ool2000@Ool00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`06Ool5000;

Ool00`00Oomoo`0nOol000ioo`05001oogooOol00007Ool00`00Oomoo`04Ool00`00Oomoo`06Ool0

0`00Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`06Ool3000=Ool00`0?Oomo

o`0FOol00`0?Oomoo`0FOol00`0?Oomoo`06000@Ool00`00Oomoo`0nOol000ioo`05001oogooOol0

0005Ool20007Ool00`00Oomoo`06Ool00`00Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`0FOol0

0`0?Oomoo`09Ool2000;Ool00`0?Oomoo`0FOol00`0?Oomoo`0DOol5000EOol20010Ool000ioo`05

001oogooOol00005Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0FOol00`0?Oomoo`0F

Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool30008Ool00`0?Oomoo`0FOol00`0?Oomoo`0=Ool70002

Ool00`0?Oomoo`0FOol00`00Oomoo`0nOol000moo`<000Moo`<000Eoo`03001oogoo00Ioo`03001o

ogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo00ioo`8000Ioo`0300moogoo01Io

o`0300moogoo00Eoo`P000Uoo`0300moogoo01Ioo`03001oogoo03ioo`008Goo00<007ooOol01Woo

00<007ooOol05Woo00<03gooOol05Woo00<03gooOol05Woo00<03gooOol047oo3P004Goo20004Goo

00<03gooOol05Goo0P00@7oo000QOol00`00Oomoo`06Ool00`00Oomoo`0FOol00`0?Oomoo`0FOol0

0`0?Oomoo`0FOol00`0?Oomoo`0FOol00`0?Oomoo`05OolA00000`0?Oomoo`0FOol00`0?Oomoo`0F

Ool00`00Oomoo`0nOol0025oo`03001oogoo00Ioo`03001oogoo01Ioo`0300moogoo01Ioo`0300mo

ogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`0300moogoo01Ioo`03001o

ogoo03ioo`008Goo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo

009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo

009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo

009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo

009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo

009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo

009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo

00=oo`03001oogoo009oo`03001oogoo0080041oo`008Goo^@00@7oo003oOolKOol00?mooa]oo`00

ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo000AOol3

0005Ool20003Ool700000goo00000003Ool30004Ool300000goo00000002Ool300000goo00000003

003GOol0019oo`03001oogoo00=oo`06001oogoo001oo`000Woo00@007ooOol0009oo`03001oogoo

00=oo`03001oogoo00Aoo`03001oo`00009oo`06001oogoo001oo`000goo00<007ooOol0eWoo000B

Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo00001Woo00<007ooOol0

17oo00<007oo00001Goo00<007oo00000goo00<007ooOol0eWoo000BOol00`00Oomoo`03Ool40002

Ool30002Ool20007Ool01000Oomoo`000goo00<007oo00000`000Woo00<007oo00000goo00<007oo

Ool0eWoo000BOol40002Ool01P00Oomoo`00Ool0009oo`06001oogoo001oo`001Woo10000goo00<0

07oo00000Woo00H007ooOol007oo0002Ool2003HOol0019oo`05001oogooOol00002Ool20003Ool2

0003Ool01000Ool000001Goo00@007ooOol0009oo`80009oo`8000=oo`03001oogoo00800003Ool0

07oo0=Moo`004Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo00aoo`03001oogoo

00=oo`03001oogoo0=Ioo`004Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`05001oogooOol0

000:Ool00`00Oomoo`03Ool00`00Oomoo`3FOol0015oo`D000aoo`8000Moo`H0009oo`03001oogoo

00Aoo`8000Aoo`800=Qoo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mo

oa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00\

\>"],

  ImageRangeCache->{{{0, 281}, {173, 0}} -> {-3.52296, 0.30902, 0.199626, 

  0.00145136}}]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{



Cell["How to Get Help", "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[StyleBox[

"The following command lists all the functions defined in the Radia.exe \

file.",

  Evaluatable->False,

  AspectRatioFixed->True]], "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[CellGroupData[{



Cell["?rad*", "Input",

  AspectRatioFixed->True],



Cell["\<\

radFld          radFldUnits     radObjDpl       radRlxPre

radFldCmpCrt    radMatApl       radObjDrw       radTrfCmbL

radFldCmpPrc    radMatLin       radObjDrwAtr    radTrfCmbR

radFldEnr       radMatMvsH      radObjDrwQD3D   radTrfInv

radFldEnrFrc    radMatSatAniso  radObjFlmCur    radTrfMlt

radFldEnrTrq    radMatSatIso    radObjMltExtPgn radTrfOrnt

radFldFocPot    radObjAddToCnt  radObjMltExtRtg radTrfPlSym

radFldFrc       radObjArcCur    radObjPolyhdr   radTrfRot

radFldFrcShpRtg radObjBckg      radObjRaceTrk   radTrfTrsl

radFldInt       radObjCnt       radObjRecCur    radUtiDel

radFldLenRndSw  radObjCntStuf   radObjRecMag    radUtiDelAll

radFldLenTol    radObjCutMag    radObjThckPgn   radUtiDmp

radFldLst       radObjDegFre    radRlxAuto      radUtiIntrptTim

radFldPtcTrj    radObjDivMag    radRlxMan       radUtiVer\

\>", "Print",

  Evaluatable->False,

  AspectRatioFixed->True]

}, Open  ]],



Cell[TextData[StyleBox[

"The following command gives the template and the description of the function \

\"radObjArcCur\".",

  Evaluatable->False,

  AspectRatioFixed->True]], "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[CellGroupData[{



Cell["?radObjArcCur", "Input",

  AspectRatioFixed->True],



Cell[BoxData[

    \("radObjArcCur[{x,y,z},{rmin,rmax},{phimin,phimax},h,nseg,j,\"man|auto\":\

\"man\"] creates a current carrying finite-length arc of rectangular \

cross-section with rotation axis along Z, center point {x,y,z}, inner and \

outer radii {rmin,rmax}, initial and final angles {phimin,phimax}, height h, \

number of segments nseg, and azimuthal current density j. According to the \

value of the \"man|auto\" switch, the field from the arc is computed based on \

the number of segments nseg (\"man\"), or on the general absolute precision \

level specified by the function radFldCmpCrt (\"auto\")."\)], "Print"]

}, Open  ]],



Cell[TextData[StyleBox[

"The following command lists all the functions defined in the Radia.m file.",

  Evaluatable->False,

  AspectRatioFixed->True]], "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[CellGroupData[{



Cell["?Rad*", "Input",

  AspectRatioFixed->True],



Cell["\<\

Rad              RadMatAFK502     RadMatSteel42    RadSolve

Radia            RadMatFerrite    RadMatXc06       RadTrfAxisPerm

RadicalBox       RadMatNdFeB      RadObjExtRtg     RadTrfZerPara

RadLinkPattern   RadMatSm2Co17    RadObjFullMag    RadTrfZerPerp

Radlk            RadMatSmCo5      RadPlot3DOptions RadUtiMem

RadMatAFK1       RadMatSteel37    RadPlotOptions   RadUtiVer\

\>", "Print",

  Evaluatable->False,

  AspectRatioFixed->True]

}, Open  ]]

}, Open  ]]

},

FrontEndVersion->"Microsoft Windows 3.0",

ScreenRectangle->{{0, 1280}, {0, 968}},

PrintingStyleEnvironment->"Working",

WindowToolbars->"EditBar",

CellGrouping->Manual,

WindowSize->{572, 528},

WindowMargins->{{73, Automatic}, {Automatic, 42}},

PrintingCopies->1,

PrintingPageRange->{Automatic, Automatic},

PageHeaders->{{Cell[ 

        TextData[ {

          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 

        TextData[ {

          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 

        TextData[ {

          ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 

        TextData[ {

          CounterBox[ "Page"]}], "PageNumber"]}},

PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},

"PrintCellBrackets"->False,

"PrintRegistrationMarks"->False,

"PrintMultipleHorizontalPages"->False,

"FirstPageHeader"->False,

"FacingPages"->True},

PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},

ShowCellLabel->False,

ShowCellTags->False,

RenderingOptions->{"ObjectDithering"->True,

"RasterDithering"->False},

CharacterEncoding->"MacintoshAutomaticEncoding",

StyleDefinitions -> "Classroom.nb"

]





(***********************************************************************

Cached data follows.  If you edit this Notebook file directly, not using

Mathematica, you must remove the line containing CacheID at the top of 

the file.  The cache data will then be recreated when you save this file 

from within Mathematica.

***********************************************************************)



(*CellTagsOutline

CellTagsIndex->{}

*)



(*CellTagsIndex

CellTagsIndex->{}

*)



(*NotebookFileOutline

Notebook[{

Cell[1709, 49, 154, 6, 55, "Title"],

Cell[1866, 57, 75, 2, 29, "Text"],



Cell[CellGroupData[{

Cell[1966, 63, 79, 2, 56, "Section"],

Cell[2048, 67, 2483, 47, 445, "Text"]

}, Open  ]],



Cell[CellGroupData[{

Cell[4568, 119, 92, 2, 56, "Section"],

Cell[4663, 123, 161, 5, 29, "Text"],

Cell[4827, 130, 52, 1, 50, "Input"]

}, Open  ]],



Cell[CellGroupData[{

Cell[4916, 136, 86, 2, 56, "Section"],

Cell[5005, 140, 455, 9, 67, "Text"],

Cell[5463, 151, 1367, 33, 608, "Input"]

}, Open  ]],



Cell[CellGroupData[{

Cell[6867, 189, 96, 2, 56, "Section"],

Cell[6966, 193, 237, 6, 29, "Text"],

Cell[7206, 201, 530, 14, 320, "Input"]

}, Open  ]],



Cell[CellGroupData[{

Cell[7773, 220, 105, 2, 56, "Section"],

Cell[7881, 224, 926, 26, 105, "Text"],

Cell[8810, 252, 62, 1, 50, "Input"]

}, Open  ]],



Cell[CellGroupData[{

Cell[8909, 258, 84, 2, 56, "Section"],

Cell[8996, 262, 190, 5, 48, "Text"],

Cell[9189, 269, 135, 6, 50, "Input"],



Cell[CellGroupData[{

Cell[9349, 279, 227, 6, 122, "Input"],

Cell[9579, 287, 256556, 10204, 326, 155077, 8945, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{

Cell[266184, 10497, 72, 2, 56, "Section"],

Cell[266259, 10501, 179, 5, 29, "Text"],



Cell[CellGroupData[{

Cell[266463, 10510, 704, 15, 302, "Input"],

Cell[267170, 10527, 201, 4, 25, "Print"],

Cell[267374, 10533, 171, 3, 25, "Print"],

Cell[267548, 10538, 463, 11, 44, "Print"],

Cell[268014, 10551, 448, 11, 25, "Print"],

Cell[268465, 10564, 410, 10, 25, "Print"],

Cell[268878, 10576, 35, 1, 25, "Print"],

Cell[268916, 10579, 359, 7, 25, "Print"]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{

Cell[269324, 10592, 100, 2, 56, "Section"],



Cell[CellGroupData[{

Cell[269449, 10598, 333, 10, 104, "Input"],

Cell[269785, 10610, 60464, 1543, 225, 19734, 1034, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{

Cell[330298, 12159, 107, 2, 56, "Section"],

Cell[330408, 12163, 261, 6, 48, "Text"],



Cell[CellGroupData[{

Cell[330694, 12173, 646, 20, 266, "Input"],

Cell[331343, 12195, 32864, 1089, 182, 15835, 873, "GraphicsData", 

"PostScript", "Graphics"],

Cell[364210, 13286, 32387, 1081, 182, 16852, 883, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{

Cell[396646, 14373, 88, 2, 56, "Section"],

Cell[396737, 14377, 417, 10, 67, "Text"],



Cell[CellGroupData[{

Cell[397179, 14391, 755, 21, 338, "Input"],

Cell[397937, 14414, 39922, 1171, 182, 14215, 848, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{

Cell[437908, 15591, 82, 2, 56, "Section"],

Cell[437993, 15595, 211, 6, 29, "Text"],



Cell[CellGroupData[{

Cell[438229, 15605, 48, 1, 50, "Input"],

Cell[438280, 15608, 899, 17, 246, "Print"]

}, Open  ]],

Cell[439194, 15628, 229, 6, 29, "Text"],



Cell[CellGroupData[{

Cell[439448, 15638, 56, 1, 50, "Input"],

Cell[439507, 15641, 625, 8, 196, "Print"]

}, Open  ]],

Cell[440147, 15652, 207, 5, 29, "Text"],



Cell[CellGroupData[{

Cell[440379, 15661, 48, 1, 50, "Input"],

Cell[440430, 15664, 450, 9, 110, "Print"]

}, Open  ]]

}, Open  ]]

}

]

*)









(***********************************************************************

End of Mathematica Notebook file.

***********************************************************************)



